
/*  Copyright (C) 2022 CZ.NIC, z.s.p.o. <knot-dns@labs.nic.cz>

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */

#include <arpa/inet.h>
#include <errno.h>
#include <fcntl.h>
#include <stdbool.h>
#include <stdint.h>
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <libgen.h>
#include <math.h>
#include <netinet/in.h>
#include <sys/socket.h>
#include <sys/mman.h>
#include <sys/stat.h>
#include <sys/types.h>
#include <unistd.h>

#include "libzscanner/scanner.h"
#include "libzscanner/functions.h"
#include "libknot/descriptor.h"

/*! \brief Maximal length of rdata item. */
#define MAX_ITEM_LENGTH		255
#define MAX_ITEM_LENGTH2	65535

/*! \brief Latitude value for equator (2^31). */
#define LOC_LAT_ZERO	(uint32_t)2147483648
/*! \brief Longitude value for meridian (2^31). */
#define LOC_LONG_ZERO	(uint32_t)2147483648
/*! \brief Zero level altitude value. */
#define LOC_ALT_ZERO	(uint32_t)10000000

/*! \brief Shorthand for setting warning data. */
#define WARN(err_code) { s->error.code = err_code; }
/*! \brief Shorthand for setting error data. */
#define ERR(err_code) { WARN(err_code); s->error.fatal = true; }
/*! \brief Shorthand for error reset. */
#define NOERR { WARN(ZS_OK); s->error.fatal = false; }

/*!
 * \brief Writes record type number to r_data.
 *
 * \param type		Type number.
 * \param rdata_tail	Position where to write type number to.
 */
static inline void type_num(const uint16_t type, uint8_t **rdata_tail)
{
	*((uint16_t *)*rdata_tail) = htons(type);
	*rdata_tail += 2;
}

/*!
 * \brief Sets bit to bitmap window.
 *
 * \param type		Type number.
 * \param s		Scanner context.
 */
static inline void window_add_bit(const uint16_t type, zs_scanner_t *s) {
	uint8_t win      = type / 256;
	uint8_t bit_pos  = type % 256;
	uint8_t byte_pos = bit_pos / 8;

	((s->windows[win]).bitmap)[byte_pos] |= 128 >> (bit_pos % 8);

	if ((s->windows[win]).length < byte_pos + 1) {
		(s->windows[win]).length = byte_pos + 1;
	}

	if (s->last_window < win) {
		s->last_window = win;
	}
}

// Include scanner file (in Ragel).






__attribute__((visibility("default")))
int zs_init(
	zs_scanner_t *s,
	const char *origin,
	const uint16_t rclass,
	const uint32_t ttl)
{
	if (s == NULL) {
		return -1;
	}

	memset(s, 0, sizeof(*s));

	// Nonzero initial scanner state.
	s->cs = 1444;

	// Reset the file descriptor.
	s->file.descriptor = -1;

	// Use the root zone as origin if not specified.
	if (origin == NULL || strlen(origin) == 0) {
		origin = ".";
	}
	size_t origin_len = strlen(origin);

	// Prepare a zone settings header.
	const char *format;
	if (origin[origin_len - 1] != '.') {
		format = "$ORIGIN %s.\n";
	} else {
		format = "$ORIGIN %s\n";
	}

	char settings[1024];
	int ret = snprintf(settings, sizeof(settings), format, origin);
	if (ret <= 0 || ret >= sizeof(settings)) {
		ERR(ZS_ENOMEM);
		return -1;
	}

	// Parse the settings to set up the scanner origin.
	if (zs_set_input_string(s, settings, ret) != 0 ||
	    zs_parse_all(s) != 0) {
		return -1;
	}

	// Set scanner defaults.
	s->path = strdup(".");
	if (s->path == NULL) {
		ERR(ZS_ENOMEM);
		return -1;
	}
	s->default_class = rclass;
	s->default_ttl = ttl;
	s->line_counter = 1;

	s->state = ZS_STATE_NONE;
	s->process.automatic = false;

	return 0;
}

static void input_deinit(
	zs_scanner_t *s,
	bool keep_filename)
{
	// Deinit the file input.
	if (s->file.descriptor != -1) {
		// Unmap the file content.
		if (s->input.start != NULL) {
			if (s->input.mmaped) {
				munmap((void *)s->input.start,
				       s->input.end - s->input.start);
			} else {
				free((void *)s->input.start);
			}
		}

		// Close the opened file.
		close(s->file.descriptor);
		s->file.descriptor = -1;
	}

	// Keep file name for possible trailing error report.
	if (!keep_filename) {
		free(s->file.name);
		s->file.name = NULL;
	}

	// Unset the input limits.
	s->input.start   = NULL;
	s->input.current = NULL;
	s->input.end     = NULL;
	s->input.eof     = false;
}

__attribute__((visibility("default")))
void zs_deinit(
	zs_scanner_t *s)
{
	if (s == NULL) {
		return;
	}

	input_deinit(s, false);
	free(s->path);
}

static int set_input_string(
	zs_scanner_t *s,
	const char *input,
	size_t size,
	bool final_block)
{
	if (s == NULL) {
		return -1;
	}

	if (input == NULL) {
		ERR(ZS_EINVAL);
		return -1;
	}

	// Deinit possibly opened file.
	input_deinit(s, final_block);

	// Set the scanner input limits.
	s->input.start   = input;
	s->input.current = input;
	s->input.end     = input + size;
	s->input.eof     = final_block;

	return 0;
}

static char *read_file_to_buf(
	int fd,
	size_t *bufsize)
{
	size_t bufs = 0, newbufs = 8192;
	char *buf = malloc(bufs + newbufs);
	int ret = 0;

	while (buf != NULL && (ret = read(fd, buf + bufs, newbufs)) > 0) {
		bufs += ret;
		if (ret < newbufs) {
			newbufs -= ret;
			continue;
		}
		newbufs = bufs;
		char *newbuf = realloc(buf, bufs + newbufs);
		if (newbuf == NULL) {
			free(buf);
		}
		buf = newbuf;
	}
	if (ret < 0) {
		free(buf);
		return NULL;
	}

	*bufsize = bufs + ret;
	return buf;
}

__attribute__((visibility("default")))
int zs_set_input_string(
	zs_scanner_t *s,
	const char *input,
	size_t size)
{
	s->state = ZS_STATE_NONE;

	return set_input_string(s, input, size, false);
}

__attribute__((visibility("default")))
int zs_set_input_file(
	zs_scanner_t *s,
	const char *file_name)
{
	if (s == NULL) {
		return -1;
	}

	if (file_name == NULL) {
		ERR(ZS_EINVAL);
		return -1;
	}

	// Deinit possibly opened file.
	input_deinit(s, false);

	// Try to open the file.
	s->file.descriptor = open(file_name, O_RDONLY);
	if (s->file.descriptor == -1) {
		ERR(errno == EACCES ? ZS_FILE_ACCESS : ZS_FILE_OPEN);
		return -1;
	}

	char *start = NULL;
	size_t size = 0;

	// Check the input.
	struct stat file_stat;
	if (fstat(s->file.descriptor, &file_stat) == -1) {
		ERR(ZS_FILE_INVALID);
		input_deinit(s, false);
		return -1;
	} else if (S_ISCHR(file_stat.st_mode) ||
	           S_ISBLK(file_stat.st_mode) ||
	           S_ISFIFO(file_stat.st_mode)) {
		// Workaround if cannot mmap, read to memory.
		start = read_file_to_buf(s->file.descriptor, &size);
		if (start == NULL) {
			ERR(ZS_FILE_INVALID);
			input_deinit(s, false);
			return -1;
		}
	} else if (!S_ISREG(file_stat.st_mode)) { // Require regular file.
		ERR(ZS_FILE_INVALID);
		input_deinit(s, false);
		return -1;
	} else if (file_stat.st_size > 0) { // Mmap non-empty file.
		start = mmap(0, file_stat.st_size, PROT_READ, MAP_SHARED,
		             s->file.descriptor, 0);
		if (start == MAP_FAILED) {
			ERR(ZS_FILE_INVALID);
			input_deinit(s, false);
			return -1;
		}

		size = file_stat.st_size;
		s->input.mmaped = true;

		// Try to set the mapped memory advise to sequential.
#if defined(MADV_SEQUENTIAL) && !defined(__sun)
		(void)madvise(start, size, MADV_SEQUENTIAL);
#else
#ifdef POSIX_MADV_SEQUENTIAL
		(void)posix_madvise(start, size, POSIX_MADV_SEQUENTIAL);
#endif /* POSIX_MADV_SEQUENTIAL */
#endif /* MADV_SEQUENTIAL && !__sun */
	}

	// Set the scanner input limits.
	s->input.start   = start;
	s->input.current = start;
	s->input.end     = (start != NULL) ? start + size : start;

	// Get absolute path of the zone file if possible.
	char *full_name = realpath(file_name, NULL);
	if (full_name != NULL) {
		free(s->path);
		s->path = strdup(dirname(full_name));
		free(full_name);
		if (s->path == NULL) {
			ERR(ZS_ENOMEM);
			input_deinit(s, false);
			return -1;
		}
	}

	s->file.name = strdup(file_name);
	if (s->file.name == NULL) {
		ERR(ZS_ENOMEM);
		input_deinit(s, false);
		return -1;
	}

	s->state = ZS_STATE_NONE;

	return 0;
}

__attribute__((visibility("default")))
int zs_set_processing(
	zs_scanner_t *s,
	void (*process_record)(zs_scanner_t *),
	void (*process_error)(zs_scanner_t *),
	void *data)
{
	if (s == NULL) {
		return -1;
	}

	s->process.record = process_record;
	s->process.error = process_error;
	s->process.data = data;

	return 0;
}

__attribute__((visibility("default")))
int zs_set_processing_comment(
	zs_scanner_t *s,
	void (*process_comment)(zs_scanner_t *))
{
	if (s == NULL) {
		return -1;
	}

	s->process.comment = process_comment;

	return 0;
}

typedef enum {
	WRAP_NONE,     // Initial state.
	WRAP_DETECTED, // Input block end is a first '\' in rdata.
	WRAP_PROCESS   // Parsing of auxiliary block = "\".
} wrap_t;

static void parse(
	zs_scanner_t *s,
	wrap_t *wrap)
{
	// Restore scanner input limits (Ragel internals).
	const char *p = s->input.current;
	const char *pe = s->input.end;
	const char *eof = s->input.eof ? pe : NULL;

	// Restore state variables (Ragel internals).
	int cs  = s->cs;
	int top = s->top;
	int stack[ZS_RAGEL_STACK_SIZE];
	memcpy(stack, s->stack, sizeof(stack));

	// Next 2 variables are for better performance.
	// Restoring r_data pointer to next free space.
	uint8_t *rdata_tail = s->r_data + s->r_data_tail;
	// Initialization of the last r_data byte.
	uint8_t *rdata_stop = s->r_data + ZS_MAX_RDATA_LENGTH - 1;

	// Write scanner body (in C).

	{
	short _widec;
	if ( p == pe )
		goto _test_eof;
	goto _resume;

_again:
	switch ( cs ) {
		case 1444: goto st1444;
		case 0: goto st0;
		case 1: goto st1;
		case 2: goto st2;
		case 3: goto st3;
		case 4: goto st4;
		case 5: goto st5;
		case 6: goto st6;
		case 7: goto st7;
		case 8: goto st8;
		case 9: goto st9;
		case 10: goto st10;
		case 11: goto st11;
		case 12: goto st12;
		case 13: goto st13;
		case 1445: goto st1445;
		case 14: goto st14;
		case 15: goto st15;
		case 16: goto st16;
		case 17: goto st17;
		case 18: goto st18;
		case 19: goto st19;
		case 20: goto st20;
		case 21: goto st21;
		case 22: goto st22;
		case 23: goto st23;
		case 24: goto st24;
		case 25: goto st25;
		case 26: goto st26;
		case 27: goto st27;
		case 28: goto st28;
		case 29: goto st29;
		case 30: goto st30;
		case 31: goto st31;
		case 32: goto st32;
		case 33: goto st33;
		case 34: goto st34;
		case 35: goto st35;
		case 36: goto st36;
		case 37: goto st37;
		case 38: goto st38;
		case 39: goto st39;
		case 40: goto st40;
		case 41: goto st41;
		case 42: goto st42;
		case 43: goto st43;
		case 44: goto st44;
		case 45: goto st45;
		case 46: goto st46;
		case 47: goto st47;
		case 48: goto st48;
		case 49: goto st49;
		case 50: goto st50;
		case 51: goto st51;
		case 52: goto st52;
		case 53: goto st53;
		case 54: goto st54;
		case 55: goto st55;
		case 56: goto st56;
		case 57: goto st57;
		case 58: goto st58;
		case 59: goto st59;
		case 60: goto st60;
		case 61: goto st61;
		case 62: goto st62;
		case 63: goto st63;
		case 64: goto st64;
		case 65: goto st65;
		case 66: goto st66;
		case 67: goto st67;
		case 68: goto st68;
		case 69: goto st69;
		case 70: goto st70;
		case 71: goto st71;
		case 72: goto st72;
		case 73: goto st73;
		case 74: goto st74;
		case 75: goto st75;
		case 76: goto st76;
		case 77: goto st77;
		case 78: goto st78;
		case 79: goto st79;
		case 80: goto st80;
		case 81: goto st81;
		case 82: goto st82;
		case 83: goto st83;
		case 84: goto st84;
		case 85: goto st85;
		case 86: goto st86;
		case 87: goto st87;
		case 88: goto st88;
		case 89: goto st89;
		case 90: goto st90;
		case 91: goto st91;
		case 92: goto st92;
		case 93: goto st93;
		case 94: goto st94;
		case 95: goto st95;
		case 96: goto st96;
		case 97: goto st97;
		case 98: goto st98;
		case 99: goto st99;
		case 100: goto st100;
		case 101: goto st101;
		case 102: goto st102;
		case 103: goto st103;
		case 104: goto st104;
		case 105: goto st105;
		case 106: goto st106;
		case 107: goto st107;
		case 108: goto st108;
		case 109: goto st109;
		case 110: goto st110;
		case 111: goto st111;
		case 112: goto st112;
		case 113: goto st113;
		case 114: goto st114;
		case 115: goto st115;
		case 116: goto st116;
		case 117: goto st117;
		case 118: goto st118;
		case 119: goto st119;
		case 120: goto st120;
		case 121: goto st121;
		case 122: goto st122;
		case 123: goto st123;
		case 124: goto st124;
		case 125: goto st125;
		case 126: goto st126;
		case 127: goto st127;
		case 128: goto st128;
		case 129: goto st129;
		case 130: goto st130;
		case 131: goto st131;
		case 132: goto st132;
		case 133: goto st133;
		case 134: goto st134;
		case 135: goto st135;
		case 136: goto st136;
		case 137: goto st137;
		case 138: goto st138;
		case 139: goto st139;
		case 140: goto st140;
		case 141: goto st141;
		case 142: goto st142;
		case 143: goto st143;
		case 144: goto st144;
		case 145: goto st145;
		case 146: goto st146;
		case 147: goto st147;
		case 148: goto st148;
		case 149: goto st149;
		case 150: goto st150;
		case 151: goto st151;
		case 152: goto st152;
		case 153: goto st153;
		case 154: goto st154;
		case 155: goto st155;
		case 156: goto st156;
		case 157: goto st157;
		case 158: goto st158;
		case 159: goto st159;
		case 160: goto st160;
		case 161: goto st161;
		case 162: goto st162;
		case 163: goto st163;
		case 164: goto st164;
		case 165: goto st165;
		case 166: goto st166;
		case 167: goto st167;
		case 168: goto st168;
		case 169: goto st169;
		case 170: goto st170;
		case 171: goto st171;
		case 172: goto st172;
		case 173: goto st173;
		case 174: goto st174;
		case 175: goto st175;
		case 176: goto st176;
		case 177: goto st177;
		case 178: goto st178;
		case 179: goto st179;
		case 1446: goto st1446;
		case 180: goto st180;
		case 181: goto st181;
		case 182: goto st182;
		case 183: goto st183;
		case 184: goto st184;
		case 185: goto st185;
		case 186: goto st186;
		case 187: goto st187;
		case 188: goto st188;
		case 189: goto st189;
		case 1447: goto st1447;
		case 190: goto st190;
		case 191: goto st191;
		case 192: goto st192;
		case 193: goto st193;
		case 194: goto st194;
		case 195: goto st195;
		case 196: goto st196;
		case 197: goto st197;
		case 1448: goto st1448;
		case 198: goto st198;
		case 199: goto st199;
		case 200: goto st200;
		case 1449: goto st1449;
		case 201: goto st201;
		case 202: goto st202;
		case 203: goto st203;
		case 204: goto st204;
		case 205: goto st205;
		case 206: goto st206;
		case 207: goto st207;
		case 208: goto st208;
		case 209: goto st209;
		case 210: goto st210;
		case 211: goto st211;
		case 1450: goto st1450;
		case 212: goto st212;
		case 213: goto st213;
		case 214: goto st214;
		case 215: goto st215;
		case 1451: goto st1451;
		case 216: goto st216;
		case 217: goto st217;
		case 218: goto st218;
		case 219: goto st219;
		case 220: goto st220;
		case 221: goto st221;
		case 222: goto st222;
		case 223: goto st223;
		case 224: goto st224;
		case 225: goto st225;
		case 226: goto st226;
		case 227: goto st227;
		case 228: goto st228;
		case 229: goto st229;
		case 230: goto st230;
		case 231: goto st231;
		case 232: goto st232;
		case 233: goto st233;
		case 234: goto st234;
		case 1452: goto st1452;
		case 235: goto st235;
		case 236: goto st236;
		case 237: goto st237;
		case 238: goto st238;
		case 239: goto st239;
		case 240: goto st240;
		case 241: goto st241;
		case 242: goto st242;
		case 243: goto st243;
		case 244: goto st244;
		case 245: goto st245;
		case 246: goto st246;
		case 247: goto st247;
		case 248: goto st248;
		case 249: goto st249;
		case 250: goto st250;
		case 1453: goto st1453;
		case 251: goto st251;
		case 252: goto st252;
		case 253: goto st253;
		case 254: goto st254;
		case 255: goto st255;
		case 256: goto st256;
		case 257: goto st257;
		case 258: goto st258;
		case 259: goto st259;
		case 260: goto st260;
		case 261: goto st261;
		case 262: goto st262;
		case 263: goto st263;
		case 264: goto st264;
		case 265: goto st265;
		case 266: goto st266;
		case 267: goto st267;
		case 268: goto st268;
		case 269: goto st269;
		case 270: goto st270;
		case 271: goto st271;
		case 272: goto st272;
		case 273: goto st273;
		case 274: goto st274;
		case 275: goto st275;
		case 276: goto st276;
		case 277: goto st277;
		case 278: goto st278;
		case 279: goto st279;
		case 280: goto st280;
		case 281: goto st281;
		case 282: goto st282;
		case 283: goto st283;
		case 284: goto st284;
		case 285: goto st285;
		case 286: goto st286;
		case 287: goto st287;
		case 288: goto st288;
		case 289: goto st289;
		case 290: goto st290;
		case 291: goto st291;
		case 292: goto st292;
		case 293: goto st293;
		case 294: goto st294;
		case 295: goto st295;
		case 296: goto st296;
		case 297: goto st297;
		case 298: goto st298;
		case 299: goto st299;
		case 300: goto st300;
		case 301: goto st301;
		case 302: goto st302;
		case 303: goto st303;
		case 304: goto st304;
		case 305: goto st305;
		case 306: goto st306;
		case 307: goto st307;
		case 308: goto st308;
		case 309: goto st309;
		case 310: goto st310;
		case 311: goto st311;
		case 312: goto st312;
		case 313: goto st313;
		case 314: goto st314;
		case 315: goto st315;
		case 1454: goto st1454;
		case 316: goto st316;
		case 317: goto st317;
		case 1455: goto st1455;
		case 318: goto st318;
		case 319: goto st319;
		case 1456: goto st1456;
		case 320: goto st320;
		case 321: goto st321;
		case 322: goto st322;
		case 323: goto st323;
		case 324: goto st324;
		case 325: goto st325;
		case 326: goto st326;
		case 327: goto st327;
		case 328: goto st328;
		case 1457: goto st1457;
		case 1458: goto st1458;
		case 329: goto st329;
		case 330: goto st330;
		case 331: goto st331;
		case 332: goto st332;
		case 333: goto st333;
		case 334: goto st334;
		case 335: goto st335;
		case 336: goto st336;
		case 337: goto st337;
		case 338: goto st338;
		case 339: goto st339;
		case 340: goto st340;
		case 341: goto st341;
		case 342: goto st342;
		case 343: goto st343;
		case 1459: goto st1459;
		case 344: goto st344;
		case 345: goto st345;
		case 346: goto st346;
		case 347: goto st347;
		case 348: goto st348;
		case 349: goto st349;
		case 350: goto st350;
		case 351: goto st351;
		case 352: goto st352;
		case 353: goto st353;
		case 1460: goto st1460;
		case 354: goto st354;
		case 355: goto st355;
		case 356: goto st356;
		case 357: goto st357;
		case 358: goto st358;
		case 359: goto st359;
		case 360: goto st360;
		case 361: goto st361;
		case 362: goto st362;
		case 363: goto st363;
		case 364: goto st364;
		case 365: goto st365;
		case 366: goto st366;
		case 367: goto st367;
		case 1461: goto st1461;
		case 368: goto st368;
		case 369: goto st369;
		case 370: goto st370;
		case 371: goto st371;
		case 372: goto st372;
		case 373: goto st373;
		case 374: goto st374;
		case 1462: goto st1462;
		case 375: goto st375;
		case 376: goto st376;
		case 377: goto st377;
		case 378: goto st378;
		case 379: goto st379;
		case 380: goto st380;
		case 381: goto st381;
		case 382: goto st382;
		case 383: goto st383;
		case 1463: goto st1463;
		case 1464: goto st1464;
		case 1465: goto st1465;
		case 384: goto st384;
		case 385: goto st385;
		case 386: goto st386;
		case 387: goto st387;
		case 388: goto st388;
		case 389: goto st389;
		case 390: goto st390;
		case 391: goto st391;
		case 1466: goto st1466;
		case 1467: goto st1467;
		case 392: goto st392;
		case 393: goto st393;
		case 394: goto st394;
		case 1468: goto st1468;
		case 395: goto st395;
		case 396: goto st396;
		case 397: goto st397;
		case 398: goto st398;
		case 399: goto st399;
		case 400: goto st400;
		case 401: goto st401;
		case 402: goto st402;
		case 403: goto st403;
		case 404: goto st404;
		case 405: goto st405;
		case 406: goto st406;
		case 407: goto st407;
		case 408: goto st408;
		case 409: goto st409;
		case 410: goto st410;
		case 411: goto st411;
		case 412: goto st412;
		case 413: goto st413;
		case 414: goto st414;
		case 415: goto st415;
		case 416: goto st416;
		case 417: goto st417;
		case 418: goto st418;
		case 419: goto st419;
		case 420: goto st420;
		case 421: goto st421;
		case 422: goto st422;
		case 423: goto st423;
		case 424: goto st424;
		case 425: goto st425;
		case 426: goto st426;
		case 427: goto st427;
		case 428: goto st428;
		case 429: goto st429;
		case 430: goto st430;
		case 431: goto st431;
		case 432: goto st432;
		case 433: goto st433;
		case 434: goto st434;
		case 435: goto st435;
		case 436: goto st436;
		case 437: goto st437;
		case 438: goto st438;
		case 439: goto st439;
		case 440: goto st440;
		case 441: goto st441;
		case 442: goto st442;
		case 443: goto st443;
		case 444: goto st444;
		case 445: goto st445;
		case 446: goto st446;
		case 447: goto st447;
		case 448: goto st448;
		case 449: goto st449;
		case 450: goto st450;
		case 451: goto st451;
		case 452: goto st452;
		case 453: goto st453;
		case 454: goto st454;
		case 455: goto st455;
		case 456: goto st456;
		case 457: goto st457;
		case 458: goto st458;
		case 459: goto st459;
		case 460: goto st460;
		case 461: goto st461;
		case 462: goto st462;
		case 463: goto st463;
		case 464: goto st464;
		case 465: goto st465;
		case 466: goto st466;
		case 467: goto st467;
		case 468: goto st468;
		case 469: goto st469;
		case 470: goto st470;
		case 471: goto st471;
		case 472: goto st472;
		case 473: goto st473;
		case 474: goto st474;
		case 475: goto st475;
		case 476: goto st476;
		case 477: goto st477;
		case 478: goto st478;
		case 479: goto st479;
		case 480: goto st480;
		case 481: goto st481;
		case 482: goto st482;
		case 483: goto st483;
		case 484: goto st484;
		case 485: goto st485;
		case 486: goto st486;
		case 487: goto st487;
		case 488: goto st488;
		case 489: goto st489;
		case 490: goto st490;
		case 491: goto st491;
		case 492: goto st492;
		case 493: goto st493;
		case 494: goto st494;
		case 495: goto st495;
		case 496: goto st496;
		case 497: goto st497;
		case 498: goto st498;
		case 499: goto st499;
		case 500: goto st500;
		case 501: goto st501;
		case 502: goto st502;
		case 503: goto st503;
		case 504: goto st504;
		case 505: goto st505;
		case 506: goto st506;
		case 507: goto st507;
		case 508: goto st508;
		case 509: goto st509;
		case 510: goto st510;
		case 511: goto st511;
		case 512: goto st512;
		case 513: goto st513;
		case 514: goto st514;
		case 515: goto st515;
		case 516: goto st516;
		case 517: goto st517;
		case 518: goto st518;
		case 519: goto st519;
		case 520: goto st520;
		case 521: goto st521;
		case 522: goto st522;
		case 523: goto st523;
		case 524: goto st524;
		case 525: goto st525;
		case 526: goto st526;
		case 527: goto st527;
		case 528: goto st528;
		case 529: goto st529;
		case 530: goto st530;
		case 531: goto st531;
		case 532: goto st532;
		case 533: goto st533;
		case 534: goto st534;
		case 535: goto st535;
		case 536: goto st536;
		case 537: goto st537;
		case 538: goto st538;
		case 539: goto st539;
		case 540: goto st540;
		case 541: goto st541;
		case 542: goto st542;
		case 543: goto st543;
		case 544: goto st544;
		case 545: goto st545;
		case 546: goto st546;
		case 547: goto st547;
		case 548: goto st548;
		case 549: goto st549;
		case 550: goto st550;
		case 551: goto st551;
		case 552: goto st552;
		case 553: goto st553;
		case 554: goto st554;
		case 555: goto st555;
		case 556: goto st556;
		case 557: goto st557;
		case 558: goto st558;
		case 559: goto st559;
		case 560: goto st560;
		case 561: goto st561;
		case 1469: goto st1469;
		case 1470: goto st1470;
		case 1471: goto st1471;
		case 562: goto st562;
		case 563: goto st563;
		case 564: goto st564;
		case 565: goto st565;
		case 566: goto st566;
		case 1472: goto st1472;
		case 567: goto st567;
		case 568: goto st568;
		case 569: goto st569;
		case 570: goto st570;
		case 1473: goto st1473;
		case 1474: goto st1474;
		case 1475: goto st1475;
		case 571: goto st571;
		case 572: goto st572;
		case 1476: goto st1476;
		case 573: goto st573;
		case 574: goto st574;
		case 575: goto st575;
		case 576: goto st576;
		case 577: goto st577;
		case 578: goto st578;
		case 1477: goto st1477;
		case 579: goto st579;
		case 580: goto st580;
		case 581: goto st581;
		case 582: goto st582;
		case 583: goto st583;
		case 584: goto st584;
		case 585: goto st585;
		case 586: goto st586;
		case 587: goto st587;
		case 588: goto st588;
		case 589: goto st589;
		case 590: goto st590;
		case 591: goto st591;
		case 592: goto st592;
		case 593: goto st593;
		case 594: goto st594;
		case 595: goto st595;
		case 596: goto st596;
		case 597: goto st597;
		case 598: goto st598;
		case 599: goto st599;
		case 600: goto st600;
		case 601: goto st601;
		case 602: goto st602;
		case 603: goto st603;
		case 604: goto st604;
		case 605: goto st605;
		case 606: goto st606;
		case 607: goto st607;
		case 608: goto st608;
		case 609: goto st609;
		case 610: goto st610;
		case 611: goto st611;
		case 612: goto st612;
		case 613: goto st613;
		case 614: goto st614;
		case 615: goto st615;
		case 616: goto st616;
		case 617: goto st617;
		case 618: goto st618;
		case 619: goto st619;
		case 620: goto st620;
		case 621: goto st621;
		case 622: goto st622;
		case 623: goto st623;
		case 624: goto st624;
		case 625: goto st625;
		case 626: goto st626;
		case 627: goto st627;
		case 628: goto st628;
		case 629: goto st629;
		case 630: goto st630;
		case 631: goto st631;
		case 632: goto st632;
		case 633: goto st633;
		case 634: goto st634;
		case 635: goto st635;
		case 636: goto st636;
		case 637: goto st637;
		case 638: goto st638;
		case 1478: goto st1478;
		case 1479: goto st1479;
		case 639: goto st639;
		case 640: goto st640;
		case 641: goto st641;
		case 642: goto st642;
		case 643: goto st643;
		case 644: goto st644;
		case 645: goto st645;
		case 646: goto st646;
		case 647: goto st647;
		case 1480: goto st1480;
		case 648: goto st648;
		case 649: goto st649;
		case 650: goto st650;
		case 651: goto st651;
		case 652: goto st652;
		case 653: goto st653;
		case 654: goto st654;
		case 655: goto st655;
		case 656: goto st656;
		case 657: goto st657;
		case 658: goto st658;
		case 659: goto st659;
		case 660: goto st660;
		case 661: goto st661;
		case 662: goto st662;
		case 663: goto st663;
		case 664: goto st664;
		case 665: goto st665;
		case 666: goto st666;
		case 667: goto st667;
		case 668: goto st668;
		case 669: goto st669;
		case 670: goto st670;
		case 671: goto st671;
		case 672: goto st672;
		case 673: goto st673;
		case 674: goto st674;
		case 675: goto st675;
		case 676: goto st676;
		case 677: goto st677;
		case 678: goto st678;
		case 679: goto st679;
		case 680: goto st680;
		case 681: goto st681;
		case 682: goto st682;
		case 683: goto st683;
		case 684: goto st684;
		case 685: goto st685;
		case 686: goto st686;
		case 687: goto st687;
		case 688: goto st688;
		case 689: goto st689;
		case 690: goto st690;
		case 691: goto st691;
		case 692: goto st692;
		case 693: goto st693;
		case 694: goto st694;
		case 695: goto st695;
		case 696: goto st696;
		case 697: goto st697;
		case 698: goto st698;
		case 699: goto st699;
		case 700: goto st700;
		case 701: goto st701;
		case 702: goto st702;
		case 703: goto st703;
		case 704: goto st704;
		case 705: goto st705;
		case 706: goto st706;
		case 707: goto st707;
		case 708: goto st708;
		case 709: goto st709;
		case 710: goto st710;
		case 711: goto st711;
		case 712: goto st712;
		case 713: goto st713;
		case 714: goto st714;
		case 715: goto st715;
		case 716: goto st716;
		case 717: goto st717;
		case 718: goto st718;
		case 719: goto st719;
		case 720: goto st720;
		case 721: goto st721;
		case 722: goto st722;
		case 723: goto st723;
		case 724: goto st724;
		case 725: goto st725;
		case 726: goto st726;
		case 727: goto st727;
		case 728: goto st728;
		case 729: goto st729;
		case 730: goto st730;
		case 731: goto st731;
		case 732: goto st732;
		case 733: goto st733;
		case 734: goto st734;
		case 735: goto st735;
		case 736: goto st736;
		case 737: goto st737;
		case 738: goto st738;
		case 739: goto st739;
		case 740: goto st740;
		case 741: goto st741;
		case 742: goto st742;
		case 1481: goto st1481;
		case 743: goto st743;
		case 744: goto st744;
		case 745: goto st745;
		case 746: goto st746;
		case 747: goto st747;
		case 748: goto st748;
		case 749: goto st749;
		case 750: goto st750;
		case 751: goto st751;
		case 752: goto st752;
		case 753: goto st753;
		case 754: goto st754;
		case 755: goto st755;
		case 756: goto st756;
		case 757: goto st757;
		case 758: goto st758;
		case 759: goto st759;
		case 760: goto st760;
		case 761: goto st761;
		case 762: goto st762;
		case 763: goto st763;
		case 764: goto st764;
		case 765: goto st765;
		case 766: goto st766;
		case 767: goto st767;
		case 768: goto st768;
		case 769: goto st769;
		case 770: goto st770;
		case 771: goto st771;
		case 772: goto st772;
		case 773: goto st773;
		case 774: goto st774;
		case 775: goto st775;
		case 776: goto st776;
		case 777: goto st777;
		case 778: goto st778;
		case 779: goto st779;
		case 780: goto st780;
		case 781: goto st781;
		case 782: goto st782;
		case 783: goto st783;
		case 784: goto st784;
		case 785: goto st785;
		case 786: goto st786;
		case 787: goto st787;
		case 788: goto st788;
		case 789: goto st789;
		case 790: goto st790;
		case 791: goto st791;
		case 792: goto st792;
		case 793: goto st793;
		case 794: goto st794;
		case 795: goto st795;
		case 796: goto st796;
		case 797: goto st797;
		case 798: goto st798;
		case 799: goto st799;
		case 800: goto st800;
		case 801: goto st801;
		case 802: goto st802;
		case 803: goto st803;
		case 804: goto st804;
		case 805: goto st805;
		case 806: goto st806;
		case 807: goto st807;
		case 808: goto st808;
		case 809: goto st809;
		case 810: goto st810;
		case 811: goto st811;
		case 812: goto st812;
		case 813: goto st813;
		case 814: goto st814;
		case 815: goto st815;
		case 816: goto st816;
		case 817: goto st817;
		case 818: goto st818;
		case 819: goto st819;
		case 820: goto st820;
		case 821: goto st821;
		case 822: goto st822;
		case 823: goto st823;
		case 824: goto st824;
		case 825: goto st825;
		case 826: goto st826;
		case 827: goto st827;
		case 828: goto st828;
		case 829: goto st829;
		case 830: goto st830;
		case 831: goto st831;
		case 832: goto st832;
		case 833: goto st833;
		case 834: goto st834;
		case 835: goto st835;
		case 836: goto st836;
		case 837: goto st837;
		case 838: goto st838;
		case 839: goto st839;
		case 840: goto st840;
		case 841: goto st841;
		case 842: goto st842;
		case 843: goto st843;
		case 844: goto st844;
		case 845: goto st845;
		case 846: goto st846;
		case 1482: goto st1482;
		case 847: goto st847;
		case 848: goto st848;
		case 849: goto st849;
		case 850: goto st850;
		case 851: goto st851;
		case 852: goto st852;
		case 853: goto st853;
		case 854: goto st854;
		case 855: goto st855;
		case 856: goto st856;
		case 857: goto st857;
		case 858: goto st858;
		case 859: goto st859;
		case 860: goto st860;
		case 861: goto st861;
		case 862: goto st862;
		case 863: goto st863;
		case 864: goto st864;
		case 865: goto st865;
		case 866: goto st866;
		case 867: goto st867;
		case 868: goto st868;
		case 869: goto st869;
		case 870: goto st870;
		case 871: goto st871;
		case 872: goto st872;
		case 873: goto st873;
		case 874: goto st874;
		case 875: goto st875;
		case 876: goto st876;
		case 877: goto st877;
		case 878: goto st878;
		case 879: goto st879;
		case 880: goto st880;
		case 881: goto st881;
		case 882: goto st882;
		case 883: goto st883;
		case 884: goto st884;
		case 885: goto st885;
		case 886: goto st886;
		case 887: goto st887;
		case 1483: goto st1483;
		case 888: goto st888;
		case 889: goto st889;
		case 1484: goto st1484;
		case 890: goto st890;
		case 891: goto st891;
		case 892: goto st892;
		case 893: goto st893;
		case 894: goto st894;
		case 895: goto st895;
		case 896: goto st896;
		case 897: goto st897;
		case 898: goto st898;
		case 899: goto st899;
		case 900: goto st900;
		case 901: goto st901;
		case 902: goto st902;
		case 903: goto st903;
		case 1485: goto st1485;
		case 904: goto st904;
		case 905: goto st905;
		case 906: goto st906;
		case 907: goto st907;
		case 908: goto st908;
		case 909: goto st909;
		case 910: goto st910;
		case 911: goto st911;
		case 912: goto st912;
		case 913: goto st913;
		case 914: goto st914;
		case 915: goto st915;
		case 916: goto st916;
		case 917: goto st917;
		case 918: goto st918;
		case 919: goto st919;
		case 920: goto st920;
		case 921: goto st921;
		case 922: goto st922;
		case 923: goto st923;
		case 924: goto st924;
		case 925: goto st925;
		case 1486: goto st1486;
		case 926: goto st926;
		case 927: goto st927;
		case 928: goto st928;
		case 929: goto st929;
		case 930: goto st930;
		case 1487: goto st1487;
		case 931: goto st931;
		case 932: goto st932;
		case 933: goto st933;
		case 934: goto st934;
		case 935: goto st935;
		case 1488: goto st1488;
		case 936: goto st936;
		case 937: goto st937;
		case 938: goto st938;
		case 939: goto st939;
		case 940: goto st940;
		case 1489: goto st1489;
		case 1490: goto st1490;
		case 1491: goto st1491;
		case 941: goto st941;
		case 942: goto st942;
		case 1492: goto st1492;
		case 943: goto st943;
		case 944: goto st944;
		case 945: goto st945;
		case 946: goto st946;
		case 947: goto st947;
		case 948: goto st948;
		case 949: goto st949;
		case 950: goto st950;
		case 951: goto st951;
		case 952: goto st952;
		case 953: goto st953;
		case 954: goto st954;
		case 955: goto st955;
		case 956: goto st956;
		case 957: goto st957;
		case 958: goto st958;
		case 959: goto st959;
		case 960: goto st960;
		case 961: goto st961;
		case 962: goto st962;
		case 963: goto st963;
		case 964: goto st964;
		case 965: goto st965;
		case 966: goto st966;
		case 967: goto st967;
		case 968: goto st968;
		case 969: goto st969;
		case 1493: goto st1493;
		case 1494: goto st1494;
		case 1495: goto st1495;
		case 970: goto st970;
		case 971: goto st971;
		case 972: goto st972;
		case 1496: goto st1496;
		case 1497: goto st1497;
		case 973: goto st973;
		case 974: goto st974;
		case 975: goto st975;
		case 976: goto st976;
		case 1498: goto st1498;
		case 1499: goto st1499;
		case 977: goto st977;
		case 978: goto st978;
		case 979: goto st979;
		case 980: goto st980;
		case 1500: goto st1500;
		case 1501: goto st1501;
		case 981: goto st981;
		case 982: goto st982;
		case 983: goto st983;
		case 984: goto st984;
		case 985: goto st985;
		case 986: goto st986;
		case 987: goto st987;
		case 988: goto st988;
		case 989: goto st989;
		case 990: goto st990;
		case 991: goto st991;
		case 992: goto st992;
		case 993: goto st993;
		case 994: goto st994;
		case 995: goto st995;
		case 996: goto st996;
		case 997: goto st997;
		case 998: goto st998;
		case 999: goto st999;
		case 1000: goto st1000;
		case 1001: goto st1001;
		case 1002: goto st1002;
		case 1003: goto st1003;
		case 1004: goto st1004;
		case 1005: goto st1005;
		case 1502: goto st1502;
		case 1006: goto st1006;
		case 1007: goto st1007;
		case 1008: goto st1008;
		case 1009: goto st1009;
		case 1010: goto st1010;
		case 1011: goto st1011;
		case 1012: goto st1012;
		case 1013: goto st1013;
		case 1014: goto st1014;
		case 1015: goto st1015;
		case 1016: goto st1016;
		case 1017: goto st1017;
		case 1018: goto st1018;
		case 1019: goto st1019;
		case 1020: goto st1020;
		case 1503: goto st1503;
		case 1021: goto st1021;
		case 1022: goto st1022;
		case 1023: goto st1023;
		case 1024: goto st1024;
		case 1025: goto st1025;
		case 1026: goto st1026;
		case 1027: goto st1027;
		case 1028: goto st1028;
		case 1029: goto st1029;
		case 1030: goto st1030;
		case 1031: goto st1031;
		case 1032: goto st1032;
		case 1033: goto st1033;
		case 1504: goto st1504;
		case 1034: goto st1034;
		case 1035: goto st1035;
		case 1036: goto st1036;
		case 1037: goto st1037;
		case 1038: goto st1038;
		case 1039: goto st1039;
		case 1040: goto st1040;
		case 1041: goto st1041;
		case 1042: goto st1042;
		case 1043: goto st1043;
		case 1044: goto st1044;
		case 1505: goto st1505;
		case 1506: goto st1506;
		case 1045: goto st1045;
		case 1046: goto st1046;
		case 1047: goto st1047;
		case 1507: goto st1507;
		case 1048: goto st1048;
		case 1049: goto st1049;
		case 1050: goto st1050;
		case 1051: goto st1051;
		case 1052: goto st1052;
		case 1053: goto st1053;
		case 1054: goto st1054;
		case 1055: goto st1055;
		case 1056: goto st1056;
		case 1057: goto st1057;
		case 1508: goto st1508;
		case 1509: goto st1509;
		case 1510: goto st1510;
		case 1058: goto st1058;
		case 1059: goto st1059;
		case 1060: goto st1060;
		case 1061: goto st1061;
		case 1062: goto st1062;
		case 1063: goto st1063;
		case 1064: goto st1064;
		case 1065: goto st1065;
		case 1066: goto st1066;
		case 1067: goto st1067;
		case 1068: goto st1068;
		case 1511: goto st1511;
		case 1512: goto st1512;
		case 1513: goto st1513;
		case 1069: goto st1069;
		case 1070: goto st1070;
		case 1071: goto st1071;
		case 1072: goto st1072;
		case 1073: goto st1073;
		case 1074: goto st1074;
		case 1075: goto st1075;
		case 1076: goto st1076;
		case 1077: goto st1077;
		case 1078: goto st1078;
		case 1079: goto st1079;
		case 1080: goto st1080;
		case 1514: goto st1514;
		case 1081: goto st1081;
		case 1082: goto st1082;
		case 1083: goto st1083;
		case 1515: goto st1515;
		case 1516: goto st1516;
		case 1084: goto st1084;
		case 1517: goto st1517;
		case 1518: goto st1518;
		case 1085: goto st1085;
		case 1519: goto st1519;
		case 1520: goto st1520;
		case 1086: goto st1086;
		case 1087: goto st1087;
		case 1088: goto st1088;
		case 1089: goto st1089;
		case 1090: goto st1090;
		case 1091: goto st1091;
		case 1092: goto st1092;
		case 1093: goto st1093;
		case 1094: goto st1094;
		case 1095: goto st1095;
		case 1096: goto st1096;
		case 1097: goto st1097;
		case 1098: goto st1098;
		case 1099: goto st1099;
		case 1100: goto st1100;
		case 1101: goto st1101;
		case 1102: goto st1102;
		case 1103: goto st1103;
		case 1104: goto st1104;
		case 1105: goto st1105;
		case 1106: goto st1106;
		case 1107: goto st1107;
		case 1108: goto st1108;
		case 1109: goto st1109;
		case 1110: goto st1110;
		case 1111: goto st1111;
		case 1112: goto st1112;
		case 1113: goto st1113;
		case 1114: goto st1114;
		case 1115: goto st1115;
		case 1116: goto st1116;
		case 1117: goto st1117;
		case 1118: goto st1118;
		case 1119: goto st1119;
		case 1120: goto st1120;
		case 1121: goto st1121;
		case 1122: goto st1122;
		case 1123: goto st1123;
		case 1124: goto st1124;
		case 1125: goto st1125;
		case 1126: goto st1126;
		case 1127: goto st1127;
		case 1521: goto st1521;
		case 1128: goto st1128;
		case 1129: goto st1129;
		case 1130: goto st1130;
		case 1131: goto st1131;
		case 1132: goto st1132;
		case 1133: goto st1133;
		case 1134: goto st1134;
		case 1135: goto st1135;
		case 1136: goto st1136;
		case 1137: goto st1137;
		case 1138: goto st1138;
		case 1139: goto st1139;
		case 1140: goto st1140;
		case 1141: goto st1141;
		case 1142: goto st1142;
		case 1143: goto st1143;
		case 1144: goto st1144;
		case 1145: goto st1145;
		case 1146: goto st1146;
		case 1147: goto st1147;
		case 1148: goto st1148;
		case 1149: goto st1149;
		case 1150: goto st1150;
		case 1151: goto st1151;
		case 1152: goto st1152;
		case 1153: goto st1153;
		case 1154: goto st1154;
		case 1155: goto st1155;
		case 1156: goto st1156;
		case 1157: goto st1157;
		case 1158: goto st1158;
		case 1159: goto st1159;
		case 1160: goto st1160;
		case 1161: goto st1161;
		case 1162: goto st1162;
		case 1163: goto st1163;
		case 1164: goto st1164;
		case 1165: goto st1165;
		case 1166: goto st1166;
		case 1167: goto st1167;
		case 1168: goto st1168;
		case 1169: goto st1169;
		case 1170: goto st1170;
		case 1171: goto st1171;
		case 1172: goto st1172;
		case 1173: goto st1173;
		case 1174: goto st1174;
		case 1175: goto st1175;
		case 1176: goto st1176;
		case 1177: goto st1177;
		case 1178: goto st1178;
		case 1179: goto st1179;
		case 1180: goto st1180;
		case 1181: goto st1181;
		case 1182: goto st1182;
		case 1183: goto st1183;
		case 1184: goto st1184;
		case 1185: goto st1185;
		case 1186: goto st1186;
		case 1187: goto st1187;
		case 1188: goto st1188;
		case 1189: goto st1189;
		case 1190: goto st1190;
		case 1191: goto st1191;
		case 1192: goto st1192;
		case 1193: goto st1193;
		case 1194: goto st1194;
		case 1195: goto st1195;
		case 1196: goto st1196;
		case 1197: goto st1197;
		case 1198: goto st1198;
		case 1199: goto st1199;
		case 1200: goto st1200;
		case 1201: goto st1201;
		case 1202: goto st1202;
		case 1203: goto st1203;
		case 1204: goto st1204;
		case 1205: goto st1205;
		case 1206: goto st1206;
		case 1207: goto st1207;
		case 1208: goto st1208;
		case 1209: goto st1209;
		case 1210: goto st1210;
		case 1211: goto st1211;
		case 1212: goto st1212;
		case 1213: goto st1213;
		case 1214: goto st1214;
		case 1215: goto st1215;
		case 1216: goto st1216;
		case 1217: goto st1217;
		case 1218: goto st1218;
		case 1219: goto st1219;
		case 1220: goto st1220;
		case 1221: goto st1221;
		case 1222: goto st1222;
		case 1223: goto st1223;
		case 1224: goto st1224;
		case 1225: goto st1225;
		case 1226: goto st1226;
		case 1227: goto st1227;
		case 1228: goto st1228;
		case 1229: goto st1229;
		case 1230: goto st1230;
		case 1231: goto st1231;
		case 1232: goto st1232;
		case 1233: goto st1233;
		case 1234: goto st1234;
		case 1235: goto st1235;
		case 1236: goto st1236;
		case 1237: goto st1237;
		case 1238: goto st1238;
		case 1239: goto st1239;
		case 1240: goto st1240;
		case 1241: goto st1241;
		case 1242: goto st1242;
		case 1243: goto st1243;
		case 1244: goto st1244;
		case 1245: goto st1245;
		case 1246: goto st1246;
		case 1247: goto st1247;
		case 1248: goto st1248;
		case 1249: goto st1249;
		case 1250: goto st1250;
		case 1251: goto st1251;
		case 1252: goto st1252;
		case 1253: goto st1253;
		case 1254: goto st1254;
		case 1255: goto st1255;
		case 1256: goto st1256;
		case 1257: goto st1257;
		case 1258: goto st1258;
		case 1259: goto st1259;
		case 1260: goto st1260;
		case 1261: goto st1261;
		case 1262: goto st1262;
		case 1263: goto st1263;
		case 1264: goto st1264;
		case 1265: goto st1265;
		case 1266: goto st1266;
		case 1267: goto st1267;
		case 1268: goto st1268;
		case 1269: goto st1269;
		case 1270: goto st1270;
		case 1271: goto st1271;
		case 1272: goto st1272;
		case 1273: goto st1273;
		case 1274: goto st1274;
		case 1275: goto st1275;
		case 1276: goto st1276;
		case 1277: goto st1277;
		case 1278: goto st1278;
		case 1279: goto st1279;
		case 1280: goto st1280;
		case 1281: goto st1281;
		case 1282: goto st1282;
		case 1283: goto st1283;
		case 1284: goto st1284;
		case 1285: goto st1285;
		case 1286: goto st1286;
		case 1287: goto st1287;
		case 1288: goto st1288;
		case 1289: goto st1289;
		case 1290: goto st1290;
		case 1291: goto st1291;
		case 1292: goto st1292;
		case 1293: goto st1293;
		case 1294: goto st1294;
		case 1295: goto st1295;
		case 1296: goto st1296;
		case 1297: goto st1297;
		case 1298: goto st1298;
		case 1299: goto st1299;
		case 1300: goto st1300;
		case 1301: goto st1301;
		case 1302: goto st1302;
		case 1303: goto st1303;
		case 1304: goto st1304;
		case 1522: goto st1522;
		case 1305: goto st1305;
		case 1306: goto st1306;
		case 1307: goto st1307;
		case 1308: goto st1308;
		case 1309: goto st1309;
		case 1310: goto st1310;
		case 1311: goto st1311;
		case 1312: goto st1312;
		case 1523: goto st1523;
		case 1313: goto st1313;
		case 1314: goto st1314;
		case 1315: goto st1315;
		case 1316: goto st1316;
		case 1317: goto st1317;
		case 1524: goto st1524;
		case 1318: goto st1318;
		case 1319: goto st1319;
		case 1320: goto st1320;
		case 1321: goto st1321;
		case 1322: goto st1322;
		case 1323: goto st1323;
		case 1324: goto st1324;
		case 1325: goto st1325;
		case 1326: goto st1326;
		case 1327: goto st1327;
		case 1328: goto st1328;
		case 1329: goto st1329;
		case 1330: goto st1330;
		case 1331: goto st1331;
		case 1332: goto st1332;
		case 1333: goto st1333;
		case 1334: goto st1334;
		case 1335: goto st1335;
		case 1525: goto st1525;
		case 1336: goto st1336;
		case 1337: goto st1337;
		case 1338: goto st1338;
		case 1339: goto st1339;
		case 1340: goto st1340;
		case 1341: goto st1341;
		case 1342: goto st1342;
		case 1343: goto st1343;
		case 1344: goto st1344;
		case 1345: goto st1345;
		case 1346: goto st1346;
		case 1347: goto st1347;
		case 1348: goto st1348;
		case 1349: goto st1349;
		case 1350: goto st1350;
		case 1351: goto st1351;
		case 1352: goto st1352;
		case 1353: goto st1353;
		case 1354: goto st1354;
		case 1526: goto st1526;
		case 1355: goto st1355;
		case 1356: goto st1356;
		case 1357: goto st1357;
		case 1358: goto st1358;
		case 1359: goto st1359;
		case 1360: goto st1360;
		case 1361: goto st1361;
		case 1362: goto st1362;
		case 1363: goto st1363;
		case 1364: goto st1364;
		case 1365: goto st1365;
		case 1366: goto st1366;
		case 1367: goto st1367;
		case 1368: goto st1368;
		case 1369: goto st1369;
		case 1527: goto st1527;
		case 1528: goto st1528;
		case 1529: goto st1529;
		case 1370: goto st1370;
		case 1371: goto st1371;
		case 1372: goto st1372;
		case 1373: goto st1373;
		case 1374: goto st1374;
		case 1375: goto st1375;
		case 1376: goto st1376;
		case 1377: goto st1377;
		case 1530: goto st1530;
		case 1378: goto st1378;
		case 1379: goto st1379;
		case 1380: goto st1380;
		case 1381: goto st1381;
		case 1382: goto st1382;
		case 1383: goto st1383;
		case 1384: goto st1384;
		case 1385: goto st1385;
		case 1386: goto st1386;
		case 1387: goto st1387;
		case 1388: goto st1388;
		case 1531: goto st1531;
		case 1532: goto st1532;
		case 1533: goto st1533;
		case 1389: goto st1389;
		case 1390: goto st1390;
		case 1391: goto st1391;
		case 1392: goto st1392;
		case 1393: goto st1393;
		case 1394: goto st1394;
		case 1395: goto st1395;
		case 1534: goto st1534;
		case 1396: goto st1396;
		case 1397: goto st1397;
		case 1398: goto st1398;
		case 1399: goto st1399;
		case 1400: goto st1400;
		case 1401: goto st1401;
		case 1402: goto st1402;
		case 1403: goto st1403;
		case 1404: goto st1404;
		case 1405: goto st1405;
		case 1406: goto st1406;
		case 1407: goto st1407;
		case 1408: goto st1408;
		case 1535: goto st1535;
		case 1409: goto st1409;
		case 1410: goto st1410;
		case 1411: goto st1411;
		case 1412: goto st1412;
		case 1413: goto st1413;
		case 1414: goto st1414;
		case 1415: goto st1415;
		case 1536: goto st1536;
		case 1416: goto st1416;
		case 1417: goto st1417;
		case 1418: goto st1418;
		case 1419: goto st1419;
		case 1420: goto st1420;
		case 1421: goto st1421;
		case 1537: goto st1537;
		case 1422: goto st1422;
		case 1423: goto st1423;
		case 1424: goto st1424;
		case 1425: goto st1425;
		case 1426: goto st1426;
		case 1427: goto st1427;
		case 1538: goto st1538;
		case 1428: goto st1428;
		case 1429: goto st1429;
		case 1430: goto st1430;
		case 1431: goto st1431;
		case 1432: goto st1432;
		case 1433: goto st1433;
		case 1434: goto st1434;
		case 1435: goto st1435;
		case 1539: goto st1539;
		case 1436: goto st1436;
		case 1437: goto st1437;
		case 1438: goto st1438;
		case 1439: goto st1439;
		case 1440: goto st1440;
		case 1441: goto st1441;
		case 1442: goto st1442;
		case 1540: goto st1540;
		case 1443: goto st1443;
	default: break;
	}

	if ( ++p == pe )
		goto _test_eof;
_resume:
	switch ( cs )
	{
tr23:
	{
		s->line_counter++;
	}
	goto st1444;
tr89:
	{
		s->buffer[0] = 0;
		s->buffer_length = 0;
	}
	{
		if (rdata_tail - s->r_data > UINT16_MAX) {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
		s->r_data_length = rdata_tail - s->r_data;

		s->state = ZS_STATE_DATA;

		// Execute the record callback.
		if (s->process.automatic) {
			if (s->process.record != NULL) {
				s->process.record(s);

				// Stop if required from the callback.
				if (s->state == ZS_STATE_STOP) {
					{p++; cs = 1444; goto _out;}
				}
			}
		} else {
			// Return if external processing.
			p--; {p++; cs = 1444; goto _out;}
		}
	}
	{
		s->line_counter++;
	}
	goto st1444;
tr95:
	{
		if (rdata_tail - s->r_data > UINT16_MAX) {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
		s->r_data_length = rdata_tail - s->r_data;

		s->state = ZS_STATE_DATA;

		// Execute the record callback.
		if (s->process.automatic) {
			if (s->process.record != NULL) {
				s->process.record(s);

				// Stop if required from the callback.
				if (s->state == ZS_STATE_STOP) {
					{p++; cs = 1444; goto _out;}
				}
			}
		} else {
			// Return if external processing.
			p--; {p++; cs = 1444; goto _out;}
		}
	}
	{
		s->line_counter++;
	}
	goto st1444;
tr98:
	{
		s->buffer[s->buffer_length++] = 0;

		// Execute the comment callback.
		if (s->process.automatic && s->process.comment != NULL) {
			s->process.comment(s);

			// Stop if required from the callback.
			if (s->state == ZS_STATE_STOP) {
				{p++; cs = 1444; goto _out;}
			}
		}
	}
	{
		if (rdata_tail - s->r_data > UINT16_MAX) {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
		s->r_data_length = rdata_tail - s->r_data;

		s->state = ZS_STATE_DATA;

		// Execute the record callback.
		if (s->process.automatic) {
			if (s->process.record != NULL) {
				s->process.record(s);

				// Stop if required from the callback.
				if (s->state == ZS_STATE_STOP) {
					{p++; cs = 1444; goto _out;}
				}
			}
		} else {
			// Return if external processing.
			p--; {p++; cs = 1444; goto _out;}
		}
	}
	{
		s->line_counter++;
	}
	goto st1444;
tr772:
	{
		s->buffer[s->buffer_length++] = 0;

		// Execute the comment callback.
		if (s->process.automatic && s->process.comment != NULL) {
			s->process.comment(s);

			// Stop if required from the callback.
			if (s->state == ZS_STATE_STOP) {
				{p++; cs = 1444; goto _out;}
			}
		}
	}
	{
		s->line_counter++;
	}
	goto st1444;
tr866:
	{
		s->buffer[0] = 0;
		s->buffer_length = 0;
	}
	{
		s->buffer[s->buffer_length++] = 0;

		// Execute the comment callback.
		if (s->process.automatic && s->process.comment != NULL) {
			s->process.comment(s);

			// Stop if required from the callback.
			if (s->state == ZS_STATE_STOP) {
				{p++; cs = 1444; goto _out;}
			}
		}
	}
	{
		if (rdata_tail - s->r_data > UINT16_MAX) {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
		s->r_data_length = rdata_tail - s->r_data;

		s->state = ZS_STATE_DATA;

		// Execute the record callback.
		if (s->process.automatic) {
			if (s->process.record != NULL) {
				s->process.record(s);

				// Stop if required from the callback.
				if (s->state == ZS_STATE_STOP) {
					{p++; cs = 1444; goto _out;}
				}
			}
		} else {
			// Return if external processing.
			p--; {p++; cs = 1444; goto _out;}
		}
	}
	{
		s->line_counter++;
	}
	goto st1444;
tr984:
	{
		s->buffer[0] = 0;
		s->buffer_length = 0;
	}
	{
		if (rdata_tail - s->r_data > UINT16_MAX) {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
		s->r_data_length = rdata_tail - s->r_data;

		s->state = ZS_STATE_DATA;

		// Execute the record callback.
		if (s->process.automatic) {
			if (s->process.record != NULL) {
				s->process.record(s);

				// Stop if required from the callback.
				if (s->state == ZS_STATE_STOP) {
					{p++; cs = 1444; goto _out;}
				}
			}
		} else {
			// Return if external processing.
			p--; {p++; cs = 1444; goto _out;}
		}
	}
	{
		s->line_counter++;
	}
	{
		s->buffer[s->buffer_length++] = 0;

		// Execute the comment callback.
		if (s->process.automatic && s->process.comment != NULL) {
			s->process.comment(s);

			// Stop if required from the callback.
			if (s->state == ZS_STATE_STOP) {
				{p++; cs = 1444; goto _out;}
			}
		}
	}
	goto st1444;
tr988:
	{
		if (rdata_tail - s->r_data > UINT16_MAX) {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
		s->r_data_length = rdata_tail - s->r_data;

		s->state = ZS_STATE_DATA;

		// Execute the record callback.
		if (s->process.automatic) {
			if (s->process.record != NULL) {
				s->process.record(s);

				// Stop if required from the callback.
				if (s->state == ZS_STATE_STOP) {
					{p++; cs = 1444; goto _out;}
				}
			}
		} else {
			// Return if external processing.
			p--; {p++; cs = 1444; goto _out;}
		}
	}
	{
		s->line_counter++;
	}
	{
		s->buffer[s->buffer_length++] = 0;

		// Execute the comment callback.
		if (s->process.automatic && s->process.comment != NULL) {
			s->process.comment(s);

			// Stop if required from the callback.
			if (s->state == ZS_STATE_STOP) {
				{p++; cs = 1444; goto _out;}
			}
		}
	}
	goto st1444;
tr4291:
	{
		s->buffer[0] = 0;
		s->buffer_length = 0;
	}
	{
		s->line_counter++;
	}
	goto st1444;
tr4357:
	{
		NOERR;
	}
	{
		s->buffer[0] = 0;
		s->buffer_length = 0;
	}
	{
		s->line_counter++;
	}
	goto st1444;
st1444:
	if ( ++p == pe )
		goto _test_eof1444;
case 1444:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr4286;
		case 32: goto tr4286;
		case 36: goto st190;
		case 40: goto tr4288;
		case 41: goto tr4289;
		case 42: goto tr4290;
		case 92: goto tr4290;
		case 95: goto tr4290;
		case 1802: goto tr4291;
		case 1851: goto tr4292;
		case 2058: goto tr4293;
		case 2107: goto tr4294;
	}
	if ( _widec < 64 ) {
		if ( 45 <= _widec && _widec <= 57 )
			goto tr4290;
	} else if ( _widec > 90 ) {
		if ( 97 <= _widec && _widec <= 122 )
			goto tr4290;
	} else
		goto tr4290;
	goto tr4285;
tr0:
	{
		WARN(ZS_BAD_NUMBER);
		p--; {goto st316;}
	}
	{
		WARN(ZS_UNSUPPORTED_TYPE);
		p--; {goto st316;}
	}
	{
		WARN(ZS_BAD_REST);
		p--; {goto st316;}
	}
	goto st0;
tr27:
	{
		WARN(ZS_BAD_TIME_UNIT);
		p--; {goto st316;}
	}
	{
		WARN(ZS_BAD_NUMBER);
		p--; {goto st316;}
	}
	{
		WARN(ZS_UNSUPPORTED_TYPE);
		p--; {goto st316;}
	}
	goto st0;
tr39:
	{
		WARN(ZS_UNSUPPORTED_TYPE);
		p--; {goto st316;}
	}
	goto st0;
tr63:
	{
		WARN(ZS_UNSUPPORTED_TYPE);
		p--; {goto st316;}
	}
	{
		WARN(ZS_BAD_RDATA);
		p--; {goto st316;}
	}
	goto st0;
tr77:
	{
		WARN(ZS_BAD_RDATA);
		p--; {goto st316;}
	}
	goto st0;
tr85:
	{
		WARN(ZS_BAD_RDATA);
		p--; {goto st316;}
	}
	{
		WARN(ZS_BAD_REST);
		p--; {goto st316;}
	}
	goto st0;
tr91:
	{
		WARN(ZS_BAD_REST);
		p--; {goto st316;}
	}
	goto st0;
tr120:
	{
		WARN(ZS_BAD_NUMBER);
		p--; {goto st316;}
	}
	{
		WARN(ZS_UNSUPPORTED_TYPE);
		p--; {goto st316;}
	}
	{
		WARN(ZS_BAD_RDATA);
		p--; {goto st316;}
	}
	{
		WARN(ZS_BAD_REST);
		p--; {goto st316;}
	}
	goto st0;
tr148:
	{
		WARN(ZS_BAD_TIME_UNIT);
		p--; {goto st316;}
	}
	{
		WARN(ZS_BAD_NUMBER);
		p--; {goto st316;}
	}
	{
		WARN(ZS_UNSUPPORTED_TYPE);
		p--; {goto st316;}
	}
	{
		WARN(ZS_BAD_RDATA);
		p--; {goto st316;}
	}
	{
		WARN(ZS_BAD_REST);
		p--; {goto st316;}
	}
	goto st0;
tr154:
	{
		WARN(ZS_UNSUPPORTED_TYPE);
		p--; {goto st316;}
	}
	{
		WARN(ZS_BAD_REST);
		p--; {goto st316;}
	}
	goto st0;
tr660:
	{
		WARN(ZS_BAD_NUMBER);
		p--; {goto st316;}
	}
	{
		WARN(ZS_UNSUPPORTED_TYPE);
		p--; {goto st316;}
	}
	goto st0;
tr662:
	{
		WARN(ZS_BAD_NUMBER);
		p--; {goto st316;}
	}
	{
		WARN(ZS_UNSUPPORTED_TYPE);
		p--; {goto st316;}
	}
	{
		WARN(ZS_BAD_RDATA);
		p--; {goto st316;}
	}
	goto st0;
tr773:
	{
		ERR(ZS_BAD_DIRECTIVE);
		p--; {goto st316;}
	}
	goto st0;
tr784:
	{
		s->r_owner_length = 0;
		WARN(ZS_BAD_OWNER);
		p--; {goto st316;}
	}
	goto st0;
tr798:
	{
		s->r_owner_length = 0;
		WARN(ZS_BAD_OWNER);
		p--; {goto st316;}
	}
	{
		WARN(ZS_BAD_TIME_UNIT);
		p--; {goto st316;}
	}
	{
		WARN(ZS_BAD_NUMBER);
		p--; {goto st316;}
	}
	{
		WARN(ZS_UNSUPPORTED_TYPE);
		p--; {goto st316;}
	}
	goto st0;
tr826:
	{
		s->r_owner_length = 0;
		WARN(ZS_BAD_OWNER);
		p--; {goto st316;}
	}
	{
		WARN(ZS_UNSUPPORTED_TYPE);
		p--; {goto st316;}
	}
	{
		WARN(ZS_BAD_RDATA);
		p--; {goto st316;}
	}
	goto st0;
tr841:
	{
		WARN(ZS_UNSUPPORTED_TYPE);
		p--; {goto st316;}
	}
	{
		WARN(ZS_BAD_RDATA);
		p--; {goto st316;}
	}
	{
		WARN(ZS_BAD_REST);
		p--; {goto st316;}
	}
	goto st0;
tr879:
	{
		WARN(ZS_BAD_RDATA);
		p--; {goto st316;}
	}
	{
		WARN(ZS_BAD_REST);
		p--; {goto st316;}
	}
	{
		ERR(ZS_BAD_DIRECTIVE);
		p--; {goto st316;}
	}
	goto st0;
tr889:
	{
		s->r_owner_length = 0;
		WARN(ZS_BAD_OWNER);
		p--; {goto st316;}
	}
	{
		WARN(ZS_BAD_RDATA);
		p--; {goto st316;}
	}
	{
		WARN(ZS_BAD_REST);
		p--; {goto st316;}
	}
	goto st0;
tr895:
	{
		s->r_owner_length = 0;
		WARN(ZS_BAD_OWNER);
		p--; {goto st316;}
	}
	{
		WARN(ZS_BAD_TIME_UNIT);
		p--; {goto st316;}
	}
	{
		WARN(ZS_BAD_NUMBER);
		p--; {goto st316;}
	}
	{
		WARN(ZS_UNSUPPORTED_TYPE);
		p--; {goto st316;}
	}
	{
		WARN(ZS_BAD_RDATA);
		p--; {goto st316;}
	}
	{
		WARN(ZS_BAD_REST);
		p--; {goto st316;}
	}
	goto st0;
tr908:
	{
		s->r_owner_length = 0;
		WARN(ZS_BAD_OWNER);
		p--; {goto st316;}
	}
	{
		WARN(ZS_UNSUPPORTED_TYPE);
		p--; {goto st316;}
	}
	{
		WARN(ZS_BAD_RDATA);
		p--; {goto st316;}
	}
	{
		WARN(ZS_BAD_REST);
		p--; {goto st316;}
	}
	goto st0;
tr922:
	{
		s->r_owner_length = 0;
		WARN(ZS_BAD_OWNER);
		p--; {goto st316;}
	}
	{
		WARN(ZS_BAD_RDATA);
		p--; {goto st316;}
	}
	goto st0;
tr1014:
	{
		s->r_owner_length = 0;
		WARN(ZS_BAD_OWNER);
		p--; {goto st316;}
	}
	{
		WARN(ZS_UNSUPPORTED_TYPE);
		p--; {goto st316;}
	}
	goto st0;
tr1029:
	{
		WARN(ZS_BAD_DNAME_CHAR);
		p--; {goto st316;}
	}
	goto st0;
tr1042:
	{
		WARN(ZS_BAD_NUMBER);
		p--; {goto st316;}
	}
	{
		WARN(ZS_BAD_DNAME_CHAR);
		p--; {goto st316;}
	}
	goto st0;
tr1050:
	{
		WARN(ZS_BAD_TEXT_CHAR);
		p--; {goto st316;}
	}
	{
		WARN(ZS_BAD_TEXT);
		p--; {goto st316;}
	}
	goto st0;
tr1058:
	{
		WARN(ZS_BAD_NUMBER);
		p--; {goto st316;}
	}
	{
		WARN(ZS_BAD_TEXT_CHAR);
		p--; {goto st316;}
	}
	{
		WARN(ZS_BAD_TEXT);
		p--; {goto st316;}
	}
	goto st0;
tr1074:
	{
		WARN(ZS_BAD_TEXT);
		p--; {goto st316;}
	}
	goto st0;
tr1083:
	{
		ERR(ZS_BAD_TTL);
		p--; {goto st316;}
	}
	goto st0;
tr1089:
	{
		WARN(ZS_BAD_NUMBER);
		p--; {goto st316;}
	}
	{
		ERR(ZS_BAD_TTL);
		p--; {goto st316;}
	}
	goto st0;
tr1091:
	{
		WARN(ZS_BAD_TIME_UNIT);
		p--; {goto st316;}
	}
	{
		WARN(ZS_BAD_NUMBER);
		p--; {goto st316;}
	}
	{
		WARN(ZS_BAD_REST);
		p--; {goto st316;}
	}
	{
		ERR(ZS_BAD_TTL);
		p--; {goto st316;}
	}
	goto st0;
tr1103:
	{
		WARN(ZS_BAD_REST);
		p--; {goto st316;}
	}
	{
		ERR(ZS_BAD_TTL);
		p--; {goto st316;}
	}
	goto st0;
tr1112:
	{
		WARN(ZS_BAD_TIME_UNIT);
		p--; {goto st316;}
	}
	{
		WARN(ZS_BAD_NUMBER);
		p--; {goto st316;}
	}
	{
		ERR(ZS_BAD_TTL);
		p--; {goto st316;}
	}
	goto st0;
tr1127:
	{
		ERR(ZS_BAD_ORIGIN);
		p--; {goto st316;}
	}
	goto st0;
tr1139:
	{
		WARN(ZS_BAD_REST);
		p--; {goto st316;}
	}
	{
		ERR(ZS_BAD_ORIGIN);
		p--; {goto st316;}
	}
	goto st0;
tr1155:
	{
		WARN(ZS_BAD_NUMBER);
		p--; {goto st316;}
	}
	{
		ERR(ZS_BAD_ORIGIN);
		p--; {goto st316;}
	}
	goto st0;
tr1169:
	{
		ERR(ZS_BAD_INCLUDE_FILENAME);
		p--; {goto st316;}
	}
	goto st0;
tr1170:
	{
		ERR(ZS_BAD_INCLUDE_FILENAME);
		p--; {goto st316;}
	}
	{
		WARN(ZS_BAD_REST);
		p--; {goto st316;}
	}
	goto st0;
tr1177:
	{
		ERR(ZS_BAD_INCLUDE_ORIGIN);
		p--; {goto st316;}
	}
	{
		WARN(ZS_BAD_REST);
		p--; {goto st316;}
	}
	goto st0;
tr1187:
	{
		ERR(ZS_BAD_INCLUDE_ORIGIN);
		p--; {goto st316;}
	}
	goto st0;
tr1204:
	{
		WARN(ZS_BAD_NUMBER);
		p--; {goto st316;}
	}
	{
		ERR(ZS_BAD_INCLUDE_ORIGIN);
		p--; {goto st316;}
	}
	goto st0;
tr1221:
	{
		WARN(ZS_BAD_BASE64_CHAR);
		p--; {goto st316;}
	}
	goto st0;
tr1237:
	{
		WARN(ZS_BAD_BITMAP);
		p--; {goto st316;}
	}
	goto st0;
tr1824:
	{
		WARN(ZS_BAD_HEX_RDATA);
		p--; {goto st316;}
	}
	goto st0;
tr1830:
	{
		WARN(ZS_BAD_NUMBER);
		p--; {goto st316;}
	}
	{
		WARN(ZS_BAD_HEX_RDATA);
		p--; {goto st316;}
	}
	goto st0;
tr1838:
	{
		WARN(ZS_BAD_HEX_CHAR);
		p--; {goto st316;}
	}
	{
		WARN(ZS_BAD_HEX_RDATA);
		p--; {goto st316;}
	}
	{
		WARN(ZS_BAD_HEX_RDATA);
		p--; {goto st316;}
	}
	goto st0;
tr1900:
	{
		WARN(ZS_BAD_SVCB_MANDATORY);
		p--; {goto st316;}
	}
	goto st0;
tr1939:
	{
		WARN(ZS_BAD_NUMBER);
		p--; {goto st316;}
	}
	{
		WARN(ZS_BAD_SVCB_MANDATORY);
		p--; {goto st316;}
	}
	goto st0;
tr1967:
	{
		WARN(ZS_BAD_SVCB_PARAM);
		p--; {goto st316;}
	}
	goto st0;
tr2063:
	{
		WARN(ZS_BAD_ADDRESS_CHAR);
		p--; {goto st316;}
	}
	{
		WARN(ZS_BAD_SVCB_PARAM);
		p--; {goto st316;}
	}
	goto st0;
tr2107:
	{
		WARN(ZS_BAD_NUMBER);
		p--; {goto st316;}
	}
	{
		WARN(ZS_BAD_SVCB_PARAM);
		p--; {goto st316;}
	}
	goto st0;
tr2198:
	{
		WARN(ZS_BAD_ALGORITHM);
		p--; {goto st316;}
	}
	goto st0;
tr2320:
	{
		WARN(ZS_BAD_CERT_TYPE);
		p--; {goto st316;}
	}
	goto st0;
tr2373:
	{
		WARN(ZS_BAD_ADDRESS_CHAR);
		p--; {goto st316;}
	}
	{
		WARN(ZS_BAD_RDATA);
		p--; {goto st316;}
	}
	goto st0;
tr2396:
	{
		WARN(ZS_BAD_NUMBER);
		p--; {goto st316;}
	}
	{
		WARN(ZS_BAD_RDATA);
		p--; {goto st316;}
	}
	goto st0;
tr2415:
	{
		WARN(ZS_BAD_TIME_UNIT);
		p--; {goto st316;}
	}
	{
		WARN(ZS_BAD_NUMBER);
		p--; {goto st316;}
	}
	{
		WARN(ZS_BAD_RDATA);
		p--; {goto st316;}
	}
	goto st0;
tr2581:
	{
		s->long_string = false;
	}
	{
		WARN(ZS_BAD_RDATA);
		p--; {goto st316;}
	}
	goto st0;
tr2604:
	{
		WARN(ZS_BAD_LOC_DATA);
		p--; {goto st316;}
	}
	{
		WARN(ZS_BAD_RDATA);
		p--; {goto st316;}
	}
	goto st0;
tr3007:
	{
		WARN(ZS_BAD_APL);
		p--; {goto st316;}
	}
	{
		WARN(ZS_BAD_RDATA);
		p--; {goto st316;}
	}
	goto st0;
tr3022:
	{
		WARN(ZS_BAD_ADDRESS_CHAR);
		p--; {goto st316;}
	}
	{
		WARN(ZS_BAD_APL);
		p--; {goto st316;}
	}
	{
		WARN(ZS_BAD_RDATA);
		p--; {goto st316;}
	}
	goto st0;
tr3067:
	{
		WARN(ZS_BAD_HEX_CHAR);
		p--; {goto st316;}
	}
	{
		WARN(ZS_BAD_RDATA);
		p--; {goto st316;}
	}
	goto st0;
tr3138:
	{
		WARN(ZS_BAD_GATEWAY);
		p--; {goto st316;}
	}
	{
		WARN(ZS_BAD_RDATA);
		p--; {goto st316;}
	}
	goto st0;
tr3153:
	{
		WARN(ZS_BAD_NUMBER);
		p--; {goto st316;}
	}
	{
		WARN(ZS_BAD_GATEWAY);
		p--; {goto st316;}
	}
	{
		WARN(ZS_BAD_RDATA);
		p--; {goto st316;}
	}
	goto st0;
tr3167:
	{
		WARN(ZS_BAD_GATEWAY);
		p--; {goto st316;}
	}
	{
		WARN(ZS_BAD_GATEWAY_KEY);
		p--; {goto st316;}
	}
	{
		WARN(ZS_BAD_RDATA);
		p--; {goto st316;}
	}
	goto st0;
tr3190:
	{
		WARN(ZS_BAD_GATEWAY_KEY);
		p--; {goto st316;}
	}
	{
		WARN(ZS_BAD_RDATA);
		p--; {goto st316;}
	}
	goto st0;
tr3214:
	{
		WARN(ZS_BAD_ADDRESS_CHAR);
		p--; {goto st316;}
	}
	{
		WARN(ZS_BAD_GATEWAY);
		p--; {goto st316;}
	}
	{
		WARN(ZS_BAD_RDATA);
		p--; {goto st316;}
	}
	goto st0;
tr3221:
	{
		WARN(ZS_BAD_ADDRESS_CHAR);
		p--; {goto st316;}
	}
	{
		WARN(ZS_BAD_GATEWAY);
		p--; {goto st316;}
	}
	{
		WARN(ZS_BAD_GATEWAY_KEY);
		p--; {goto st316;}
	}
	{
		WARN(ZS_BAD_RDATA);
		p--; {goto st316;}
	}
	goto st0;
tr3340:
	{
		WARN(ZS_UNSUPPORTED_TYPE);
		p--; {goto st316;}
	}
	{
		WARN(ZS_BAD_RDATA);
		p--; {goto st316;}
	}
	goto st0;
tr3397:
	{
		WARN(ZS_BAD_TIMESTAMP_CHAR);
		p--; {goto st316;}
	}
	{
		WARN(ZS_BAD_RDATA);
		p--; {goto st316;}
	}
	goto st0;
tr3826:
	{
		WARN(ZS_BAD_NUMBER);
		p--; {goto st316;}
	}
	{
		WARN(ZS_UNSUPPORTED_TYPE);
		p--; {goto st316;}
	}
	{
		WARN(ZS_BAD_RDATA);
		p--; {goto st316;}
	}
	goto st0;
tr3947:
	{
		WARN(ZS_BAD_BASE32HEX_CHAR);
		p--; {goto st316;}
	}
	{
		WARN(ZS_BAD_RDATA);
		p--; {goto st316;}
	}
	goto st0;
tr4186:
	{
		WARN(ZS_BAD_HEX_CHAR);
		p--; {goto st316;}
	}
	{
		WARN(ZS_BAD_CHAR_COLON);
		p--; {goto st316;}
	}
	{
		WARN(ZS_BAD_RDATA);
		p--; {goto st316;}
	}
	goto st0;
tr4192:
	{
		WARN(ZS_BAD_CHAR_COLON);
		p--; {goto st316;}
	}
	{
		WARN(ZS_BAD_HEX_CHAR);
		p--; {goto st316;}
	}
	{
		WARN(ZS_BAD_RDATA);
		p--; {goto st316;}
	}
	goto st0;
tr4198:
	{
		WARN(ZS_BAD_CHAR_DASH);
		p--; {goto st316;}
	}
	{
		WARN(ZS_BAD_HEX_CHAR);
		p--; {goto st316;}
	}
	{
		WARN(ZS_BAD_RDATA);
		p--; {goto st316;}
	}
	goto st0;
tr4285:
	{
		s->r_owner_length = 0;
		WARN(ZS_BAD_OWNER);
		p--; {goto st316;}
	}
	{
		WARN(ZS_BAD_REST);
		p--; {goto st316;}
	}
	goto st0;
tr4307:
	{
		s->r_owner_length = 0;
		WARN(ZS_BAD_OWNER);
		p--; {goto st316;}
	}
	{
		WARN(ZS_UNSUPPORTED_TYPE);
		p--; {goto st316;}
	}
	{
		WARN(ZS_BAD_REST);
		p--; {goto st316;}
	}
	goto st0;
tr4331:
	{
		s->r_owner_length = 0;
		WARN(ZS_BAD_OWNER);
		p--; {goto st316;}
	}
	{
		WARN(ZS_BAD_NUMBER);
		p--; {goto st316;}
	}
	{
		WARN(ZS_UNSUPPORTED_TYPE);
		p--; {goto st316;}
	}
	{
		WARN(ZS_BAD_REST);
		p--; {goto st316;}
	}
	goto st0;
tr4351:
	{
		s->r_owner_length = 0;
		WARN(ZS_BAD_OWNER);
		p--; {goto st316;}
	}
	{
		ERR(ZS_BAD_DIRECTIVE);
		p--; {goto st316;}
	}
	{
		WARN(ZS_BAD_REST);
		p--; {goto st316;}
	}
	goto st0;
tr4375:
	{
		s->r_owner_length = 0;
		WARN(ZS_BAD_OWNER);
		p--; {goto st316;}
	}
	{
		WARN(ZS_BAD_NUMBER);
		p--; {goto st316;}
	}
	{
		WARN(ZS_UNSUPPORTED_TYPE);
		p--; {goto st316;}
	}
	{
		WARN(ZS_BAD_RDATA);
		p--; {goto st316;}
	}
	{
		WARN(ZS_BAD_REST);
		p--; {goto st316;}
	}
	goto st0;
st0:
cs = 0;
	goto _out;
tr2:
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st1;
tr3:
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st1;
tr4286:
	{
		if (s->r_owner_length == 0) {
			WARN(ZS_BAD_PREVIOUS_OWNER);
			p--; {goto st316;}
		}
	}
	{
		s->buffer[0] = 0;
		s->buffer_length = 0;
	}
	goto st1;
tr4288:
	{
		if (s->r_owner_length == 0) {
			WARN(ZS_BAD_PREVIOUS_OWNER);
			p--; {goto st316;}
		}
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	{
		s->buffer[0] = 0;
		s->buffer_length = 0;
	}
	goto st1;
tr4289:
	{
		if (s->r_owner_length == 0) {
			WARN(ZS_BAD_PREVIOUS_OWNER);
			p--; {goto st316;}
		}
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	{
		s->buffer[0] = 0;
		s->buffer_length = 0;
	}
	goto st1;
tr4361:
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	{
		if (s->r_owner_length == 0) {
			WARN(ZS_BAD_PREVIOUS_OWNER);
			p--; {goto st316;}
		}
	}
	{
		s->buffer[0] = 0;
		s->buffer_length = 0;
	}
	goto st1;
tr4362:
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	{
		if (s->r_owner_length == 0) {
			WARN(ZS_BAD_PREVIOUS_OWNER);
			p--; {goto st316;}
		}
	}
	{
		s->buffer[0] = 0;
		s->buffer_length = 0;
	}
	goto st1;
tr4352:
	{
		NOERR;
	}
	{
		if (s->r_owner_length == 0) {
			WARN(ZS_BAD_PREVIOUS_OWNER);
			p--; {goto st316;}
		}
	}
	{
		s->buffer[0] = 0;
		s->buffer_length = 0;
	}
	goto st1;
tr4354:
	{
		NOERR;
	}
	{
		if (s->r_owner_length == 0) {
			WARN(ZS_BAD_PREVIOUS_OWNER);
			p--; {goto st316;}
		}
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	{
		s->buffer[0] = 0;
		s->buffer_length = 0;
	}
	goto st1;
tr4355:
	{
		NOERR;
	}
	{
		if (s->r_owner_length == 0) {
			WARN(ZS_BAD_PREVIOUS_OWNER);
			p--; {goto st316;}
		}
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	{
		s->buffer[0] = 0;
		s->buffer_length = 0;
	}
	goto st1;
st1:
	if ( ++p == pe )
		goto _test_eof1;
case 1:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto st1;
		case 32: goto st1;
		case 40: goto tr2;
		case 41: goto tr3;
		case 65: goto tr5;
		case 67: goto tr6;
		case 68: goto tr7;
		case 69: goto tr8;
		case 72: goto tr9;
		case 73: goto tr10;
		case 75: goto tr11;
		case 76: goto tr12;
		case 77: goto tr13;
		case 78: goto tr14;
		case 79: goto tr15;
		case 80: goto tr16;
		case 82: goto tr17;
		case 83: goto tr18;
		case 84: goto tr19;
		case 85: goto tr20;
		case 87: goto tr21;
		case 90: goto tr22;
		case 97: goto tr5;
		case 99: goto tr6;
		case 100: goto tr7;
		case 101: goto tr8;
		case 104: goto tr9;
		case 105: goto tr10;
		case 107: goto tr11;
		case 108: goto tr12;
		case 109: goto tr13;
		case 110: goto tr14;
		case 111: goto tr15;
		case 112: goto tr16;
		case 114: goto tr17;
		case 115: goto tr18;
		case 116: goto tr19;
		case 117: goto tr20;
		case 119: goto tr21;
		case 122: goto tr22;
		case 1802: goto tr23;
		case 1851: goto tr24;
		case 2058: goto tr25;
		case 2107: goto tr26;
	}
	if ( 48 <= _widec && _widec <= 57 )
		goto tr4;
	goto tr0;
tr4:
	{
		s->number64 = 0;
	}
	{
		// Overflow check: 10*(s->number64) + fc - '0' <= UINT64_MAX
		if ((s->number64 < (UINT64_MAX / 10)) ||   // Dominant fast check.
			((s->number64 == (UINT64_MAX / 10)) && // Marginal case.
			 ((uint8_t)(*p) <= (UINT64_MAX % 10) + '0')
			)
		   ) {
			s->number64 *= 10;
			s->number64 += digit_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_NUMBER64_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st2;
tr31:
	{
		// Overflow check: 10*(s->number64) + fc - '0' <= UINT64_MAX
		if ((s->number64 < (UINT64_MAX / 10)) ||   // Dominant fast check.
			((s->number64 == (UINT64_MAX / 10)) && // Marginal case.
			 ((uint8_t)(*p) <= (UINT64_MAX % 10) + '0')
			)
		   ) {
			s->number64 *= 10;
			s->number64 += digit_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_NUMBER64_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st2;
st2:
	if ( ++p == pe )
		goto _test_eof2;
case 2:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr28;
		case 32: goto tr28;
		case 40: goto tr29;
		case 41: goto tr30;
		case 68: goto tr32;
		case 72: goto tr33;
		case 77: goto tr34;
		case 83: goto st204;
		case 87: goto tr36;
		case 100: goto tr32;
		case 104: goto tr33;
		case 109: goto tr34;
		case 115: goto st204;
		case 119: goto tr36;
		case 2058: goto tr37;
		case 2107: goto tr38;
	}
	if ( 48 <= _widec && _widec <= 57 )
		goto tr31;
	goto tr27;
tr41:
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st3;
tr42:
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st3;
tr61:
	{
		s->line_counter++;
	}
	goto st3;
tr28:
	{
		if (s->number64 <= UINT32_MAX) {
			s->r_ttl = (uint32_t)(s->number64);
		} else {
			WARN(ZS_NUMBER32_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st3;
tr29:
	{
		if (s->number64 <= UINT32_MAX) {
			s->r_ttl = (uint32_t)(s->number64);
		} else {
			WARN(ZS_NUMBER32_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st3;
tr30:
	{
		if (s->number64 <= UINT32_MAX) {
			s->r_ttl = (uint32_t)(s->number64);
		} else {
			WARN(ZS_NUMBER32_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st3;
tr37:
	{
		if (s->number64 <= UINT32_MAX) {
			s->r_ttl = (uint32_t)(s->number64);
		} else {
			WARN(ZS_NUMBER32_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		s->line_counter++;
	}
	goto st3;
tr825:
	{
		s->buffer[s->buffer_length++] = 0;

		// Execute the comment callback.
		if (s->process.automatic && s->process.comment != NULL) {
			s->process.comment(s);

			// Stop if required from the callback.
			if (s->state == ZS_STATE_STOP) {
				{p++; cs = 3; goto _out;}
			}
		}
	}
	{
		s->line_counter++;
	}
	goto st3;
tr818:
	{
		if (s->number64 + s->number64_tmp < UINT32_MAX) {
			s->number64 += s->number64_tmp;
		} else {
			WARN(ZS_NUMBER32_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->number64 <= UINT32_MAX) {
			s->r_ttl = (uint32_t)(s->number64);
		} else {
			WARN(ZS_NUMBER32_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st3;
tr819:
	{
		if (s->number64 + s->number64_tmp < UINT32_MAX) {
			s->number64 += s->number64_tmp;
		} else {
			WARN(ZS_NUMBER32_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->number64 <= UINT32_MAX) {
			s->r_ttl = (uint32_t)(s->number64);
		} else {
			WARN(ZS_NUMBER32_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st3;
tr820:
	{
		if (s->number64 + s->number64_tmp < UINT32_MAX) {
			s->number64 += s->number64_tmp;
		} else {
			WARN(ZS_NUMBER32_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->number64 <= UINT32_MAX) {
			s->r_ttl = (uint32_t)(s->number64);
		} else {
			WARN(ZS_NUMBER32_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st3;
tr822:
	{
		if (s->number64 + s->number64_tmp < UINT32_MAX) {
			s->number64 += s->number64_tmp;
		} else {
			WARN(ZS_NUMBER32_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->number64 <= UINT32_MAX) {
			s->r_ttl = (uint32_t)(s->number64);
		} else {
			WARN(ZS_NUMBER32_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		s->line_counter++;
	}
	goto st3;
st3:
	if ( ++p == pe )
		goto _test_eof3;
case 3:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto st3;
		case 32: goto st3;
		case 40: goto tr41;
		case 41: goto tr42;
		case 65: goto tr43;
		case 67: goto tr44;
		case 68: goto tr45;
		case 69: goto tr46;
		case 72: goto tr47;
		case 73: goto tr48;
		case 75: goto tr49;
		case 76: goto tr50;
		case 77: goto tr51;
		case 78: goto tr52;
		case 79: goto tr53;
		case 80: goto tr54;
		case 82: goto tr55;
		case 83: goto tr56;
		case 84: goto tr57;
		case 85: goto tr58;
		case 87: goto tr59;
		case 90: goto tr60;
		case 97: goto tr43;
		case 99: goto tr44;
		case 100: goto tr45;
		case 101: goto tr46;
		case 104: goto tr47;
		case 105: goto tr48;
		case 107: goto tr49;
		case 108: goto tr50;
		case 109: goto tr51;
		case 110: goto tr52;
		case 111: goto tr53;
		case 112: goto tr54;
		case 114: goto tr55;
		case 115: goto tr56;
		case 116: goto tr57;
		case 117: goto tr58;
		case 119: goto tr59;
		case 122: goto tr60;
		case 2058: goto tr61;
		case 2107: goto tr62;
	}
	goto tr39;
tr5:
	{
		s->r_class = s->default_class;
	}
	{
		s->r_ttl = s->default_ttl;
	}
	goto st4;
tr43:
	{
		s->r_class = s->default_class;
	}
	goto st4;
tr725:
	{
		s->r_ttl = s->default_ttl;
	}
	goto st4;
st4:
	if ( ++p == pe )
		goto _test_eof4;
case 4:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(2688 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 !s->multiline  ) _widec += 512;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(2688 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		if (
 !s->multiline  ) _widec += 512;
	}
	switch( _widec ) {
		case 9: goto tr64;
		case 32: goto tr64;
		case 40: goto tr65;
		case 41: goto tr66;
		case 65: goto st274;
		case 70: goto st277;
		case 80: goto st281;
		case 97: goto st274;
		case 102: goto st277;
		case 112: goto st281;
		case 3082: goto tr70;
		case 3131: goto tr71;
		case 3338: goto tr72;
		case 3387: goto tr72;
		case 3594: goto tr73;
		case 3643: goto tr74;
	}
	goto tr63;
tr78:
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st5;
tr79:
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st5;
tr81:
	{
		s->line_counter++;
	}
	goto st5;
tr64:
	{ s->r_type = KNOT_RRTYPE_A; }
	{
		rdata_tail = s->r_data;
	}
	goto st5;
tr65:
	{ s->r_type = KNOT_RRTYPE_A; }
	{
		rdata_tail = s->r_data;
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st5;
tr66:
	{ s->r_type = KNOT_RRTYPE_A; }
	{
		rdata_tail = s->r_data;
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st5;
tr70:
	{ s->r_type = KNOT_RRTYPE_A; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->line_counter++;
	}
	goto st5;
tr102:
	{
		s->buffer[s->buffer_length++] = 0;

		// Execute the comment callback.
		if (s->process.automatic && s->process.comment != NULL) {
			s->process.comment(s);

			// Stop if required from the callback.
			if (s->state == ZS_STATE_STOP) {
				{p++; cs = 5; goto _out;}
			}
		}
	}
	{
		s->line_counter++;
	}
	goto st5;
tr166:
	{ s->r_type = KNOT_RRTYPE_CAA; }
	{
		rdata_tail = s->r_data;
	}
	goto st5;
tr167:
	{ s->r_type = KNOT_RRTYPE_CAA; }
	{
		rdata_tail = s->r_data;
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st5;
tr168:
	{ s->r_type = KNOT_RRTYPE_CAA; }
	{
		rdata_tail = s->r_data;
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st5;
tr169:
	{ s->r_type = KNOT_RRTYPE_CAA; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->line_counter++;
	}
	goto st5;
tr188:
	{ s->r_type = KNOT_RRTYPE_CDNSKEY; }
	{
		rdata_tail = s->r_data;
	}
	goto st5;
tr189:
	{ s->r_type = KNOT_RRTYPE_CDNSKEY; }
	{
		rdata_tail = s->r_data;
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st5;
tr190:
	{ s->r_type = KNOT_RRTYPE_CDNSKEY; }
	{
		rdata_tail = s->r_data;
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st5;
tr191:
	{ s->r_type = KNOT_RRTYPE_CDNSKEY; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->line_counter++;
	}
	goto st5;
tr196:
	{ s->r_type = KNOT_RRTYPE_CDS; }
	{
		rdata_tail = s->r_data;
	}
	goto st5;
tr197:
	{ s->r_type = KNOT_RRTYPE_CDS; }
	{
		rdata_tail = s->r_data;
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st5;
tr198:
	{ s->r_type = KNOT_RRTYPE_CDS; }
	{
		rdata_tail = s->r_data;
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st5;
tr199:
	{ s->r_type = KNOT_RRTYPE_CDS; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->line_counter++;
	}
	goto st5;
tr206:
	{ s->r_type = KNOT_RRTYPE_CERT; }
	{
		rdata_tail = s->r_data;
	}
	goto st5;
tr207:
	{ s->r_type = KNOT_RRTYPE_CERT; }
	{
		rdata_tail = s->r_data;
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st5;
tr208:
	{ s->r_type = KNOT_RRTYPE_CERT; }
	{
		rdata_tail = s->r_data;
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st5;
tr209:
	{ s->r_type = KNOT_RRTYPE_CERT; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->line_counter++;
	}
	goto st5;
tr217:
	{ s->r_type = KNOT_RRTYPE_CNAME; }
	{
		rdata_tail = s->r_data;
	}
	goto st5;
tr218:
	{ s->r_type = KNOT_RRTYPE_CNAME; }
	{
		rdata_tail = s->r_data;
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st5;
tr219:
	{ s->r_type = KNOT_RRTYPE_CNAME; }
	{
		rdata_tail = s->r_data;
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st5;
tr220:
	{ s->r_type = KNOT_RRTYPE_CNAME; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->line_counter++;
	}
	goto st5;
tr228:
	{ s->r_type = KNOT_RRTYPE_CSYNC; }
	{
		rdata_tail = s->r_data;
	}
	goto st5;
tr229:
	{ s->r_type = KNOT_RRTYPE_CSYNC; }
	{
		rdata_tail = s->r_data;
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st5;
tr230:
	{ s->r_type = KNOT_RRTYPE_CSYNC; }
	{
		rdata_tail = s->r_data;
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st5;
tr231:
	{ s->r_type = KNOT_RRTYPE_CSYNC; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->line_counter++;
	}
	goto st5;
tr242:
	{ s->r_type = KNOT_RRTYPE_DHCID; }
	{
		rdata_tail = s->r_data;
	}
	goto st5;
tr243:
	{ s->r_type = KNOT_RRTYPE_DHCID; }
	{
		rdata_tail = s->r_data;
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st5;
tr244:
	{ s->r_type = KNOT_RRTYPE_DHCID; }
	{
		rdata_tail = s->r_data;
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st5;
tr245:
	{ s->r_type = KNOT_RRTYPE_DHCID; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->line_counter++;
	}
	goto st5;
tr254:
	{ s->r_type = KNOT_RRTYPE_DNAME; }
	{
		rdata_tail = s->r_data;
	}
	goto st5;
tr255:
	{ s->r_type = KNOT_RRTYPE_DNAME; }
	{
		rdata_tail = s->r_data;
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st5;
tr256:
	{ s->r_type = KNOT_RRTYPE_DNAME; }
	{
		rdata_tail = s->r_data;
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st5;
tr257:
	{ s->r_type = KNOT_RRTYPE_DNAME; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->line_counter++;
	}
	goto st5;
tr265:
	{ s->r_type = KNOT_RRTYPE_DNSKEY; }
	{
		rdata_tail = s->r_data;
	}
	goto st5;
tr266:
	{ s->r_type = KNOT_RRTYPE_DNSKEY; }
	{
		rdata_tail = s->r_data;
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st5;
tr267:
	{ s->r_type = KNOT_RRTYPE_DNSKEY; }
	{
		rdata_tail = s->r_data;
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st5;
tr268:
	{ s->r_type = KNOT_RRTYPE_DNSKEY; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->line_counter++;
	}
	goto st5;
tr273:
	{ s->r_type = KNOT_RRTYPE_DS; }
	{
		rdata_tail = s->r_data;
	}
	goto st5;
tr274:
	{ s->r_type = KNOT_RRTYPE_DS; }
	{
		rdata_tail = s->r_data;
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st5;
tr275:
	{ s->r_type = KNOT_RRTYPE_DS; }
	{
		rdata_tail = s->r_data;
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st5;
tr276:
	{ s->r_type = KNOT_RRTYPE_DS; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->line_counter++;
	}
	goto st5;
tr286:
	{ s->r_type = KNOT_RRTYPE_EUI48; }
	{
		rdata_tail = s->r_data;
	}
	goto st5;
tr287:
	{ s->r_type = KNOT_RRTYPE_EUI48; }
	{
		rdata_tail = s->r_data;
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st5;
tr288:
	{ s->r_type = KNOT_RRTYPE_EUI48; }
	{
		rdata_tail = s->r_data;
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st5;
tr289:
	{ s->r_type = KNOT_RRTYPE_EUI48; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->line_counter++;
	}
	goto st5;
tr295:
	{ s->r_type = KNOT_RRTYPE_EUI64; }
	{
		rdata_tail = s->r_data;
	}
	goto st5;
tr296:
	{ s->r_type = KNOT_RRTYPE_EUI64; }
	{
		rdata_tail = s->r_data;
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st5;
tr297:
	{ s->r_type = KNOT_RRTYPE_EUI64; }
	{
		rdata_tail = s->r_data;
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st5;
tr298:
	{ s->r_type = KNOT_RRTYPE_EUI64; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->line_counter++;
	}
	goto st5;
tr308:
	{ s->r_type = KNOT_RRTYPE_HINFO; }
	{
		rdata_tail = s->r_data;
	}
	goto st5;
tr309:
	{ s->r_type = KNOT_RRTYPE_HINFO; }
	{
		rdata_tail = s->r_data;
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st5;
tr310:
	{ s->r_type = KNOT_RRTYPE_HINFO; }
	{
		rdata_tail = s->r_data;
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st5;
tr311:
	{ s->r_type = KNOT_RRTYPE_HINFO; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->line_counter++;
	}
	goto st5;
tr319:
	{ s->r_type = KNOT_RRTYPE_HTTPS; }
	{
		rdata_tail = s->r_data;
	}
	goto st5;
tr320:
	{ s->r_type = KNOT_RRTYPE_HTTPS; }
	{
		rdata_tail = s->r_data;
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st5;
tr321:
	{ s->r_type = KNOT_RRTYPE_HTTPS; }
	{
		rdata_tail = s->r_data;
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st5;
tr322:
	{ s->r_type = KNOT_RRTYPE_HTTPS; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->line_counter++;
	}
	goto st5;
tr363:
	{ s->r_type = KNOT_RRTYPE_IPSECKEY; }
	{
		rdata_tail = s->r_data;
	}
	goto st5;
tr364:
	{ s->r_type = KNOT_RRTYPE_IPSECKEY; }
	{
		rdata_tail = s->r_data;
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st5;
tr365:
	{ s->r_type = KNOT_RRTYPE_IPSECKEY; }
	{
		rdata_tail = s->r_data;
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st5;
tr366:
	{ s->r_type = KNOT_RRTYPE_IPSECKEY; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->line_counter++;
	}
	goto st5;
tr374:
	{ s->r_type = KNOT_RRTYPE_KEY; }
	{
		rdata_tail = s->r_data;
	}
	goto st5;
tr375:
	{ s->r_type = KNOT_RRTYPE_KEY; }
	{
		rdata_tail = s->r_data;
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st5;
tr376:
	{ s->r_type = KNOT_RRTYPE_KEY; }
	{
		rdata_tail = s->r_data;
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st5;
tr377:
	{ s->r_type = KNOT_RRTYPE_KEY; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->line_counter++;
	}
	goto st5;
tr382:
	{ s->r_type = KNOT_RRTYPE_KX; }
	{
		rdata_tail = s->r_data;
	}
	goto st5;
tr383:
	{ s->r_type = KNOT_RRTYPE_KX; }
	{
		rdata_tail = s->r_data;
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st5;
tr384:
	{ s->r_type = KNOT_RRTYPE_KX; }
	{
		rdata_tail = s->r_data;
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st5;
tr385:
	{ s->r_type = KNOT_RRTYPE_KX; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->line_counter++;
	}
	goto st5;
tr395:
	{ s->r_type = KNOT_RRTYPE_L32; }
	{
		rdata_tail = s->r_data;
	}
	goto st5;
tr396:
	{ s->r_type = KNOT_RRTYPE_L32; }
	{
		rdata_tail = s->r_data;
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st5;
tr397:
	{ s->r_type = KNOT_RRTYPE_L32; }
	{
		rdata_tail = s->r_data;
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st5;
tr398:
	{ s->r_type = KNOT_RRTYPE_L32; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->line_counter++;
	}
	goto st5;
tr404:
	{ s->r_type = KNOT_RRTYPE_L64; }
	{
		rdata_tail = s->r_data;
	}
	goto st5;
tr405:
	{ s->r_type = KNOT_RRTYPE_L64; }
	{
		rdata_tail = s->r_data;
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st5;
tr406:
	{ s->r_type = KNOT_RRTYPE_L64; }
	{
		rdata_tail = s->r_data;
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st5;
tr407:
	{ s->r_type = KNOT_RRTYPE_L64; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->line_counter++;
	}
	goto st5;
tr413:
	{ s->r_type = KNOT_RRTYPE_LOC; }
	{
		rdata_tail = s->r_data;
	}
	goto st5;
tr414:
	{ s->r_type = KNOT_RRTYPE_LOC; }
	{
		rdata_tail = s->r_data;
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st5;
tr415:
	{ s->r_type = KNOT_RRTYPE_LOC; }
	{
		rdata_tail = s->r_data;
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st5;
tr416:
	{ s->r_type = KNOT_RRTYPE_LOC; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->line_counter++;
	}
	goto st5;
tr421:
	{ s->r_type = KNOT_RRTYPE_LP; }
	{
		rdata_tail = s->r_data;
	}
	goto st5;
tr422:
	{ s->r_type = KNOT_RRTYPE_LP; }
	{
		rdata_tail = s->r_data;
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st5;
tr423:
	{ s->r_type = KNOT_RRTYPE_LP; }
	{
		rdata_tail = s->r_data;
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st5;
tr424:
	{ s->r_type = KNOT_RRTYPE_LP; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->line_counter++;
	}
	goto st5;
tr434:
	{ s->r_type = KNOT_RRTYPE_MINFO; }
	{
		rdata_tail = s->r_data;
	}
	goto st5;
tr435:
	{ s->r_type = KNOT_RRTYPE_MINFO; }
	{
		rdata_tail = s->r_data;
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st5;
tr436:
	{ s->r_type = KNOT_RRTYPE_MINFO; }
	{
		rdata_tail = s->r_data;
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st5;
tr437:
	{ s->r_type = KNOT_RRTYPE_MINFO; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->line_counter++;
	}
	goto st5;
tr442:
	{ s->r_type = KNOT_RRTYPE_MX; }
	{
		rdata_tail = s->r_data;
	}
	goto st5;
tr443:
	{ s->r_type = KNOT_RRTYPE_MX; }
	{
		rdata_tail = s->r_data;
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st5;
tr444:
	{ s->r_type = KNOT_RRTYPE_MX; }
	{
		rdata_tail = s->r_data;
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st5;
tr445:
	{ s->r_type = KNOT_RRTYPE_MX; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->line_counter++;
	}
	goto st5;
tr456:
	{ s->r_type = KNOT_RRTYPE_NAPTR; }
	{
		rdata_tail = s->r_data;
	}
	goto st5;
tr457:
	{ s->r_type = KNOT_RRTYPE_NAPTR; }
	{
		rdata_tail = s->r_data;
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st5;
tr458:
	{ s->r_type = KNOT_RRTYPE_NAPTR; }
	{
		rdata_tail = s->r_data;
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st5;
tr459:
	{ s->r_type = KNOT_RRTYPE_NAPTR; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->line_counter++;
	}
	goto st5;
tr465:
	{ s->r_type = KNOT_RRTYPE_NID; }
	{
		rdata_tail = s->r_data;
	}
	goto st5;
tr466:
	{ s->r_type = KNOT_RRTYPE_NID; }
	{
		rdata_tail = s->r_data;
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st5;
tr467:
	{ s->r_type = KNOT_RRTYPE_NID; }
	{
		rdata_tail = s->r_data;
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st5;
tr468:
	{ s->r_type = KNOT_RRTYPE_NID; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->line_counter++;
	}
	goto st5;
tr473:
	{ s->r_type = KNOT_RRTYPE_NS; }
	{
		rdata_tail = s->r_data;
	}
	goto st5;
tr474:
	{ s->r_type = KNOT_RRTYPE_NS; }
	{
		rdata_tail = s->r_data;
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st5;
tr475:
	{ s->r_type = KNOT_RRTYPE_NS; }
	{
		rdata_tail = s->r_data;
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st5;
tr477:
	{ s->r_type = KNOT_RRTYPE_NS; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->line_counter++;
	}
	goto st5;
tr483:
	{ s->r_type = KNOT_RRTYPE_NSEC; }
	{
		rdata_tail = s->r_data;
	}
	goto st5;
tr484:
	{ s->r_type = KNOT_RRTYPE_NSEC; }
	{
		rdata_tail = s->r_data;
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st5;
tr485:
	{ s->r_type = KNOT_RRTYPE_NSEC; }
	{
		rdata_tail = s->r_data;
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st5;
tr487:
	{ s->r_type = KNOT_RRTYPE_NSEC; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->line_counter++;
	}
	goto st5;
tr492:
	{ s->r_type = KNOT_RRTYPE_NSEC3; }
	{
		rdata_tail = s->r_data;
	}
	goto st5;
tr493:
	{ s->r_type = KNOT_RRTYPE_NSEC3; }
	{
		rdata_tail = s->r_data;
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st5;
tr494:
	{ s->r_type = KNOT_RRTYPE_NSEC3; }
	{
		rdata_tail = s->r_data;
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st5;
tr496:
	{ s->r_type = KNOT_RRTYPE_NSEC3; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->line_counter++;
	}
	goto st5;
tr505:
	{ s->r_type = KNOT_RRTYPE_NSEC3PARAM; }
	{
		rdata_tail = s->r_data;
	}
	goto st5;
tr506:
	{ s->r_type = KNOT_RRTYPE_NSEC3PARAM; }
	{
		rdata_tail = s->r_data;
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st5;
tr507:
	{ s->r_type = KNOT_RRTYPE_NSEC3PARAM; }
	{
		rdata_tail = s->r_data;
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st5;
tr508:
	{ s->r_type = KNOT_RRTYPE_NSEC3PARAM; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->line_counter++;
	}
	goto st5;
tr522:
	{ s->r_type = KNOT_RRTYPE_OPENPGPKEY; }
	{
		rdata_tail = s->r_data;
	}
	goto st5;
tr523:
	{ s->r_type = KNOT_RRTYPE_OPENPGPKEY; }
	{
		rdata_tail = s->r_data;
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st5;
tr524:
	{ s->r_type = KNOT_RRTYPE_OPENPGPKEY; }
	{
		rdata_tail = s->r_data;
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st5;
tr525:
	{ s->r_type = KNOT_RRTYPE_OPENPGPKEY; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->line_counter++;
	}
	goto st5;
tr532:
	{ s->r_type = KNOT_RRTYPE_PTR; }
	{
		rdata_tail = s->r_data;
	}
	goto st5;
tr533:
	{ s->r_type = KNOT_RRTYPE_PTR; }
	{
		rdata_tail = s->r_data;
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st5;
tr534:
	{ s->r_type = KNOT_RRTYPE_PTR; }
	{
		rdata_tail = s->r_data;
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st5;
tr535:
	{ s->r_type = KNOT_RRTYPE_PTR; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->line_counter++;
	}
	goto st5;
tr543:
	{ s->r_type = KNOT_RRTYPE_RP; }
	{
		rdata_tail = s->r_data;
	}
	goto st5;
tr544:
	{ s->r_type = KNOT_RRTYPE_RP; }
	{
		rdata_tail = s->r_data;
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st5;
tr545:
	{ s->r_type = KNOT_RRTYPE_RP; }
	{
		rdata_tail = s->r_data;
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st5;
tr546:
	{ s->r_type = KNOT_RRTYPE_RP; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->line_counter++;
	}
	goto st5;
tr554:
	{ s->r_type = KNOT_RRTYPE_RRSIG; }
	{
		rdata_tail = s->r_data;
	}
	goto st5;
tr555:
	{ s->r_type = KNOT_RRTYPE_RRSIG; }
	{
		rdata_tail = s->r_data;
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st5;
tr556:
	{ s->r_type = KNOT_RRTYPE_RRSIG; }
	{
		rdata_tail = s->r_data;
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st5;
tr557:
	{ s->r_type = KNOT_RRTYPE_RRSIG; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->line_counter++;
	}
	goto st5;
tr562:
	{ s->r_type = KNOT_RRTYPE_RT; }
	{
		rdata_tail = s->r_data;
	}
	goto st5;
tr563:
	{ s->r_type = KNOT_RRTYPE_RT; }
	{
		rdata_tail = s->r_data;
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st5;
tr564:
	{ s->r_type = KNOT_RRTYPE_RT; }
	{
		rdata_tail = s->r_data;
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st5;
tr565:
	{ s->r_type = KNOT_RRTYPE_RT; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->line_counter++;
	}
	goto st5;
tr580:
	{ s->r_type = KNOT_RRTYPE_SMIMEA; }
	{
		rdata_tail = s->r_data;
	}
	goto st5;
tr581:
	{ s->r_type = KNOT_RRTYPE_SMIMEA; }
	{
		rdata_tail = s->r_data;
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st5;
tr582:
	{ s->r_type = KNOT_RRTYPE_SMIMEA; }
	{
		rdata_tail = s->r_data;
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st5;
tr583:
	{ s->r_type = KNOT_RRTYPE_SMIMEA; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->line_counter++;
	}
	goto st5;
tr589:
	{ s->r_type = KNOT_RRTYPE_SOA; }
	{
		rdata_tail = s->r_data;
	}
	goto st5;
tr590:
	{ s->r_type = KNOT_RRTYPE_SOA; }
	{
		rdata_tail = s->r_data;
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st5;
tr591:
	{ s->r_type = KNOT_RRTYPE_SOA; }
	{
		rdata_tail = s->r_data;
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st5;
tr592:
	{ s->r_type = KNOT_RRTYPE_SOA; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->line_counter++;
	}
	goto st5;
tr598:
	{ s->r_type = KNOT_RRTYPE_SPF; }
	{
		rdata_tail = s->r_data;
	}
	goto st5;
tr599:
	{ s->r_type = KNOT_RRTYPE_SPF; }
	{
		rdata_tail = s->r_data;
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st5;
tr600:
	{ s->r_type = KNOT_RRTYPE_SPF; }
	{
		rdata_tail = s->r_data;
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st5;
tr601:
	{ s->r_type = KNOT_RRTYPE_SPF; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->line_counter++;
	}
	goto st5;
tr607:
	{ s->r_type = KNOT_RRTYPE_SRV; }
	{
		rdata_tail = s->r_data;
	}
	goto st5;
tr608:
	{ s->r_type = KNOT_RRTYPE_SRV; }
	{
		rdata_tail = s->r_data;
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st5;
tr609:
	{ s->r_type = KNOT_RRTYPE_SRV; }
	{
		rdata_tail = s->r_data;
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st5;
tr610:
	{ s->r_type = KNOT_RRTYPE_SRV; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->line_counter++;
	}
	goto st5;
tr618:
	{ s->r_type = KNOT_RRTYPE_SSHFP; }
	{
		rdata_tail = s->r_data;
	}
	goto st5;
tr619:
	{ s->r_type = KNOT_RRTYPE_SSHFP; }
	{
		rdata_tail = s->r_data;
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st5;
tr620:
	{ s->r_type = KNOT_RRTYPE_SSHFP; }
	{
		rdata_tail = s->r_data;
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st5;
tr621:
	{ s->r_type = KNOT_RRTYPE_SSHFP; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->line_counter++;
	}
	goto st5;
tr628:
	{ s->r_type = KNOT_RRTYPE_SVCB; }
	{
		rdata_tail = s->r_data;
	}
	goto st5;
tr629:
	{ s->r_type = KNOT_RRTYPE_SVCB; }
	{
		rdata_tail = s->r_data;
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st5;
tr630:
	{ s->r_type = KNOT_RRTYPE_SVCB; }
	{
		rdata_tail = s->r_data;
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st5;
tr631:
	{ s->r_type = KNOT_RRTYPE_SVCB; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->line_counter++;
	}
	goto st5;
tr641:
	{ s->r_type = KNOT_RRTYPE_TLSA; }
	{
		rdata_tail = s->r_data;
	}
	goto st5;
tr642:
	{ s->r_type = KNOT_RRTYPE_TLSA; }
	{
		rdata_tail = s->r_data;
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st5;
tr643:
	{ s->r_type = KNOT_RRTYPE_TLSA; }
	{
		rdata_tail = s->r_data;
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st5;
tr644:
	{ s->r_type = KNOT_RRTYPE_TLSA; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->line_counter++;
	}
	goto st5;
tr650:
	{ s->r_type = KNOT_RRTYPE_TXT; }
	{
		rdata_tail = s->r_data;
	}
	goto st5;
tr651:
	{ s->r_type = KNOT_RRTYPE_TXT; }
	{
		rdata_tail = s->r_data;
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st5;
tr652:
	{ s->r_type = KNOT_RRTYPE_TXT; }
	{
		rdata_tail = s->r_data;
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st5;
tr653:
	{ s->r_type = KNOT_RRTYPE_TXT; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->line_counter++;
	}
	goto st5;
tr663:
	{
		if (s->number64 <= UINT16_MAX) {
			s->r_type = (uint16_t)(s->number64);
		} else {
			WARN(ZS_NUMBER16_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		rdata_tail = s->r_data;
	}
	goto st5;
tr664:
	{
		if (s->number64 <= UINT16_MAX) {
			s->r_type = (uint16_t)(s->number64);
		} else {
			WARN(ZS_NUMBER16_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		rdata_tail = s->r_data;
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st5;
tr665:
	{
		if (s->number64 <= UINT16_MAX) {
			s->r_type = (uint16_t)(s->number64);
		} else {
			WARN(ZS_NUMBER16_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		rdata_tail = s->r_data;
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st5;
tr667:
	{
		if (s->number64 <= UINT16_MAX) {
			s->r_type = (uint16_t)(s->number64);
		} else {
			WARN(ZS_NUMBER16_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		rdata_tail = s->r_data;
	}
	{
		s->line_counter++;
	}
	goto st5;
tr674:
	{ s->r_type = KNOT_RRTYPE_URI; }
	{
		rdata_tail = s->r_data;
	}
	goto st5;
tr675:
	{ s->r_type = KNOT_RRTYPE_URI; }
	{
		rdata_tail = s->r_data;
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st5;
tr676:
	{ s->r_type = KNOT_RRTYPE_URI; }
	{
		rdata_tail = s->r_data;
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st5;
tr677:
	{ s->r_type = KNOT_RRTYPE_URI; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->line_counter++;
	}
	goto st5;
tr687:
	{ s->r_type = KNOT_RRTYPE_WALLET; }
	{
		rdata_tail = s->r_data;
	}
	goto st5;
tr688:
	{ s->r_type = KNOT_RRTYPE_WALLET; }
	{
		rdata_tail = s->r_data;
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st5;
tr689:
	{ s->r_type = KNOT_RRTYPE_WALLET; }
	{
		rdata_tail = s->r_data;
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st5;
tr690:
	{ s->r_type = KNOT_RRTYPE_WALLET; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->line_counter++;
	}
	goto st5;
tr700:
	{ s->r_type = KNOT_RRTYPE_ZONEMD; }
	{
		rdata_tail = s->r_data;
	}
	goto st5;
tr701:
	{ s->r_type = KNOT_RRTYPE_ZONEMD; }
	{
		rdata_tail = s->r_data;
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st5;
tr702:
	{ s->r_type = KNOT_RRTYPE_ZONEMD; }
	{
		rdata_tail = s->r_data;
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st5;
tr703:
	{ s->r_type = KNOT_RRTYPE_ZONEMD; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->line_counter++;
	}
	goto st5;
tr951:
	{ s->r_type = KNOT_RRTYPE_AAAA; }
	{
		rdata_tail = s->r_data;
	}
	goto st5;
tr952:
	{ s->r_type = KNOT_RRTYPE_AAAA; }
	{
		rdata_tail = s->r_data;
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st5;
tr953:
	{ s->r_type = KNOT_RRTYPE_AAAA; }
	{
		rdata_tail = s->r_data;
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st5;
tr954:
	{ s->r_type = KNOT_RRTYPE_AAAA; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->line_counter++;
	}
	goto st5;
tr962:
	{ s->r_type = KNOT_RRTYPE_AFSDB; }
	{
		rdata_tail = s->r_data;
	}
	goto st5;
tr963:
	{ s->r_type = KNOT_RRTYPE_AFSDB; }
	{
		rdata_tail = s->r_data;
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st5;
tr964:
	{ s->r_type = KNOT_RRTYPE_AFSDB; }
	{
		rdata_tail = s->r_data;
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st5;
tr965:
	{ s->r_type = KNOT_RRTYPE_AFSDB; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->line_counter++;
	}
	goto st5;
tr971:
	{ s->r_type = KNOT_RRTYPE_APL; }
	{
		rdata_tail = s->r_data;
	}
	goto st5;
tr972:
	{ s->r_type = KNOT_RRTYPE_APL; }
	{
		rdata_tail = s->r_data;
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st5;
tr973:
	{ s->r_type = KNOT_RRTYPE_APL; }
	{
		rdata_tail = s->r_data;
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st5;
tr974:
	{ s->r_type = KNOT_RRTYPE_APL; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->line_counter++;
	}
	goto st5;
st5:
	if ( ++p == pe )
		goto _test_eof5;
case 5:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(2688 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 !s->multiline  ) _widec += 512;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(2688 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		if (
 !s->multiline  ) _widec += 512;
	}
	switch( _widec ) {
		case 9: goto st5;
		case 32: goto st5;
		case 40: goto tr78;
		case 41: goto tr79;
		case 92: goto tr80;
		case 3082: goto tr81;
		case 3131: goto tr82;
		case 3338: goto tr75;
		case 3387: goto tr75;
		case 3594: goto tr83;
		case 3643: goto tr84;
	}
	if ( _widec < 11 ) {
		if ( _widec <= 8 )
			goto tr75;
	} else if ( _widec > 58 ) {
		if ( 60 <= _widec )
			goto tr75;
	} else
		goto tr75;
	goto tr77;
tr72:
	{ s->r_type = KNOT_RRTYPE_A; }
	{
		rdata_tail = s->r_data;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 6;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 6;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 6;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 6;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 6;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 6;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 6;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 6;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 6;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 6;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 6;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 6;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 6;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 6;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 6;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 6;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 6;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 6;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 6;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 6;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 6;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 6;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 6;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 6;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 6;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 6;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 6;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 6;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 6;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 6;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 6;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 6;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	goto st6;
tr75:
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 6;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 6;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 6;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 6;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 6;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 6;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 6;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 6;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 6;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 6;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 6;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 6;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 6;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 6;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 6;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 6;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 6;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 6;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 6;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 6;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 6;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 6;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 6;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 6;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 6;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 6;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 6;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 6;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 6;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 6;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 6;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 6;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	goto st6;
tr99:
	{
		if (*wrap == WRAP_NONE) {
			p--;
		}
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 6;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 6;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 6;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 6;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 6;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 6;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 6;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 6;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 6;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 6;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 6;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 6;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 6;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 6;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 6;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 6;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 6;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 6;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 6;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 6;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 6;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 6;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 6;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 6;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 6;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 6;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 6;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 6;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 6;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 6;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 6;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 6;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	goto st6;
tr100:
	{
		switch (s->r_type) {
		// Next types must not have empty rdata.
		case KNOT_RRTYPE_A:
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
		case KNOT_RRTYPE_SOA:
		case KNOT_RRTYPE_HINFO:
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_RP:
		case KNOT_RRTYPE_AAAA:
		case KNOT_RRTYPE_LOC:
		case KNOT_RRTYPE_SRV:
		case KNOT_RRTYPE_NAPTR:
		case KNOT_RRTYPE_CERT:
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_SSHFP:
		case KNOT_RRTYPE_IPSECKEY:
		case KNOT_RRTYPE_RRSIG:
		case KNOT_RRTYPE_NSEC:
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_NSEC3:
		case KNOT_RRTYPE_NSEC3PARAM:
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
		case KNOT_RRTYPE_CDS:
		case KNOT_RRTYPE_CDNSKEY:
		case KNOT_RRTYPE_OPENPGPKEY:
		case KNOT_RRTYPE_CSYNC:
		case KNOT_RRTYPE_ZONEMD:
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L32:
		case KNOT_RRTYPE_L64:
		case KNOT_RRTYPE_LP:
		case KNOT_RRTYPE_EUI48:
		case KNOT_RRTYPE_EUI64:
		case KNOT_RRTYPE_URI:
		case KNOT_RRTYPE_CAA:
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 6;goto st555;}
		// Next types can have empty rdata.
		case KNOT_RRTYPE_APL:
		default:
			{stack[top++] = 6;goto st564;}
		}
	}
	goto st6;
tr171:
	{ s->r_type = KNOT_RRTYPE_CAA; }
	{
		rdata_tail = s->r_data;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 6;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 6;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 6;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 6;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 6;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 6;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 6;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 6;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 6;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 6;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 6;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 6;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 6;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 6;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 6;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 6;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 6;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 6;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 6;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 6;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 6;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 6;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 6;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 6;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 6;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 6;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 6;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 6;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 6;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 6;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 6;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 6;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	goto st6;
tr193:
	{ s->r_type = KNOT_RRTYPE_CDNSKEY; }
	{
		rdata_tail = s->r_data;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 6;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 6;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 6;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 6;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 6;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 6;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 6;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 6;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 6;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 6;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 6;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 6;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 6;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 6;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 6;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 6;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 6;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 6;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 6;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 6;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 6;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 6;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 6;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 6;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 6;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 6;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 6;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 6;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 6;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 6;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 6;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 6;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	goto st6;
tr201:
	{ s->r_type = KNOT_RRTYPE_CDS; }
	{
		rdata_tail = s->r_data;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 6;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 6;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 6;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 6;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 6;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 6;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 6;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 6;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 6;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 6;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 6;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 6;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 6;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 6;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 6;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 6;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 6;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 6;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 6;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 6;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 6;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 6;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 6;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 6;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 6;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 6;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 6;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 6;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 6;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 6;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 6;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 6;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	goto st6;
tr211:
	{ s->r_type = KNOT_RRTYPE_CERT; }
	{
		rdata_tail = s->r_data;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 6;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 6;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 6;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 6;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 6;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 6;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 6;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 6;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 6;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 6;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 6;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 6;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 6;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 6;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 6;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 6;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 6;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 6;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 6;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 6;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 6;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 6;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 6;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 6;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 6;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 6;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 6;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 6;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 6;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 6;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 6;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 6;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	goto st6;
tr222:
	{ s->r_type = KNOT_RRTYPE_CNAME; }
	{
		rdata_tail = s->r_data;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 6;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 6;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 6;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 6;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 6;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 6;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 6;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 6;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 6;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 6;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 6;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 6;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 6;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 6;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 6;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 6;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 6;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 6;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 6;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 6;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 6;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 6;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 6;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 6;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 6;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 6;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 6;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 6;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 6;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 6;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 6;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 6;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	goto st6;
tr233:
	{ s->r_type = KNOT_RRTYPE_CSYNC; }
	{
		rdata_tail = s->r_data;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 6;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 6;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 6;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 6;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 6;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 6;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 6;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 6;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 6;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 6;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 6;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 6;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 6;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 6;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 6;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 6;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 6;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 6;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 6;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 6;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 6;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 6;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 6;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 6;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 6;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 6;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 6;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 6;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 6;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 6;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 6;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 6;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	goto st6;
tr247:
	{ s->r_type = KNOT_RRTYPE_DHCID; }
	{
		rdata_tail = s->r_data;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 6;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 6;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 6;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 6;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 6;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 6;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 6;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 6;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 6;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 6;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 6;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 6;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 6;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 6;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 6;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 6;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 6;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 6;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 6;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 6;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 6;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 6;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 6;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 6;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 6;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 6;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 6;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 6;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 6;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 6;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 6;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 6;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	goto st6;
tr259:
	{ s->r_type = KNOT_RRTYPE_DNAME; }
	{
		rdata_tail = s->r_data;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 6;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 6;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 6;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 6;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 6;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 6;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 6;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 6;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 6;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 6;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 6;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 6;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 6;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 6;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 6;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 6;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 6;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 6;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 6;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 6;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 6;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 6;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 6;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 6;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 6;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 6;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 6;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 6;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 6;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 6;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 6;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 6;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	goto st6;
tr270:
	{ s->r_type = KNOT_RRTYPE_DNSKEY; }
	{
		rdata_tail = s->r_data;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 6;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 6;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 6;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 6;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 6;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 6;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 6;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 6;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 6;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 6;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 6;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 6;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 6;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 6;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 6;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 6;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 6;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 6;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 6;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 6;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 6;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 6;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 6;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 6;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 6;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 6;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 6;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 6;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 6;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 6;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 6;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 6;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	goto st6;
tr278:
	{ s->r_type = KNOT_RRTYPE_DS; }
	{
		rdata_tail = s->r_data;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 6;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 6;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 6;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 6;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 6;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 6;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 6;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 6;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 6;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 6;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 6;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 6;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 6;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 6;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 6;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 6;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 6;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 6;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 6;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 6;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 6;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 6;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 6;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 6;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 6;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 6;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 6;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 6;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 6;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 6;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 6;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 6;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	goto st6;
tr291:
	{ s->r_type = KNOT_RRTYPE_EUI48; }
	{
		rdata_tail = s->r_data;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 6;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 6;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 6;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 6;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 6;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 6;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 6;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 6;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 6;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 6;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 6;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 6;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 6;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 6;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 6;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 6;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 6;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 6;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 6;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 6;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 6;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 6;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 6;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 6;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 6;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 6;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 6;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 6;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 6;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 6;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 6;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 6;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	goto st6;
tr300:
	{ s->r_type = KNOT_RRTYPE_EUI64; }
	{
		rdata_tail = s->r_data;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 6;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 6;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 6;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 6;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 6;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 6;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 6;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 6;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 6;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 6;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 6;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 6;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 6;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 6;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 6;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 6;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 6;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 6;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 6;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 6;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 6;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 6;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 6;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 6;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 6;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 6;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 6;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 6;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 6;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 6;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 6;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 6;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	goto st6;
tr313:
	{ s->r_type = KNOT_RRTYPE_HINFO; }
	{
		rdata_tail = s->r_data;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 6;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 6;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 6;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 6;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 6;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 6;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 6;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 6;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 6;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 6;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 6;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 6;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 6;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 6;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 6;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 6;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 6;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 6;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 6;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 6;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 6;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 6;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 6;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 6;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 6;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 6;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 6;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 6;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 6;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 6;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 6;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 6;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	goto st6;
tr324:
	{ s->r_type = KNOT_RRTYPE_HTTPS; }
	{
		rdata_tail = s->r_data;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 6;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 6;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 6;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 6;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 6;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 6;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 6;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 6;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 6;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 6;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 6;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 6;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 6;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 6;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 6;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 6;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 6;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 6;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 6;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 6;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 6;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 6;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 6;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 6;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 6;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 6;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 6;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 6;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 6;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 6;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 6;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 6;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	goto st6;
tr368:
	{ s->r_type = KNOT_RRTYPE_IPSECKEY; }
	{
		rdata_tail = s->r_data;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 6;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 6;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 6;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 6;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 6;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 6;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 6;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 6;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 6;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 6;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 6;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 6;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 6;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 6;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 6;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 6;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 6;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 6;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 6;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 6;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 6;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 6;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 6;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 6;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 6;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 6;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 6;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 6;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 6;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 6;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 6;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 6;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	goto st6;
tr379:
	{ s->r_type = KNOT_RRTYPE_KEY; }
	{
		rdata_tail = s->r_data;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 6;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 6;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 6;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 6;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 6;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 6;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 6;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 6;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 6;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 6;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 6;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 6;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 6;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 6;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 6;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 6;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 6;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 6;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 6;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 6;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 6;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 6;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 6;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 6;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 6;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 6;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 6;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 6;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 6;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 6;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 6;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 6;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	goto st6;
tr387:
	{ s->r_type = KNOT_RRTYPE_KX; }
	{
		rdata_tail = s->r_data;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 6;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 6;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 6;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 6;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 6;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 6;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 6;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 6;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 6;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 6;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 6;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 6;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 6;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 6;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 6;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 6;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 6;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 6;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 6;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 6;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 6;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 6;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 6;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 6;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 6;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 6;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 6;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 6;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 6;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 6;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 6;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 6;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	goto st6;
tr400:
	{ s->r_type = KNOT_RRTYPE_L32; }
	{
		rdata_tail = s->r_data;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 6;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 6;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 6;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 6;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 6;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 6;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 6;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 6;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 6;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 6;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 6;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 6;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 6;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 6;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 6;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 6;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 6;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 6;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 6;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 6;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 6;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 6;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 6;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 6;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 6;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 6;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 6;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 6;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 6;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 6;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 6;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 6;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	goto st6;
tr409:
	{ s->r_type = KNOT_RRTYPE_L64; }
	{
		rdata_tail = s->r_data;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 6;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 6;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 6;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 6;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 6;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 6;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 6;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 6;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 6;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 6;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 6;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 6;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 6;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 6;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 6;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 6;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 6;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 6;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 6;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 6;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 6;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 6;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 6;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 6;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 6;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 6;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 6;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 6;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 6;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 6;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 6;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 6;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	goto st6;
tr418:
	{ s->r_type = KNOT_RRTYPE_LOC; }
	{
		rdata_tail = s->r_data;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 6;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 6;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 6;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 6;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 6;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 6;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 6;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 6;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 6;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 6;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 6;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 6;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 6;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 6;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 6;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 6;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 6;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 6;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 6;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 6;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 6;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 6;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 6;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 6;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 6;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 6;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 6;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 6;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 6;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 6;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 6;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 6;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	goto st6;
tr426:
	{ s->r_type = KNOT_RRTYPE_LP; }
	{
		rdata_tail = s->r_data;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 6;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 6;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 6;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 6;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 6;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 6;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 6;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 6;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 6;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 6;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 6;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 6;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 6;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 6;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 6;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 6;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 6;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 6;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 6;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 6;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 6;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 6;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 6;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 6;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 6;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 6;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 6;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 6;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 6;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 6;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 6;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 6;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	goto st6;
tr439:
	{ s->r_type = KNOT_RRTYPE_MINFO; }
	{
		rdata_tail = s->r_data;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 6;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 6;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 6;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 6;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 6;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 6;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 6;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 6;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 6;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 6;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 6;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 6;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 6;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 6;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 6;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 6;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 6;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 6;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 6;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 6;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 6;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 6;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 6;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 6;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 6;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 6;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 6;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 6;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 6;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 6;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 6;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 6;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	goto st6;
tr447:
	{ s->r_type = KNOT_RRTYPE_MX; }
	{
		rdata_tail = s->r_data;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 6;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 6;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 6;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 6;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 6;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 6;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 6;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 6;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 6;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 6;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 6;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 6;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 6;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 6;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 6;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 6;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 6;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 6;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 6;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 6;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 6;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 6;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 6;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 6;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 6;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 6;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 6;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 6;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 6;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 6;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 6;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 6;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	goto st6;
tr461:
	{ s->r_type = KNOT_RRTYPE_NAPTR; }
	{
		rdata_tail = s->r_data;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 6;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 6;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 6;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 6;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 6;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 6;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 6;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 6;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 6;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 6;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 6;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 6;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 6;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 6;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 6;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 6;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 6;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 6;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 6;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 6;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 6;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 6;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 6;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 6;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 6;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 6;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 6;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 6;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 6;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 6;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 6;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 6;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	goto st6;
tr470:
	{ s->r_type = KNOT_RRTYPE_NID; }
	{
		rdata_tail = s->r_data;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 6;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 6;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 6;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 6;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 6;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 6;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 6;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 6;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 6;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 6;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 6;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 6;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 6;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 6;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 6;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 6;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 6;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 6;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 6;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 6;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 6;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 6;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 6;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 6;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 6;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 6;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 6;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 6;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 6;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 6;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 6;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 6;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	goto st6;
tr479:
	{ s->r_type = KNOT_RRTYPE_NS; }
	{
		rdata_tail = s->r_data;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 6;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 6;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 6;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 6;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 6;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 6;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 6;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 6;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 6;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 6;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 6;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 6;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 6;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 6;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 6;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 6;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 6;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 6;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 6;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 6;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 6;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 6;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 6;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 6;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 6;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 6;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 6;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 6;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 6;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 6;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 6;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 6;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	goto st6;
tr489:
	{ s->r_type = KNOT_RRTYPE_NSEC; }
	{
		rdata_tail = s->r_data;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 6;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 6;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 6;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 6;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 6;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 6;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 6;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 6;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 6;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 6;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 6;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 6;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 6;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 6;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 6;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 6;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 6;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 6;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 6;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 6;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 6;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 6;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 6;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 6;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 6;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 6;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 6;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 6;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 6;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 6;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 6;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 6;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	goto st6;
tr498:
	{ s->r_type = KNOT_RRTYPE_NSEC3; }
	{
		rdata_tail = s->r_data;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 6;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 6;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 6;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 6;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 6;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 6;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 6;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 6;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 6;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 6;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 6;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 6;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 6;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 6;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 6;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 6;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 6;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 6;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 6;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 6;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 6;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 6;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 6;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 6;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 6;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 6;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 6;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 6;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 6;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 6;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 6;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 6;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	goto st6;
tr510:
	{ s->r_type = KNOT_RRTYPE_NSEC3PARAM; }
	{
		rdata_tail = s->r_data;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 6;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 6;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 6;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 6;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 6;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 6;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 6;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 6;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 6;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 6;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 6;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 6;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 6;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 6;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 6;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 6;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 6;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 6;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 6;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 6;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 6;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 6;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 6;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 6;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 6;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 6;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 6;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 6;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 6;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 6;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 6;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 6;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	goto st6;
tr527:
	{ s->r_type = KNOT_RRTYPE_OPENPGPKEY; }
	{
		rdata_tail = s->r_data;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 6;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 6;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 6;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 6;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 6;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 6;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 6;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 6;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 6;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 6;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 6;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 6;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 6;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 6;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 6;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 6;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 6;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 6;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 6;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 6;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 6;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 6;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 6;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 6;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 6;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 6;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 6;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 6;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 6;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 6;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 6;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 6;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	goto st6;
tr537:
	{ s->r_type = KNOT_RRTYPE_PTR; }
	{
		rdata_tail = s->r_data;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 6;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 6;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 6;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 6;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 6;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 6;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 6;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 6;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 6;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 6;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 6;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 6;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 6;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 6;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 6;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 6;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 6;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 6;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 6;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 6;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 6;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 6;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 6;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 6;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 6;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 6;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 6;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 6;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 6;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 6;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 6;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 6;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	goto st6;
tr548:
	{ s->r_type = KNOT_RRTYPE_RP; }
	{
		rdata_tail = s->r_data;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 6;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 6;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 6;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 6;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 6;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 6;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 6;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 6;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 6;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 6;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 6;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 6;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 6;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 6;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 6;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 6;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 6;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 6;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 6;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 6;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 6;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 6;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 6;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 6;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 6;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 6;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 6;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 6;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 6;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 6;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 6;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 6;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	goto st6;
tr559:
	{ s->r_type = KNOT_RRTYPE_RRSIG; }
	{
		rdata_tail = s->r_data;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 6;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 6;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 6;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 6;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 6;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 6;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 6;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 6;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 6;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 6;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 6;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 6;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 6;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 6;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 6;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 6;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 6;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 6;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 6;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 6;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 6;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 6;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 6;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 6;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 6;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 6;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 6;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 6;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 6;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 6;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 6;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 6;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	goto st6;
tr567:
	{ s->r_type = KNOT_RRTYPE_RT; }
	{
		rdata_tail = s->r_data;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 6;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 6;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 6;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 6;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 6;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 6;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 6;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 6;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 6;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 6;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 6;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 6;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 6;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 6;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 6;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 6;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 6;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 6;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 6;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 6;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 6;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 6;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 6;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 6;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 6;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 6;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 6;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 6;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 6;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 6;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 6;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 6;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	goto st6;
tr585:
	{ s->r_type = KNOT_RRTYPE_SMIMEA; }
	{
		rdata_tail = s->r_data;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 6;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 6;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 6;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 6;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 6;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 6;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 6;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 6;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 6;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 6;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 6;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 6;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 6;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 6;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 6;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 6;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 6;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 6;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 6;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 6;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 6;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 6;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 6;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 6;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 6;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 6;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 6;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 6;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 6;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 6;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 6;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 6;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	goto st6;
tr594:
	{ s->r_type = KNOT_RRTYPE_SOA; }
	{
		rdata_tail = s->r_data;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 6;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 6;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 6;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 6;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 6;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 6;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 6;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 6;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 6;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 6;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 6;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 6;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 6;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 6;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 6;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 6;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 6;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 6;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 6;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 6;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 6;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 6;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 6;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 6;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 6;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 6;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 6;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 6;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 6;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 6;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 6;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 6;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	goto st6;
tr603:
	{ s->r_type = KNOT_RRTYPE_SPF; }
	{
		rdata_tail = s->r_data;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 6;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 6;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 6;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 6;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 6;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 6;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 6;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 6;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 6;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 6;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 6;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 6;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 6;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 6;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 6;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 6;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 6;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 6;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 6;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 6;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 6;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 6;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 6;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 6;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 6;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 6;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 6;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 6;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 6;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 6;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 6;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 6;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	goto st6;
tr612:
	{ s->r_type = KNOT_RRTYPE_SRV; }
	{
		rdata_tail = s->r_data;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 6;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 6;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 6;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 6;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 6;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 6;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 6;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 6;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 6;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 6;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 6;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 6;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 6;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 6;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 6;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 6;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 6;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 6;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 6;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 6;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 6;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 6;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 6;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 6;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 6;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 6;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 6;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 6;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 6;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 6;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 6;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 6;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	goto st6;
tr623:
	{ s->r_type = KNOT_RRTYPE_SSHFP; }
	{
		rdata_tail = s->r_data;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 6;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 6;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 6;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 6;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 6;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 6;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 6;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 6;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 6;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 6;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 6;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 6;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 6;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 6;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 6;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 6;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 6;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 6;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 6;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 6;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 6;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 6;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 6;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 6;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 6;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 6;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 6;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 6;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 6;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 6;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 6;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 6;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	goto st6;
tr633:
	{ s->r_type = KNOT_RRTYPE_SVCB; }
	{
		rdata_tail = s->r_data;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 6;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 6;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 6;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 6;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 6;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 6;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 6;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 6;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 6;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 6;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 6;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 6;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 6;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 6;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 6;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 6;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 6;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 6;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 6;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 6;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 6;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 6;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 6;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 6;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 6;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 6;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 6;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 6;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 6;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 6;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 6;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 6;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	goto st6;
tr646:
	{ s->r_type = KNOT_RRTYPE_TLSA; }
	{
		rdata_tail = s->r_data;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 6;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 6;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 6;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 6;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 6;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 6;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 6;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 6;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 6;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 6;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 6;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 6;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 6;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 6;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 6;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 6;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 6;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 6;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 6;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 6;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 6;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 6;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 6;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 6;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 6;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 6;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 6;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 6;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 6;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 6;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 6;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 6;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	goto st6;
tr655:
	{ s->r_type = KNOT_RRTYPE_TXT; }
	{
		rdata_tail = s->r_data;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 6;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 6;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 6;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 6;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 6;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 6;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 6;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 6;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 6;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 6;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 6;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 6;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 6;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 6;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 6;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 6;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 6;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 6;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 6;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 6;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 6;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 6;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 6;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 6;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 6;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 6;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 6;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 6;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 6;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 6;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 6;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 6;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	goto st6;
tr669:
	{
		if (s->number64 <= UINT16_MAX) {
			s->r_type = (uint16_t)(s->number64);
		} else {
			WARN(ZS_NUMBER16_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		rdata_tail = s->r_data;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 6;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 6;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 6;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 6;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 6;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 6;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 6;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 6;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 6;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 6;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 6;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 6;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 6;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 6;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 6;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 6;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 6;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 6;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 6;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 6;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 6;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 6;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 6;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 6;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 6;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 6;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 6;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 6;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 6;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 6;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 6;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 6;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	goto st6;
tr679:
	{ s->r_type = KNOT_RRTYPE_URI; }
	{
		rdata_tail = s->r_data;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 6;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 6;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 6;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 6;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 6;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 6;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 6;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 6;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 6;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 6;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 6;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 6;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 6;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 6;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 6;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 6;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 6;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 6;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 6;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 6;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 6;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 6;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 6;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 6;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 6;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 6;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 6;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 6;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 6;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 6;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 6;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 6;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	goto st6;
tr692:
	{ s->r_type = KNOT_RRTYPE_WALLET; }
	{
		rdata_tail = s->r_data;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 6;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 6;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 6;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 6;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 6;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 6;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 6;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 6;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 6;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 6;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 6;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 6;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 6;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 6;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 6;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 6;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 6;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 6;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 6;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 6;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 6;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 6;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 6;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 6;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 6;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 6;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 6;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 6;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 6;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 6;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 6;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 6;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	goto st6;
tr705:
	{ s->r_type = KNOT_RRTYPE_ZONEMD; }
	{
		rdata_tail = s->r_data;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 6;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 6;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 6;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 6;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 6;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 6;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 6;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 6;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 6;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 6;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 6;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 6;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 6;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 6;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 6;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 6;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 6;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 6;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 6;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 6;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 6;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 6;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 6;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 6;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 6;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 6;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 6;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 6;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 6;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 6;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 6;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 6;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	goto st6;
tr956:
	{ s->r_type = KNOT_RRTYPE_AAAA; }
	{
		rdata_tail = s->r_data;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 6;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 6;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 6;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 6;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 6;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 6;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 6;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 6;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 6;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 6;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 6;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 6;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 6;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 6;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 6;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 6;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 6;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 6;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 6;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 6;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 6;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 6;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 6;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 6;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 6;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 6;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 6;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 6;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 6;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 6;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 6;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 6;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	goto st6;
tr967:
	{ s->r_type = KNOT_RRTYPE_AFSDB; }
	{
		rdata_tail = s->r_data;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 6;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 6;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 6;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 6;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 6;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 6;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 6;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 6;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 6;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 6;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 6;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 6;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 6;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 6;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 6;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 6;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 6;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 6;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 6;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 6;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 6;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 6;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 6;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 6;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 6;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 6;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 6;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 6;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 6;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 6;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 6;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 6;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	goto st6;
tr976:
	{ s->r_type = KNOT_RRTYPE_APL; }
	{
		rdata_tail = s->r_data;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 6;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 6;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 6;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 6;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 6;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 6;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 6;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 6;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 6;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 6;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 6;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 6;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 6;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 6;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 6;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 6;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 6;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 6;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 6;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 6;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 6;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 6;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 6;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 6;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 6;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 6;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 6;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 6;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 6;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 6;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 6;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 6;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	goto st6;
st6:
	if ( ++p == pe )
		goto _test_eof6;
case 6:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr86;
		case 32: goto tr86;
		case 40: goto tr87;
		case 41: goto tr88;
		case 1802: goto tr89;
		case 1851: goto tr90;
		case 2058: goto tr89;
		case 2107: goto tr90;
	}
	goto tr85;
tr93:
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st7;
tr94:
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st7;
tr86:
	{
		s->buffer[0] = 0;
		s->buffer_length = 0;
	}
	goto st7;
tr87:
	{
		s->buffer[0] = 0;
		s->buffer_length = 0;
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st7;
tr88:
	{
		s->buffer[0] = 0;
		s->buffer_length = 0;
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st7;
st7:
	if ( ++p == pe )
		goto _test_eof7;
case 7:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto st7;
		case 32: goto st7;
		case 40: goto tr93;
		case 41: goto tr94;
		case 1802: goto tr95;
		case 1851: goto tr96;
		case 2058: goto tr95;
		case 2107: goto tr96;
	}
	goto tr91;
tr96:
	{
		s->buffer_length = 0;
	}
	goto st8;
tr90:
	{
		s->buffer[0] = 0;
		s->buffer_length = 0;
	}
	{
		s->buffer_length = 0;
	}
	goto st8;
tr97:
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		}
	}
	goto st8;
tr867:
	{
		s->buffer[0] = 0;
		s->buffer_length = 0;
	}
	{
		s->buffer_length = 0;
	}
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		}
	}
	goto st8;
tr871:
	{
		s->buffer_length = 0;
	}
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		}
	}
	goto st8;
st8:
	if ( ++p == pe )
		goto _test_eof8;
case 8:
	if ( (*p) == 10 )
		goto tr98;
	goto tr97;
tr80:
	{
		if (pe - p == 1) {
			*wrap = WRAP_DETECTED;
		}
	}
	goto st9;
st9:
	if ( ++p == pe )
		goto _test_eof9;
case 9:
	if ( (*p) == 35 )
		goto tr100;
	goto tr99;
tr82:
	{
		s->buffer_length = 0;
	}
	goto st10;
tr71:
	{ s->r_type = KNOT_RRTYPE_A; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->buffer_length = 0;
	}
	goto st10;
tr101:
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		}
	}
	goto st10;
tr170:
	{ s->r_type = KNOT_RRTYPE_CAA; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->buffer_length = 0;
	}
	goto st10;
tr192:
	{ s->r_type = KNOT_RRTYPE_CDNSKEY; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->buffer_length = 0;
	}
	goto st10;
tr200:
	{ s->r_type = KNOT_RRTYPE_CDS; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->buffer_length = 0;
	}
	goto st10;
tr210:
	{ s->r_type = KNOT_RRTYPE_CERT; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->buffer_length = 0;
	}
	goto st10;
tr221:
	{ s->r_type = KNOT_RRTYPE_CNAME; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->buffer_length = 0;
	}
	goto st10;
tr232:
	{ s->r_type = KNOT_RRTYPE_CSYNC; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->buffer_length = 0;
	}
	goto st10;
tr246:
	{ s->r_type = KNOT_RRTYPE_DHCID; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->buffer_length = 0;
	}
	goto st10;
tr258:
	{ s->r_type = KNOT_RRTYPE_DNAME; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->buffer_length = 0;
	}
	goto st10;
tr269:
	{ s->r_type = KNOT_RRTYPE_DNSKEY; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->buffer_length = 0;
	}
	goto st10;
tr277:
	{ s->r_type = KNOT_RRTYPE_DS; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->buffer_length = 0;
	}
	goto st10;
tr290:
	{ s->r_type = KNOT_RRTYPE_EUI48; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->buffer_length = 0;
	}
	goto st10;
tr299:
	{ s->r_type = KNOT_RRTYPE_EUI64; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->buffer_length = 0;
	}
	goto st10;
tr312:
	{ s->r_type = KNOT_RRTYPE_HINFO; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->buffer_length = 0;
	}
	goto st10;
tr323:
	{ s->r_type = KNOT_RRTYPE_HTTPS; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->buffer_length = 0;
	}
	goto st10;
tr367:
	{ s->r_type = KNOT_RRTYPE_IPSECKEY; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->buffer_length = 0;
	}
	goto st10;
tr378:
	{ s->r_type = KNOT_RRTYPE_KEY; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->buffer_length = 0;
	}
	goto st10;
tr386:
	{ s->r_type = KNOT_RRTYPE_KX; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->buffer_length = 0;
	}
	goto st10;
tr399:
	{ s->r_type = KNOT_RRTYPE_L32; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->buffer_length = 0;
	}
	goto st10;
tr408:
	{ s->r_type = KNOT_RRTYPE_L64; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->buffer_length = 0;
	}
	goto st10;
tr417:
	{ s->r_type = KNOT_RRTYPE_LOC; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->buffer_length = 0;
	}
	goto st10;
tr425:
	{ s->r_type = KNOT_RRTYPE_LP; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->buffer_length = 0;
	}
	goto st10;
tr438:
	{ s->r_type = KNOT_RRTYPE_MINFO; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->buffer_length = 0;
	}
	goto st10;
tr446:
	{ s->r_type = KNOT_RRTYPE_MX; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->buffer_length = 0;
	}
	goto st10;
tr460:
	{ s->r_type = KNOT_RRTYPE_NAPTR; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->buffer_length = 0;
	}
	goto st10;
tr469:
	{ s->r_type = KNOT_RRTYPE_NID; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->buffer_length = 0;
	}
	goto st10;
tr478:
	{ s->r_type = KNOT_RRTYPE_NS; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->buffer_length = 0;
	}
	goto st10;
tr488:
	{ s->r_type = KNOT_RRTYPE_NSEC; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->buffer_length = 0;
	}
	goto st10;
tr497:
	{ s->r_type = KNOT_RRTYPE_NSEC3; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->buffer_length = 0;
	}
	goto st10;
tr509:
	{ s->r_type = KNOT_RRTYPE_NSEC3PARAM; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->buffer_length = 0;
	}
	goto st10;
tr526:
	{ s->r_type = KNOT_RRTYPE_OPENPGPKEY; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->buffer_length = 0;
	}
	goto st10;
tr536:
	{ s->r_type = KNOT_RRTYPE_PTR; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->buffer_length = 0;
	}
	goto st10;
tr547:
	{ s->r_type = KNOT_RRTYPE_RP; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->buffer_length = 0;
	}
	goto st10;
tr558:
	{ s->r_type = KNOT_RRTYPE_RRSIG; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->buffer_length = 0;
	}
	goto st10;
tr566:
	{ s->r_type = KNOT_RRTYPE_RT; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->buffer_length = 0;
	}
	goto st10;
tr584:
	{ s->r_type = KNOT_RRTYPE_SMIMEA; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->buffer_length = 0;
	}
	goto st10;
tr593:
	{ s->r_type = KNOT_RRTYPE_SOA; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->buffer_length = 0;
	}
	goto st10;
tr602:
	{ s->r_type = KNOT_RRTYPE_SPF; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->buffer_length = 0;
	}
	goto st10;
tr611:
	{ s->r_type = KNOT_RRTYPE_SRV; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->buffer_length = 0;
	}
	goto st10;
tr622:
	{ s->r_type = KNOT_RRTYPE_SSHFP; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->buffer_length = 0;
	}
	goto st10;
tr632:
	{ s->r_type = KNOT_RRTYPE_SVCB; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->buffer_length = 0;
	}
	goto st10;
tr645:
	{ s->r_type = KNOT_RRTYPE_TLSA; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->buffer_length = 0;
	}
	goto st10;
tr654:
	{ s->r_type = KNOT_RRTYPE_TXT; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->buffer_length = 0;
	}
	goto st10;
tr668:
	{
		if (s->number64 <= UINT16_MAX) {
			s->r_type = (uint16_t)(s->number64);
		} else {
			WARN(ZS_NUMBER16_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		rdata_tail = s->r_data;
	}
	{
		s->buffer_length = 0;
	}
	goto st10;
tr678:
	{ s->r_type = KNOT_RRTYPE_URI; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->buffer_length = 0;
	}
	goto st10;
tr691:
	{ s->r_type = KNOT_RRTYPE_WALLET; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->buffer_length = 0;
	}
	goto st10;
tr704:
	{ s->r_type = KNOT_RRTYPE_ZONEMD; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->buffer_length = 0;
	}
	goto st10;
tr955:
	{ s->r_type = KNOT_RRTYPE_AAAA; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->buffer_length = 0;
	}
	goto st10;
tr966:
	{ s->r_type = KNOT_RRTYPE_AFSDB; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->buffer_length = 0;
	}
	goto st10;
tr975:
	{ s->r_type = KNOT_RRTYPE_APL; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->buffer_length = 0;
	}
	goto st10;
st10:
	if ( ++p == pe )
		goto _test_eof10;
case 10:
	_widec = (*p);
	if ( (*p) < 10 ) {
		if ( (*p) <= 9 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) > 10 ) {
		if ( 11 <= (*p) )
 {			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	if ( _widec == 2058 )
		goto tr102;
	if ( 1920 <= _widec && _widec <= 2175 )
		goto tr101;
	goto tr77;
tr73:
	{ s->r_type = KNOT_RRTYPE_A; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->line_counter++;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 11;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 11;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 11;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 11;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 11;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 11;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 11;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 11;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 11;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 11;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 11;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 11;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 11;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 11;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 11;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 11;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 11;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 11;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 11;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 11;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 11;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 11;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 11;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 11;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 11;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 11;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 11;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 11;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 11;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 11;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 11;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 11;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	goto st11;
tr83:
	{
		s->line_counter++;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 11;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 11;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 11;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 11;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 11;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 11;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 11;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 11;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 11;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 11;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 11;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 11;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 11;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 11;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 11;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 11;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 11;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 11;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 11;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 11;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 11;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 11;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 11;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 11;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 11;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 11;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 11;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 11;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 11;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 11;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 11;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 11;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	goto st11;
tr172:
	{ s->r_type = KNOT_RRTYPE_CAA; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->line_counter++;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 11;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 11;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 11;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 11;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 11;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 11;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 11;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 11;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 11;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 11;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 11;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 11;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 11;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 11;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 11;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 11;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 11;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 11;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 11;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 11;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 11;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 11;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 11;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 11;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 11;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 11;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 11;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 11;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 11;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 11;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 11;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 11;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	goto st11;
tr194:
	{ s->r_type = KNOT_RRTYPE_CDNSKEY; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->line_counter++;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 11;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 11;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 11;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 11;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 11;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 11;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 11;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 11;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 11;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 11;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 11;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 11;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 11;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 11;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 11;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 11;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 11;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 11;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 11;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 11;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 11;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 11;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 11;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 11;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 11;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 11;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 11;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 11;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 11;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 11;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 11;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 11;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	goto st11;
tr202:
	{ s->r_type = KNOT_RRTYPE_CDS; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->line_counter++;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 11;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 11;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 11;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 11;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 11;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 11;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 11;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 11;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 11;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 11;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 11;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 11;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 11;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 11;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 11;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 11;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 11;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 11;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 11;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 11;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 11;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 11;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 11;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 11;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 11;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 11;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 11;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 11;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 11;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 11;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 11;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 11;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	goto st11;
tr212:
	{ s->r_type = KNOT_RRTYPE_CERT; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->line_counter++;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 11;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 11;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 11;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 11;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 11;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 11;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 11;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 11;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 11;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 11;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 11;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 11;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 11;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 11;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 11;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 11;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 11;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 11;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 11;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 11;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 11;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 11;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 11;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 11;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 11;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 11;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 11;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 11;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 11;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 11;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 11;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 11;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	goto st11;
tr223:
	{ s->r_type = KNOT_RRTYPE_CNAME; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->line_counter++;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 11;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 11;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 11;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 11;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 11;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 11;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 11;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 11;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 11;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 11;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 11;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 11;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 11;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 11;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 11;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 11;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 11;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 11;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 11;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 11;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 11;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 11;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 11;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 11;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 11;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 11;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 11;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 11;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 11;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 11;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 11;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 11;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	goto st11;
tr234:
	{ s->r_type = KNOT_RRTYPE_CSYNC; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->line_counter++;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 11;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 11;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 11;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 11;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 11;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 11;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 11;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 11;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 11;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 11;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 11;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 11;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 11;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 11;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 11;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 11;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 11;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 11;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 11;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 11;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 11;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 11;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 11;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 11;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 11;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 11;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 11;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 11;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 11;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 11;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 11;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 11;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	goto st11;
tr248:
	{ s->r_type = KNOT_RRTYPE_DHCID; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->line_counter++;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 11;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 11;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 11;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 11;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 11;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 11;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 11;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 11;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 11;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 11;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 11;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 11;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 11;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 11;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 11;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 11;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 11;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 11;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 11;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 11;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 11;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 11;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 11;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 11;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 11;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 11;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 11;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 11;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 11;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 11;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 11;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 11;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	goto st11;
tr260:
	{ s->r_type = KNOT_RRTYPE_DNAME; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->line_counter++;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 11;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 11;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 11;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 11;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 11;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 11;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 11;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 11;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 11;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 11;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 11;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 11;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 11;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 11;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 11;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 11;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 11;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 11;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 11;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 11;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 11;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 11;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 11;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 11;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 11;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 11;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 11;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 11;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 11;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 11;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 11;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 11;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	goto st11;
tr271:
	{ s->r_type = KNOT_RRTYPE_DNSKEY; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->line_counter++;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 11;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 11;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 11;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 11;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 11;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 11;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 11;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 11;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 11;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 11;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 11;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 11;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 11;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 11;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 11;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 11;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 11;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 11;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 11;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 11;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 11;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 11;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 11;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 11;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 11;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 11;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 11;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 11;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 11;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 11;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 11;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 11;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	goto st11;
tr279:
	{ s->r_type = KNOT_RRTYPE_DS; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->line_counter++;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 11;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 11;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 11;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 11;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 11;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 11;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 11;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 11;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 11;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 11;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 11;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 11;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 11;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 11;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 11;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 11;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 11;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 11;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 11;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 11;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 11;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 11;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 11;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 11;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 11;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 11;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 11;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 11;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 11;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 11;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 11;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 11;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	goto st11;
tr292:
	{ s->r_type = KNOT_RRTYPE_EUI48; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->line_counter++;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 11;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 11;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 11;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 11;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 11;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 11;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 11;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 11;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 11;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 11;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 11;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 11;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 11;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 11;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 11;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 11;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 11;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 11;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 11;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 11;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 11;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 11;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 11;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 11;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 11;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 11;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 11;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 11;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 11;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 11;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 11;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 11;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	goto st11;
tr301:
	{ s->r_type = KNOT_RRTYPE_EUI64; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->line_counter++;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 11;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 11;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 11;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 11;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 11;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 11;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 11;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 11;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 11;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 11;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 11;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 11;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 11;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 11;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 11;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 11;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 11;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 11;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 11;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 11;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 11;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 11;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 11;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 11;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 11;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 11;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 11;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 11;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 11;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 11;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 11;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 11;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	goto st11;
tr314:
	{ s->r_type = KNOT_RRTYPE_HINFO; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->line_counter++;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 11;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 11;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 11;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 11;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 11;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 11;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 11;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 11;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 11;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 11;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 11;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 11;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 11;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 11;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 11;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 11;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 11;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 11;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 11;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 11;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 11;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 11;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 11;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 11;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 11;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 11;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 11;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 11;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 11;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 11;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 11;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 11;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	goto st11;
tr325:
	{ s->r_type = KNOT_RRTYPE_HTTPS; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->line_counter++;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 11;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 11;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 11;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 11;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 11;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 11;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 11;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 11;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 11;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 11;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 11;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 11;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 11;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 11;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 11;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 11;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 11;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 11;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 11;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 11;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 11;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 11;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 11;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 11;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 11;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 11;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 11;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 11;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 11;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 11;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 11;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 11;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	goto st11;
tr369:
	{ s->r_type = KNOT_RRTYPE_IPSECKEY; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->line_counter++;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 11;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 11;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 11;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 11;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 11;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 11;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 11;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 11;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 11;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 11;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 11;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 11;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 11;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 11;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 11;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 11;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 11;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 11;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 11;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 11;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 11;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 11;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 11;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 11;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 11;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 11;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 11;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 11;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 11;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 11;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 11;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 11;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	goto st11;
tr380:
	{ s->r_type = KNOT_RRTYPE_KEY; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->line_counter++;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 11;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 11;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 11;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 11;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 11;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 11;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 11;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 11;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 11;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 11;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 11;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 11;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 11;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 11;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 11;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 11;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 11;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 11;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 11;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 11;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 11;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 11;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 11;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 11;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 11;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 11;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 11;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 11;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 11;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 11;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 11;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 11;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	goto st11;
tr388:
	{ s->r_type = KNOT_RRTYPE_KX; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->line_counter++;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 11;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 11;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 11;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 11;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 11;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 11;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 11;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 11;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 11;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 11;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 11;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 11;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 11;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 11;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 11;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 11;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 11;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 11;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 11;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 11;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 11;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 11;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 11;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 11;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 11;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 11;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 11;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 11;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 11;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 11;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 11;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 11;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	goto st11;
tr401:
	{ s->r_type = KNOT_RRTYPE_L32; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->line_counter++;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 11;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 11;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 11;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 11;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 11;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 11;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 11;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 11;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 11;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 11;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 11;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 11;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 11;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 11;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 11;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 11;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 11;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 11;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 11;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 11;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 11;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 11;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 11;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 11;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 11;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 11;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 11;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 11;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 11;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 11;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 11;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 11;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	goto st11;
tr410:
	{ s->r_type = KNOT_RRTYPE_L64; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->line_counter++;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 11;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 11;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 11;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 11;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 11;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 11;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 11;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 11;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 11;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 11;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 11;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 11;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 11;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 11;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 11;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 11;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 11;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 11;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 11;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 11;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 11;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 11;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 11;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 11;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 11;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 11;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 11;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 11;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 11;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 11;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 11;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 11;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	goto st11;
tr419:
	{ s->r_type = KNOT_RRTYPE_LOC; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->line_counter++;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 11;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 11;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 11;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 11;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 11;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 11;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 11;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 11;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 11;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 11;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 11;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 11;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 11;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 11;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 11;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 11;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 11;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 11;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 11;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 11;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 11;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 11;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 11;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 11;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 11;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 11;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 11;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 11;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 11;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 11;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 11;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 11;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	goto st11;
tr427:
	{ s->r_type = KNOT_RRTYPE_LP; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->line_counter++;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 11;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 11;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 11;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 11;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 11;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 11;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 11;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 11;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 11;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 11;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 11;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 11;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 11;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 11;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 11;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 11;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 11;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 11;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 11;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 11;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 11;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 11;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 11;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 11;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 11;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 11;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 11;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 11;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 11;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 11;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 11;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 11;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	goto st11;
tr440:
	{ s->r_type = KNOT_RRTYPE_MINFO; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->line_counter++;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 11;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 11;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 11;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 11;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 11;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 11;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 11;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 11;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 11;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 11;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 11;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 11;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 11;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 11;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 11;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 11;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 11;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 11;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 11;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 11;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 11;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 11;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 11;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 11;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 11;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 11;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 11;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 11;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 11;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 11;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 11;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 11;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	goto st11;
tr448:
	{ s->r_type = KNOT_RRTYPE_MX; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->line_counter++;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 11;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 11;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 11;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 11;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 11;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 11;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 11;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 11;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 11;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 11;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 11;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 11;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 11;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 11;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 11;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 11;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 11;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 11;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 11;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 11;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 11;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 11;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 11;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 11;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 11;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 11;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 11;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 11;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 11;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 11;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 11;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 11;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	goto st11;
tr462:
	{ s->r_type = KNOT_RRTYPE_NAPTR; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->line_counter++;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 11;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 11;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 11;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 11;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 11;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 11;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 11;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 11;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 11;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 11;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 11;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 11;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 11;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 11;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 11;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 11;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 11;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 11;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 11;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 11;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 11;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 11;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 11;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 11;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 11;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 11;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 11;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 11;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 11;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 11;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 11;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 11;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	goto st11;
tr471:
	{ s->r_type = KNOT_RRTYPE_NID; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->line_counter++;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 11;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 11;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 11;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 11;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 11;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 11;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 11;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 11;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 11;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 11;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 11;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 11;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 11;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 11;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 11;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 11;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 11;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 11;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 11;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 11;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 11;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 11;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 11;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 11;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 11;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 11;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 11;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 11;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 11;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 11;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 11;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 11;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	goto st11;
tr480:
	{ s->r_type = KNOT_RRTYPE_NS; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->line_counter++;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 11;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 11;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 11;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 11;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 11;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 11;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 11;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 11;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 11;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 11;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 11;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 11;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 11;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 11;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 11;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 11;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 11;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 11;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 11;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 11;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 11;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 11;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 11;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 11;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 11;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 11;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 11;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 11;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 11;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 11;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 11;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 11;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	goto st11;
tr490:
	{ s->r_type = KNOT_RRTYPE_NSEC; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->line_counter++;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 11;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 11;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 11;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 11;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 11;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 11;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 11;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 11;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 11;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 11;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 11;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 11;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 11;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 11;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 11;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 11;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 11;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 11;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 11;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 11;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 11;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 11;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 11;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 11;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 11;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 11;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 11;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 11;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 11;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 11;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 11;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 11;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	goto st11;
tr499:
	{ s->r_type = KNOT_RRTYPE_NSEC3; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->line_counter++;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 11;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 11;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 11;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 11;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 11;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 11;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 11;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 11;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 11;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 11;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 11;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 11;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 11;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 11;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 11;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 11;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 11;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 11;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 11;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 11;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 11;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 11;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 11;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 11;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 11;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 11;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 11;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 11;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 11;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 11;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 11;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 11;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	goto st11;
tr511:
	{ s->r_type = KNOT_RRTYPE_NSEC3PARAM; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->line_counter++;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 11;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 11;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 11;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 11;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 11;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 11;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 11;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 11;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 11;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 11;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 11;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 11;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 11;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 11;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 11;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 11;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 11;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 11;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 11;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 11;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 11;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 11;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 11;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 11;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 11;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 11;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 11;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 11;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 11;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 11;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 11;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 11;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	goto st11;
tr528:
	{ s->r_type = KNOT_RRTYPE_OPENPGPKEY; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->line_counter++;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 11;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 11;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 11;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 11;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 11;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 11;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 11;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 11;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 11;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 11;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 11;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 11;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 11;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 11;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 11;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 11;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 11;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 11;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 11;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 11;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 11;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 11;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 11;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 11;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 11;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 11;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 11;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 11;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 11;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 11;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 11;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 11;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	goto st11;
tr538:
	{ s->r_type = KNOT_RRTYPE_PTR; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->line_counter++;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 11;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 11;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 11;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 11;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 11;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 11;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 11;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 11;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 11;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 11;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 11;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 11;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 11;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 11;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 11;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 11;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 11;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 11;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 11;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 11;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 11;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 11;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 11;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 11;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 11;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 11;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 11;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 11;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 11;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 11;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 11;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 11;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	goto st11;
tr549:
	{ s->r_type = KNOT_RRTYPE_RP; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->line_counter++;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 11;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 11;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 11;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 11;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 11;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 11;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 11;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 11;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 11;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 11;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 11;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 11;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 11;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 11;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 11;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 11;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 11;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 11;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 11;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 11;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 11;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 11;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 11;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 11;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 11;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 11;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 11;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 11;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 11;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 11;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 11;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 11;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	goto st11;
tr560:
	{ s->r_type = KNOT_RRTYPE_RRSIG; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->line_counter++;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 11;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 11;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 11;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 11;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 11;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 11;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 11;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 11;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 11;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 11;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 11;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 11;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 11;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 11;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 11;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 11;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 11;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 11;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 11;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 11;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 11;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 11;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 11;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 11;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 11;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 11;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 11;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 11;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 11;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 11;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 11;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 11;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	goto st11;
tr568:
	{ s->r_type = KNOT_RRTYPE_RT; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->line_counter++;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 11;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 11;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 11;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 11;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 11;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 11;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 11;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 11;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 11;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 11;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 11;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 11;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 11;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 11;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 11;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 11;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 11;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 11;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 11;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 11;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 11;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 11;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 11;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 11;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 11;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 11;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 11;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 11;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 11;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 11;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 11;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 11;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	goto st11;
tr586:
	{ s->r_type = KNOT_RRTYPE_SMIMEA; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->line_counter++;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 11;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 11;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 11;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 11;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 11;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 11;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 11;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 11;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 11;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 11;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 11;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 11;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 11;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 11;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 11;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 11;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 11;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 11;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 11;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 11;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 11;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 11;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 11;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 11;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 11;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 11;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 11;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 11;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 11;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 11;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 11;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 11;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	goto st11;
tr595:
	{ s->r_type = KNOT_RRTYPE_SOA; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->line_counter++;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 11;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 11;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 11;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 11;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 11;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 11;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 11;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 11;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 11;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 11;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 11;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 11;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 11;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 11;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 11;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 11;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 11;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 11;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 11;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 11;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 11;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 11;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 11;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 11;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 11;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 11;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 11;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 11;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 11;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 11;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 11;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 11;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	goto st11;
tr604:
	{ s->r_type = KNOT_RRTYPE_SPF; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->line_counter++;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 11;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 11;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 11;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 11;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 11;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 11;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 11;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 11;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 11;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 11;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 11;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 11;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 11;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 11;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 11;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 11;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 11;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 11;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 11;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 11;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 11;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 11;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 11;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 11;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 11;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 11;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 11;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 11;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 11;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 11;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 11;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 11;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	goto st11;
tr613:
	{ s->r_type = KNOT_RRTYPE_SRV; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->line_counter++;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 11;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 11;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 11;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 11;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 11;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 11;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 11;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 11;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 11;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 11;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 11;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 11;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 11;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 11;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 11;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 11;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 11;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 11;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 11;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 11;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 11;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 11;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 11;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 11;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 11;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 11;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 11;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 11;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 11;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 11;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 11;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 11;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	goto st11;
tr624:
	{ s->r_type = KNOT_RRTYPE_SSHFP; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->line_counter++;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 11;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 11;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 11;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 11;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 11;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 11;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 11;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 11;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 11;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 11;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 11;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 11;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 11;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 11;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 11;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 11;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 11;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 11;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 11;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 11;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 11;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 11;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 11;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 11;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 11;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 11;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 11;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 11;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 11;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 11;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 11;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 11;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	goto st11;
tr634:
	{ s->r_type = KNOT_RRTYPE_SVCB; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->line_counter++;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 11;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 11;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 11;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 11;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 11;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 11;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 11;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 11;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 11;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 11;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 11;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 11;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 11;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 11;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 11;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 11;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 11;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 11;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 11;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 11;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 11;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 11;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 11;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 11;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 11;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 11;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 11;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 11;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 11;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 11;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 11;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 11;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	goto st11;
tr647:
	{ s->r_type = KNOT_RRTYPE_TLSA; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->line_counter++;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 11;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 11;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 11;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 11;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 11;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 11;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 11;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 11;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 11;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 11;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 11;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 11;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 11;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 11;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 11;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 11;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 11;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 11;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 11;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 11;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 11;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 11;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 11;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 11;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 11;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 11;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 11;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 11;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 11;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 11;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 11;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 11;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	goto st11;
tr656:
	{ s->r_type = KNOT_RRTYPE_TXT; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->line_counter++;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 11;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 11;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 11;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 11;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 11;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 11;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 11;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 11;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 11;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 11;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 11;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 11;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 11;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 11;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 11;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 11;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 11;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 11;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 11;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 11;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 11;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 11;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 11;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 11;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 11;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 11;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 11;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 11;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 11;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 11;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 11;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 11;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	goto st11;
tr670:
	{
		if (s->number64 <= UINT16_MAX) {
			s->r_type = (uint16_t)(s->number64);
		} else {
			WARN(ZS_NUMBER16_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		rdata_tail = s->r_data;
	}
	{
		s->line_counter++;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 11;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 11;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 11;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 11;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 11;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 11;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 11;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 11;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 11;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 11;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 11;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 11;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 11;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 11;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 11;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 11;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 11;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 11;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 11;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 11;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 11;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 11;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 11;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 11;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 11;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 11;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 11;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 11;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 11;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 11;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 11;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 11;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	goto st11;
tr680:
	{ s->r_type = KNOT_RRTYPE_URI; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->line_counter++;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 11;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 11;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 11;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 11;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 11;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 11;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 11;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 11;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 11;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 11;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 11;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 11;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 11;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 11;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 11;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 11;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 11;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 11;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 11;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 11;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 11;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 11;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 11;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 11;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 11;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 11;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 11;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 11;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 11;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 11;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 11;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 11;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	goto st11;
tr693:
	{ s->r_type = KNOT_RRTYPE_WALLET; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->line_counter++;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 11;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 11;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 11;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 11;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 11;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 11;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 11;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 11;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 11;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 11;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 11;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 11;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 11;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 11;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 11;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 11;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 11;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 11;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 11;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 11;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 11;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 11;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 11;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 11;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 11;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 11;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 11;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 11;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 11;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 11;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 11;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 11;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	goto st11;
tr706:
	{ s->r_type = KNOT_RRTYPE_ZONEMD; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->line_counter++;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 11;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 11;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 11;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 11;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 11;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 11;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 11;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 11;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 11;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 11;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 11;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 11;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 11;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 11;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 11;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 11;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 11;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 11;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 11;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 11;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 11;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 11;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 11;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 11;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 11;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 11;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 11;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 11;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 11;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 11;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 11;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 11;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	goto st11;
tr957:
	{ s->r_type = KNOT_RRTYPE_AAAA; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->line_counter++;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 11;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 11;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 11;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 11;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 11;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 11;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 11;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 11;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 11;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 11;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 11;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 11;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 11;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 11;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 11;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 11;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 11;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 11;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 11;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 11;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 11;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 11;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 11;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 11;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 11;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 11;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 11;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 11;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 11;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 11;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 11;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 11;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	goto st11;
tr968:
	{ s->r_type = KNOT_RRTYPE_AFSDB; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->line_counter++;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 11;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 11;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 11;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 11;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 11;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 11;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 11;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 11;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 11;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 11;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 11;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 11;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 11;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 11;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 11;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 11;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 11;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 11;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 11;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 11;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 11;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 11;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 11;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 11;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 11;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 11;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 11;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 11;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 11;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 11;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 11;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 11;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	goto st11;
tr977:
	{ s->r_type = KNOT_RRTYPE_APL; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->line_counter++;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 11;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 11;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 11;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 11;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 11;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 11;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 11;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 11;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 11;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 11;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 11;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 11;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 11;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 11;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 11;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 11;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 11;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 11;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 11;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 11;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 11;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 11;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 11;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 11;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 11;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 11;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 11;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 11;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 11;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 11;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 11;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 11;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	goto st11;
st11:
	if ( ++p == pe )
		goto _test_eof11;
case 11:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(2688 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 !s->multiline  ) _widec += 512;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(2688 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		if (
 !s->multiline  ) _widec += 512;
	}
	switch( _widec ) {
		case 9: goto tr103;
		case 32: goto tr103;
		case 40: goto tr104;
		case 41: goto tr105;
		case 92: goto tr80;
		case 2826: goto tr89;
		case 2875: goto tr90;
		case 3082: goto tr89;
		case 3131: goto tr106;
		case 3338: goto tr107;
		case 3387: goto tr108;
		case 3594: goto tr89;
		case 3643: goto tr109;
	}
	if ( _widec < 11 ) {
		if ( _widec <= 8 )
			goto tr75;
	} else if ( _widec > 58 ) {
		if ( 60 <= _widec )
			goto tr75;
	} else
		goto tr75;
	goto tr85;
tr111:
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st12;
tr112:
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st12;
tr103:
	{
		s->buffer[0] = 0;
		s->buffer_length = 0;
	}
	goto st12;
tr104:
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	{
		s->buffer[0] = 0;
		s->buffer_length = 0;
	}
	goto st12;
tr105:
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	{
		s->buffer[0] = 0;
		s->buffer_length = 0;
	}
	goto st12;
st12:
	if ( ++p == pe )
		goto _test_eof12;
case 12:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(2688 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 !s->multiline  ) _widec += 512;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(2688 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		if (
 !s->multiline  ) _widec += 512;
	}
	switch( _widec ) {
		case 9: goto st12;
		case 32: goto st12;
		case 40: goto tr111;
		case 41: goto tr112;
		case 92: goto tr80;
		case 2826: goto tr95;
		case 2875: goto tr96;
		case 3082: goto tr95;
		case 3131: goto tr113;
		case 3338: goto tr114;
		case 3387: goto tr115;
		case 3594: goto tr95;
		case 3643: goto tr116;
	}
	if ( _widec < 11 ) {
		if ( _widec <= 8 )
			goto tr75;
	} else if ( _widec > 58 ) {
		if ( 60 <= _widec )
			goto tr75;
	} else
		goto tr75;
	goto tr85;
tr113:
	{
		s->buffer_length = 0;
	}
	goto st13;
tr117:
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		}
	}
	goto st13;
tr106:
	{
		s->buffer_length = 0;
	}
	{
		s->buffer[0] = 0;
		s->buffer_length = 0;
	}
	goto st13;
tr177:
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		}
	}
	{
		s->buffer[0] = 0;
		s->buffer_length = 0;
	}
	{
		s->buffer_length = 0;
	}
	goto st13;
tr181:
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		}
	}
	{
		s->buffer_length = 0;
	}
	goto st13;
tr846:
	{ s->r_type = KNOT_RRTYPE_A; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->buffer_length = 0;
	}
	{
		s->buffer[0] = 0;
		s->buffer_length = 0;
	}
	goto st13;
st13:
	if ( ++p == pe )
		goto _test_eof13;
case 13:
	_widec = (*p);
	if ( (*p) < 10 ) {
		if ( (*p) <= 9 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) > 10 ) {
		if ( 11 <= (*p) )
 {			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 1802: goto tr98;
		case 2058: goto tr118;
	}
	if ( _widec > 1919 ) {
		if ( 1920 <= _widec && _widec <= 2175 )
			goto tr117;
	} else if ( _widec >= 1664 )
		goto tr97;
	goto tr85;
tr118:
	{
		s->buffer[s->buffer_length++] = 0;

		// Execute the comment callback.
		if (s->process.automatic && s->process.comment != NULL) {
			s->process.comment(s);

			// Stop if required from the callback.
			if (s->state == ZS_STATE_STOP) {
				{p++; cs = 1445; goto _out;}
			}
		}
	}
	{
		s->line_counter++;
	}
	{
		if (rdata_tail - s->r_data > UINT16_MAX) {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
		s->r_data_length = rdata_tail - s->r_data;

		s->state = ZS_STATE_DATA;

		// Execute the record callback.
		if (s->process.automatic) {
			if (s->process.record != NULL) {
				s->process.record(s);

				// Stop if required from the callback.
				if (s->state == ZS_STATE_STOP) {
					{p++; cs = 1445; goto _out;}
				}
			}
		} else {
			// Return if external processing.
			p--; {p++; cs = 1445; goto _out;}
		}
	}
	goto st1445;
tr854:
	{
		s->line_counter++;
	}
	{
		if (rdata_tail - s->r_data > UINT16_MAX) {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
		s->r_data_length = rdata_tail - s->r_data;

		s->state = ZS_STATE_DATA;

		// Execute the record callback.
		if (s->process.automatic) {
			if (s->process.record != NULL) {
				s->process.record(s);

				// Stop if required from the callback.
				if (s->state == ZS_STATE_STOP) {
					{p++; cs = 1445; goto _out;}
				}
			}
		} else {
			// Return if external processing.
			p--; {p++; cs = 1445; goto _out;}
		}
	}
	goto st1445;
tr845:
	{ s->r_type = KNOT_RRTYPE_A; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->line_counter++;
	}
	{
		s->buffer[0] = 0;
		s->buffer_length = 0;
	}
	{
		if (rdata_tail - s->r_data > UINT16_MAX) {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
		s->r_data_length = rdata_tail - s->r_data;

		s->state = ZS_STATE_DATA;

		// Execute the record callback.
		if (s->process.automatic) {
			if (s->process.record != NULL) {
				s->process.record(s);

				// Stop if required from the callback.
				if (s->state == ZS_STATE_STOP) {
					{p++; cs = 1445; goto _out;}
				}
			}
		} else {
			// Return if external processing.
			p--; {p++; cs = 1445; goto _out;}
		}
	}
	goto st1445;
st1445:
	if ( ++p == pe )
		goto _test_eof1445;
case 1445:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(2688 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 !s->multiline  ) _widec += 512;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(2688 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		if (
 !s->multiline  ) _widec += 512;
	}
	switch( _widec ) {
		case 9: goto tr4295;
		case 32: goto tr4295;
		case 36: goto tr4296;
		case 40: goto tr4297;
		case 41: goto tr4298;
		case 42: goto tr4299;
		case 58: goto tr75;
		case 92: goto tr4300;
		case 95: goto tr4299;
		case 2826: goto tr4291;
		case 2875: goto tr4292;
		case 3082: goto tr4301;
		case 3131: goto tr4302;
		case 3338: goto tr4303;
		case 3387: goto tr4304;
		case 3594: goto tr4305;
		case 3643: goto tr4306;
	}
	if ( _widec < 60 ) {
		if ( _widec < 11 ) {
			if ( _widec <= 8 )
				goto tr75;
		} else if ( _widec > 44 ) {
			if ( 45 <= _widec && _widec <= 57 )
				goto tr4299;
		} else
			goto tr75;
	} else if ( _widec > 63 ) {
		if ( _widec < 91 ) {
			if ( 64 <= _widec && _widec <= 90 )
				goto tr4299;
		} else if ( _widec > 96 ) {
			if ( _widec > 122 ) {
				if ( 123 <= _widec )
					goto tr75;
			} else if ( _widec >= 97 )
				goto tr4299;
		} else
			goto tr75;
	} else
		goto tr75;
	goto tr889;
tr121:
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st14;
tr122:
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st14;
tr4295:
	{
		if (s->r_owner_length == 0) {
			WARN(ZS_BAD_PREVIOUS_OWNER);
			p--; {goto st316;}
		}
	}
	{
		s->buffer[0] = 0;
		s->buffer_length = 0;
	}
	goto st14;
tr4297:
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	{
		if (s->r_owner_length == 0) {
			WARN(ZS_BAD_PREVIOUS_OWNER);
			p--; {goto st316;}
		}
	}
	{
		s->buffer[0] = 0;
		s->buffer_length = 0;
	}
	goto st14;
tr4298:
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	{
		if (s->r_owner_length == 0) {
			WARN(ZS_BAD_PREVIOUS_OWNER);
			p--; {goto st316;}
		}
	}
	{
		s->buffer[0] = 0;
		s->buffer_length = 0;
	}
	goto st14;
st14:
	if ( ++p == pe )
		goto _test_eof14;
case 14:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(2688 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 !s->multiline  ) _widec += 512;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(2688 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		if (
 !s->multiline  ) _widec += 512;
	}
	switch( _widec ) {
		case 9: goto st14;
		case 32: goto st14;
		case 40: goto tr121;
		case 41: goto tr122;
		case 58: goto tr75;
		case 65: goto tr124;
		case 67: goto tr125;
		case 68: goto tr126;
		case 69: goto tr127;
		case 72: goto tr128;
		case 73: goto tr129;
		case 75: goto tr130;
		case 76: goto tr131;
		case 77: goto tr132;
		case 78: goto tr133;
		case 79: goto tr134;
		case 80: goto tr135;
		case 82: goto tr136;
		case 83: goto tr137;
		case 84: goto tr138;
		case 85: goto tr139;
		case 87: goto tr140;
		case 90: goto tr141;
		case 92: goto tr80;
		case 97: goto tr124;
		case 99: goto tr125;
		case 100: goto tr126;
		case 101: goto tr127;
		case 104: goto tr128;
		case 105: goto tr129;
		case 107: goto tr130;
		case 108: goto tr131;
		case 109: goto tr132;
		case 110: goto tr133;
		case 111: goto tr134;
		case 112: goto tr135;
		case 114: goto tr136;
		case 115: goto tr137;
		case 116: goto tr138;
		case 117: goto tr139;
		case 119: goto tr140;
		case 122: goto tr141;
		case 2826: goto tr23;
		case 2875: goto tr24;
		case 3082: goto tr142;
		case 3131: goto tr143;
		case 3338: goto tr144;
		case 3387: goto tr145;
		case 3594: goto tr146;
		case 3643: goto tr147;
	}
	if ( _widec < 11 ) {
		if ( _widec <= 8 )
			goto tr75;
	} else if ( _widec > 47 ) {
		if ( _widec > 57 ) {
			if ( 60 <= _widec )
				goto tr75;
		} else if ( _widec >= 48 )
			goto tr123;
	} else
		goto tr75;
	goto tr120;
tr123:
	{
		s->number64 = 0;
	}
	{
		// Overflow check: 10*(s->number64) + fc - '0' <= UINT64_MAX
		if ((s->number64 < (UINT64_MAX / 10)) ||   // Dominant fast check.
			((s->number64 == (UINT64_MAX / 10)) && // Marginal case.
			 ((uint8_t)(*p) <= (UINT64_MAX % 10) + '0')
			)
		   ) {
			s->number64 *= 10;
			s->number64 += digit_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_NUMBER64_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 15;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 15;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 15;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 15;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 15;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 15;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 15;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 15;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 15;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 15;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 15;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 15;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 15;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 15;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 15;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 15;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 15;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 15;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 15;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 15;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 15;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 15;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 15;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 15;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 15;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 15;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 15;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 15;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 15;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 15;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 15;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 15;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	goto st15;
st15:
	if ( ++p == pe )
		goto _test_eof15;
case 15:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr149;
		case 32: goto tr149;
		case 40: goto tr150;
		case 41: goto tr151;
		case 68: goto tr32;
		case 72: goto tr33;
		case 77: goto tr34;
		case 83: goto st204;
		case 87: goto tr36;
		case 100: goto tr32;
		case 104: goto tr33;
		case 109: goto tr34;
		case 115: goto st204;
		case 119: goto tr36;
		case 1802: goto tr89;
		case 1851: goto tr90;
		case 2058: goto tr152;
		case 2107: goto tr153;
	}
	if ( 48 <= _widec && _widec <= 57 )
		goto tr31;
	goto tr148;
tr156:
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st16;
tr157:
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st16;
tr149:
	{
		if (s->number64 <= UINT32_MAX) {
			s->r_ttl = (uint32_t)(s->number64);
		} else {
			WARN(ZS_NUMBER32_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		s->buffer[0] = 0;
		s->buffer_length = 0;
	}
	goto st16;
tr150:
	{
		if (s->number64 <= UINT32_MAX) {
			s->r_ttl = (uint32_t)(s->number64);
		} else {
			WARN(ZS_NUMBER32_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	{
		s->buffer[0] = 0;
		s->buffer_length = 0;
	}
	goto st16;
tr151:
	{
		if (s->number64 <= UINT32_MAX) {
			s->r_ttl = (uint32_t)(s->number64);
		} else {
			WARN(ZS_NUMBER32_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	{
		s->buffer[0] = 0;
		s->buffer_length = 0;
	}
	goto st16;
st16:
	if ( ++p == pe )
		goto _test_eof16;
case 16:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto st16;
		case 32: goto st16;
		case 40: goto tr156;
		case 41: goto tr157;
		case 65: goto tr43;
		case 67: goto tr44;
		case 68: goto tr45;
		case 69: goto tr46;
		case 72: goto tr47;
		case 73: goto tr48;
		case 75: goto tr49;
		case 76: goto tr50;
		case 77: goto tr51;
		case 78: goto tr52;
		case 79: goto tr53;
		case 80: goto tr54;
		case 82: goto tr55;
		case 83: goto tr56;
		case 84: goto tr57;
		case 85: goto tr58;
		case 87: goto tr59;
		case 90: goto tr60;
		case 97: goto tr43;
		case 99: goto tr44;
		case 100: goto tr45;
		case 101: goto tr46;
		case 104: goto tr47;
		case 105: goto tr48;
		case 107: goto tr49;
		case 108: goto tr50;
		case 109: goto tr51;
		case 110: goto tr52;
		case 111: goto tr53;
		case 112: goto tr54;
		case 114: goto tr55;
		case 115: goto tr56;
		case 116: goto tr57;
		case 117: goto tr58;
		case 119: goto tr59;
		case 122: goto tr60;
		case 1802: goto tr95;
		case 1851: goto tr96;
		case 2058: goto tr158;
		case 2107: goto tr159;
	}
	goto tr154;
tr6:
	{
		s->r_class = s->default_class;
	}
	{
		s->r_ttl = s->default_ttl;
	}
	goto st17;
tr44:
	{
		s->r_class = s->default_class;
	}
	goto st17;
tr726:
	{
		s->r_ttl = s->default_ttl;
	}
	goto st17;
st17:
	if ( ++p == pe )
		goto _test_eof17;
case 17:
	switch( (*p) ) {
		case 65: goto st18;
		case 68: goto st22;
		case 69: goto st29;
		case 78: goto st32;
		case 83: goto st36;
		case 97: goto st18;
		case 100: goto st22;
		case 101: goto st29;
		case 110: goto st32;
		case 115: goto st36;
	}
	goto tr39;
st18:
	if ( ++p == pe )
		goto _test_eof18;
case 18:
	switch( (*p) ) {
		case 65: goto st19;
		case 97: goto st19;
	}
	goto tr39;
st19:
	if ( ++p == pe )
		goto _test_eof19;
case 19:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(2688 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 !s->multiline  ) _widec += 512;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(2688 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		if (
 !s->multiline  ) _widec += 512;
	}
	switch( _widec ) {
		case 9: goto tr166;
		case 32: goto tr166;
		case 40: goto tr167;
		case 41: goto tr168;
		case 3082: goto tr169;
		case 3131: goto tr170;
		case 3338: goto tr171;
		case 3387: goto tr171;
		case 3594: goto tr172;
		case 3643: goto tr173;
	}
	goto tr63;
tr74:
	{ s->r_type = KNOT_RRTYPE_A; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->buffer_length = 0;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 20;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 20;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 20;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 20;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 20;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 20;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 20;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 20;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 20;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 20;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 20;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 20;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 20;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 20;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 20;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 20;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 20;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 20;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 20;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 20;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 20;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 20;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 20;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 20;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 20;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 20;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 20;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 20;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 20;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 20;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 20;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 20;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	goto st20;
tr84:
	{
		s->buffer_length = 0;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 20;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 20;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 20;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 20;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 20;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 20;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 20;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 20;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 20;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 20;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 20;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 20;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 20;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 20;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 20;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 20;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 20;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 20;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 20;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 20;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 20;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 20;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 20;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 20;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 20;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 20;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 20;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 20;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 20;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 20;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 20;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 20;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	goto st20;
tr173:
	{ s->r_type = KNOT_RRTYPE_CAA; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->buffer_length = 0;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 20;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 20;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 20;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 20;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 20;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 20;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 20;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 20;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 20;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 20;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 20;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 20;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 20;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 20;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 20;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 20;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 20;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 20;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 20;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 20;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 20;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 20;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 20;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 20;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 20;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 20;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 20;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 20;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 20;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 20;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 20;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 20;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	goto st20;
tr195:
	{ s->r_type = KNOT_RRTYPE_CDNSKEY; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->buffer_length = 0;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 20;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 20;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 20;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 20;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 20;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 20;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 20;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 20;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 20;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 20;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 20;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 20;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 20;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 20;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 20;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 20;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 20;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 20;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 20;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 20;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 20;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 20;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 20;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 20;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 20;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 20;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 20;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 20;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 20;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 20;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 20;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 20;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	goto st20;
tr203:
	{ s->r_type = KNOT_RRTYPE_CDS; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->buffer_length = 0;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 20;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 20;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 20;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 20;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 20;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 20;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 20;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 20;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 20;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 20;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 20;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 20;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 20;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 20;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 20;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 20;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 20;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 20;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 20;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 20;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 20;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 20;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 20;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 20;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 20;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 20;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 20;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 20;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 20;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 20;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 20;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 20;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	goto st20;
tr213:
	{ s->r_type = KNOT_RRTYPE_CERT; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->buffer_length = 0;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 20;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 20;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 20;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 20;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 20;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 20;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 20;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 20;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 20;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 20;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 20;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 20;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 20;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 20;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 20;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 20;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 20;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 20;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 20;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 20;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 20;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 20;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 20;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 20;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 20;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 20;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 20;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 20;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 20;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 20;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 20;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 20;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	goto st20;
tr224:
	{ s->r_type = KNOT_RRTYPE_CNAME; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->buffer_length = 0;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 20;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 20;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 20;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 20;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 20;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 20;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 20;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 20;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 20;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 20;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 20;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 20;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 20;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 20;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 20;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 20;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 20;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 20;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 20;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 20;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 20;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 20;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 20;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 20;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 20;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 20;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 20;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 20;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 20;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 20;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 20;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 20;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	goto st20;
tr235:
	{ s->r_type = KNOT_RRTYPE_CSYNC; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->buffer_length = 0;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 20;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 20;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 20;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 20;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 20;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 20;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 20;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 20;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 20;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 20;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 20;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 20;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 20;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 20;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 20;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 20;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 20;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 20;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 20;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 20;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 20;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 20;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 20;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 20;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 20;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 20;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 20;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 20;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 20;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 20;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 20;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 20;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	goto st20;
tr249:
	{ s->r_type = KNOT_RRTYPE_DHCID; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->buffer_length = 0;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 20;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 20;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 20;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 20;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 20;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 20;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 20;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 20;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 20;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 20;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 20;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 20;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 20;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 20;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 20;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 20;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 20;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 20;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 20;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 20;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 20;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 20;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 20;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 20;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 20;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 20;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 20;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 20;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 20;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 20;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 20;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 20;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	goto st20;
tr261:
	{ s->r_type = KNOT_RRTYPE_DNAME; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->buffer_length = 0;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 20;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 20;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 20;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 20;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 20;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 20;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 20;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 20;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 20;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 20;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 20;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 20;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 20;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 20;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 20;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 20;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 20;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 20;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 20;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 20;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 20;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 20;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 20;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 20;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 20;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 20;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 20;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 20;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 20;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 20;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 20;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 20;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	goto st20;
tr272:
	{ s->r_type = KNOT_RRTYPE_DNSKEY; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->buffer_length = 0;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 20;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 20;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 20;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 20;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 20;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 20;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 20;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 20;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 20;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 20;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 20;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 20;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 20;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 20;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 20;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 20;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 20;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 20;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 20;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 20;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 20;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 20;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 20;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 20;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 20;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 20;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 20;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 20;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 20;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 20;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 20;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 20;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	goto st20;
tr280:
	{ s->r_type = KNOT_RRTYPE_DS; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->buffer_length = 0;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 20;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 20;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 20;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 20;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 20;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 20;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 20;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 20;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 20;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 20;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 20;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 20;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 20;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 20;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 20;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 20;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 20;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 20;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 20;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 20;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 20;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 20;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 20;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 20;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 20;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 20;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 20;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 20;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 20;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 20;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 20;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 20;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	goto st20;
tr293:
	{ s->r_type = KNOT_RRTYPE_EUI48; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->buffer_length = 0;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 20;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 20;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 20;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 20;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 20;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 20;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 20;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 20;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 20;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 20;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 20;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 20;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 20;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 20;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 20;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 20;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 20;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 20;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 20;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 20;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 20;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 20;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 20;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 20;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 20;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 20;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 20;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 20;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 20;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 20;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 20;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 20;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	goto st20;
tr302:
	{ s->r_type = KNOT_RRTYPE_EUI64; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->buffer_length = 0;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 20;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 20;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 20;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 20;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 20;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 20;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 20;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 20;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 20;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 20;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 20;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 20;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 20;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 20;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 20;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 20;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 20;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 20;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 20;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 20;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 20;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 20;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 20;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 20;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 20;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 20;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 20;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 20;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 20;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 20;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 20;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 20;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	goto st20;
tr315:
	{ s->r_type = KNOT_RRTYPE_HINFO; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->buffer_length = 0;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 20;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 20;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 20;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 20;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 20;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 20;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 20;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 20;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 20;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 20;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 20;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 20;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 20;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 20;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 20;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 20;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 20;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 20;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 20;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 20;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 20;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 20;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 20;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 20;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 20;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 20;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 20;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 20;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 20;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 20;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 20;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 20;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	goto st20;
tr326:
	{ s->r_type = KNOT_RRTYPE_HTTPS; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->buffer_length = 0;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 20;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 20;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 20;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 20;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 20;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 20;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 20;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 20;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 20;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 20;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 20;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 20;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 20;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 20;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 20;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 20;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 20;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 20;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 20;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 20;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 20;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 20;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 20;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 20;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 20;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 20;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 20;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 20;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 20;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 20;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 20;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 20;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	goto st20;
tr370:
	{ s->r_type = KNOT_RRTYPE_IPSECKEY; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->buffer_length = 0;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 20;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 20;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 20;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 20;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 20;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 20;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 20;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 20;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 20;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 20;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 20;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 20;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 20;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 20;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 20;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 20;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 20;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 20;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 20;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 20;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 20;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 20;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 20;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 20;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 20;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 20;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 20;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 20;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 20;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 20;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 20;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 20;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	goto st20;
tr381:
	{ s->r_type = KNOT_RRTYPE_KEY; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->buffer_length = 0;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 20;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 20;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 20;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 20;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 20;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 20;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 20;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 20;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 20;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 20;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 20;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 20;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 20;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 20;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 20;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 20;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 20;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 20;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 20;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 20;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 20;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 20;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 20;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 20;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 20;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 20;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 20;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 20;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 20;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 20;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 20;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 20;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	goto st20;
tr389:
	{ s->r_type = KNOT_RRTYPE_KX; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->buffer_length = 0;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 20;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 20;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 20;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 20;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 20;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 20;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 20;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 20;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 20;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 20;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 20;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 20;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 20;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 20;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 20;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 20;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 20;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 20;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 20;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 20;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 20;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 20;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 20;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 20;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 20;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 20;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 20;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 20;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 20;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 20;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 20;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 20;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	goto st20;
tr402:
	{ s->r_type = KNOT_RRTYPE_L32; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->buffer_length = 0;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 20;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 20;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 20;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 20;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 20;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 20;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 20;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 20;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 20;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 20;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 20;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 20;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 20;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 20;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 20;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 20;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 20;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 20;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 20;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 20;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 20;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 20;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 20;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 20;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 20;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 20;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 20;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 20;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 20;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 20;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 20;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 20;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	goto st20;
tr411:
	{ s->r_type = KNOT_RRTYPE_L64; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->buffer_length = 0;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 20;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 20;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 20;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 20;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 20;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 20;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 20;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 20;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 20;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 20;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 20;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 20;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 20;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 20;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 20;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 20;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 20;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 20;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 20;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 20;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 20;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 20;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 20;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 20;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 20;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 20;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 20;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 20;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 20;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 20;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 20;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 20;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	goto st20;
tr420:
	{ s->r_type = KNOT_RRTYPE_LOC; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->buffer_length = 0;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 20;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 20;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 20;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 20;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 20;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 20;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 20;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 20;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 20;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 20;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 20;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 20;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 20;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 20;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 20;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 20;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 20;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 20;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 20;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 20;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 20;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 20;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 20;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 20;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 20;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 20;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 20;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 20;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 20;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 20;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 20;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 20;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	goto st20;
tr428:
	{ s->r_type = KNOT_RRTYPE_LP; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->buffer_length = 0;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 20;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 20;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 20;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 20;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 20;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 20;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 20;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 20;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 20;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 20;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 20;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 20;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 20;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 20;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 20;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 20;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 20;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 20;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 20;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 20;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 20;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 20;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 20;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 20;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 20;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 20;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 20;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 20;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 20;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 20;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 20;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 20;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	goto st20;
tr441:
	{ s->r_type = KNOT_RRTYPE_MINFO; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->buffer_length = 0;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 20;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 20;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 20;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 20;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 20;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 20;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 20;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 20;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 20;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 20;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 20;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 20;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 20;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 20;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 20;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 20;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 20;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 20;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 20;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 20;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 20;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 20;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 20;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 20;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 20;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 20;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 20;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 20;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 20;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 20;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 20;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 20;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	goto st20;
tr449:
	{ s->r_type = KNOT_RRTYPE_MX; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->buffer_length = 0;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 20;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 20;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 20;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 20;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 20;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 20;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 20;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 20;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 20;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 20;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 20;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 20;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 20;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 20;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 20;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 20;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 20;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 20;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 20;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 20;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 20;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 20;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 20;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 20;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 20;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 20;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 20;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 20;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 20;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 20;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 20;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 20;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	goto st20;
tr463:
	{ s->r_type = KNOT_RRTYPE_NAPTR; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->buffer_length = 0;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 20;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 20;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 20;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 20;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 20;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 20;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 20;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 20;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 20;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 20;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 20;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 20;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 20;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 20;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 20;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 20;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 20;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 20;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 20;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 20;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 20;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 20;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 20;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 20;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 20;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 20;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 20;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 20;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 20;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 20;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 20;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 20;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	goto st20;
tr472:
	{ s->r_type = KNOT_RRTYPE_NID; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->buffer_length = 0;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 20;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 20;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 20;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 20;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 20;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 20;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 20;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 20;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 20;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 20;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 20;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 20;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 20;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 20;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 20;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 20;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 20;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 20;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 20;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 20;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 20;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 20;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 20;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 20;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 20;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 20;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 20;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 20;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 20;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 20;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 20;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 20;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	goto st20;
tr481:
	{ s->r_type = KNOT_RRTYPE_NS; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->buffer_length = 0;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 20;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 20;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 20;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 20;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 20;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 20;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 20;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 20;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 20;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 20;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 20;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 20;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 20;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 20;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 20;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 20;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 20;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 20;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 20;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 20;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 20;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 20;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 20;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 20;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 20;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 20;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 20;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 20;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 20;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 20;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 20;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 20;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	goto st20;
tr491:
	{ s->r_type = KNOT_RRTYPE_NSEC; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->buffer_length = 0;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 20;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 20;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 20;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 20;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 20;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 20;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 20;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 20;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 20;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 20;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 20;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 20;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 20;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 20;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 20;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 20;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 20;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 20;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 20;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 20;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 20;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 20;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 20;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 20;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 20;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 20;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 20;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 20;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 20;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 20;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 20;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 20;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	goto st20;
tr500:
	{ s->r_type = KNOT_RRTYPE_NSEC3; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->buffer_length = 0;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 20;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 20;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 20;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 20;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 20;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 20;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 20;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 20;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 20;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 20;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 20;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 20;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 20;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 20;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 20;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 20;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 20;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 20;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 20;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 20;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 20;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 20;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 20;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 20;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 20;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 20;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 20;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 20;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 20;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 20;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 20;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 20;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	goto st20;
tr512:
	{ s->r_type = KNOT_RRTYPE_NSEC3PARAM; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->buffer_length = 0;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 20;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 20;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 20;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 20;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 20;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 20;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 20;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 20;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 20;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 20;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 20;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 20;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 20;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 20;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 20;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 20;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 20;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 20;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 20;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 20;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 20;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 20;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 20;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 20;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 20;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 20;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 20;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 20;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 20;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 20;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 20;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 20;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	goto st20;
tr529:
	{ s->r_type = KNOT_RRTYPE_OPENPGPKEY; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->buffer_length = 0;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 20;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 20;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 20;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 20;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 20;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 20;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 20;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 20;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 20;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 20;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 20;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 20;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 20;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 20;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 20;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 20;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 20;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 20;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 20;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 20;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 20;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 20;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 20;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 20;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 20;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 20;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 20;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 20;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 20;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 20;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 20;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 20;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	goto st20;
tr539:
	{ s->r_type = KNOT_RRTYPE_PTR; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->buffer_length = 0;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 20;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 20;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 20;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 20;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 20;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 20;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 20;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 20;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 20;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 20;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 20;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 20;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 20;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 20;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 20;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 20;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 20;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 20;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 20;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 20;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 20;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 20;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 20;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 20;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 20;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 20;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 20;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 20;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 20;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 20;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 20;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 20;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	goto st20;
tr550:
	{ s->r_type = KNOT_RRTYPE_RP; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->buffer_length = 0;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 20;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 20;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 20;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 20;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 20;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 20;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 20;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 20;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 20;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 20;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 20;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 20;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 20;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 20;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 20;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 20;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 20;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 20;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 20;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 20;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 20;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 20;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 20;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 20;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 20;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 20;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 20;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 20;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 20;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 20;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 20;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 20;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	goto st20;
tr561:
	{ s->r_type = KNOT_RRTYPE_RRSIG; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->buffer_length = 0;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 20;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 20;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 20;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 20;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 20;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 20;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 20;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 20;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 20;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 20;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 20;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 20;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 20;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 20;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 20;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 20;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 20;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 20;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 20;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 20;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 20;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 20;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 20;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 20;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 20;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 20;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 20;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 20;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 20;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 20;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 20;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 20;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	goto st20;
tr569:
	{ s->r_type = KNOT_RRTYPE_RT; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->buffer_length = 0;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 20;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 20;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 20;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 20;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 20;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 20;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 20;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 20;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 20;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 20;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 20;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 20;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 20;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 20;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 20;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 20;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 20;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 20;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 20;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 20;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 20;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 20;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 20;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 20;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 20;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 20;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 20;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 20;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 20;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 20;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 20;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 20;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	goto st20;
tr587:
	{ s->r_type = KNOT_RRTYPE_SMIMEA; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->buffer_length = 0;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 20;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 20;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 20;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 20;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 20;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 20;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 20;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 20;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 20;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 20;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 20;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 20;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 20;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 20;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 20;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 20;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 20;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 20;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 20;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 20;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 20;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 20;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 20;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 20;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 20;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 20;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 20;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 20;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 20;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 20;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 20;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 20;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	goto st20;
tr596:
	{ s->r_type = KNOT_RRTYPE_SOA; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->buffer_length = 0;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 20;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 20;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 20;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 20;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 20;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 20;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 20;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 20;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 20;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 20;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 20;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 20;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 20;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 20;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 20;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 20;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 20;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 20;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 20;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 20;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 20;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 20;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 20;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 20;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 20;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 20;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 20;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 20;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 20;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 20;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 20;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 20;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	goto st20;
tr605:
	{ s->r_type = KNOT_RRTYPE_SPF; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->buffer_length = 0;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 20;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 20;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 20;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 20;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 20;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 20;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 20;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 20;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 20;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 20;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 20;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 20;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 20;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 20;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 20;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 20;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 20;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 20;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 20;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 20;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 20;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 20;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 20;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 20;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 20;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 20;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 20;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 20;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 20;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 20;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 20;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 20;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	goto st20;
tr614:
	{ s->r_type = KNOT_RRTYPE_SRV; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->buffer_length = 0;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 20;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 20;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 20;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 20;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 20;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 20;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 20;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 20;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 20;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 20;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 20;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 20;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 20;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 20;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 20;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 20;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 20;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 20;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 20;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 20;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 20;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 20;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 20;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 20;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 20;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 20;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 20;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 20;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 20;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 20;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 20;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 20;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	goto st20;
tr625:
	{ s->r_type = KNOT_RRTYPE_SSHFP; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->buffer_length = 0;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 20;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 20;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 20;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 20;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 20;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 20;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 20;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 20;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 20;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 20;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 20;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 20;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 20;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 20;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 20;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 20;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 20;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 20;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 20;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 20;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 20;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 20;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 20;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 20;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 20;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 20;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 20;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 20;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 20;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 20;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 20;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 20;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	goto st20;
tr635:
	{ s->r_type = KNOT_RRTYPE_SVCB; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->buffer_length = 0;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 20;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 20;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 20;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 20;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 20;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 20;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 20;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 20;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 20;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 20;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 20;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 20;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 20;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 20;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 20;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 20;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 20;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 20;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 20;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 20;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 20;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 20;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 20;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 20;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 20;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 20;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 20;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 20;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 20;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 20;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 20;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 20;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	goto st20;
tr648:
	{ s->r_type = KNOT_RRTYPE_TLSA; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->buffer_length = 0;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 20;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 20;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 20;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 20;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 20;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 20;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 20;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 20;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 20;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 20;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 20;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 20;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 20;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 20;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 20;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 20;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 20;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 20;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 20;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 20;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 20;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 20;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 20;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 20;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 20;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 20;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 20;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 20;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 20;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 20;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 20;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 20;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	goto st20;
tr657:
	{ s->r_type = KNOT_RRTYPE_TXT; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->buffer_length = 0;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 20;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 20;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 20;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 20;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 20;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 20;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 20;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 20;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 20;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 20;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 20;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 20;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 20;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 20;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 20;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 20;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 20;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 20;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 20;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 20;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 20;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 20;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 20;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 20;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 20;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 20;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 20;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 20;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 20;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 20;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 20;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 20;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	goto st20;
tr671:
	{
		if (s->number64 <= UINT16_MAX) {
			s->r_type = (uint16_t)(s->number64);
		} else {
			WARN(ZS_NUMBER16_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		rdata_tail = s->r_data;
	}
	{
		s->buffer_length = 0;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 20;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 20;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 20;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 20;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 20;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 20;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 20;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 20;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 20;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 20;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 20;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 20;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 20;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 20;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 20;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 20;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 20;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 20;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 20;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 20;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 20;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 20;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 20;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 20;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 20;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 20;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 20;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 20;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 20;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 20;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 20;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 20;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	goto st20;
tr681:
	{ s->r_type = KNOT_RRTYPE_URI; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->buffer_length = 0;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 20;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 20;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 20;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 20;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 20;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 20;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 20;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 20;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 20;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 20;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 20;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 20;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 20;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 20;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 20;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 20;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 20;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 20;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 20;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 20;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 20;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 20;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 20;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 20;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 20;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 20;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 20;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 20;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 20;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 20;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 20;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 20;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	goto st20;
tr694:
	{ s->r_type = KNOT_RRTYPE_WALLET; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->buffer_length = 0;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 20;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 20;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 20;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 20;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 20;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 20;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 20;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 20;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 20;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 20;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 20;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 20;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 20;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 20;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 20;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 20;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 20;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 20;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 20;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 20;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 20;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 20;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 20;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 20;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 20;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 20;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 20;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 20;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 20;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 20;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 20;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 20;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	goto st20;
tr707:
	{ s->r_type = KNOT_RRTYPE_ZONEMD; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->buffer_length = 0;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 20;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 20;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 20;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 20;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 20;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 20;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 20;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 20;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 20;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 20;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 20;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 20;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 20;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 20;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 20;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 20;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 20;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 20;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 20;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 20;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 20;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 20;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 20;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 20;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 20;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 20;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 20;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 20;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 20;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 20;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 20;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 20;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	goto st20;
tr958:
	{ s->r_type = KNOT_RRTYPE_AAAA; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->buffer_length = 0;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 20;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 20;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 20;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 20;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 20;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 20;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 20;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 20;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 20;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 20;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 20;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 20;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 20;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 20;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 20;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 20;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 20;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 20;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 20;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 20;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 20;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 20;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 20;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 20;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 20;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 20;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 20;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 20;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 20;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 20;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 20;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 20;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	goto st20;
tr969:
	{ s->r_type = KNOT_RRTYPE_AFSDB; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->buffer_length = 0;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 20;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 20;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 20;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 20;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 20;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 20;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 20;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 20;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 20;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 20;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 20;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 20;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 20;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 20;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 20;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 20;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 20;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 20;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 20;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 20;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 20;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 20;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 20;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 20;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 20;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 20;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 20;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 20;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 20;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 20;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 20;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 20;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	goto st20;
tr978:
	{ s->r_type = KNOT_RRTYPE_APL; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->buffer_length = 0;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 20;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 20;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 20;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 20;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 20;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 20;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 20;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 20;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 20;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 20;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 20;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 20;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 20;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 20;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 20;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 20;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 20;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 20;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 20;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 20;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 20;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 20;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 20;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 20;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 20;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 20;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 20;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 20;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 20;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 20;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 20;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 20;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	goto st20;
st20:
	if ( ++p == pe )
		goto _test_eof20;
case 20:
	_widec = (*p);
	if ( (*p) < 11 ) {
		if ( (*p) > 9 ) {
			if ( 10 <= (*p) && (*p) <= 10 ) {
				_widec = (short)(1664 + ((*p) - -128));
				if (
 s->multiline  ) _widec += 256;
			}
		} else {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) > 58 ) {
		if ( (*p) > 59 ) {
			if ( 60 <= (*p) )
 {				_widec = (short)(1664 + ((*p) - -128));
				if (
 s->multiline  ) _widec += 256;
			}
		} else if ( (*p) >= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 1801: goto tr86;
		case 1802: goto tr89;
		case 1824: goto tr86;
		case 1832: goto tr87;
		case 1833: goto tr88;
		case 1851: goto tr90;
		case 2057: goto tr174;
		case 2058: goto tr89;
		case 2080: goto tr174;
		case 2088: goto tr175;
		case 2089: goto tr176;
		case 2107: goto tr177;
	}
	if ( 1920 <= _widec && _widec <= 2175 )
		goto tr101;
	goto tr85;
tr178:
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		}
	}
	goto st21;
tr174:
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		}
	}
	{
		s->buffer[0] = 0;
		s->buffer_length = 0;
	}
	goto st21;
tr175:
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		}
	}
	{
		s->buffer[0] = 0;
		s->buffer_length = 0;
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st21;
tr176:
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		}
	}
	{
		s->buffer[0] = 0;
		s->buffer_length = 0;
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st21;
tr179:
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		}
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st21;
tr180:
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		}
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st21;
st21:
	if ( ++p == pe )
		goto _test_eof21;
case 21:
	_widec = (*p);
	if ( (*p) < 11 ) {
		if ( (*p) > 9 ) {
			if ( 10 <= (*p) && (*p) <= 10 ) {
				_widec = (short)(1664 + ((*p) - -128));
				if (
 s->multiline  ) _widec += 256;
			}
		} else {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) > 58 ) {
		if ( (*p) > 59 ) {
			if ( 60 <= (*p) )
 {				_widec = (short)(1664 + ((*p) - -128));
				if (
 s->multiline  ) _widec += 256;
			}
		} else if ( (*p) >= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 1801: goto st7;
		case 1802: goto tr95;
		case 1824: goto st7;
		case 1832: goto tr93;
		case 1833: goto tr94;
		case 1851: goto tr96;
		case 2057: goto tr178;
		case 2058: goto tr95;
		case 2080: goto tr178;
		case 2088: goto tr179;
		case 2089: goto tr180;
		case 2107: goto tr181;
	}
	if ( 1920 <= _widec && _widec <= 2175 )
		goto tr101;
	goto tr85;
st22:
	if ( ++p == pe )
		goto _test_eof22;
case 22:
	switch( (*p) ) {
		case 78: goto st23;
		case 83: goto st28;
		case 110: goto st23;
		case 115: goto st28;
	}
	goto tr39;
st23:
	if ( ++p == pe )
		goto _test_eof23;
case 23:
	switch( (*p) ) {
		case 83: goto st24;
		case 115: goto st24;
	}
	goto tr39;
st24:
	if ( ++p == pe )
		goto _test_eof24;
case 24:
	switch( (*p) ) {
		case 75: goto st25;
		case 107: goto st25;
	}
	goto tr39;
st25:
	if ( ++p == pe )
		goto _test_eof25;
case 25:
	switch( (*p) ) {
		case 69: goto st26;
		case 101: goto st26;
	}
	goto tr39;
st26:
	if ( ++p == pe )
		goto _test_eof26;
case 26:
	switch( (*p) ) {
		case 89: goto st27;
		case 121: goto st27;
	}
	goto tr39;
st27:
	if ( ++p == pe )
		goto _test_eof27;
case 27:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(2688 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 !s->multiline  ) _widec += 512;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(2688 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		if (
 !s->multiline  ) _widec += 512;
	}
	switch( _widec ) {
		case 9: goto tr188;
		case 32: goto tr188;
		case 40: goto tr189;
		case 41: goto tr190;
		case 3082: goto tr191;
		case 3131: goto tr192;
		case 3338: goto tr193;
		case 3387: goto tr193;
		case 3594: goto tr194;
		case 3643: goto tr195;
	}
	goto tr63;
st28:
	if ( ++p == pe )
		goto _test_eof28;
case 28:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(2688 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 !s->multiline  ) _widec += 512;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(2688 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		if (
 !s->multiline  ) _widec += 512;
	}
	switch( _widec ) {
		case 9: goto tr196;
		case 32: goto tr196;
		case 40: goto tr197;
		case 41: goto tr198;
		case 3082: goto tr199;
		case 3131: goto tr200;
		case 3338: goto tr201;
		case 3387: goto tr201;
		case 3594: goto tr202;
		case 3643: goto tr203;
	}
	goto tr63;
st29:
	if ( ++p == pe )
		goto _test_eof29;
case 29:
	switch( (*p) ) {
		case 82: goto st30;
		case 114: goto st30;
	}
	goto tr39;
st30:
	if ( ++p == pe )
		goto _test_eof30;
case 30:
	switch( (*p) ) {
		case 84: goto st31;
		case 116: goto st31;
	}
	goto tr39;
st31:
	if ( ++p == pe )
		goto _test_eof31;
case 31:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(2688 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 !s->multiline  ) _widec += 512;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(2688 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		if (
 !s->multiline  ) _widec += 512;
	}
	switch( _widec ) {
		case 9: goto tr206;
		case 32: goto tr206;
		case 40: goto tr207;
		case 41: goto tr208;
		case 3082: goto tr209;
		case 3131: goto tr210;
		case 3338: goto tr211;
		case 3387: goto tr211;
		case 3594: goto tr212;
		case 3643: goto tr213;
	}
	goto tr63;
st32:
	if ( ++p == pe )
		goto _test_eof32;
case 32:
	switch( (*p) ) {
		case 65: goto st33;
		case 97: goto st33;
	}
	goto tr39;
st33:
	if ( ++p == pe )
		goto _test_eof33;
case 33:
	switch( (*p) ) {
		case 77: goto st34;
		case 109: goto st34;
	}
	goto tr39;
st34:
	if ( ++p == pe )
		goto _test_eof34;
case 34:
	switch( (*p) ) {
		case 69: goto st35;
		case 101: goto st35;
	}
	goto tr39;
st35:
	if ( ++p == pe )
		goto _test_eof35;
case 35:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(2688 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 !s->multiline  ) _widec += 512;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(2688 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		if (
 !s->multiline  ) _widec += 512;
	}
	switch( _widec ) {
		case 9: goto tr217;
		case 32: goto tr217;
		case 40: goto tr218;
		case 41: goto tr219;
		case 3082: goto tr220;
		case 3131: goto tr221;
		case 3338: goto tr222;
		case 3387: goto tr222;
		case 3594: goto tr223;
		case 3643: goto tr224;
	}
	goto tr63;
st36:
	if ( ++p == pe )
		goto _test_eof36;
case 36:
	switch( (*p) ) {
		case 89: goto st37;
		case 121: goto st37;
	}
	goto tr39;
st37:
	if ( ++p == pe )
		goto _test_eof37;
case 37:
	switch( (*p) ) {
		case 78: goto st38;
		case 110: goto st38;
	}
	goto tr39;
st38:
	if ( ++p == pe )
		goto _test_eof38;
case 38:
	switch( (*p) ) {
		case 67: goto st39;
		case 99: goto st39;
	}
	goto tr39;
st39:
	if ( ++p == pe )
		goto _test_eof39;
case 39:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(2688 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 !s->multiline  ) _widec += 512;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(2688 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		if (
 !s->multiline  ) _widec += 512;
	}
	switch( _widec ) {
		case 9: goto tr228;
		case 32: goto tr228;
		case 40: goto tr229;
		case 41: goto tr230;
		case 3082: goto tr231;
		case 3131: goto tr232;
		case 3338: goto tr233;
		case 3387: goto tr233;
		case 3594: goto tr234;
		case 3643: goto tr235;
	}
	goto tr63;
tr7:
	{
		s->r_class = s->default_class;
	}
	{
		s->r_ttl = s->default_ttl;
	}
	goto st40;
tr45:
	{
		s->r_class = s->default_class;
	}
	goto st40;
tr727:
	{
		s->r_ttl = s->default_ttl;
	}
	goto st40;
st40:
	if ( ++p == pe )
		goto _test_eof40;
case 40:
	switch( (*p) ) {
		case 72: goto st41;
		case 78: goto st45;
		case 83: goto st53;
		case 104: goto st41;
		case 110: goto st45;
		case 115: goto st53;
	}
	goto tr39;
st41:
	if ( ++p == pe )
		goto _test_eof41;
case 41:
	switch( (*p) ) {
		case 67: goto st42;
		case 99: goto st42;
	}
	goto tr39;
st42:
	if ( ++p == pe )
		goto _test_eof42;
case 42:
	switch( (*p) ) {
		case 73: goto st43;
		case 105: goto st43;
	}
	goto tr39;
st43:
	if ( ++p == pe )
		goto _test_eof43;
case 43:
	switch( (*p) ) {
		case 68: goto st44;
		case 100: goto st44;
	}
	goto tr39;
st44:
	if ( ++p == pe )
		goto _test_eof44;
case 44:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(2688 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 !s->multiline  ) _widec += 512;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(2688 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		if (
 !s->multiline  ) _widec += 512;
	}
	switch( _widec ) {
		case 9: goto tr242;
		case 32: goto tr242;
		case 40: goto tr243;
		case 41: goto tr244;
		case 3082: goto tr245;
		case 3131: goto tr246;
		case 3338: goto tr247;
		case 3387: goto tr247;
		case 3594: goto tr248;
		case 3643: goto tr249;
	}
	goto tr63;
st45:
	if ( ++p == pe )
		goto _test_eof45;
case 45:
	switch( (*p) ) {
		case 65: goto st46;
		case 83: goto st49;
		case 97: goto st46;
		case 115: goto st49;
	}
	goto tr39;
st46:
	if ( ++p == pe )
		goto _test_eof46;
case 46:
	switch( (*p) ) {
		case 77: goto st47;
		case 109: goto st47;
	}
	goto tr39;
st47:
	if ( ++p == pe )
		goto _test_eof47;
case 47:
	switch( (*p) ) {
		case 69: goto st48;
		case 101: goto st48;
	}
	goto tr39;
st48:
	if ( ++p == pe )
		goto _test_eof48;
case 48:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(2688 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 !s->multiline  ) _widec += 512;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(2688 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		if (
 !s->multiline  ) _widec += 512;
	}
	switch( _widec ) {
		case 9: goto tr254;
		case 32: goto tr254;
		case 40: goto tr255;
		case 41: goto tr256;
		case 3082: goto tr257;
		case 3131: goto tr258;
		case 3338: goto tr259;
		case 3387: goto tr259;
		case 3594: goto tr260;
		case 3643: goto tr261;
	}
	goto tr63;
st49:
	if ( ++p == pe )
		goto _test_eof49;
case 49:
	switch( (*p) ) {
		case 75: goto st50;
		case 107: goto st50;
	}
	goto tr39;
st50:
	if ( ++p == pe )
		goto _test_eof50;
case 50:
	switch( (*p) ) {
		case 69: goto st51;
		case 101: goto st51;
	}
	goto tr39;
st51:
	if ( ++p == pe )
		goto _test_eof51;
case 51:
	switch( (*p) ) {
		case 89: goto st52;
		case 121: goto st52;
	}
	goto tr39;
st52:
	if ( ++p == pe )
		goto _test_eof52;
case 52:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(2688 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 !s->multiline  ) _widec += 512;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(2688 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		if (
 !s->multiline  ) _widec += 512;
	}
	switch( _widec ) {
		case 9: goto tr265;
		case 32: goto tr265;
		case 40: goto tr266;
		case 41: goto tr267;
		case 3082: goto tr268;
		case 3131: goto tr269;
		case 3338: goto tr270;
		case 3387: goto tr270;
		case 3594: goto tr271;
		case 3643: goto tr272;
	}
	goto tr63;
st53:
	if ( ++p == pe )
		goto _test_eof53;
case 53:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(2688 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 !s->multiline  ) _widec += 512;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(2688 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		if (
 !s->multiline  ) _widec += 512;
	}
	switch( _widec ) {
		case 9: goto tr273;
		case 32: goto tr273;
		case 40: goto tr274;
		case 41: goto tr275;
		case 3082: goto tr276;
		case 3131: goto tr277;
		case 3338: goto tr278;
		case 3387: goto tr278;
		case 3594: goto tr279;
		case 3643: goto tr280;
	}
	goto tr63;
tr8:
	{
		s->r_class = s->default_class;
	}
	{
		s->r_ttl = s->default_ttl;
	}
	goto st54;
tr46:
	{
		s->r_class = s->default_class;
	}
	goto st54;
tr728:
	{
		s->r_ttl = s->default_ttl;
	}
	goto st54;
st54:
	if ( ++p == pe )
		goto _test_eof54;
case 54:
	switch( (*p) ) {
		case 85: goto st55;
		case 117: goto st55;
	}
	goto tr39;
st55:
	if ( ++p == pe )
		goto _test_eof55;
case 55:
	switch( (*p) ) {
		case 73: goto st56;
		case 105: goto st56;
	}
	goto tr39;
st56:
	if ( ++p == pe )
		goto _test_eof56;
case 56:
	switch( (*p) ) {
		case 52: goto st57;
		case 54: goto st59;
	}
	goto tr39;
st57:
	if ( ++p == pe )
		goto _test_eof57;
case 57:
	if ( (*p) == 56 )
		goto st58;
	goto tr39;
st58:
	if ( ++p == pe )
		goto _test_eof58;
case 58:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(2688 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 !s->multiline  ) _widec += 512;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(2688 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		if (
 !s->multiline  ) _widec += 512;
	}
	switch( _widec ) {
		case 9: goto tr286;
		case 32: goto tr286;
		case 40: goto tr287;
		case 41: goto tr288;
		case 3082: goto tr289;
		case 3131: goto tr290;
		case 3338: goto tr291;
		case 3387: goto tr291;
		case 3594: goto tr292;
		case 3643: goto tr293;
	}
	goto tr63;
st59:
	if ( ++p == pe )
		goto _test_eof59;
case 59:
	if ( (*p) == 52 )
		goto st60;
	goto tr39;
st60:
	if ( ++p == pe )
		goto _test_eof60;
case 60:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(2688 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 !s->multiline  ) _widec += 512;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(2688 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		if (
 !s->multiline  ) _widec += 512;
	}
	switch( _widec ) {
		case 9: goto tr295;
		case 32: goto tr295;
		case 40: goto tr296;
		case 41: goto tr297;
		case 3082: goto tr298;
		case 3131: goto tr299;
		case 3338: goto tr300;
		case 3387: goto tr300;
		case 3594: goto tr301;
		case 3643: goto tr302;
	}
	goto tr63;
tr9:
	{
		s->r_class = s->default_class;
	}
	{
		s->r_ttl = s->default_ttl;
	}
	goto st61;
tr47:
	{
		s->r_class = s->default_class;
	}
	goto st61;
tr729:
	{
		s->r_ttl = s->default_ttl;
	}
	goto st61;
st61:
	if ( ++p == pe )
		goto _test_eof61;
case 61:
	switch( (*p) ) {
		case 73: goto st62;
		case 84: goto st66;
		case 105: goto st62;
		case 116: goto st66;
	}
	goto tr39;
st62:
	if ( ++p == pe )
		goto _test_eof62;
case 62:
	switch( (*p) ) {
		case 78: goto st63;
		case 110: goto st63;
	}
	goto tr39;
st63:
	if ( ++p == pe )
		goto _test_eof63;
case 63:
	switch( (*p) ) {
		case 70: goto st64;
		case 102: goto st64;
	}
	goto tr39;
st64:
	if ( ++p == pe )
		goto _test_eof64;
case 64:
	switch( (*p) ) {
		case 79: goto st65;
		case 111: goto st65;
	}
	goto tr39;
st65:
	if ( ++p == pe )
		goto _test_eof65;
case 65:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(2688 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 !s->multiline  ) _widec += 512;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(2688 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		if (
 !s->multiline  ) _widec += 512;
	}
	switch( _widec ) {
		case 9: goto tr308;
		case 32: goto tr308;
		case 40: goto tr309;
		case 41: goto tr310;
		case 3082: goto tr311;
		case 3131: goto tr312;
		case 3338: goto tr313;
		case 3387: goto tr313;
		case 3594: goto tr314;
		case 3643: goto tr315;
	}
	goto tr63;
st66:
	if ( ++p == pe )
		goto _test_eof66;
case 66:
	switch( (*p) ) {
		case 84: goto st67;
		case 116: goto st67;
	}
	goto tr39;
st67:
	if ( ++p == pe )
		goto _test_eof67;
case 67:
	switch( (*p) ) {
		case 80: goto st68;
		case 112: goto st68;
	}
	goto tr39;
st68:
	if ( ++p == pe )
		goto _test_eof68;
case 68:
	switch( (*p) ) {
		case 83: goto st69;
		case 115: goto st69;
	}
	goto tr39;
st69:
	if ( ++p == pe )
		goto _test_eof69;
case 69:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(2688 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 !s->multiline  ) _widec += 512;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(2688 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		if (
 !s->multiline  ) _widec += 512;
	}
	switch( _widec ) {
		case 9: goto tr319;
		case 32: goto tr319;
		case 40: goto tr320;
		case 41: goto tr321;
		case 3082: goto tr322;
		case 3131: goto tr323;
		case 3338: goto tr324;
		case 3387: goto tr324;
		case 3594: goto tr325;
		case 3643: goto tr326;
	}
	goto tr63;
tr48:
	{
		s->r_class = s->default_class;
	}
	goto st70;
st70:
	if ( ++p == pe )
		goto _test_eof70;
case 70:
	switch( (*p) ) {
		case 78: goto st71;
		case 80: goto st74;
		case 110: goto st71;
		case 112: goto st74;
	}
	goto tr39;
st71:
	if ( ++p == pe )
		goto _test_eof71;
case 71:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr329;
		case 32: goto tr329;
		case 40: goto tr330;
		case 41: goto tr331;
		case 2058: goto tr332;
		case 2107: goto tr333;
	}
	goto tr39;
tr335:
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st72;
tr336:
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st72;
tr355:
	{
		s->line_counter++;
	}
	goto st72;
tr745:
	{
		if (s->number64 <= UINT32_MAX) {
			s->r_ttl = (uint32_t)(s->number64);
		} else {
			WARN(ZS_NUMBER32_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st72;
tr746:
	{
		if (s->number64 <= UINT32_MAX) {
			s->r_ttl = (uint32_t)(s->number64);
		} else {
			WARN(ZS_NUMBER32_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st72;
tr747:
	{
		if (s->number64 <= UINT32_MAX) {
			s->r_ttl = (uint32_t)(s->number64);
		} else {
			WARN(ZS_NUMBER32_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st72;
tr754:
	{
		if (s->number64 <= UINT32_MAX) {
			s->r_ttl = (uint32_t)(s->number64);
		} else {
			WARN(ZS_NUMBER32_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		s->line_counter++;
	}
	goto st72;
tr709:
	{
		s->buffer[s->buffer_length++] = 0;

		// Execute the comment callback.
		if (s->process.automatic && s->process.comment != NULL) {
			s->process.comment(s);

			// Stop if required from the callback.
			if (s->state == ZS_STATE_STOP) {
				{p++; cs = 72; goto _out;}
			}
		}
	}
	{
		s->line_counter++;
	}
	goto st72;
tr329:
	{
		s->r_class = KNOT_CLASS_IN;
	}
	goto st72;
tr330:
	{
		s->r_class = KNOT_CLASS_IN;
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st72;
tr331:
	{
		s->r_class = KNOT_CLASS_IN;
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st72;
tr332:
	{
		s->r_class = KNOT_CLASS_IN;
	}
	{
		s->line_counter++;
	}
	goto st72;
tr763:
	{
		if (s->number64 + s->number64_tmp < UINT32_MAX) {
			s->number64 += s->number64_tmp;
		} else {
			WARN(ZS_NUMBER32_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->number64 <= UINT32_MAX) {
			s->r_ttl = (uint32_t)(s->number64);
		} else {
			WARN(ZS_NUMBER32_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st72;
tr764:
	{
		if (s->number64 + s->number64_tmp < UINT32_MAX) {
			s->number64 += s->number64_tmp;
		} else {
			WARN(ZS_NUMBER32_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->number64 <= UINT32_MAX) {
			s->r_ttl = (uint32_t)(s->number64);
		} else {
			WARN(ZS_NUMBER32_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st72;
tr765:
	{
		if (s->number64 + s->number64_tmp < UINT32_MAX) {
			s->number64 += s->number64_tmp;
		} else {
			WARN(ZS_NUMBER32_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->number64 <= UINT32_MAX) {
			s->r_ttl = (uint32_t)(s->number64);
		} else {
			WARN(ZS_NUMBER32_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st72;
tr767:
	{
		if (s->number64 + s->number64_tmp < UINT32_MAX) {
			s->number64 += s->number64_tmp;
		} else {
			WARN(ZS_NUMBER32_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->number64 <= UINT32_MAX) {
			s->r_ttl = (uint32_t)(s->number64);
		} else {
			WARN(ZS_NUMBER32_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		s->line_counter++;
	}
	goto st72;
st72:
	if ( ++p == pe )
		goto _test_eof72;
case 72:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto st72;
		case 32: goto st72;
		case 40: goto tr335;
		case 41: goto tr336;
		case 65: goto st4;
		case 67: goto st17;
		case 68: goto st40;
		case 69: goto st54;
		case 72: goto st61;
		case 73: goto st73;
		case 75: goto st81;
		case 76: goto st85;
		case 77: goto st93;
		case 78: goto st99;
		case 79: goto st115;
		case 80: goto st125;
		case 82: goto st128;
		case 83: goto st135;
		case 84: goto st154;
		case 85: goto st164;
		case 87: goto st167;
		case 90: goto st173;
		case 97: goto st4;
		case 99: goto st17;
		case 100: goto st40;
		case 101: goto st54;
		case 104: goto st61;
		case 105: goto st73;
		case 107: goto st81;
		case 108: goto st85;
		case 109: goto st93;
		case 110: goto st99;
		case 111: goto st115;
		case 112: goto st125;
		case 114: goto st128;
		case 115: goto st135;
		case 116: goto st154;
		case 117: goto st164;
		case 119: goto st167;
		case 122: goto st173;
		case 2058: goto tr355;
		case 2107: goto tr356;
	}
	goto tr39;
tr730:
	{
		s->r_ttl = s->default_ttl;
	}
	goto st73;
st73:
	if ( ++p == pe )
		goto _test_eof73;
case 73:
	switch( (*p) ) {
		case 80: goto st74;
		case 112: goto st74;
	}
	goto tr39;
st74:
	if ( ++p == pe )
		goto _test_eof74;
case 74:
	switch( (*p) ) {
		case 83: goto st75;
		case 115: goto st75;
	}
	goto tr39;
st75:
	if ( ++p == pe )
		goto _test_eof75;
case 75:
	switch( (*p) ) {
		case 69: goto st76;
		case 101: goto st76;
	}
	goto tr39;
st76:
	if ( ++p == pe )
		goto _test_eof76;
case 76:
	switch( (*p) ) {
		case 67: goto st77;
		case 99: goto st77;
	}
	goto tr39;
st77:
	if ( ++p == pe )
		goto _test_eof77;
case 77:
	switch( (*p) ) {
		case 75: goto st78;
		case 107: goto st78;
	}
	goto tr39;
st78:
	if ( ++p == pe )
		goto _test_eof78;
case 78:
	switch( (*p) ) {
		case 69: goto st79;
		case 101: goto st79;
	}
	goto tr39;
st79:
	if ( ++p == pe )
		goto _test_eof79;
case 79:
	switch( (*p) ) {
		case 89: goto st80;
		case 121: goto st80;
	}
	goto tr39;
st80:
	if ( ++p == pe )
		goto _test_eof80;
case 80:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(2688 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 !s->multiline  ) _widec += 512;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(2688 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		if (
 !s->multiline  ) _widec += 512;
	}
	switch( _widec ) {
		case 9: goto tr363;
		case 32: goto tr363;
		case 40: goto tr364;
		case 41: goto tr365;
		case 3082: goto tr366;
		case 3131: goto tr367;
		case 3338: goto tr368;
		case 3387: goto tr368;
		case 3594: goto tr369;
		case 3643: goto tr370;
	}
	goto tr63;
tr11:
	{
		s->r_class = s->default_class;
	}
	{
		s->r_ttl = s->default_ttl;
	}
	goto st81;
tr49:
	{
		s->r_class = s->default_class;
	}
	goto st81;
tr731:
	{
		s->r_ttl = s->default_ttl;
	}
	goto st81;
st81:
	if ( ++p == pe )
		goto _test_eof81;
case 81:
	switch( (*p) ) {
		case 69: goto st82;
		case 88: goto st84;
		case 101: goto st82;
		case 120: goto st84;
	}
	goto tr39;
st82:
	if ( ++p == pe )
		goto _test_eof82;
case 82:
	switch( (*p) ) {
		case 89: goto st83;
		case 121: goto st83;
	}
	goto tr39;
st83:
	if ( ++p == pe )
		goto _test_eof83;
case 83:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(2688 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 !s->multiline  ) _widec += 512;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(2688 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		if (
 !s->multiline  ) _widec += 512;
	}
	switch( _widec ) {
		case 9: goto tr374;
		case 32: goto tr374;
		case 40: goto tr375;
		case 41: goto tr376;
		case 3082: goto tr377;
		case 3131: goto tr378;
		case 3338: goto tr379;
		case 3387: goto tr379;
		case 3594: goto tr380;
		case 3643: goto tr381;
	}
	goto tr63;
st84:
	if ( ++p == pe )
		goto _test_eof84;
case 84:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(2688 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 !s->multiline  ) _widec += 512;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(2688 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		if (
 !s->multiline  ) _widec += 512;
	}
	switch( _widec ) {
		case 9: goto tr382;
		case 32: goto tr382;
		case 40: goto tr383;
		case 41: goto tr384;
		case 3082: goto tr385;
		case 3131: goto tr386;
		case 3338: goto tr387;
		case 3387: goto tr387;
		case 3594: goto tr388;
		case 3643: goto tr389;
	}
	goto tr63;
tr12:
	{
		s->r_class = s->default_class;
	}
	{
		s->r_ttl = s->default_ttl;
	}
	goto st85;
tr50:
	{
		s->r_class = s->default_class;
	}
	goto st85;
tr732:
	{
		s->r_ttl = s->default_ttl;
	}
	goto st85;
st85:
	if ( ++p == pe )
		goto _test_eof85;
case 85:
	switch( (*p) ) {
		case 51: goto st86;
		case 54: goto st88;
		case 79: goto st90;
		case 80: goto st92;
		case 111: goto st90;
		case 112: goto st92;
	}
	goto tr39;
st86:
	if ( ++p == pe )
		goto _test_eof86;
case 86:
	if ( (*p) == 50 )
		goto st87;
	goto tr39;
st87:
	if ( ++p == pe )
		goto _test_eof87;
case 87:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(2688 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 !s->multiline  ) _widec += 512;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(2688 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		if (
 !s->multiline  ) _widec += 512;
	}
	switch( _widec ) {
		case 9: goto tr395;
		case 32: goto tr395;
		case 40: goto tr396;
		case 41: goto tr397;
		case 3082: goto tr398;
		case 3131: goto tr399;
		case 3338: goto tr400;
		case 3387: goto tr400;
		case 3594: goto tr401;
		case 3643: goto tr402;
	}
	goto tr63;
st88:
	if ( ++p == pe )
		goto _test_eof88;
case 88:
	if ( (*p) == 52 )
		goto st89;
	goto tr39;
st89:
	if ( ++p == pe )
		goto _test_eof89;
case 89:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(2688 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 !s->multiline  ) _widec += 512;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(2688 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		if (
 !s->multiline  ) _widec += 512;
	}
	switch( _widec ) {
		case 9: goto tr404;
		case 32: goto tr404;
		case 40: goto tr405;
		case 41: goto tr406;
		case 3082: goto tr407;
		case 3131: goto tr408;
		case 3338: goto tr409;
		case 3387: goto tr409;
		case 3594: goto tr410;
		case 3643: goto tr411;
	}
	goto tr63;
st90:
	if ( ++p == pe )
		goto _test_eof90;
case 90:
	switch( (*p) ) {
		case 67: goto st91;
		case 99: goto st91;
	}
	goto tr39;
st91:
	if ( ++p == pe )
		goto _test_eof91;
case 91:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(2688 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 !s->multiline  ) _widec += 512;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(2688 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		if (
 !s->multiline  ) _widec += 512;
	}
	switch( _widec ) {
		case 9: goto tr413;
		case 32: goto tr413;
		case 40: goto tr414;
		case 41: goto tr415;
		case 3082: goto tr416;
		case 3131: goto tr417;
		case 3338: goto tr418;
		case 3387: goto tr418;
		case 3594: goto tr419;
		case 3643: goto tr420;
	}
	goto tr63;
st92:
	if ( ++p == pe )
		goto _test_eof92;
case 92:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(2688 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 !s->multiline  ) _widec += 512;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(2688 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		if (
 !s->multiline  ) _widec += 512;
	}
	switch( _widec ) {
		case 9: goto tr421;
		case 32: goto tr421;
		case 40: goto tr422;
		case 41: goto tr423;
		case 3082: goto tr424;
		case 3131: goto tr425;
		case 3338: goto tr426;
		case 3387: goto tr426;
		case 3594: goto tr427;
		case 3643: goto tr428;
	}
	goto tr63;
tr13:
	{
		s->r_class = s->default_class;
	}
	{
		s->r_ttl = s->default_ttl;
	}
	goto st93;
tr51:
	{
		s->r_class = s->default_class;
	}
	goto st93;
tr733:
	{
		s->r_ttl = s->default_ttl;
	}
	goto st93;
st93:
	if ( ++p == pe )
		goto _test_eof93;
case 93:
	switch( (*p) ) {
		case 73: goto st94;
		case 88: goto st98;
		case 105: goto st94;
		case 120: goto st98;
	}
	goto tr39;
st94:
	if ( ++p == pe )
		goto _test_eof94;
case 94:
	switch( (*p) ) {
		case 78: goto st95;
		case 110: goto st95;
	}
	goto tr39;
st95:
	if ( ++p == pe )
		goto _test_eof95;
case 95:
	switch( (*p) ) {
		case 70: goto st96;
		case 102: goto st96;
	}
	goto tr39;
st96:
	if ( ++p == pe )
		goto _test_eof96;
case 96:
	switch( (*p) ) {
		case 79: goto st97;
		case 111: goto st97;
	}
	goto tr39;
st97:
	if ( ++p == pe )
		goto _test_eof97;
case 97:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(2688 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 !s->multiline  ) _widec += 512;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(2688 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		if (
 !s->multiline  ) _widec += 512;
	}
	switch( _widec ) {
		case 9: goto tr434;
		case 32: goto tr434;
		case 40: goto tr435;
		case 41: goto tr436;
		case 3082: goto tr437;
		case 3131: goto tr438;
		case 3338: goto tr439;
		case 3387: goto tr439;
		case 3594: goto tr440;
		case 3643: goto tr441;
	}
	goto tr63;
st98:
	if ( ++p == pe )
		goto _test_eof98;
case 98:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(2688 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 !s->multiline  ) _widec += 512;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(2688 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		if (
 !s->multiline  ) _widec += 512;
	}
	switch( _widec ) {
		case 9: goto tr442;
		case 32: goto tr442;
		case 40: goto tr443;
		case 41: goto tr444;
		case 3082: goto tr445;
		case 3131: goto tr446;
		case 3338: goto tr447;
		case 3387: goto tr447;
		case 3594: goto tr448;
		case 3643: goto tr449;
	}
	goto tr63;
tr14:
	{
		s->r_class = s->default_class;
	}
	{
		s->r_ttl = s->default_ttl;
	}
	goto st99;
tr52:
	{
		s->r_class = s->default_class;
	}
	goto st99;
tr734:
	{
		s->r_ttl = s->default_ttl;
	}
	goto st99;
st99:
	if ( ++p == pe )
		goto _test_eof99;
case 99:
	switch( (*p) ) {
		case 65: goto st100;
		case 73: goto st104;
		case 83: goto st106;
		case 97: goto st100;
		case 105: goto st104;
		case 115: goto st106;
	}
	goto tr39;
st100:
	if ( ++p == pe )
		goto _test_eof100;
case 100:
	switch( (*p) ) {
		case 80: goto st101;
		case 112: goto st101;
	}
	goto tr39;
st101:
	if ( ++p == pe )
		goto _test_eof101;
case 101:
	switch( (*p) ) {
		case 84: goto st102;
		case 116: goto st102;
	}
	goto tr39;
st102:
	if ( ++p == pe )
		goto _test_eof102;
case 102:
	switch( (*p) ) {
		case 82: goto st103;
		case 114: goto st103;
	}
	goto tr39;
st103:
	if ( ++p == pe )
		goto _test_eof103;
case 103:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(2688 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 !s->multiline  ) _widec += 512;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(2688 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		if (
 !s->multiline  ) _widec += 512;
	}
	switch( _widec ) {
		case 9: goto tr456;
		case 32: goto tr456;
		case 40: goto tr457;
		case 41: goto tr458;
		case 3082: goto tr459;
		case 3131: goto tr460;
		case 3338: goto tr461;
		case 3387: goto tr461;
		case 3594: goto tr462;
		case 3643: goto tr463;
	}
	goto tr63;
st104:
	if ( ++p == pe )
		goto _test_eof104;
case 104:
	switch( (*p) ) {
		case 68: goto st105;
		case 100: goto st105;
	}
	goto tr39;
st105:
	if ( ++p == pe )
		goto _test_eof105;
case 105:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(2688 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 !s->multiline  ) _widec += 512;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(2688 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		if (
 !s->multiline  ) _widec += 512;
	}
	switch( _widec ) {
		case 9: goto tr465;
		case 32: goto tr465;
		case 40: goto tr466;
		case 41: goto tr467;
		case 3082: goto tr468;
		case 3131: goto tr469;
		case 3338: goto tr470;
		case 3387: goto tr470;
		case 3594: goto tr471;
		case 3643: goto tr472;
	}
	goto tr63;
st106:
	if ( ++p == pe )
		goto _test_eof106;
case 106:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(2688 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 !s->multiline  ) _widec += 512;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(2688 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		if (
 !s->multiline  ) _widec += 512;
	}
	switch( _widec ) {
		case 9: goto tr473;
		case 32: goto tr473;
		case 40: goto tr474;
		case 41: goto tr475;
		case 69: goto st107;
		case 101: goto st107;
		case 3082: goto tr477;
		case 3131: goto tr478;
		case 3338: goto tr479;
		case 3387: goto tr479;
		case 3594: goto tr480;
		case 3643: goto tr481;
	}
	goto tr63;
st107:
	if ( ++p == pe )
		goto _test_eof107;
case 107:
	switch( (*p) ) {
		case 67: goto st108;
		case 99: goto st108;
	}
	goto tr39;
st108:
	if ( ++p == pe )
		goto _test_eof108;
case 108:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(2688 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 !s->multiline  ) _widec += 512;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(2688 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		if (
 !s->multiline  ) _widec += 512;
	}
	switch( _widec ) {
		case 9: goto tr483;
		case 32: goto tr483;
		case 40: goto tr484;
		case 41: goto tr485;
		case 51: goto st109;
		case 3082: goto tr487;
		case 3131: goto tr488;
		case 3338: goto tr489;
		case 3387: goto tr489;
		case 3594: goto tr490;
		case 3643: goto tr491;
	}
	goto tr63;
st109:
	if ( ++p == pe )
		goto _test_eof109;
case 109:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(2688 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 !s->multiline  ) _widec += 512;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(2688 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		if (
 !s->multiline  ) _widec += 512;
	}
	switch( _widec ) {
		case 9: goto tr492;
		case 32: goto tr492;
		case 40: goto tr493;
		case 41: goto tr494;
		case 80: goto st110;
		case 112: goto st110;
		case 3082: goto tr496;
		case 3131: goto tr497;
		case 3338: goto tr498;
		case 3387: goto tr498;
		case 3594: goto tr499;
		case 3643: goto tr500;
	}
	goto tr63;
st110:
	if ( ++p == pe )
		goto _test_eof110;
case 110:
	switch( (*p) ) {
		case 65: goto st111;
		case 97: goto st111;
	}
	goto tr39;
st111:
	if ( ++p == pe )
		goto _test_eof111;
case 111:
	switch( (*p) ) {
		case 82: goto st112;
		case 114: goto st112;
	}
	goto tr39;
st112:
	if ( ++p == pe )
		goto _test_eof112;
case 112:
	switch( (*p) ) {
		case 65: goto st113;
		case 97: goto st113;
	}
	goto tr39;
st113:
	if ( ++p == pe )
		goto _test_eof113;
case 113:
	switch( (*p) ) {
		case 77: goto st114;
		case 109: goto st114;
	}
	goto tr39;
st114:
	if ( ++p == pe )
		goto _test_eof114;
case 114:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(2688 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 !s->multiline  ) _widec += 512;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(2688 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		if (
 !s->multiline  ) _widec += 512;
	}
	switch( _widec ) {
		case 9: goto tr505;
		case 32: goto tr505;
		case 40: goto tr506;
		case 41: goto tr507;
		case 3082: goto tr508;
		case 3131: goto tr509;
		case 3338: goto tr510;
		case 3387: goto tr510;
		case 3594: goto tr511;
		case 3643: goto tr512;
	}
	goto tr63;
tr15:
	{
		s->r_class = s->default_class;
	}
	{
		s->r_ttl = s->default_ttl;
	}
	goto st115;
tr53:
	{
		s->r_class = s->default_class;
	}
	goto st115;
tr735:
	{
		s->r_ttl = s->default_ttl;
	}
	goto st115;
st115:
	if ( ++p == pe )
		goto _test_eof115;
case 115:
	switch( (*p) ) {
		case 80: goto st116;
		case 112: goto st116;
	}
	goto tr39;
st116:
	if ( ++p == pe )
		goto _test_eof116;
case 116:
	switch( (*p) ) {
		case 69: goto st117;
		case 101: goto st117;
	}
	goto tr39;
st117:
	if ( ++p == pe )
		goto _test_eof117;
case 117:
	switch( (*p) ) {
		case 78: goto st118;
		case 110: goto st118;
	}
	goto tr39;
st118:
	if ( ++p == pe )
		goto _test_eof118;
case 118:
	switch( (*p) ) {
		case 80: goto st119;
		case 112: goto st119;
	}
	goto tr39;
st119:
	if ( ++p == pe )
		goto _test_eof119;
case 119:
	switch( (*p) ) {
		case 71: goto st120;
		case 103: goto st120;
	}
	goto tr39;
st120:
	if ( ++p == pe )
		goto _test_eof120;
case 120:
	switch( (*p) ) {
		case 80: goto st121;
		case 112: goto st121;
	}
	goto tr39;
st121:
	if ( ++p == pe )
		goto _test_eof121;
case 121:
	switch( (*p) ) {
		case 75: goto st122;
		case 107: goto st122;
	}
	goto tr39;
st122:
	if ( ++p == pe )
		goto _test_eof122;
case 122:
	switch( (*p) ) {
		case 69: goto st123;
		case 101: goto st123;
	}
	goto tr39;
st123:
	if ( ++p == pe )
		goto _test_eof123;
case 123:
	switch( (*p) ) {
		case 89: goto st124;
		case 121: goto st124;
	}
	goto tr39;
st124:
	if ( ++p == pe )
		goto _test_eof124;
case 124:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(2688 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 !s->multiline  ) _widec += 512;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(2688 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		if (
 !s->multiline  ) _widec += 512;
	}
	switch( _widec ) {
		case 9: goto tr522;
		case 32: goto tr522;
		case 40: goto tr523;
		case 41: goto tr524;
		case 3082: goto tr525;
		case 3131: goto tr526;
		case 3338: goto tr527;
		case 3387: goto tr527;
		case 3594: goto tr528;
		case 3643: goto tr529;
	}
	goto tr63;
tr16:
	{
		s->r_class = s->default_class;
	}
	{
		s->r_ttl = s->default_ttl;
	}
	goto st125;
tr54:
	{
		s->r_class = s->default_class;
	}
	goto st125;
tr736:
	{
		s->r_ttl = s->default_ttl;
	}
	goto st125;
st125:
	if ( ++p == pe )
		goto _test_eof125;
case 125:
	switch( (*p) ) {
		case 84: goto st126;
		case 116: goto st126;
	}
	goto tr39;
st126:
	if ( ++p == pe )
		goto _test_eof126;
case 126:
	switch( (*p) ) {
		case 82: goto st127;
		case 114: goto st127;
	}
	goto tr39;
st127:
	if ( ++p == pe )
		goto _test_eof127;
case 127:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(2688 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 !s->multiline  ) _widec += 512;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(2688 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		if (
 !s->multiline  ) _widec += 512;
	}
	switch( _widec ) {
		case 9: goto tr532;
		case 32: goto tr532;
		case 40: goto tr533;
		case 41: goto tr534;
		case 3082: goto tr535;
		case 3131: goto tr536;
		case 3338: goto tr537;
		case 3387: goto tr537;
		case 3594: goto tr538;
		case 3643: goto tr539;
	}
	goto tr63;
tr17:
	{
		s->r_class = s->default_class;
	}
	{
		s->r_ttl = s->default_ttl;
	}
	goto st128;
tr55:
	{
		s->r_class = s->default_class;
	}
	goto st128;
tr737:
	{
		s->r_ttl = s->default_ttl;
	}
	goto st128;
st128:
	if ( ++p == pe )
		goto _test_eof128;
case 128:
	switch( (*p) ) {
		case 80: goto st129;
		case 82: goto st130;
		case 84: goto st134;
		case 112: goto st129;
		case 114: goto st130;
		case 116: goto st134;
	}
	goto tr39;
st129:
	if ( ++p == pe )
		goto _test_eof129;
case 129:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(2688 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 !s->multiline  ) _widec += 512;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(2688 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		if (
 !s->multiline  ) _widec += 512;
	}
	switch( _widec ) {
		case 9: goto tr543;
		case 32: goto tr543;
		case 40: goto tr544;
		case 41: goto tr545;
		case 3082: goto tr546;
		case 3131: goto tr547;
		case 3338: goto tr548;
		case 3387: goto tr548;
		case 3594: goto tr549;
		case 3643: goto tr550;
	}
	goto tr63;
st130:
	if ( ++p == pe )
		goto _test_eof130;
case 130:
	switch( (*p) ) {
		case 83: goto st131;
		case 115: goto st131;
	}
	goto tr39;
st131:
	if ( ++p == pe )
		goto _test_eof131;
case 131:
	switch( (*p) ) {
		case 73: goto st132;
		case 105: goto st132;
	}
	goto tr39;
st132:
	if ( ++p == pe )
		goto _test_eof132;
case 132:
	switch( (*p) ) {
		case 71: goto st133;
		case 103: goto st133;
	}
	goto tr39;
st133:
	if ( ++p == pe )
		goto _test_eof133;
case 133:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(2688 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 !s->multiline  ) _widec += 512;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(2688 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		if (
 !s->multiline  ) _widec += 512;
	}
	switch( _widec ) {
		case 9: goto tr554;
		case 32: goto tr554;
		case 40: goto tr555;
		case 41: goto tr556;
		case 3082: goto tr557;
		case 3131: goto tr558;
		case 3338: goto tr559;
		case 3387: goto tr559;
		case 3594: goto tr560;
		case 3643: goto tr561;
	}
	goto tr63;
st134:
	if ( ++p == pe )
		goto _test_eof134;
case 134:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(2688 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 !s->multiline  ) _widec += 512;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(2688 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		if (
 !s->multiline  ) _widec += 512;
	}
	switch( _widec ) {
		case 9: goto tr562;
		case 32: goto tr562;
		case 40: goto tr563;
		case 41: goto tr564;
		case 3082: goto tr565;
		case 3131: goto tr566;
		case 3338: goto tr567;
		case 3387: goto tr567;
		case 3594: goto tr568;
		case 3643: goto tr569;
	}
	goto tr63;
tr18:
	{
		s->r_class = s->default_class;
	}
	{
		s->r_ttl = s->default_ttl;
	}
	goto st135;
tr56:
	{
		s->r_class = s->default_class;
	}
	goto st135;
tr738:
	{
		s->r_ttl = s->default_ttl;
	}
	goto st135;
st135:
	if ( ++p == pe )
		goto _test_eof135;
case 135:
	switch( (*p) ) {
		case 77: goto st136;
		case 79: goto st141;
		case 80: goto st143;
		case 82: goto st145;
		case 83: goto st147;
		case 86: goto st151;
		case 109: goto st136;
		case 111: goto st141;
		case 112: goto st143;
		case 114: goto st145;
		case 115: goto st147;
		case 118: goto st151;
	}
	goto tr39;
st136:
	if ( ++p == pe )
		goto _test_eof136;
case 136:
	switch( (*p) ) {
		case 73: goto st137;
		case 105: goto st137;
	}
	goto tr39;
st137:
	if ( ++p == pe )
		goto _test_eof137;
case 137:
	switch( (*p) ) {
		case 77: goto st138;
		case 109: goto st138;
	}
	goto tr39;
st138:
	if ( ++p == pe )
		goto _test_eof138;
case 138:
	switch( (*p) ) {
		case 69: goto st139;
		case 101: goto st139;
	}
	goto tr39;
st139:
	if ( ++p == pe )
		goto _test_eof139;
case 139:
	switch( (*p) ) {
		case 65: goto st140;
		case 97: goto st140;
	}
	goto tr39;
st140:
	if ( ++p == pe )
		goto _test_eof140;
case 140:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(2688 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 !s->multiline  ) _widec += 512;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(2688 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		if (
 !s->multiline  ) _widec += 512;
	}
	switch( _widec ) {
		case 9: goto tr580;
		case 32: goto tr580;
		case 40: goto tr581;
		case 41: goto tr582;
		case 3082: goto tr583;
		case 3131: goto tr584;
		case 3338: goto tr585;
		case 3387: goto tr585;
		case 3594: goto tr586;
		case 3643: goto tr587;
	}
	goto tr63;
st141:
	if ( ++p == pe )
		goto _test_eof141;
case 141:
	switch( (*p) ) {
		case 65: goto st142;
		case 97: goto st142;
	}
	goto tr39;
st142:
	if ( ++p == pe )
		goto _test_eof142;
case 142:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(2688 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 !s->multiline  ) _widec += 512;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(2688 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		if (
 !s->multiline  ) _widec += 512;
	}
	switch( _widec ) {
		case 9: goto tr589;
		case 32: goto tr589;
		case 40: goto tr590;
		case 41: goto tr591;
		case 3082: goto tr592;
		case 3131: goto tr593;
		case 3338: goto tr594;
		case 3387: goto tr594;
		case 3594: goto tr595;
		case 3643: goto tr596;
	}
	goto tr63;
st143:
	if ( ++p == pe )
		goto _test_eof143;
case 143:
	switch( (*p) ) {
		case 70: goto st144;
		case 102: goto st144;
	}
	goto tr39;
st144:
	if ( ++p == pe )
		goto _test_eof144;
case 144:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(2688 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 !s->multiline  ) _widec += 512;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(2688 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		if (
 !s->multiline  ) _widec += 512;
	}
	switch( _widec ) {
		case 9: goto tr598;
		case 32: goto tr598;
		case 40: goto tr599;
		case 41: goto tr600;
		case 3082: goto tr601;
		case 3131: goto tr602;
		case 3338: goto tr603;
		case 3387: goto tr603;
		case 3594: goto tr604;
		case 3643: goto tr605;
	}
	goto tr63;
st145:
	if ( ++p == pe )
		goto _test_eof145;
case 145:
	switch( (*p) ) {
		case 86: goto st146;
		case 118: goto st146;
	}
	goto tr39;
st146:
	if ( ++p == pe )
		goto _test_eof146;
case 146:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(2688 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 !s->multiline  ) _widec += 512;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(2688 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		if (
 !s->multiline  ) _widec += 512;
	}
	switch( _widec ) {
		case 9: goto tr607;
		case 32: goto tr607;
		case 40: goto tr608;
		case 41: goto tr609;
		case 3082: goto tr610;
		case 3131: goto tr611;
		case 3338: goto tr612;
		case 3387: goto tr612;
		case 3594: goto tr613;
		case 3643: goto tr614;
	}
	goto tr63;
st147:
	if ( ++p == pe )
		goto _test_eof147;
case 147:
	switch( (*p) ) {
		case 72: goto st148;
		case 104: goto st148;
	}
	goto tr39;
st148:
	if ( ++p == pe )
		goto _test_eof148;
case 148:
	switch( (*p) ) {
		case 70: goto st149;
		case 102: goto st149;
	}
	goto tr39;
st149:
	if ( ++p == pe )
		goto _test_eof149;
case 149:
	switch( (*p) ) {
		case 80: goto st150;
		case 112: goto st150;
	}
	goto tr39;
st150:
	if ( ++p == pe )
		goto _test_eof150;
case 150:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(2688 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 !s->multiline  ) _widec += 512;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(2688 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		if (
 !s->multiline  ) _widec += 512;
	}
	switch( _widec ) {
		case 9: goto tr618;
		case 32: goto tr618;
		case 40: goto tr619;
		case 41: goto tr620;
		case 3082: goto tr621;
		case 3131: goto tr622;
		case 3338: goto tr623;
		case 3387: goto tr623;
		case 3594: goto tr624;
		case 3643: goto tr625;
	}
	goto tr63;
st151:
	if ( ++p == pe )
		goto _test_eof151;
case 151:
	switch( (*p) ) {
		case 67: goto st152;
		case 99: goto st152;
	}
	goto tr39;
st152:
	if ( ++p == pe )
		goto _test_eof152;
case 152:
	switch( (*p) ) {
		case 66: goto st153;
		case 98: goto st153;
	}
	goto tr39;
st153:
	if ( ++p == pe )
		goto _test_eof153;
case 153:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(2688 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 !s->multiline  ) _widec += 512;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(2688 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		if (
 !s->multiline  ) _widec += 512;
	}
	switch( _widec ) {
		case 9: goto tr628;
		case 32: goto tr628;
		case 40: goto tr629;
		case 41: goto tr630;
		case 3082: goto tr631;
		case 3131: goto tr632;
		case 3338: goto tr633;
		case 3387: goto tr633;
		case 3594: goto tr634;
		case 3643: goto tr635;
	}
	goto tr63;
tr19:
	{
		s->r_class = s->default_class;
	}
	{
		s->r_ttl = s->default_ttl;
	}
	goto st154;
tr57:
	{
		s->r_class = s->default_class;
	}
	goto st154;
tr739:
	{
		s->r_ttl = s->default_ttl;
	}
	goto st154;
st154:
	if ( ++p == pe )
		goto _test_eof154;
case 154:
	switch( (*p) ) {
		case 76: goto st155;
		case 88: goto st158;
		case 89: goto st160;
		case 108: goto st155;
		case 120: goto st158;
		case 121: goto st160;
	}
	goto tr39;
st155:
	if ( ++p == pe )
		goto _test_eof155;
case 155:
	switch( (*p) ) {
		case 83: goto st156;
		case 115: goto st156;
	}
	goto tr39;
st156:
	if ( ++p == pe )
		goto _test_eof156;
case 156:
	switch( (*p) ) {
		case 65: goto st157;
		case 97: goto st157;
	}
	goto tr39;
st157:
	if ( ++p == pe )
		goto _test_eof157;
case 157:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(2688 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 !s->multiline  ) _widec += 512;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(2688 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		if (
 !s->multiline  ) _widec += 512;
	}
	switch( _widec ) {
		case 9: goto tr641;
		case 32: goto tr641;
		case 40: goto tr642;
		case 41: goto tr643;
		case 3082: goto tr644;
		case 3131: goto tr645;
		case 3338: goto tr646;
		case 3387: goto tr646;
		case 3594: goto tr647;
		case 3643: goto tr648;
	}
	goto tr63;
st158:
	if ( ++p == pe )
		goto _test_eof158;
case 158:
	switch( (*p) ) {
		case 84: goto st159;
		case 116: goto st159;
	}
	goto tr39;
st159:
	if ( ++p == pe )
		goto _test_eof159;
case 159:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(2688 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 !s->multiline  ) _widec += 512;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(2688 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		if (
 !s->multiline  ) _widec += 512;
	}
	switch( _widec ) {
		case 9: goto tr650;
		case 32: goto tr650;
		case 40: goto tr651;
		case 41: goto tr652;
		case 3082: goto tr653;
		case 3131: goto tr654;
		case 3338: goto tr655;
		case 3387: goto tr655;
		case 3594: goto tr656;
		case 3643: goto tr657;
	}
	goto tr63;
st160:
	if ( ++p == pe )
		goto _test_eof160;
case 160:
	switch( (*p) ) {
		case 80: goto st161;
		case 112: goto st161;
	}
	goto tr39;
st161:
	if ( ++p == pe )
		goto _test_eof161;
case 161:
	switch( (*p) ) {
		case 69: goto st162;
		case 101: goto st162;
	}
	goto tr39;
st162:
	if ( ++p == pe )
		goto _test_eof162;
case 162:
	if ( 48 <= (*p) && (*p) <= 57 )
		goto tr661;
	goto tr660;
tr661:
	{
		s->number64 = 0;
	}
	{
		// Overflow check: 10*(s->number64) + fc - '0' <= UINT64_MAX
		if ((s->number64 < (UINT64_MAX / 10)) ||   // Dominant fast check.
			((s->number64 == (UINT64_MAX / 10)) && // Marginal case.
			 ((uint8_t)(*p) <= (UINT64_MAX % 10) + '0')
			)
		   ) {
			s->number64 *= 10;
			s->number64 += digit_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_NUMBER64_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st163;
tr666:
	{
		// Overflow check: 10*(s->number64) + fc - '0' <= UINT64_MAX
		if ((s->number64 < (UINT64_MAX / 10)) ||   // Dominant fast check.
			((s->number64 == (UINT64_MAX / 10)) && // Marginal case.
			 ((uint8_t)(*p) <= (UINT64_MAX % 10) + '0')
			)
		   ) {
			s->number64 *= 10;
			s->number64 += digit_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_NUMBER64_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st163;
st163:
	if ( ++p == pe )
		goto _test_eof163;
case 163:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(2688 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 !s->multiline  ) _widec += 512;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(2688 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		if (
 !s->multiline  ) _widec += 512;
	}
	switch( _widec ) {
		case 9: goto tr663;
		case 32: goto tr663;
		case 40: goto tr664;
		case 41: goto tr665;
		case 3082: goto tr667;
		case 3131: goto tr668;
		case 3338: goto tr669;
		case 3387: goto tr669;
		case 3594: goto tr670;
		case 3643: goto tr671;
	}
	if ( 48 <= _widec && _widec <= 57 )
		goto tr666;
	goto tr662;
tr20:
	{
		s->r_class = s->default_class;
	}
	{
		s->r_ttl = s->default_ttl;
	}
	goto st164;
tr58:
	{
		s->r_class = s->default_class;
	}
	goto st164;
tr740:
	{
		s->r_ttl = s->default_ttl;
	}
	goto st164;
st164:
	if ( ++p == pe )
		goto _test_eof164;
case 164:
	switch( (*p) ) {
		case 82: goto st165;
		case 114: goto st165;
	}
	goto tr39;
st165:
	if ( ++p == pe )
		goto _test_eof165;
case 165:
	switch( (*p) ) {
		case 73: goto st166;
		case 105: goto st166;
	}
	goto tr39;
st166:
	if ( ++p == pe )
		goto _test_eof166;
case 166:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(2688 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 !s->multiline  ) _widec += 512;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(2688 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		if (
 !s->multiline  ) _widec += 512;
	}
	switch( _widec ) {
		case 9: goto tr674;
		case 32: goto tr674;
		case 40: goto tr675;
		case 41: goto tr676;
		case 3082: goto tr677;
		case 3131: goto tr678;
		case 3338: goto tr679;
		case 3387: goto tr679;
		case 3594: goto tr680;
		case 3643: goto tr681;
	}
	goto tr63;
tr21:
	{
		s->r_class = s->default_class;
	}
	{
		s->r_ttl = s->default_ttl;
	}
	goto st167;
tr59:
	{
		s->r_class = s->default_class;
	}
	goto st167;
tr741:
	{
		s->r_ttl = s->default_ttl;
	}
	goto st167;
st167:
	if ( ++p == pe )
		goto _test_eof167;
case 167:
	switch( (*p) ) {
		case 65: goto st168;
		case 97: goto st168;
	}
	goto tr39;
st168:
	if ( ++p == pe )
		goto _test_eof168;
case 168:
	switch( (*p) ) {
		case 76: goto st169;
		case 108: goto st169;
	}
	goto tr39;
st169:
	if ( ++p == pe )
		goto _test_eof169;
case 169:
	switch( (*p) ) {
		case 76: goto st170;
		case 108: goto st170;
	}
	goto tr39;
st170:
	if ( ++p == pe )
		goto _test_eof170;
case 170:
	switch( (*p) ) {
		case 69: goto st171;
		case 101: goto st171;
	}
	goto tr39;
st171:
	if ( ++p == pe )
		goto _test_eof171;
case 171:
	switch( (*p) ) {
		case 84: goto st172;
		case 116: goto st172;
	}
	goto tr39;
st172:
	if ( ++p == pe )
		goto _test_eof172;
case 172:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(2688 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 !s->multiline  ) _widec += 512;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(2688 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		if (
 !s->multiline  ) _widec += 512;
	}
	switch( _widec ) {
		case 9: goto tr687;
		case 32: goto tr687;
		case 40: goto tr688;
		case 41: goto tr689;
		case 3082: goto tr690;
		case 3131: goto tr691;
		case 3338: goto tr692;
		case 3387: goto tr692;
		case 3594: goto tr693;
		case 3643: goto tr694;
	}
	goto tr63;
tr22:
	{
		s->r_class = s->default_class;
	}
	{
		s->r_ttl = s->default_ttl;
	}
	goto st173;
tr60:
	{
		s->r_class = s->default_class;
	}
	goto st173;
tr742:
	{
		s->r_ttl = s->default_ttl;
	}
	goto st173;
st173:
	if ( ++p == pe )
		goto _test_eof173;
case 173:
	switch( (*p) ) {
		case 79: goto st174;
		case 111: goto st174;
	}
	goto tr39;
st174:
	if ( ++p == pe )
		goto _test_eof174;
case 174:
	switch( (*p) ) {
		case 78: goto st175;
		case 110: goto st175;
	}
	goto tr39;
st175:
	if ( ++p == pe )
		goto _test_eof175;
case 175:
	switch( (*p) ) {
		case 69: goto st176;
		case 101: goto st176;
	}
	goto tr39;
st176:
	if ( ++p == pe )
		goto _test_eof176;
case 176:
	switch( (*p) ) {
		case 77: goto st177;
		case 109: goto st177;
	}
	goto tr39;
st177:
	if ( ++p == pe )
		goto _test_eof177;
case 177:
	switch( (*p) ) {
		case 68: goto st178;
		case 100: goto st178;
	}
	goto tr39;
st178:
	if ( ++p == pe )
		goto _test_eof178;
case 178:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(2688 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 !s->multiline  ) _widec += 512;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(2688 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		if (
 !s->multiline  ) _widec += 512;
	}
	switch( _widec ) {
		case 9: goto tr700;
		case 32: goto tr700;
		case 40: goto tr701;
		case 41: goto tr702;
		case 3082: goto tr703;
		case 3131: goto tr704;
		case 3338: goto tr705;
		case 3387: goto tr705;
		case 3594: goto tr706;
		case 3643: goto tr707;
	}
	goto tr63;
tr356:
	{
		s->buffer_length = 0;
	}
	goto st179;
tr755:
	{
		if (s->number64 <= UINT32_MAX) {
			s->r_ttl = (uint32_t)(s->number64);
		} else {
			WARN(ZS_NUMBER32_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		s->buffer_length = 0;
	}
	goto st179;
tr708:
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		}
	}
	goto st179;
tr333:
	{
		s->r_class = KNOT_CLASS_IN;
	}
	{
		s->buffer_length = 0;
	}
	goto st179;
tr768:
	{
		if (s->number64 + s->number64_tmp < UINT32_MAX) {
			s->number64 += s->number64_tmp;
		} else {
			WARN(ZS_NUMBER32_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->number64 <= UINT32_MAX) {
			s->r_ttl = (uint32_t)(s->number64);
		} else {
			WARN(ZS_NUMBER32_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		s->buffer_length = 0;
	}
	goto st179;
st179:
	if ( ++p == pe )
		goto _test_eof179;
case 179:
	_widec = (*p);
	if ( (*p) < 10 ) {
		if ( (*p) <= 9 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) > 10 ) {
		if ( 11 <= (*p) )
 {			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	if ( _widec == 2058 )
		goto tr709;
	if ( 1920 <= _widec && _widec <= 2175 )
		goto tr708;
	goto tr39;
tr1020:
	{
		s->buffer[s->buffer_length++] = 0;

		// Execute the comment callback.
		if (s->process.automatic && s->process.comment != NULL) {
			s->process.comment(s);

			// Stop if required from the callback.
			if (s->state == ZS_STATE_STOP) {
				{p++; cs = 1446; goto _out;}
			}
		}
	}
	{
		s->line_counter++;
	}
	{
		if (rdata_tail - s->r_data > UINT16_MAX) {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
		s->r_data_length = rdata_tail - s->r_data;

		s->state = ZS_STATE_DATA;

		// Execute the record callback.
		if (s->process.automatic) {
			if (s->process.record != NULL) {
				s->process.record(s);

				// Stop if required from the callback.
				if (s->state == ZS_STATE_STOP) {
					{p++; cs = 1446; goto _out;}
				}
			}
		} else {
			// Return if external processing.
			p--; {p++; cs = 1446; goto _out;}
		}
	}
	goto st1446;
tr152:
	{
		if (s->number64 <= UINT32_MAX) {
			s->r_ttl = (uint32_t)(s->number64);
		} else {
			WARN(ZS_NUMBER32_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		s->line_counter++;
	}
	{
		s->buffer[0] = 0;
		s->buffer_length = 0;
	}
	{
		if (rdata_tail - s->r_data > UINT16_MAX) {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
		s->r_data_length = rdata_tail - s->r_data;

		s->state = ZS_STATE_DATA;

		// Execute the record callback.
		if (s->process.automatic) {
			if (s->process.record != NULL) {
				s->process.record(s);

				// Stop if required from the callback.
				if (s->state == ZS_STATE_STOP) {
					{p++; cs = 1446; goto _out;}
				}
			}
		} else {
			// Return if external processing.
			p--; {p++; cs = 1446; goto _out;}
		}
	}
	goto st1446;
tr158:
	{
		s->line_counter++;
	}
	{
		if (rdata_tail - s->r_data > UINT16_MAX) {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
		s->r_data_length = rdata_tail - s->r_data;

		s->state = ZS_STATE_DATA;

		// Execute the record callback.
		if (s->process.automatic) {
			if (s->process.record != NULL) {
				s->process.record(s);

				// Stop if required from the callback.
				if (s->state == ZS_STATE_STOP) {
					{p++; cs = 1446; goto _out;}
				}
			}
		} else {
			// Return if external processing.
			p--; {p++; cs = 1446; goto _out;}
		}
	}
	goto st1446;
st1446:
	if ( ++p == pe )
		goto _test_eof1446;
case 1446:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr4308;
		case 32: goto tr4308;
		case 36: goto st190;
		case 40: goto tr4309;
		case 41: goto tr4310;
		case 42: goto tr4290;
		case 65: goto tr4311;
		case 67: goto tr4312;
		case 68: goto tr4313;
		case 69: goto tr4314;
		case 72: goto tr4315;
		case 73: goto tr4316;
		case 75: goto tr4317;
		case 76: goto tr4318;
		case 77: goto tr4319;
		case 78: goto tr4320;
		case 79: goto tr4321;
		case 80: goto tr4322;
		case 82: goto tr4323;
		case 83: goto tr4324;
		case 84: goto tr4325;
		case 85: goto tr4326;
		case 87: goto tr4327;
		case 90: goto tr4328;
		case 92: goto tr4290;
		case 95: goto tr4290;
		case 97: goto tr4311;
		case 99: goto tr4312;
		case 100: goto tr4313;
		case 101: goto tr4314;
		case 104: goto tr4315;
		case 105: goto tr4316;
		case 107: goto tr4317;
		case 108: goto tr4318;
		case 109: goto tr4319;
		case 110: goto tr4320;
		case 111: goto tr4321;
		case 112: goto tr4322;
		case 114: goto tr4323;
		case 115: goto tr4324;
		case 116: goto tr4325;
		case 117: goto tr4326;
		case 119: goto tr4327;
		case 122: goto tr4328;
		case 1802: goto tr4291;
		case 1851: goto tr4292;
		case 2058: goto tr4329;
		case 2107: goto tr4330;
	}
	if ( _widec < 64 ) {
		if ( 45 <= _widec && _widec <= 57 )
			goto tr4290;
	} else if ( _widec > 89 ) {
		if ( 98 <= _widec && _widec <= 121 )
			goto tr4290;
	} else
		goto tr4290;
	goto tr4307;
tr711:
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st180;
tr712:
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st180;
tr4308:
	{
		if (s->r_owner_length == 0) {
			WARN(ZS_BAD_PREVIOUS_OWNER);
			p--; {goto st316;}
		}
	}
	{
		s->buffer[0] = 0;
		s->buffer_length = 0;
	}
	goto st180;
tr4309:
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	{
		if (s->r_owner_length == 0) {
			WARN(ZS_BAD_PREVIOUS_OWNER);
			p--; {goto st316;}
		}
	}
	{
		s->buffer[0] = 0;
		s->buffer_length = 0;
	}
	goto st180;
tr4310:
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	{
		if (s->r_owner_length == 0) {
			WARN(ZS_BAD_PREVIOUS_OWNER);
			p--; {goto st316;}
		}
	}
	{
		s->buffer[0] = 0;
		s->buffer_length = 0;
	}
	goto st180;
st180:
	if ( ++p == pe )
		goto _test_eof180;
case 180:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto st180;
		case 32: goto st180;
		case 40: goto tr711;
		case 41: goto tr712;
		case 65: goto tr5;
		case 67: goto tr6;
		case 68: goto tr7;
		case 69: goto tr8;
		case 72: goto tr9;
		case 73: goto tr10;
		case 75: goto tr11;
		case 76: goto tr12;
		case 77: goto tr13;
		case 78: goto tr14;
		case 79: goto tr15;
		case 80: goto tr16;
		case 82: goto tr17;
		case 83: goto tr18;
		case 84: goto tr19;
		case 85: goto tr20;
		case 87: goto tr21;
		case 90: goto tr22;
		case 97: goto tr5;
		case 99: goto tr6;
		case 100: goto tr7;
		case 101: goto tr8;
		case 104: goto tr9;
		case 105: goto tr10;
		case 107: goto tr11;
		case 108: goto tr12;
		case 109: goto tr13;
		case 110: goto tr14;
		case 111: goto tr15;
		case 112: goto tr16;
		case 114: goto tr17;
		case 115: goto tr18;
		case 116: goto tr19;
		case 117: goto tr20;
		case 119: goto tr21;
		case 122: goto tr22;
		case 1802: goto tr23;
		case 1851: goto tr24;
		case 2058: goto tr713;
		case 2107: goto tr714;
	}
	if ( 48 <= _widec && _widec <= 57 )
		goto tr4;
	goto tr0;
tr10:
	{
		s->r_class = s->default_class;
	}
	{
		s->r_ttl = s->default_ttl;
	}
	goto st181;
st181:
	if ( ++p == pe )
		goto _test_eof181;
case 181:
	switch( (*p) ) {
		case 78: goto st182;
		case 80: goto st74;
		case 110: goto st182;
		case 112: goto st74;
	}
	goto tr39;
st182:
	if ( ++p == pe )
		goto _test_eof182;
case 182:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr716;
		case 32: goto tr716;
		case 40: goto tr717;
		case 41: goto tr718;
		case 2058: goto tr719;
		case 2107: goto tr720;
	}
	goto tr39;
tr722:
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st183;
tr723:
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st183;
tr743:
	{
		s->line_counter++;
	}
	goto st183;
tr770:
	{
		s->buffer[s->buffer_length++] = 0;

		// Execute the comment callback.
		if (s->process.automatic && s->process.comment != NULL) {
			s->process.comment(s);

			// Stop if required from the callback.
			if (s->state == ZS_STATE_STOP) {
				{p++; cs = 183; goto _out;}
			}
		}
	}
	{
		s->line_counter++;
	}
	goto st183;
tr716:
	{
		s->r_class = KNOT_CLASS_IN;
	}
	goto st183;
tr717:
	{
		s->r_class = KNOT_CLASS_IN;
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st183;
tr718:
	{
		s->r_class = KNOT_CLASS_IN;
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st183;
tr719:
	{
		s->r_class = KNOT_CLASS_IN;
	}
	{
		s->line_counter++;
	}
	goto st183;
st183:
	if ( ++p == pe )
		goto _test_eof183;
case 183:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto st183;
		case 32: goto st183;
		case 40: goto tr722;
		case 41: goto tr723;
		case 65: goto tr725;
		case 67: goto tr726;
		case 68: goto tr727;
		case 69: goto tr728;
		case 72: goto tr729;
		case 73: goto tr730;
		case 75: goto tr731;
		case 76: goto tr732;
		case 77: goto tr733;
		case 78: goto tr734;
		case 79: goto tr735;
		case 80: goto tr736;
		case 82: goto tr737;
		case 83: goto tr738;
		case 84: goto tr739;
		case 85: goto tr740;
		case 87: goto tr741;
		case 90: goto tr742;
		case 97: goto tr725;
		case 99: goto tr726;
		case 100: goto tr727;
		case 101: goto tr728;
		case 104: goto tr729;
		case 105: goto tr730;
		case 107: goto tr731;
		case 108: goto tr732;
		case 109: goto tr733;
		case 110: goto tr734;
		case 111: goto tr735;
		case 112: goto tr736;
		case 114: goto tr737;
		case 115: goto tr738;
		case 116: goto tr739;
		case 117: goto tr740;
		case 119: goto tr741;
		case 122: goto tr742;
		case 2058: goto tr743;
		case 2107: goto tr744;
	}
	if ( 48 <= _widec && _widec <= 57 )
		goto tr724;
	goto tr660;
tr724:
	{
		s->number64 = 0;
	}
	{
		// Overflow check: 10*(s->number64) + fc - '0' <= UINT64_MAX
		if ((s->number64 < (UINT64_MAX / 10)) ||   // Dominant fast check.
			((s->number64 == (UINT64_MAX / 10)) && // Marginal case.
			 ((uint8_t)(*p) <= (UINT64_MAX % 10) + '0')
			)
		   ) {
			s->number64 *= 10;
			s->number64 += digit_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_NUMBER64_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st184;
tr748:
	{
		// Overflow check: 10*(s->number64) + fc - '0' <= UINT64_MAX
		if ((s->number64 < (UINT64_MAX / 10)) ||   // Dominant fast check.
			((s->number64 == (UINT64_MAX / 10)) && // Marginal case.
			 ((uint8_t)(*p) <= (UINT64_MAX % 10) + '0')
			)
		   ) {
			s->number64 *= 10;
			s->number64 += digit_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_NUMBER64_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st184;
st184:
	if ( ++p == pe )
		goto _test_eof184;
case 184:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr745;
		case 32: goto tr745;
		case 40: goto tr746;
		case 41: goto tr747;
		case 68: goto tr749;
		case 72: goto tr750;
		case 77: goto tr751;
		case 83: goto st185;
		case 87: goto tr753;
		case 100: goto tr749;
		case 104: goto tr750;
		case 109: goto tr751;
		case 115: goto st185;
		case 119: goto tr753;
		case 2058: goto tr754;
		case 2107: goto tr755;
	}
	if ( 48 <= _widec && _widec <= 57 )
		goto tr748;
	goto tr27;
tr749:
	{ if (s->number64 <= (UINT32_MAX / 86400)) {
	                  s->number64 *= 86400;
	              } else {
	                  WARN(ZS_NUMBER32_OVERFLOW);
	                  p--; {goto st316;}
	              }
	            }
	goto st185;
tr750:
	{ if (s->number64 <= (UINT32_MAX / 3600)) {
	                  s->number64 *= 3600;
	              } else {
	                  WARN(ZS_NUMBER32_OVERFLOW);
	                  p--; {goto st316;}
	              }
	            }
	goto st185;
tr751:
	{ if (s->number64 <= (UINT32_MAX / 60)) {
	                  s->number64 *= 60;
	              } else {
	                  WARN(ZS_NUMBER32_OVERFLOW);
	                  p--; {goto st316;}
	              }
	            }
	goto st185;
tr753:
	{ if (s->number64 <= (UINT32_MAX / 604800)) {
	                  s->number64 *= 604800;
	              } else {
	                  WARN(ZS_NUMBER32_OVERFLOW);
	                  p--; {goto st316;}
	              }
	            }
	goto st185;
st185:
	if ( ++p == pe )
		goto _test_eof185;
case 185:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr745;
		case 32: goto tr745;
		case 40: goto tr746;
		case 41: goto tr747;
		case 2058: goto tr754;
		case 2107: goto tr755;
	}
	if ( 48 <= _widec && _widec <= 57 )
		goto tr756;
	goto tr27;
tr757:
	{
		// Overflow check: 10*(s->number64) + fc - '0' <= UINT64_MAX
		if ((s->number64 < (UINT64_MAX / 10)) ||   // Dominant fast check.
			((s->number64 == (UINT64_MAX / 10)) && // Marginal case.
			 ((uint8_t)(*p) <= (UINT64_MAX % 10) + '0')
			)
		   ) {
			s->number64 *= 10;
			s->number64 += digit_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_NUMBER64_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st186;
tr756:
	{
		s->number64_tmp = s->number64;
	}
	{
		s->number64 = 0;
	}
	{
		// Overflow check: 10*(s->number64) + fc - '0' <= UINT64_MAX
		if ((s->number64 < (UINT64_MAX / 10)) ||   // Dominant fast check.
			((s->number64 == (UINT64_MAX / 10)) && // Marginal case.
			 ((uint8_t)(*p) <= (UINT64_MAX % 10) + '0')
			)
		   ) {
			s->number64 *= 10;
			s->number64 += digit_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_NUMBER64_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st186;
tr766:
	{
		if (s->number64 + s->number64_tmp < UINT32_MAX) {
			s->number64 += s->number64_tmp;
		} else {
			WARN(ZS_NUMBER32_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		s->number64_tmp = s->number64;
	}
	{
		s->number64 = 0;
	}
	{
		// Overflow check: 10*(s->number64) + fc - '0' <= UINT64_MAX
		if ((s->number64 < (UINT64_MAX / 10)) ||   // Dominant fast check.
			((s->number64 == (UINT64_MAX / 10)) && // Marginal case.
			 ((uint8_t)(*p) <= (UINT64_MAX % 10) + '0')
			)
		   ) {
			s->number64 *= 10;
			s->number64 += digit_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_NUMBER64_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st186;
st186:
	if ( ++p == pe )
		goto _test_eof186;
case 186:
	switch( (*p) ) {
		case 68: goto tr758;
		case 72: goto tr759;
		case 77: goto tr760;
		case 83: goto st187;
		case 87: goto tr762;
		case 100: goto tr758;
		case 104: goto tr759;
		case 109: goto tr760;
		case 115: goto st187;
		case 119: goto tr762;
	}
	if ( 48 <= (*p) && (*p) <= 57 )
		goto tr757;
	goto tr27;
tr758:
	{ if (s->number64 <= (UINT32_MAX / 86400)) {
	                  s->number64 *= 86400;
	              } else {
	                  WARN(ZS_NUMBER32_OVERFLOW);
	                  p--; {goto st316;}
	              }
	            }
	goto st187;
tr759:
	{ if (s->number64 <= (UINT32_MAX / 3600)) {
	                  s->number64 *= 3600;
	              } else {
	                  WARN(ZS_NUMBER32_OVERFLOW);
	                  p--; {goto st316;}
	              }
	            }
	goto st187;
tr760:
	{ if (s->number64 <= (UINT32_MAX / 60)) {
	                  s->number64 *= 60;
	              } else {
	                  WARN(ZS_NUMBER32_OVERFLOW);
	                  p--; {goto st316;}
	              }
	            }
	goto st187;
tr762:
	{ if (s->number64 <= (UINT32_MAX / 604800)) {
	                  s->number64 *= 604800;
	              } else {
	                  WARN(ZS_NUMBER32_OVERFLOW);
	                  p--; {goto st316;}
	              }
	            }
	goto st187;
st187:
	if ( ++p == pe )
		goto _test_eof187;
case 187:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr763;
		case 32: goto tr763;
		case 40: goto tr764;
		case 41: goto tr765;
		case 2058: goto tr767;
		case 2107: goto tr768;
	}
	if ( 48 <= _widec && _widec <= 57 )
		goto tr766;
	goto tr27;
tr744:
	{
		s->buffer_length = 0;
	}
	goto st188;
tr769:
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		}
	}
	goto st188;
tr720:
	{
		s->r_class = KNOT_CLASS_IN;
	}
	{
		s->buffer_length = 0;
	}
	goto st188;
st188:
	if ( ++p == pe )
		goto _test_eof188;
case 188:
	_widec = (*p);
	if ( (*p) < 10 ) {
		if ( (*p) <= 9 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) > 10 ) {
		if ( 11 <= (*p) )
 {			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	if ( _widec == 2058 )
		goto tr770;
	if ( 1920 <= _widec && _widec <= 2175 )
		goto tr769;
	goto tr39;
tr24:
	{
		s->buffer_length = 0;
	}
	goto st189;
tr4292:
	{
		s->buffer[0] = 0;
		s->buffer_length = 0;
	}
	{
		s->buffer_length = 0;
	}
	goto st189;
tr771:
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		}
	}
	goto st189;
tr4358:
	{
		NOERR;
	}
	{
		s->buffer[0] = 0;
		s->buffer_length = 0;
	}
	{
		s->buffer_length = 0;
	}
	goto st189;
st189:
	if ( ++p == pe )
		goto _test_eof189;
case 189:
	if ( (*p) == 10 )
		goto tr772;
	goto tr771;
tr713:
	{
		s->line_counter++;
	}
	goto st1447;
tr1018:
	{
		s->buffer[s->buffer_length++] = 0;

		// Execute the comment callback.
		if (s->process.automatic && s->process.comment != NULL) {
			s->process.comment(s);

			// Stop if required from the callback.
			if (s->state == ZS_STATE_STOP) {
				{p++; cs = 1447; goto _out;}
			}
		}
	}
	{
		s->line_counter++;
	}
	goto st1447;
tr907:
	{
		s->buffer[s->buffer_length++] = 0;

		// Execute the comment callback.
		if (s->process.automatic && s->process.comment != NULL) {
			s->process.comment(s);

			// Stop if required from the callback.
			if (s->state == ZS_STATE_STOP) {
				{p++; cs = 1447; goto _out;}
			}
		}
	}
	{
		s->line_counter++;
	}
	{
		if (rdata_tail - s->r_data > UINT16_MAX) {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
		s->r_data_length = rdata_tail - s->r_data;

		s->state = ZS_STATE_DATA;

		// Execute the record callback.
		if (s->process.automatic) {
			if (s->process.record != NULL) {
				s->process.record(s);

				// Stop if required from the callback.
				if (s->state == ZS_STATE_STOP) {
					{p++; cs = 1447; goto _out;}
				}
			}
		} else {
			// Return if external processing.
			p--; {p++; cs = 1447; goto _out;}
		}
	}
	goto st1447;
tr904:
	{
		s->line_counter++;
	}
	{
		if (rdata_tail - s->r_data > UINT16_MAX) {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
		s->r_data_length = rdata_tail - s->r_data;

		s->state = ZS_STATE_DATA;

		// Execute the record callback.
		if (s->process.automatic) {
			if (s->process.record != NULL) {
				s->process.record(s);

				// Stop if required from the callback.
				if (s->state == ZS_STATE_STOP) {
					{p++; cs = 1447; goto _out;}
				}
			}
		} else {
			// Return if external processing.
			p--; {p++; cs = 1447; goto _out;}
		}
	}
	goto st1447;
tr899:
	{
		s->r_owner_length = s->dname_tmp_length;
	}
	{
		s->line_counter++;
	}
	{
		if (s->number64 <= UINT32_MAX) {
			s->r_ttl = (uint32_t)(s->number64);
		} else {
			WARN(ZS_NUMBER32_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		s->buffer[0] = 0;
		s->buffer_length = 0;
	}
	{
		if (rdata_tail - s->r_data > UINT16_MAX) {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
		s->r_data_length = rdata_tail - s->r_data;

		s->state = ZS_STATE_DATA;

		// Execute the record callback.
		if (s->process.automatic) {
			if (s->process.record != NULL) {
				s->process.record(s);

				// Stop if required from the callback.
				if (s->state == ZS_STATE_STOP) {
					{p++; cs = 1447; goto _out;}
				}
			}
		} else {
			// Return if external processing.
			p--; {p++; cs = 1447; goto _out;}
		}
	}
	goto st1447;
tr4329:
	{
		s->line_counter++;
	}
	{
		if (s->r_owner_length == 0) {
			WARN(ZS_BAD_PREVIOUS_OWNER);
			p--; {goto st316;}
		}
	}
	{
		s->buffer[0] = 0;
		s->buffer_length = 0;
	}
	goto st1447;
st1447:
	if ( ++p == pe )
		goto _test_eof1447;
case 1447:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr4308;
		case 32: goto tr4308;
		case 36: goto st190;
		case 40: goto tr4309;
		case 41: goto tr4310;
		case 42: goto tr4290;
		case 65: goto tr4333;
		case 67: goto tr4334;
		case 68: goto tr4335;
		case 69: goto tr4336;
		case 72: goto tr4337;
		case 73: goto tr4338;
		case 75: goto tr4339;
		case 76: goto tr4340;
		case 77: goto tr4341;
		case 78: goto tr4342;
		case 79: goto tr4343;
		case 80: goto tr4344;
		case 82: goto tr4345;
		case 83: goto tr4346;
		case 84: goto tr4347;
		case 85: goto tr4348;
		case 87: goto tr4349;
		case 90: goto tr4350;
		case 92: goto tr4290;
		case 95: goto tr4290;
		case 97: goto tr4333;
		case 99: goto tr4334;
		case 100: goto tr4335;
		case 101: goto tr4336;
		case 104: goto tr4337;
		case 105: goto tr4338;
		case 107: goto tr4339;
		case 108: goto tr4340;
		case 109: goto tr4341;
		case 110: goto tr4342;
		case 111: goto tr4343;
		case 112: goto tr4344;
		case 114: goto tr4345;
		case 115: goto tr4346;
		case 116: goto tr4347;
		case 117: goto tr4348;
		case 119: goto tr4349;
		case 122: goto tr4350;
		case 1802: goto tr4291;
		case 1851: goto tr4292;
		case 2058: goto tr4329;
		case 2107: goto tr4330;
	}
	if ( _widec < 48 ) {
		if ( 45 <= _widec && _widec <= 47 )
			goto tr4290;
	} else if ( _widec > 57 ) {
		if ( _widec > 89 ) {
			if ( 98 <= _widec && _widec <= 121 )
				goto tr4290;
		} else if ( _widec >= 64 )
			goto tr4290;
	} else
		goto tr4332;
	goto tr4331;
tr4353:
	{
		NOERR;
	}
	goto st190;
st190:
	if ( ++p == pe )
		goto _test_eof190;
case 190:
	switch( (*p) ) {
		case 73: goto tr774;
		case 79: goto tr775;
		case 84: goto tr776;
		case 105: goto tr774;
		case 111: goto tr775;
		case 116: goto tr776;
	}
	goto tr773;
tr774:
	{
		ERR(ZS_OK);
	}
	goto st191;
st191:
	if ( ++p == pe )
		goto _test_eof191;
case 191:
	switch( (*p) ) {
		case 78: goto st192;
		case 110: goto st192;
	}
	goto tr773;
st192:
	if ( ++p == pe )
		goto _test_eof192;
case 192:
	switch( (*p) ) {
		case 67: goto st193;
		case 99: goto st193;
	}
	goto tr773;
st193:
	if ( ++p == pe )
		goto _test_eof193;
case 193:
	switch( (*p) ) {
		case 76: goto st194;
		case 108: goto st194;
	}
	goto tr773;
st194:
	if ( ++p == pe )
		goto _test_eof194;
case 194:
	switch( (*p) ) {
		case 85: goto st195;
		case 117: goto st195;
	}
	goto tr773;
st195:
	if ( ++p == pe )
		goto _test_eof195;
case 195:
	switch( (*p) ) {
		case 68: goto st196;
		case 100: goto st196;
	}
	goto tr773;
st196:
	if ( ++p == pe )
		goto _test_eof196;
case 196:
	switch( (*p) ) {
		case 69: goto st197;
		case 101: goto st197;
	}
	goto tr773;
st197:
	if ( ++p == pe )
		goto _test_eof197;
case 197:
	switch( (*p) ) {
		case 32: goto tr783;
		case 59: goto tr783;
	}
	if ( (*p) > 10 ) {
		if ( 40 <= (*p) && (*p) <= 41 )
			goto tr783;
	} else if ( (*p) >= 9 )
		goto tr783;
	goto tr773;
tr783:
	{ p--; {stack[top++] = 1448;goto st361;} }
	goto st1448;
tr885:
	{ p--; {stack[top++] = 1448;goto st349;} }
	goto st1448;
tr888:
	{ p--; {stack[top++] = 1448;goto st340;} }
	goto st1448;
st1448:
	if ( ++p == pe )
		goto _test_eof1448;
case 1448:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr4352;
		case 32: goto tr4352;
		case 36: goto tr4353;
		case 40: goto tr4354;
		case 41: goto tr4355;
		case 42: goto tr4356;
		case 92: goto tr4356;
		case 95: goto tr4356;
		case 1802: goto tr4357;
		case 1851: goto tr4358;
		case 2058: goto tr4359;
		case 2107: goto tr4360;
	}
	if ( _widec < 64 ) {
		if ( 45 <= _widec && _widec <= 57 )
			goto tr4356;
	} else if ( _widec > 90 ) {
		if ( 97 <= _widec && _widec <= 122 )
			goto tr4356;
	} else
		goto tr4356;
	goto tr4351;
tr4290:
	{
		s->dname = s->r_owner;
		s->r_owner_length = 0;
	}
	{ p--; {stack[top++] = 198;goto st318;} }
	goto st198;
tr4356:
	{
		NOERR;
	}
	{
		s->dname = s->r_owner;
		s->r_owner_length = 0;
	}
	{ p--; {stack[top++] = 198;goto st318;} }
	goto st198;
st198:
	if ( ++p == pe )
		goto _test_eof198;
case 198:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr785;
		case 32: goto tr785;
		case 40: goto tr786;
		case 41: goto tr787;
		case 2058: goto tr788;
		case 2107: goto tr789;
	}
	goto tr784;
tr791:
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st199;
tr792:
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st199;
tr793:
	{
		s->line_counter++;
	}
	goto st199;
tr797:
	{
		s->buffer[s->buffer_length++] = 0;

		// Execute the comment callback.
		if (s->process.automatic && s->process.comment != NULL) {
			s->process.comment(s);

			// Stop if required from the callback.
			if (s->state == ZS_STATE_STOP) {
				{p++; cs = 199; goto _out;}
			}
		}
	}
	{
		s->line_counter++;
	}
	goto st199;
tr785:
	{
		s->r_owner_length = s->dname_tmp_length;
	}
	goto st199;
tr786:
	{
		s->r_owner_length = s->dname_tmp_length;
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st199;
tr787:
	{
		s->r_owner_length = s->dname_tmp_length;
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st199;
tr788:
	{
		s->r_owner_length = s->dname_tmp_length;
	}
	{
		s->line_counter++;
	}
	goto st199;
st199:
	if ( ++p == pe )
		goto _test_eof199;
case 199:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto st199;
		case 32: goto st199;
		case 40: goto tr791;
		case 41: goto tr792;
		case 65: goto tr5;
		case 67: goto tr6;
		case 68: goto tr7;
		case 69: goto tr8;
		case 72: goto tr9;
		case 73: goto tr10;
		case 75: goto tr11;
		case 76: goto tr12;
		case 77: goto tr13;
		case 78: goto tr14;
		case 79: goto tr15;
		case 80: goto tr16;
		case 82: goto tr17;
		case 83: goto tr18;
		case 84: goto tr19;
		case 85: goto tr20;
		case 87: goto tr21;
		case 90: goto tr22;
		case 97: goto tr5;
		case 99: goto tr6;
		case 100: goto tr7;
		case 101: goto tr8;
		case 104: goto tr9;
		case 105: goto tr10;
		case 107: goto tr11;
		case 108: goto tr12;
		case 109: goto tr13;
		case 110: goto tr14;
		case 111: goto tr15;
		case 112: goto tr16;
		case 114: goto tr17;
		case 115: goto tr18;
		case 116: goto tr19;
		case 117: goto tr20;
		case 119: goto tr21;
		case 122: goto tr22;
		case 2058: goto tr793;
		case 2107: goto tr794;
	}
	if ( 48 <= _widec && _widec <= 57 )
		goto tr4;
	goto tr660;
tr794:
	{
		s->buffer_length = 0;
	}
	goto st200;
tr795:
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		}
	}
	goto st200;
tr789:
	{
		s->r_owner_length = s->dname_tmp_length;
	}
	{
		s->buffer_length = 0;
	}
	goto st200;
st200:
	if ( ++p == pe )
		goto _test_eof200;
case 200:
	_widec = (*p);
	if ( (*p) < 10 ) {
		if ( (*p) <= 9 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) > 10 ) {
		if ( 11 <= (*p) )
 {			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	if ( _widec == 2058 )
		goto tr797;
	if ( 1920 <= _widec && _widec <= 2175 )
		goto tr795;
	goto st0;
tr25:
	{
		s->line_counter++;
	}
	goto st1449;
tr1016:
	{
		s->buffer[s->buffer_length++] = 0;

		// Execute the comment callback.
		if (s->process.automatic && s->process.comment != NULL) {
			s->process.comment(s);

			// Stop if required from the callback.
			if (s->state == ZS_STATE_STOP) {
				{p++; cs = 1449; goto _out;}
			}
		}
	}
	{
		s->line_counter++;
	}
	goto st1449;
tr862:
	{
		s->buffer[s->buffer_length++] = 0;

		// Execute the comment callback.
		if (s->process.automatic && s->process.comment != NULL) {
			s->process.comment(s);

			// Stop if required from the callback.
			if (s->state == ZS_STATE_STOP) {
				{p++; cs = 1449; goto _out;}
			}
		}
	}
	{
		s->line_counter++;
	}
	{
		if (rdata_tail - s->r_data > UINT16_MAX) {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
		s->r_data_length = rdata_tail - s->r_data;

		s->state = ZS_STATE_DATA;

		// Execute the record callback.
		if (s->process.automatic) {
			if (s->process.record != NULL) {
				s->process.record(s);

				// Stop if required from the callback.
				if (s->state == ZS_STATE_STOP) {
					{p++; cs = 1449; goto _out;}
				}
			}
		} else {
			// Return if external processing.
			p--; {p++; cs = 1449; goto _out;}
		}
	}
	goto st1449;
tr859:
	{
		s->line_counter++;
	}
	{
		if (rdata_tail - s->r_data > UINT16_MAX) {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
		s->r_data_length = rdata_tail - s->r_data;

		s->state = ZS_STATE_DATA;

		// Execute the record callback.
		if (s->process.automatic) {
			if (s->process.record != NULL) {
				s->process.record(s);

				// Stop if required from the callback.
				if (s->state == ZS_STATE_STOP) {
					{p++; cs = 1449; goto _out;}
				}
			}
		} else {
			// Return if external processing.
			p--; {p++; cs = 1449; goto _out;}
		}
	}
	goto st1449;
tr893:
	{
		s->r_owner_length = s->dname_tmp_length;
	}
	{
		s->line_counter++;
	}
	{
		s->buffer[0] = 0;
		s->buffer_length = 0;
	}
	{
		if (rdata_tail - s->r_data > UINT16_MAX) {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
		s->r_data_length = rdata_tail - s->r_data;

		s->state = ZS_STATE_DATA;

		// Execute the record callback.
		if (s->process.automatic) {
			if (s->process.record != NULL) {
				s->process.record(s);

				// Stop if required from the callback.
				if (s->state == ZS_STATE_STOP) {
					{p++; cs = 1449; goto _out;}
				}
			}
		} else {
			// Return if external processing.
			p--; {p++; cs = 1449; goto _out;}
		}
	}
	goto st1449;
tr930:
	{
		s->line_counter++;
	}
	{
		s->buffer[0] = 0;
		s->buffer_length = 0;
	}
	{
		if (rdata_tail - s->r_data > UINT16_MAX) {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
		s->r_data_length = rdata_tail - s->r_data;

		s->state = ZS_STATE_DATA;

		// Execute the record callback.
		if (s->process.automatic) {
			if (s->process.record != NULL) {
				s->process.record(s);

				// Stop if required from the callback.
				if (s->state == ZS_STATE_STOP) {
					{p++; cs = 1449; goto _out;}
				}
			}
		} else {
			// Return if external processing.
			p--; {p++; cs = 1449; goto _out;}
		}
	}
	goto st1449;
tr933:
	{
		s->buffer[s->buffer_length++] = 0;

		// Execute the comment callback.
		if (s->process.automatic && s->process.comment != NULL) {
			s->process.comment(s);

			// Stop if required from the callback.
			if (s->state == ZS_STATE_STOP) {
				{p++; cs = 1449; goto _out;}
			}
		}
	}
	{
		s->line_counter++;
	}
	{
		s->buffer[0] = 0;
		s->buffer_length = 0;
	}
	{
		if (rdata_tail - s->r_data > UINT16_MAX) {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
		s->r_data_length = rdata_tail - s->r_data;

		s->state = ZS_STATE_DATA;

		// Execute the record callback.
		if (s->process.automatic) {
			if (s->process.record != NULL) {
				s->process.record(s);

				// Stop if required from the callback.
				if (s->state == ZS_STATE_STOP) {
					{p++; cs = 1449; goto _out;}
				}
			}
		} else {
			// Return if external processing.
			p--; {p++; cs = 1449; goto _out;}
		}
	}
	goto st1449;
tr4293:
	{
		if (s->r_owner_length == 0) {
			WARN(ZS_BAD_PREVIOUS_OWNER);
			p--; {goto st316;}
		}
	}
	{
		s->line_counter++;
	}
	{
		s->buffer[0] = 0;
		s->buffer_length = 0;
	}
	goto st1449;
tr4363:
	{
		s->line_counter++;
	}
	{
		if (s->r_owner_length == 0) {
			WARN(ZS_BAD_PREVIOUS_OWNER);
			p--; {goto st316;}
		}
	}
	{
		s->buffer[0] = 0;
		s->buffer_length = 0;
	}
	goto st1449;
tr4359:
	{
		NOERR;
	}
	{
		if (s->r_owner_length == 0) {
			WARN(ZS_BAD_PREVIOUS_OWNER);
			p--; {goto st316;}
		}
	}
	{
		s->line_counter++;
	}
	{
		s->buffer[0] = 0;
		s->buffer_length = 0;
	}
	goto st1449;
tr4368:
	{
		s->buffer[0] = 0;
		s->buffer_length = 0;
	}
	{
		if (rdata_tail - s->r_data > UINT16_MAX) {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
		s->r_data_length = rdata_tail - s->r_data;

		s->state = ZS_STATE_DATA;

		// Execute the record callback.
		if (s->process.automatic) {
			if (s->process.record != NULL) {
				s->process.record(s);

				// Stop if required from the callback.
				if (s->state == ZS_STATE_STOP) {
					{p++; cs = 1449; goto _out;}
				}
			}
		} else {
			// Return if external processing.
			p--; {p++; cs = 1449; goto _out;}
		}
	}
	{
		s->line_counter++;
	}
	{
		if (s->r_owner_length == 0) {
			WARN(ZS_BAD_PREVIOUS_OWNER);
			p--; {goto st316;}
		}
	}
	goto st1449;
tr4395:
	{
		s->line_counter++;
	}
	{
		s->buffer[0] = 0;
		s->buffer_length = 0;
	}
	{
		if (rdata_tail - s->r_data > UINT16_MAX) {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
		s->r_data_length = rdata_tail - s->r_data;

		s->state = ZS_STATE_DATA;

		// Execute the record callback.
		if (s->process.automatic) {
			if (s->process.record != NULL) {
				s->process.record(s);

				// Stop if required from the callback.
				if (s->state == ZS_STATE_STOP) {
					{p++; cs = 1449; goto _out;}
				}
			}
		} else {
			// Return if external processing.
			p--; {p++; cs = 1449; goto _out;}
		}
	}
	{
		if (s->r_owner_length == 0) {
			WARN(ZS_BAD_PREVIOUS_OWNER);
			p--; {goto st316;}
		}
	}
	goto st1449;
st1449:
	if ( ++p == pe )
		goto _test_eof1449;
case 1449:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr4286;
		case 32: goto tr4286;
		case 36: goto st190;
		case 40: goto tr4361;
		case 41: goto tr4362;
		case 42: goto tr4290;
		case 65: goto tr4333;
		case 67: goto tr4334;
		case 68: goto tr4335;
		case 69: goto tr4336;
		case 72: goto tr4337;
		case 73: goto tr4338;
		case 75: goto tr4339;
		case 76: goto tr4340;
		case 77: goto tr4341;
		case 78: goto tr4342;
		case 79: goto tr4343;
		case 80: goto tr4344;
		case 82: goto tr4345;
		case 83: goto tr4346;
		case 84: goto tr4347;
		case 85: goto tr4348;
		case 87: goto tr4349;
		case 90: goto tr4350;
		case 92: goto tr4290;
		case 95: goto tr4290;
		case 97: goto tr4333;
		case 99: goto tr4334;
		case 100: goto tr4335;
		case 101: goto tr4336;
		case 104: goto tr4337;
		case 105: goto tr4338;
		case 107: goto tr4339;
		case 108: goto tr4340;
		case 109: goto tr4341;
		case 110: goto tr4342;
		case 111: goto tr4343;
		case 112: goto tr4344;
		case 114: goto tr4345;
		case 115: goto tr4346;
		case 116: goto tr4347;
		case 117: goto tr4348;
		case 119: goto tr4349;
		case 122: goto tr4350;
		case 1802: goto tr4291;
		case 1851: goto tr4292;
		case 2058: goto tr4363;
		case 2107: goto tr4364;
	}
	if ( _widec < 48 ) {
		if ( 45 <= _widec && _widec <= 47 )
			goto tr4290;
	} else if ( _widec > 57 ) {
		if ( _widec > 89 ) {
			if ( 98 <= _widec && _widec <= 121 )
				goto tr4290;
		} else if ( _widec >= 64 )
			goto tr4290;
	} else
		goto tr4332;
	goto tr4331;
tr4332:
	{
		s->number64 = 0;
	}
	{
		// Overflow check: 10*(s->number64) + fc - '0' <= UINT64_MAX
		if ((s->number64 < (UINT64_MAX / 10)) ||   // Dominant fast check.
			((s->number64 == (UINT64_MAX / 10)) && // Marginal case.
			 ((uint8_t)(*p) <= (UINT64_MAX % 10) + '0')
			)
		   ) {
			s->number64 *= 10;
			s->number64 += digit_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_NUMBER64_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		s->dname = s->r_owner;
		s->r_owner_length = 0;
	}
	{ p--; {stack[top++] = 201;goto st318;} }
	goto st201;
st201:
	if ( ++p == pe )
		goto _test_eof201;
case 201:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr799;
		case 32: goto tr799;
		case 40: goto tr800;
		case 41: goto tr801;
		case 68: goto tr32;
		case 72: goto tr33;
		case 77: goto tr34;
		case 83: goto st204;
		case 87: goto tr36;
		case 100: goto tr32;
		case 104: goto tr33;
		case 109: goto tr34;
		case 115: goto st204;
		case 119: goto tr36;
		case 2058: goto tr802;
		case 2107: goto tr803;
	}
	if ( 48 <= _widec && _widec <= 57 )
		goto tr31;
	goto tr798;
tr805:
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st202;
tr806:
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st202;
tr807:
	{
		s->line_counter++;
	}
	goto st202;
tr810:
	{
		s->buffer[s->buffer_length++] = 0;

		// Execute the comment callback.
		if (s->process.automatic && s->process.comment != NULL) {
			s->process.comment(s);

			// Stop if required from the callback.
			if (s->state == ZS_STATE_STOP) {
				{p++; cs = 202; goto _out;}
			}
		}
	}
	{
		s->line_counter++;
	}
	goto st202;
tr799:
	{
		s->r_owner_length = s->dname_tmp_length;
	}
	{
		if (s->number64 <= UINT32_MAX) {
			s->r_ttl = (uint32_t)(s->number64);
		} else {
			WARN(ZS_NUMBER32_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st202;
tr800:
	{
		s->r_owner_length = s->dname_tmp_length;
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	{
		if (s->number64 <= UINT32_MAX) {
			s->r_ttl = (uint32_t)(s->number64);
		} else {
			WARN(ZS_NUMBER32_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st202;
tr801:
	{
		s->r_owner_length = s->dname_tmp_length;
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	{
		if (s->number64 <= UINT32_MAX) {
			s->r_ttl = (uint32_t)(s->number64);
		} else {
			WARN(ZS_NUMBER32_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st202;
tr802:
	{
		s->r_owner_length = s->dname_tmp_length;
	}
	{
		s->line_counter++;
	}
	{
		if (s->number64 <= UINT32_MAX) {
			s->r_ttl = (uint32_t)(s->number64);
		} else {
			WARN(ZS_NUMBER32_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st202;
st202:
	if ( ++p == pe )
		goto _test_eof202;
case 202:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto st202;
		case 32: goto st202;
		case 40: goto tr805;
		case 41: goto tr806;
		case 65: goto tr5;
		case 67: goto tr6;
		case 68: goto tr7;
		case 69: goto tr8;
		case 72: goto tr9;
		case 73: goto tr10;
		case 75: goto tr11;
		case 76: goto tr12;
		case 77: goto tr13;
		case 78: goto tr14;
		case 79: goto tr15;
		case 80: goto tr16;
		case 82: goto tr17;
		case 83: goto tr18;
		case 84: goto tr19;
		case 85: goto tr20;
		case 87: goto tr21;
		case 90: goto tr22;
		case 97: goto tr5;
		case 99: goto tr6;
		case 100: goto tr7;
		case 101: goto tr8;
		case 104: goto tr9;
		case 105: goto tr10;
		case 107: goto tr11;
		case 108: goto tr12;
		case 109: goto tr13;
		case 110: goto tr14;
		case 111: goto tr15;
		case 112: goto tr16;
		case 114: goto tr17;
		case 115: goto tr18;
		case 116: goto tr19;
		case 117: goto tr20;
		case 119: goto tr21;
		case 122: goto tr22;
		case 2058: goto tr807;
		case 2107: goto tr808;
	}
	if ( 48 <= _widec && _widec <= 57 )
		goto tr4;
	goto tr660;
tr808:
	{
		s->buffer_length = 0;
	}
	goto st203;
tr809:
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		}
	}
	goto st203;
tr803:
	{
		s->r_owner_length = s->dname_tmp_length;
	}
	{
		s->buffer_length = 0;
	}
	{
		if (s->number64 <= UINT32_MAX) {
			s->r_ttl = (uint32_t)(s->number64);
		} else {
			WARN(ZS_NUMBER32_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st203;
st203:
	if ( ++p == pe )
		goto _test_eof203;
case 203:
	_widec = (*p);
	if ( (*p) < 10 ) {
		if ( (*p) <= 9 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) > 10 ) {
		if ( 11 <= (*p) )
 {			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	if ( _widec == 2058 )
		goto tr810;
	if ( 1920 <= _widec && _widec <= 2175 )
		goto tr809;
	goto tr39;
tr32:
	{ if (s->number64 <= (UINT32_MAX / 86400)) {
	                  s->number64 *= 86400;
	              } else {
	                  WARN(ZS_NUMBER32_OVERFLOW);
	                  p--; {goto st316;}
	              }
	            }
	goto st204;
tr33:
	{ if (s->number64 <= (UINT32_MAX / 3600)) {
	                  s->number64 *= 3600;
	              } else {
	                  WARN(ZS_NUMBER32_OVERFLOW);
	                  p--; {goto st316;}
	              }
	            }
	goto st204;
tr34:
	{ if (s->number64 <= (UINT32_MAX / 60)) {
	                  s->number64 *= 60;
	              } else {
	                  WARN(ZS_NUMBER32_OVERFLOW);
	                  p--; {goto st316;}
	              }
	            }
	goto st204;
tr36:
	{ if (s->number64 <= (UINT32_MAX / 604800)) {
	                  s->number64 *= 604800;
	              } else {
	                  WARN(ZS_NUMBER32_OVERFLOW);
	                  p--; {goto st316;}
	              }
	            }
	goto st204;
st204:
	if ( ++p == pe )
		goto _test_eof204;
case 204:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr28;
		case 32: goto tr28;
		case 40: goto tr29;
		case 41: goto tr30;
		case 2058: goto tr37;
		case 2107: goto tr38;
	}
	if ( 48 <= _widec && _widec <= 57 )
		goto tr811;
	goto tr27;
tr812:
	{
		// Overflow check: 10*(s->number64) + fc - '0' <= UINT64_MAX
		if ((s->number64 < (UINT64_MAX / 10)) ||   // Dominant fast check.
			((s->number64 == (UINT64_MAX / 10)) && // Marginal case.
			 ((uint8_t)(*p) <= (UINT64_MAX % 10) + '0')
			)
		   ) {
			s->number64 *= 10;
			s->number64 += digit_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_NUMBER64_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st205;
tr811:
	{
		s->number64_tmp = s->number64;
	}
	{
		s->number64 = 0;
	}
	{
		// Overflow check: 10*(s->number64) + fc - '0' <= UINT64_MAX
		if ((s->number64 < (UINT64_MAX / 10)) ||   // Dominant fast check.
			((s->number64 == (UINT64_MAX / 10)) && // Marginal case.
			 ((uint8_t)(*p) <= (UINT64_MAX % 10) + '0')
			)
		   ) {
			s->number64 *= 10;
			s->number64 += digit_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_NUMBER64_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st205;
tr821:
	{
		if (s->number64 + s->number64_tmp < UINT32_MAX) {
			s->number64 += s->number64_tmp;
		} else {
			WARN(ZS_NUMBER32_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		s->number64_tmp = s->number64;
	}
	{
		s->number64 = 0;
	}
	{
		// Overflow check: 10*(s->number64) + fc - '0' <= UINT64_MAX
		if ((s->number64 < (UINT64_MAX / 10)) ||   // Dominant fast check.
			((s->number64 == (UINT64_MAX / 10)) && // Marginal case.
			 ((uint8_t)(*p) <= (UINT64_MAX % 10) + '0')
			)
		   ) {
			s->number64 *= 10;
			s->number64 += digit_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_NUMBER64_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st205;
st205:
	if ( ++p == pe )
		goto _test_eof205;
case 205:
	switch( (*p) ) {
		case 68: goto tr813;
		case 72: goto tr814;
		case 77: goto tr815;
		case 83: goto st206;
		case 87: goto tr817;
		case 100: goto tr813;
		case 104: goto tr814;
		case 109: goto tr815;
		case 115: goto st206;
		case 119: goto tr817;
	}
	if ( 48 <= (*p) && (*p) <= 57 )
		goto tr812;
	goto tr27;
tr813:
	{ if (s->number64 <= (UINT32_MAX / 86400)) {
	                  s->number64 *= 86400;
	              } else {
	                  WARN(ZS_NUMBER32_OVERFLOW);
	                  p--; {goto st316;}
	              }
	            }
	goto st206;
tr814:
	{ if (s->number64 <= (UINT32_MAX / 3600)) {
	                  s->number64 *= 3600;
	              } else {
	                  WARN(ZS_NUMBER32_OVERFLOW);
	                  p--; {goto st316;}
	              }
	            }
	goto st206;
tr815:
	{ if (s->number64 <= (UINT32_MAX / 60)) {
	                  s->number64 *= 60;
	              } else {
	                  WARN(ZS_NUMBER32_OVERFLOW);
	                  p--; {goto st316;}
	              }
	            }
	goto st206;
tr817:
	{ if (s->number64 <= (UINT32_MAX / 604800)) {
	                  s->number64 *= 604800;
	              } else {
	                  WARN(ZS_NUMBER32_OVERFLOW);
	                  p--; {goto st316;}
	              }
	            }
	goto st206;
st206:
	if ( ++p == pe )
		goto _test_eof206;
case 206:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr818;
		case 32: goto tr818;
		case 40: goto tr819;
		case 41: goto tr820;
		case 2058: goto tr822;
		case 2107: goto tr823;
	}
	if ( 48 <= _widec && _widec <= 57 )
		goto tr821;
	goto tr27;
tr62:
	{
		s->buffer_length = 0;
	}
	goto st207;
tr38:
	{
		if (s->number64 <= UINT32_MAX) {
			s->r_ttl = (uint32_t)(s->number64);
		} else {
			WARN(ZS_NUMBER32_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		s->buffer_length = 0;
	}
	goto st207;
tr824:
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		}
	}
	goto st207;
tr823:
	{
		if (s->number64 + s->number64_tmp < UINT32_MAX) {
			s->number64 += s->number64_tmp;
		} else {
			WARN(ZS_NUMBER32_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->number64 <= UINT32_MAX) {
			s->r_ttl = (uint32_t)(s->number64);
		} else {
			WARN(ZS_NUMBER32_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		s->buffer_length = 0;
	}
	goto st207;
st207:
	if ( ++p == pe )
		goto _test_eof207;
case 207:
	_widec = (*p);
	if ( (*p) < 10 ) {
		if ( (*p) <= 9 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) > 10 ) {
		if ( 11 <= (*p) )
 {			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	if ( _widec == 2058 )
		goto tr825;
	if ( 1920 <= _widec && _widec <= 2175 )
		goto tr824;
	goto tr39;
tr4311:
	{
		s->r_class = s->default_class;
	}
	{
		s->dname = s->r_owner;
		s->r_owner_length = 0;
	}
	{ p--; {stack[top++] = 208;goto st318;} }
	goto st208;
tr4333:
	{
		s->r_class = s->default_class;
	}
	{
		s->r_ttl = s->default_ttl;
	}
	{
		s->dname = s->r_owner;
		s->r_owner_length = 0;
	}
	{ p--; {stack[top++] = 208;goto st318;} }
	goto st208;
st208:
	if ( ++p == pe )
		goto _test_eof208;
case 208:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(2688 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 !s->multiline  ) _widec += 512;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(2688 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		if (
 !s->multiline  ) _widec += 512;
	}
	switch( _widec ) {
		case 9: goto tr827;
		case 32: goto tr827;
		case 40: goto tr828;
		case 41: goto tr829;
		case 65: goto st274;
		case 70: goto st277;
		case 80: goto st281;
		case 97: goto st274;
		case 102: goto st277;
		case 112: goto st281;
		case 3082: goto tr830;
		case 3131: goto tr831;
		case 3338: goto tr72;
		case 3387: goto tr72;
		case 3594: goto tr832;
		case 3643: goto tr833;
	}
	goto tr826;
tr835:
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st209;
tr836:
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st209;
tr837:
	{
		s->line_counter++;
	}
	goto st209;
tr1002:
	{
		s->buffer[s->buffer_length++] = 0;

		// Execute the comment callback.
		if (s->process.automatic && s->process.comment != NULL) {
			s->process.comment(s);

			// Stop if required from the callback.
			if (s->state == ZS_STATE_STOP) {
				{p++; cs = 209; goto _out;}
			}
		}
	}
	{
		s->line_counter++;
	}
	goto st209;
tr827:
	{
		s->r_owner_length = s->dname_tmp_length;
	}
	{ s->r_type = KNOT_RRTYPE_A; }
	{
		rdata_tail = s->r_data;
	}
	goto st209;
tr828:
	{
		s->r_owner_length = s->dname_tmp_length;
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	{ s->r_type = KNOT_RRTYPE_A; }
	{
		rdata_tail = s->r_data;
	}
	goto st209;
tr829:
	{
		s->r_owner_length = s->dname_tmp_length;
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	{ s->r_type = KNOT_RRTYPE_A; }
	{
		rdata_tail = s->r_data;
	}
	goto st209;
tr830:
	{
		s->r_owner_length = s->dname_tmp_length;
	}
	{
		s->line_counter++;
	}
	{ s->r_type = KNOT_RRTYPE_A; }
	{
		rdata_tail = s->r_data;
	}
	goto st209;
st209:
	if ( ++p == pe )
		goto _test_eof209;
case 209:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(2688 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 !s->multiline  ) _widec += 512;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(2688 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		if (
 !s->multiline  ) _widec += 512;
	}
	switch( _widec ) {
		case 9: goto st209;
		case 32: goto st209;
		case 40: goto tr835;
		case 41: goto tr836;
		case 58: goto tr75;
		case 65: goto tr124;
		case 67: goto tr125;
		case 68: goto tr126;
		case 69: goto tr127;
		case 72: goto tr128;
		case 73: goto tr129;
		case 75: goto tr130;
		case 76: goto tr131;
		case 77: goto tr132;
		case 78: goto tr133;
		case 79: goto tr134;
		case 80: goto tr135;
		case 82: goto tr136;
		case 83: goto tr137;
		case 84: goto tr138;
		case 85: goto tr139;
		case 87: goto tr140;
		case 90: goto tr141;
		case 92: goto tr80;
		case 97: goto tr124;
		case 99: goto tr125;
		case 100: goto tr126;
		case 101: goto tr127;
		case 104: goto tr128;
		case 105: goto tr129;
		case 107: goto tr130;
		case 108: goto tr131;
		case 109: goto tr132;
		case 110: goto tr133;
		case 111: goto tr134;
		case 112: goto tr135;
		case 114: goto tr136;
		case 115: goto tr137;
		case 116: goto tr138;
		case 117: goto tr139;
		case 119: goto tr140;
		case 122: goto tr141;
		case 3082: goto tr837;
		case 3131: goto tr838;
		case 3338: goto tr75;
		case 3387: goto tr75;
		case 3594: goto tr839;
		case 3643: goto tr840;
	}
	if ( _widec < 11 ) {
		if ( _widec <= 8 )
			goto tr75;
	} else if ( _widec > 47 ) {
		if ( _widec > 57 ) {
			if ( 60 <= _widec )
				goto tr75;
		} else if ( _widec >= 48 )
			goto tr123;
	} else
		goto tr75;
	goto tr662;
tr124:
	{
		s->r_class = s->default_class;
	}
	{
		s->r_ttl = s->default_ttl;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 210;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 210;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 210;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 210;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 210;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 210;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 210;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 210;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 210;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 210;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 210;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 210;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 210;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 210;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 210;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 210;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 210;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 210;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 210;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 210;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 210;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 210;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 210;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 210;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 210;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 210;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 210;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 210;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 210;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 210;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 210;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 210;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	goto st210;
st210:
	if ( ++p == pe )
		goto _test_eof210;
case 210:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(2688 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 !s->multiline  ) _widec += 512;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(2688 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		if (
 !s->multiline  ) _widec += 512;
	}
	switch( _widec ) {
		case 9: goto tr842;
		case 32: goto tr842;
		case 40: goto tr843;
		case 41: goto tr844;
		case 65: goto st274;
		case 70: goto st277;
		case 80: goto st281;
		case 97: goto st274;
		case 102: goto st277;
		case 112: goto st281;
		case 2826: goto tr89;
		case 2875: goto tr90;
		case 3082: goto tr845;
		case 3131: goto tr846;
		case 3338: goto tr847;
		case 3387: goto tr848;
		case 3594: goto tr849;
		case 3643: goto tr850;
	}
	goto tr841;
tr852:
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st211;
tr853:
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st211;
tr842:
	{ s->r_type = KNOT_RRTYPE_A; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->buffer[0] = 0;
		s->buffer_length = 0;
	}
	goto st211;
tr843:
	{ s->r_type = KNOT_RRTYPE_A; }
	{
		rdata_tail = s->r_data;
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	{
		s->buffer[0] = 0;
		s->buffer_length = 0;
	}
	goto st211;
tr844:
	{ s->r_type = KNOT_RRTYPE_A; }
	{
		rdata_tail = s->r_data;
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	{
		s->buffer[0] = 0;
		s->buffer_length = 0;
	}
	goto st211;
st211:
	if ( ++p == pe )
		goto _test_eof211;
case 211:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(2688 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 !s->multiline  ) _widec += 512;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(2688 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		if (
 !s->multiline  ) _widec += 512;
	}
	switch( _widec ) {
		case 9: goto st211;
		case 32: goto st211;
		case 40: goto tr852;
		case 41: goto tr853;
		case 92: goto tr80;
		case 2826: goto tr95;
		case 2875: goto tr96;
		case 3082: goto tr854;
		case 3131: goto tr113;
		case 3338: goto tr114;
		case 3387: goto tr115;
		case 3594: goto tr855;
		case 3643: goto tr116;
	}
	if ( _widec < 11 ) {
		if ( _widec <= 8 )
			goto tr75;
	} else if ( _widec > 58 ) {
		if ( 60 <= _widec )
			goto tr75;
	} else
		goto tr75;
	goto tr85;
tr107:
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 1450;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 1450;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 1450;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 1450;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 1450;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 1450;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 1450;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 1450;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 1450;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 1450;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 1450;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 1450;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 1450;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 1450;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 1450;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 1450;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 1450;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 1450;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 1450;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 1450;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 1450;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 1450;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 1450;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 1450;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 1450;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 1450;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 1450;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 1450;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 1450;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 1450;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 1450;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 1450;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	{
		s->buffer[0] = 0;
		s->buffer_length = 0;
	}
	{
		if (rdata_tail - s->r_data > UINT16_MAX) {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
		s->r_data_length = rdata_tail - s->r_data;

		s->state = ZS_STATE_DATA;

		// Execute the record callback.
		if (s->process.automatic) {
			if (s->process.record != NULL) {
				s->process.record(s);

				// Stop if required from the callback.
				if (s->state == ZS_STATE_STOP) {
					{p++; cs = 1450; goto _out;}
				}
			}
		} else {
			// Return if external processing.
			p--; {p++; cs = 1450; goto _out;}
		}
	}
	{
		s->line_counter++;
	}
	goto st1450;
tr114:
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 1450;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 1450;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 1450;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 1450;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 1450;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 1450;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 1450;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 1450;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 1450;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 1450;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 1450;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 1450;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 1450;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 1450;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 1450;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 1450;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 1450;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 1450;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 1450;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 1450;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 1450;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 1450;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 1450;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 1450;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 1450;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 1450;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 1450;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 1450;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 1450;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 1450;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 1450;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 1450;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	{
		if (rdata_tail - s->r_data > UINT16_MAX) {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
		s->r_data_length = rdata_tail - s->r_data;

		s->state = ZS_STATE_DATA;

		// Execute the record callback.
		if (s->process.automatic) {
			if (s->process.record != NULL) {
				s->process.record(s);

				// Stop if required from the callback.
				if (s->state == ZS_STATE_STOP) {
					{p++; cs = 1450; goto _out;}
				}
			}
		} else {
			// Return if external processing.
			p--; {p++; cs = 1450; goto _out;}
		}
	}
	{
		s->line_counter++;
	}
	goto st1450;
tr144:
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 1450;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 1450;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 1450;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 1450;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 1450;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 1450;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 1450;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 1450;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 1450;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 1450;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 1450;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 1450;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 1450;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 1450;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 1450;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 1450;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 1450;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 1450;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 1450;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 1450;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 1450;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 1450;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 1450;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 1450;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 1450;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 1450;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 1450;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 1450;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 1450;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 1450;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 1450;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 1450;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	{
		s->line_counter++;
	}
	goto st1450;
tr847:
	{ s->r_type = KNOT_RRTYPE_A; }
	{
		rdata_tail = s->r_data;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 1450;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 1450;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 1450;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 1450;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 1450;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 1450;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 1450;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 1450;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 1450;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 1450;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 1450;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 1450;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 1450;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 1450;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 1450;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 1450;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 1450;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 1450;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 1450;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 1450;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 1450;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 1450;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 1450;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 1450;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 1450;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 1450;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 1450;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 1450;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 1450;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 1450;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 1450;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 1450;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	{
		s->buffer[0] = 0;
		s->buffer_length = 0;
	}
	{
		if (rdata_tail - s->r_data > UINT16_MAX) {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
		s->r_data_length = rdata_tail - s->r_data;

		s->state = ZS_STATE_DATA;

		// Execute the record callback.
		if (s->process.automatic) {
			if (s->process.record != NULL) {
				s->process.record(s);

				// Stop if required from the callback.
				if (s->state == ZS_STATE_STOP) {
					{p++; cs = 1450; goto _out;}
				}
			}
		} else {
			// Return if external processing.
			p--; {p++; cs = 1450; goto _out;}
		}
	}
	{
		s->line_counter++;
	}
	goto st1450;
tr4303:
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 1450;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 1450;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 1450;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 1450;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 1450;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 1450;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 1450;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 1450;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 1450;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 1450;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 1450;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 1450;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 1450;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 1450;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 1450;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 1450;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 1450;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 1450;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 1450;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 1450;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 1450;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 1450;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 1450;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 1450;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 1450;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 1450;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 1450;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 1450;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 1450;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 1450;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 1450;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 1450;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	{
		s->buffer[0] = 0;
		s->buffer_length = 0;
	}
	{
		s->line_counter++;
	}
	goto st1450;
st1450:
	if ( ++p == pe )
		goto _test_eof1450;
case 1450:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr4365;
		case 32: goto tr4365;
		case 36: goto st190;
		case 40: goto tr4366;
		case 41: goto tr4367;
		case 42: goto tr4290;
		case 92: goto tr4290;
		case 95: goto tr4290;
		case 1802: goto tr89;
		case 1851: goto tr90;
		case 2058: goto tr4368;
		case 2107: goto tr4369;
	}
	if ( _widec < 64 ) {
		if ( 45 <= _widec && _widec <= 57 )
			goto tr4290;
	} else if ( _widec > 90 ) {
		if ( 97 <= _widec && _widec <= 122 )
			goto tr4290;
	} else
		goto tr4290;
	goto tr889;
tr857:
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st212;
tr858:
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st212;
tr927:
	{
		s->buffer[0] = 0;
		s->buffer_length = 0;
	}
	goto st212;
tr928:
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	{
		s->buffer[0] = 0;
		s->buffer_length = 0;
	}
	goto st212;
tr929:
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	{
		s->buffer[0] = 0;
		s->buffer_length = 0;
	}
	goto st212;
tr890:
	{
		s->r_owner_length = s->dname_tmp_length;
	}
	{
		s->buffer[0] = 0;
		s->buffer_length = 0;
	}
	goto st212;
tr891:
	{
		s->r_owner_length = s->dname_tmp_length;
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	{
		s->buffer[0] = 0;
		s->buffer_length = 0;
	}
	goto st212;
tr892:
	{
		s->r_owner_length = s->dname_tmp_length;
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	{
		s->buffer[0] = 0;
		s->buffer_length = 0;
	}
	goto st212;
tr4365:
	{
		s->buffer[0] = 0;
		s->buffer_length = 0;
	}
	{
		if (s->r_owner_length == 0) {
			WARN(ZS_BAD_PREVIOUS_OWNER);
			p--; {goto st316;}
		}
	}
	goto st212;
tr4366:
	{
		s->buffer[0] = 0;
		s->buffer_length = 0;
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	{
		if (s->r_owner_length == 0) {
			WARN(ZS_BAD_PREVIOUS_OWNER);
			p--; {goto st316;}
		}
	}
	goto st212;
tr4367:
	{
		s->buffer[0] = 0;
		s->buffer_length = 0;
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	{
		if (s->r_owner_length == 0) {
			WARN(ZS_BAD_PREVIOUS_OWNER);
			p--; {goto st316;}
		}
	}
	goto st212;
st212:
	if ( ++p == pe )
		goto _test_eof212;
case 212:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto st212;
		case 32: goto st212;
		case 40: goto tr857;
		case 41: goto tr858;
		case 65: goto tr5;
		case 67: goto tr6;
		case 68: goto tr7;
		case 69: goto tr8;
		case 72: goto tr9;
		case 73: goto tr10;
		case 75: goto tr11;
		case 76: goto tr12;
		case 77: goto tr13;
		case 78: goto tr14;
		case 79: goto tr15;
		case 80: goto tr16;
		case 82: goto tr17;
		case 83: goto tr18;
		case 84: goto tr19;
		case 85: goto tr20;
		case 87: goto tr21;
		case 90: goto tr22;
		case 97: goto tr5;
		case 99: goto tr6;
		case 100: goto tr7;
		case 101: goto tr8;
		case 104: goto tr9;
		case 105: goto tr10;
		case 107: goto tr11;
		case 108: goto tr12;
		case 109: goto tr13;
		case 110: goto tr14;
		case 111: goto tr15;
		case 112: goto tr16;
		case 114: goto tr17;
		case 115: goto tr18;
		case 116: goto tr19;
		case 117: goto tr20;
		case 119: goto tr21;
		case 122: goto tr22;
		case 1802: goto tr95;
		case 1851: goto tr96;
		case 2058: goto tr859;
		case 2107: goto tr860;
	}
	if ( 48 <= _widec && _widec <= 57 )
		goto tr4;
	goto tr0;
tr860:
	{
		s->buffer_length = 0;
	}
	goto st213;
tr861:
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		}
	}
	goto st213;
tr931:
	{
		s->buffer_length = 0;
	}
	{
		s->buffer[0] = 0;
		s->buffer_length = 0;
	}
	goto st213;
tr936:
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		}
	}
	{
		s->buffer[0] = 0;
		s->buffer_length = 0;
	}
	{
		s->buffer_length = 0;
	}
	goto st213;
tr940:
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		}
	}
	{
		s->buffer_length = 0;
	}
	goto st213;
tr894:
	{
		s->r_owner_length = s->dname_tmp_length;
	}
	{
		s->buffer_length = 0;
	}
	{
		s->buffer[0] = 0;
		s->buffer_length = 0;
	}
	goto st213;
tr4369:
	{
		s->buffer[0] = 0;
		s->buffer_length = 0;
	}
	{
		s->buffer_length = 0;
	}
	{
		if (s->r_owner_length == 0) {
			WARN(ZS_BAD_PREVIOUS_OWNER);
			p--; {goto st316;}
		}
	}
	goto st213;
st213:
	if ( ++p == pe )
		goto _test_eof213;
case 213:
	_widec = (*p);
	if ( (*p) < 10 ) {
		if ( (*p) <= 9 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) > 10 ) {
		if ( 11 <= (*p) )
 {			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 1802: goto tr98;
		case 2058: goto tr862;
	}
	if ( _widec > 1919 ) {
		if ( 1920 <= _widec && _widec <= 2175 )
			goto tr861;
	} else if ( _widec >= 1664 )
		goto tr97;
	goto tr91;
tr108:
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 214;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 214;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 214;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 214;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 214;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 214;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 214;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 214;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 214;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 214;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 214;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 214;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 214;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 214;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 214;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 214;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 214;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 214;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 214;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 214;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 214;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 214;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 214;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 214;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 214;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 214;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 214;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 214;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 214;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 214;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 214;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 214;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	{
		s->buffer[0] = 0;
		s->buffer_length = 0;
	}
	{
		s->buffer_length = 0;
	}
	goto st214;
tr115:
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 214;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 214;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 214;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 214;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 214;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 214;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 214;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 214;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 214;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 214;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 214;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 214;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 214;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 214;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 214;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 214;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 214;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 214;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 214;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 214;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 214;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 214;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 214;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 214;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 214;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 214;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 214;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 214;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 214;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 214;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 214;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 214;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	{
		s->buffer_length = 0;
	}
	goto st214;
tr848:
	{ s->r_type = KNOT_RRTYPE_A; }
	{
		rdata_tail = s->r_data;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 214;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 214;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 214;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 214;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 214;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 214;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 214;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 214;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 214;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 214;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 214;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 214;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 214;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 214;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 214;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 214;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 214;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 214;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 214;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 214;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 214;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 214;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 214;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 214;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 214;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 214;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 214;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 214;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 214;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 214;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 214;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 214;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	{
		s->buffer[0] = 0;
		s->buffer_length = 0;
	}
	{
		s->buffer_length = 0;
	}
	goto st214;
st214:
	if ( ++p == pe )
		goto _test_eof214;
case 214:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr863;
		case 32: goto tr863;
		case 40: goto tr864;
		case 41: goto tr865;
		case 1802: goto tr866;
		case 1851: goto tr867;
		case 2058: goto tr866;
		case 2107: goto tr867;
	}
	if ( _widec < 11 ) {
		if ( _widec <= 8 )
			goto tr97;
	} else if ( _widec > 58 ) {
		if ( 60 <= _widec )
			goto tr97;
	} else
		goto tr97;
	goto tr85;
tr868:
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		}
	}
	goto st215;
tr863:
	{
		s->buffer[0] = 0;
		s->buffer_length = 0;
	}
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		}
	}
	goto st215;
tr864:
	{
		s->buffer[0] = 0;
		s->buffer_length = 0;
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		}
	}
	goto st215;
tr865:
	{
		s->buffer[0] = 0;
		s->buffer_length = 0;
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		}
	}
	goto st215;
tr869:
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		}
	}
	goto st215;
tr870:
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		}
	}
	goto st215;
st215:
	if ( ++p == pe )
		goto _test_eof215;
case 215:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr868;
		case 32: goto tr868;
		case 40: goto tr869;
		case 41: goto tr870;
		case 1802: goto tr98;
		case 1851: goto tr871;
		case 2058: goto tr98;
		case 2107: goto tr871;
	}
	if ( _widec < 11 ) {
		if ( _widec <= 8 )
			goto tr97;
	} else if ( _widec > 58 ) {
		if ( 60 <= _widec )
			goto tr97;
	} else
		goto tr97;
	goto tr91;
tr849:
	{ s->r_type = KNOT_RRTYPE_A; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->line_counter++;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 1451;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 1451;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 1451;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 1451;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 1451;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 1451;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 1451;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 1451;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 1451;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 1451;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 1451;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 1451;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 1451;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 1451;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 1451;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 1451;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 1451;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 1451;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 1451;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 1451;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 1451;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 1451;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 1451;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 1451;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 1451;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 1451;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 1451;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 1451;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 1451;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 1451;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 1451;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 1451;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	{
		s->buffer[0] = 0;
		s->buffer_length = 0;
	}
	{
		if (rdata_tail - s->r_data > UINT16_MAX) {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
		s->r_data_length = rdata_tail - s->r_data;

		s->state = ZS_STATE_DATA;

		// Execute the record callback.
		if (s->process.automatic) {
			if (s->process.record != NULL) {
				s->process.record(s);

				// Stop if required from the callback.
				if (s->state == ZS_STATE_STOP) {
					{p++; cs = 1451; goto _out;}
				}
			}
		} else {
			// Return if external processing.
			p--; {p++; cs = 1451; goto _out;}
		}
	}
	goto st1451;
tr855:
	{
		s->line_counter++;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 1451;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 1451;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 1451;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 1451;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 1451;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 1451;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 1451;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 1451;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 1451;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 1451;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 1451;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 1451;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 1451;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 1451;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 1451;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 1451;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 1451;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 1451;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 1451;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 1451;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 1451;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 1451;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 1451;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 1451;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 1451;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 1451;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 1451;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 1451;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 1451;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 1451;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 1451;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 1451;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	{
		if (rdata_tail - s->r_data > UINT16_MAX) {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
		s->r_data_length = rdata_tail - s->r_data;

		s->state = ZS_STATE_DATA;

		// Execute the record callback.
		if (s->process.automatic) {
			if (s->process.record != NULL) {
				s->process.record(s);

				// Stop if required from the callback.
				if (s->state == ZS_STATE_STOP) {
					{p++; cs = 1451; goto _out;}
				}
			}
		} else {
			// Return if external processing.
			p--; {p++; cs = 1451; goto _out;}
		}
	}
	goto st1451;
st1451:
	if ( ++p == pe )
		goto _test_eof1451;
case 1451:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(2688 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 !s->multiline  ) _widec += 512;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(2688 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		if (
 !s->multiline  ) _widec += 512;
	}
	switch( _widec ) {
		case 9: goto tr4370;
		case 32: goto tr4370;
		case 36: goto tr4296;
		case 40: goto tr4371;
		case 41: goto tr4372;
		case 42: goto tr4299;
		case 58: goto tr75;
		case 92: goto tr4300;
		case 95: goto tr4299;
		case 2826: goto tr89;
		case 2875: goto tr90;
		case 3082: goto tr4368;
		case 3131: goto tr4373;
		case 3338: goto tr107;
		case 3387: goto tr108;
		case 3594: goto tr4368;
		case 3643: goto tr4374;
	}
	if ( _widec < 60 ) {
		if ( _widec < 11 ) {
			if ( _widec <= 8 )
				goto tr75;
		} else if ( _widec > 44 ) {
			if ( 45 <= _widec && _widec <= 57 )
				goto tr4299;
		} else
			goto tr75;
	} else if ( _widec > 63 ) {
		if ( _widec < 91 ) {
			if ( 64 <= _widec && _widec <= 90 )
				goto tr4299;
		} else if ( _widec > 96 ) {
			if ( _widec > 122 ) {
				if ( 123 <= _widec )
					goto tr75;
			} else if ( _widec >= 97 )
				goto tr4299;
		} else
			goto tr75;
	} else
		goto tr75;
	goto tr889;
tr873:
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st216;
tr874:
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st216;
tr1003:
	{
		s->buffer[0] = 0;
		s->buffer_length = 0;
	}
	goto st216;
tr1004:
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	{
		s->buffer[0] = 0;
		s->buffer_length = 0;
	}
	goto st216;
tr1005:
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	{
		s->buffer[0] = 0;
		s->buffer_length = 0;
	}
	goto st216;
tr4370:
	{
		s->buffer[0] = 0;
		s->buffer_length = 0;
	}
	{
		if (s->r_owner_length == 0) {
			WARN(ZS_BAD_PREVIOUS_OWNER);
			p--; {goto st316;}
		}
	}
	goto st216;
tr4371:
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	{
		s->buffer[0] = 0;
		s->buffer_length = 0;
	}
	{
		if (s->r_owner_length == 0) {
			WARN(ZS_BAD_PREVIOUS_OWNER);
			p--; {goto st316;}
		}
	}
	goto st216;
tr4372:
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	{
		s->buffer[0] = 0;
		s->buffer_length = 0;
	}
	{
		if (s->r_owner_length == 0) {
			WARN(ZS_BAD_PREVIOUS_OWNER);
			p--; {goto st316;}
		}
	}
	goto st216;
st216:
	if ( ++p == pe )
		goto _test_eof216;
case 216:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(2688 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 !s->multiline  ) _widec += 512;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(2688 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		if (
 !s->multiline  ) _widec += 512;
	}
	switch( _widec ) {
		case 9: goto st216;
		case 32: goto st216;
		case 40: goto tr873;
		case 41: goto tr874;
		case 58: goto tr75;
		case 65: goto tr124;
		case 67: goto tr125;
		case 68: goto tr126;
		case 69: goto tr127;
		case 72: goto tr128;
		case 73: goto tr129;
		case 75: goto tr130;
		case 76: goto tr131;
		case 77: goto tr132;
		case 78: goto tr133;
		case 79: goto tr134;
		case 80: goto tr135;
		case 82: goto tr136;
		case 83: goto tr137;
		case 84: goto tr138;
		case 85: goto tr139;
		case 87: goto tr140;
		case 90: goto tr141;
		case 92: goto tr80;
		case 97: goto tr124;
		case 99: goto tr125;
		case 100: goto tr126;
		case 101: goto tr127;
		case 104: goto tr128;
		case 105: goto tr129;
		case 107: goto tr130;
		case 108: goto tr131;
		case 109: goto tr132;
		case 110: goto tr133;
		case 111: goto tr134;
		case 112: goto tr135;
		case 114: goto tr136;
		case 115: goto tr137;
		case 116: goto tr138;
		case 117: goto tr139;
		case 119: goto tr140;
		case 122: goto tr141;
		case 2826: goto tr95;
		case 2875: goto tr96;
		case 3082: goto tr859;
		case 3131: goto tr875;
		case 3338: goto tr114;
		case 3387: goto tr115;
		case 3594: goto tr859;
		case 3643: goto tr876;
	}
	if ( _widec < 11 ) {
		if ( _widec <= 8 )
			goto tr75;
	} else if ( _widec > 47 ) {
		if ( _widec > 57 ) {
			if ( 60 <= _widec )
				goto tr75;
		} else if ( _widec >= 48 )
			goto tr123;
	} else
		goto tr75;
	goto tr120;
tr125:
	{
		s->r_class = s->default_class;
	}
	{
		s->r_ttl = s->default_ttl;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 217;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 217;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 217;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 217;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 217;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 217;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 217;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 217;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 217;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 217;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 217;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 217;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 217;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 217;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 217;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 217;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 217;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 217;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 217;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 217;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 217;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 217;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 217;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 217;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 217;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 217;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 217;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 217;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 217;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 217;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 217;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 217;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	goto st217;
st217:
	if ( ++p == pe )
		goto _test_eof217;
case 217:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr86;
		case 32: goto tr86;
		case 40: goto tr87;
		case 41: goto tr88;
		case 65: goto st18;
		case 68: goto st22;
		case 69: goto st29;
		case 78: goto st32;
		case 83: goto st36;
		case 97: goto st18;
		case 100: goto st22;
		case 101: goto st29;
		case 110: goto st32;
		case 115: goto st36;
		case 1802: goto tr89;
		case 1851: goto tr90;
		case 2058: goto tr89;
		case 2107: goto tr90;
	}
	goto tr841;
tr126:
	{
		s->r_class = s->default_class;
	}
	{
		s->r_ttl = s->default_ttl;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 218;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 218;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 218;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 218;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 218;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 218;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 218;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 218;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 218;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 218;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 218;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 218;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 218;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 218;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 218;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 218;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 218;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 218;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 218;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 218;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 218;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 218;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 218;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 218;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 218;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 218;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 218;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 218;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 218;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 218;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 218;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 218;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	goto st218;
st218:
	if ( ++p == pe )
		goto _test_eof218;
case 218:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr86;
		case 32: goto tr86;
		case 40: goto tr87;
		case 41: goto tr88;
		case 72: goto st41;
		case 78: goto st45;
		case 83: goto st53;
		case 104: goto st41;
		case 110: goto st45;
		case 115: goto st53;
		case 1802: goto tr89;
		case 1851: goto tr90;
		case 2058: goto tr89;
		case 2107: goto tr90;
	}
	goto tr841;
tr127:
	{
		s->r_class = s->default_class;
	}
	{
		s->r_ttl = s->default_ttl;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 219;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 219;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 219;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 219;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 219;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 219;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 219;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 219;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 219;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 219;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 219;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 219;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 219;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 219;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 219;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 219;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 219;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 219;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 219;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 219;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 219;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 219;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 219;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 219;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 219;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 219;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 219;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 219;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 219;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 219;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 219;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 219;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	goto st219;
st219:
	if ( ++p == pe )
		goto _test_eof219;
case 219:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr86;
		case 32: goto tr86;
		case 40: goto tr87;
		case 41: goto tr88;
		case 85: goto st55;
		case 117: goto st55;
		case 1802: goto tr89;
		case 1851: goto tr90;
		case 2058: goto tr89;
		case 2107: goto tr90;
	}
	goto tr841;
tr128:
	{
		s->r_class = s->default_class;
	}
	{
		s->r_ttl = s->default_ttl;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 220;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 220;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 220;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 220;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 220;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 220;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 220;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 220;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 220;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 220;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 220;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 220;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 220;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 220;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 220;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 220;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 220;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 220;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 220;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 220;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 220;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 220;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 220;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 220;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 220;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 220;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 220;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 220;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 220;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 220;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 220;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 220;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	goto st220;
st220:
	if ( ++p == pe )
		goto _test_eof220;
case 220:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr86;
		case 32: goto tr86;
		case 40: goto tr87;
		case 41: goto tr88;
		case 73: goto st62;
		case 84: goto st66;
		case 105: goto st62;
		case 116: goto st66;
		case 1802: goto tr89;
		case 1851: goto tr90;
		case 2058: goto tr89;
		case 2107: goto tr90;
	}
	goto tr841;
tr129:
	{
		s->r_class = s->default_class;
	}
	{
		s->r_ttl = s->default_ttl;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 221;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 221;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 221;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 221;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 221;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 221;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 221;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 221;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 221;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 221;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 221;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 221;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 221;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 221;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 221;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 221;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 221;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 221;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 221;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 221;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 221;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 221;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 221;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 221;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 221;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 221;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 221;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 221;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 221;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 221;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 221;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 221;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	goto st221;
st221:
	if ( ++p == pe )
		goto _test_eof221;
case 221:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr86;
		case 32: goto tr86;
		case 40: goto tr87;
		case 41: goto tr88;
		case 78: goto st182;
		case 80: goto st74;
		case 110: goto st182;
		case 112: goto st74;
		case 1802: goto tr89;
		case 1851: goto tr90;
		case 2058: goto tr89;
		case 2107: goto tr90;
	}
	goto tr841;
tr130:
	{
		s->r_class = s->default_class;
	}
	{
		s->r_ttl = s->default_ttl;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 222;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 222;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 222;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 222;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 222;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 222;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 222;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 222;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 222;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 222;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 222;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 222;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 222;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 222;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 222;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 222;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 222;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 222;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 222;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 222;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 222;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 222;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 222;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 222;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 222;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 222;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 222;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 222;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 222;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 222;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 222;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 222;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	goto st222;
st222:
	if ( ++p == pe )
		goto _test_eof222;
case 222:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr86;
		case 32: goto tr86;
		case 40: goto tr87;
		case 41: goto tr88;
		case 69: goto st82;
		case 88: goto st84;
		case 101: goto st82;
		case 120: goto st84;
		case 1802: goto tr89;
		case 1851: goto tr90;
		case 2058: goto tr89;
		case 2107: goto tr90;
	}
	goto tr841;
tr131:
	{
		s->r_class = s->default_class;
	}
	{
		s->r_ttl = s->default_ttl;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 223;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 223;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 223;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 223;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 223;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 223;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 223;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 223;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 223;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 223;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 223;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 223;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 223;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 223;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 223;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 223;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 223;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 223;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 223;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 223;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 223;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 223;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 223;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 223;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 223;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 223;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 223;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 223;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 223;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 223;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 223;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 223;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	goto st223;
st223:
	if ( ++p == pe )
		goto _test_eof223;
case 223:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr86;
		case 32: goto tr86;
		case 40: goto tr87;
		case 41: goto tr88;
		case 51: goto st86;
		case 54: goto st88;
		case 79: goto st90;
		case 80: goto st92;
		case 111: goto st90;
		case 112: goto st92;
		case 1802: goto tr89;
		case 1851: goto tr90;
		case 2058: goto tr89;
		case 2107: goto tr90;
	}
	goto tr841;
tr132:
	{
		s->r_class = s->default_class;
	}
	{
		s->r_ttl = s->default_ttl;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 224;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 224;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 224;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 224;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 224;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 224;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 224;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 224;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 224;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 224;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 224;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 224;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 224;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 224;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 224;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 224;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 224;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 224;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 224;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 224;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 224;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 224;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 224;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 224;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 224;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 224;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 224;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 224;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 224;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 224;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 224;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 224;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	goto st224;
st224:
	if ( ++p == pe )
		goto _test_eof224;
case 224:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr86;
		case 32: goto tr86;
		case 40: goto tr87;
		case 41: goto tr88;
		case 73: goto st94;
		case 88: goto st98;
		case 105: goto st94;
		case 120: goto st98;
		case 1802: goto tr89;
		case 1851: goto tr90;
		case 2058: goto tr89;
		case 2107: goto tr90;
	}
	goto tr841;
tr133:
	{
		s->r_class = s->default_class;
	}
	{
		s->r_ttl = s->default_ttl;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 225;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 225;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 225;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 225;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 225;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 225;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 225;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 225;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 225;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 225;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 225;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 225;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 225;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 225;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 225;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 225;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 225;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 225;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 225;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 225;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 225;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 225;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 225;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 225;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 225;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 225;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 225;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 225;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 225;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 225;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 225;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 225;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	goto st225;
st225:
	if ( ++p == pe )
		goto _test_eof225;
case 225:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr86;
		case 32: goto tr86;
		case 40: goto tr87;
		case 41: goto tr88;
		case 65: goto st100;
		case 73: goto st104;
		case 83: goto st106;
		case 97: goto st100;
		case 105: goto st104;
		case 115: goto st106;
		case 1802: goto tr89;
		case 1851: goto tr90;
		case 2058: goto tr89;
		case 2107: goto tr90;
	}
	goto tr841;
tr134:
	{
		s->r_class = s->default_class;
	}
	{
		s->r_ttl = s->default_ttl;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 226;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 226;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 226;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 226;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 226;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 226;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 226;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 226;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 226;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 226;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 226;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 226;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 226;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 226;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 226;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 226;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 226;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 226;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 226;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 226;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 226;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 226;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 226;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 226;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 226;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 226;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 226;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 226;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 226;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 226;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 226;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 226;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	goto st226;
st226:
	if ( ++p == pe )
		goto _test_eof226;
case 226:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr86;
		case 32: goto tr86;
		case 40: goto tr87;
		case 41: goto tr88;
		case 80: goto st116;
		case 112: goto st116;
		case 1802: goto tr89;
		case 1851: goto tr90;
		case 2058: goto tr89;
		case 2107: goto tr90;
	}
	goto tr841;
tr135:
	{
		s->r_class = s->default_class;
	}
	{
		s->r_ttl = s->default_ttl;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 227;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 227;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 227;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 227;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 227;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 227;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 227;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 227;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 227;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 227;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 227;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 227;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 227;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 227;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 227;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 227;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 227;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 227;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 227;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 227;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 227;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 227;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 227;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 227;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 227;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 227;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 227;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 227;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 227;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 227;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 227;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 227;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	goto st227;
st227:
	if ( ++p == pe )
		goto _test_eof227;
case 227:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr86;
		case 32: goto tr86;
		case 40: goto tr87;
		case 41: goto tr88;
		case 84: goto st126;
		case 116: goto st126;
		case 1802: goto tr89;
		case 1851: goto tr90;
		case 2058: goto tr89;
		case 2107: goto tr90;
	}
	goto tr841;
tr136:
	{
		s->r_class = s->default_class;
	}
	{
		s->r_ttl = s->default_ttl;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 228;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 228;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 228;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 228;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 228;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 228;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 228;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 228;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 228;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 228;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 228;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 228;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 228;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 228;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 228;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 228;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 228;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 228;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 228;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 228;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 228;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 228;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 228;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 228;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 228;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 228;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 228;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 228;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 228;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 228;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 228;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 228;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	goto st228;
st228:
	if ( ++p == pe )
		goto _test_eof228;
case 228:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr86;
		case 32: goto tr86;
		case 40: goto tr87;
		case 41: goto tr88;
		case 80: goto st129;
		case 82: goto st130;
		case 84: goto st134;
		case 112: goto st129;
		case 114: goto st130;
		case 116: goto st134;
		case 1802: goto tr89;
		case 1851: goto tr90;
		case 2058: goto tr89;
		case 2107: goto tr90;
	}
	goto tr841;
tr137:
	{
		s->r_class = s->default_class;
	}
	{
		s->r_ttl = s->default_ttl;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 229;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 229;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 229;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 229;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 229;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 229;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 229;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 229;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 229;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 229;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 229;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 229;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 229;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 229;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 229;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 229;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 229;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 229;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 229;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 229;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 229;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 229;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 229;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 229;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 229;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 229;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 229;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 229;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 229;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 229;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 229;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 229;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	goto st229;
st229:
	if ( ++p == pe )
		goto _test_eof229;
case 229:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr86;
		case 32: goto tr86;
		case 40: goto tr87;
		case 41: goto tr88;
		case 77: goto st136;
		case 79: goto st141;
		case 80: goto st143;
		case 82: goto st145;
		case 83: goto st147;
		case 86: goto st151;
		case 109: goto st136;
		case 111: goto st141;
		case 112: goto st143;
		case 114: goto st145;
		case 115: goto st147;
		case 118: goto st151;
		case 1802: goto tr89;
		case 1851: goto tr90;
		case 2058: goto tr89;
		case 2107: goto tr90;
	}
	goto tr841;
tr138:
	{
		s->r_class = s->default_class;
	}
	{
		s->r_ttl = s->default_ttl;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 230;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 230;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 230;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 230;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 230;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 230;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 230;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 230;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 230;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 230;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 230;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 230;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 230;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 230;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 230;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 230;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 230;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 230;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 230;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 230;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 230;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 230;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 230;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 230;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 230;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 230;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 230;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 230;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 230;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 230;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 230;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 230;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	goto st230;
st230:
	if ( ++p == pe )
		goto _test_eof230;
case 230:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr86;
		case 32: goto tr86;
		case 40: goto tr87;
		case 41: goto tr88;
		case 76: goto st155;
		case 88: goto st158;
		case 89: goto st160;
		case 108: goto st155;
		case 120: goto st158;
		case 121: goto st160;
		case 1802: goto tr89;
		case 1851: goto tr90;
		case 2058: goto tr89;
		case 2107: goto tr90;
	}
	goto tr841;
tr139:
	{
		s->r_class = s->default_class;
	}
	{
		s->r_ttl = s->default_ttl;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 231;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 231;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 231;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 231;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 231;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 231;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 231;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 231;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 231;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 231;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 231;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 231;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 231;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 231;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 231;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 231;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 231;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 231;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 231;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 231;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 231;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 231;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 231;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 231;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 231;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 231;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 231;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 231;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 231;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 231;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 231;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 231;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	goto st231;
st231:
	if ( ++p == pe )
		goto _test_eof231;
case 231:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr86;
		case 32: goto tr86;
		case 40: goto tr87;
		case 41: goto tr88;
		case 82: goto st165;
		case 114: goto st165;
		case 1802: goto tr89;
		case 1851: goto tr90;
		case 2058: goto tr89;
		case 2107: goto tr90;
	}
	goto tr841;
tr140:
	{
		s->r_class = s->default_class;
	}
	{
		s->r_ttl = s->default_ttl;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 232;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 232;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 232;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 232;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 232;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 232;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 232;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 232;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 232;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 232;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 232;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 232;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 232;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 232;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 232;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 232;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 232;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 232;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 232;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 232;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 232;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 232;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 232;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 232;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 232;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 232;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 232;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 232;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 232;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 232;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 232;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 232;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	goto st232;
st232:
	if ( ++p == pe )
		goto _test_eof232;
case 232:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr86;
		case 32: goto tr86;
		case 40: goto tr87;
		case 41: goto tr88;
		case 65: goto st168;
		case 97: goto st168;
		case 1802: goto tr89;
		case 1851: goto tr90;
		case 2058: goto tr89;
		case 2107: goto tr90;
	}
	goto tr841;
tr141:
	{
		s->r_class = s->default_class;
	}
	{
		s->r_ttl = s->default_ttl;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 233;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 233;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 233;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 233;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 233;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 233;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 233;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 233;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 233;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 233;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 233;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 233;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 233;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 233;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 233;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 233;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 233;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 233;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 233;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 233;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 233;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 233;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 233;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 233;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 233;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 233;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 233;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 233;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 233;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 233;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 233;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 233;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	goto st233;
st233:
	if ( ++p == pe )
		goto _test_eof233;
case 233:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr86;
		case 32: goto tr86;
		case 40: goto tr87;
		case 41: goto tr88;
		case 79: goto st174;
		case 111: goto st174;
		case 1802: goto tr89;
		case 1851: goto tr90;
		case 2058: goto tr89;
		case 2107: goto tr90;
	}
	goto tr841;
tr875:
	{
		s->buffer_length = 0;
	}
	goto st234;
tr877:
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		}
	}
	goto st234;
tr1006:
	{
		s->buffer_length = 0;
	}
	{
		s->buffer[0] = 0;
		s->buffer_length = 0;
	}
	goto st234;
tr944:
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		}
	}
	{
		s->buffer[0] = 0;
		s->buffer_length = 0;
	}
	{
		s->buffer_length = 0;
	}
	goto st234;
tr948:
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		}
	}
	{
		s->buffer_length = 0;
	}
	goto st234;
tr913:
	{
		s->r_owner_length = s->dname_tmp_length;
	}
	{
		s->buffer_length = 0;
	}
	{ s->r_type = KNOT_RRTYPE_A; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->buffer[0] = 0;
		s->buffer_length = 0;
	}
	goto st234;
tr4373:
	{
		s->buffer_length = 0;
	}
	{
		s->buffer[0] = 0;
		s->buffer_length = 0;
	}
	{
		if (s->r_owner_length == 0) {
			WARN(ZS_BAD_PREVIOUS_OWNER);
			p--; {goto st316;}
		}
	}
	goto st234;
st234:
	if ( ++p == pe )
		goto _test_eof234;
case 234:
	_widec = (*p);
	if ( (*p) < 10 ) {
		if ( (*p) <= 9 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) > 10 ) {
		if ( 11 <= (*p) )
 {			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 1802: goto tr98;
		case 2058: goto tr878;
	}
	if ( _widec > 1919 ) {
		if ( 1920 <= _widec && _widec <= 2175 )
			goto tr877;
	} else if ( _widec >= 1664 )
		goto tr97;
	goto tr85;
tr142:
	{
		s->line_counter++;
	}
	goto st1452;
tr980:
	{
		s->buffer[s->buffer_length++] = 0;

		// Execute the comment callback.
		if (s->process.automatic && s->process.comment != NULL) {
			s->process.comment(s);

			// Stop if required from the callback.
			if (s->state == ZS_STATE_STOP) {
				{p++; cs = 1452; goto _out;}
			}
		}
	}
	{
		s->line_counter++;
	}
	goto st1452;
tr878:
	{
		s->buffer[s->buffer_length++] = 0;

		// Execute the comment callback.
		if (s->process.automatic && s->process.comment != NULL) {
			s->process.comment(s);

			// Stop if required from the callback.
			if (s->state == ZS_STATE_STOP) {
				{p++; cs = 1452; goto _out;}
			}
		}
	}
	{
		s->line_counter++;
	}
	{
		if (rdata_tail - s->r_data > UINT16_MAX) {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
		s->r_data_length = rdata_tail - s->r_data;

		s->state = ZS_STATE_DATA;

		// Execute the record callback.
		if (s->process.automatic) {
			if (s->process.record != NULL) {
				s->process.record(s);

				// Stop if required from the callback.
				if (s->state == ZS_STATE_STOP) {
					{p++; cs = 1452; goto _out;}
				}
			}
		} else {
			// Return if external processing.
			p--; {p++; cs = 1452; goto _out;}
		}
	}
	goto st1452;
tr919:
	{
		s->line_counter++;
	}
	{
		if (rdata_tail - s->r_data > UINT16_MAX) {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
		s->r_data_length = rdata_tail - s->r_data;

		s->state = ZS_STATE_DATA;

		// Execute the record callback.
		if (s->process.automatic) {
			if (s->process.record != NULL) {
				s->process.record(s);

				// Stop if required from the callback.
				if (s->state == ZS_STATE_STOP) {
					{p++; cs = 1452; goto _out;}
				}
			}
		} else {
			// Return if external processing.
			p--; {p++; cs = 1452; goto _out;}
		}
	}
	goto st1452;
tr912:
	{
		s->r_owner_length = s->dname_tmp_length;
	}
	{
		s->line_counter++;
	}
	{ s->r_type = KNOT_RRTYPE_A; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->buffer[0] = 0;
		s->buffer_length = 0;
	}
	{
		if (rdata_tail - s->r_data > UINT16_MAX) {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
		s->r_data_length = rdata_tail - s->r_data;

		s->state = ZS_STATE_DATA;

		// Execute the record callback.
		if (s->process.automatic) {
			if (s->process.record != NULL) {
				s->process.record(s);

				// Stop if required from the callback.
				if (s->state == ZS_STATE_STOP) {
					{p++; cs = 1452; goto _out;}
				}
			}
		} else {
			// Return if external processing.
			p--; {p++; cs = 1452; goto _out;}
		}
	}
	goto st1452;
tr4301:
	{
		s->line_counter++;
	}
	{
		if (s->r_owner_length == 0) {
			WARN(ZS_BAD_PREVIOUS_OWNER);
			p--; {goto st316;}
		}
	}
	{
		s->buffer[0] = 0;
		s->buffer_length = 0;
	}
	goto st1452;
st1452:
	if ( ++p == pe )
		goto _test_eof1452;
case 1452:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(2688 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 !s->multiline  ) _widec += 512;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(2688 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		if (
 !s->multiline  ) _widec += 512;
	}
	switch( _widec ) {
		case 9: goto tr4295;
		case 32: goto tr4295;
		case 36: goto tr4296;
		case 40: goto tr4297;
		case 41: goto tr4298;
		case 42: goto tr4299;
		case 58: goto tr75;
		case 65: goto tr4377;
		case 67: goto tr4378;
		case 68: goto tr4379;
		case 69: goto tr4380;
		case 72: goto tr4381;
		case 73: goto tr4382;
		case 75: goto tr4383;
		case 76: goto tr4384;
		case 77: goto tr4385;
		case 78: goto tr4386;
		case 79: goto tr4387;
		case 80: goto tr4388;
		case 82: goto tr4389;
		case 83: goto tr4390;
		case 84: goto tr4391;
		case 85: goto tr4392;
		case 87: goto tr4393;
		case 90: goto tr4394;
		case 92: goto tr4300;
		case 95: goto tr4299;
		case 97: goto tr4377;
		case 99: goto tr4378;
		case 100: goto tr4379;
		case 101: goto tr4380;
		case 104: goto tr4381;
		case 105: goto tr4382;
		case 107: goto tr4383;
		case 108: goto tr4384;
		case 109: goto tr4385;
		case 110: goto tr4386;
		case 111: goto tr4387;
		case 112: goto tr4388;
		case 114: goto tr4389;
		case 115: goto tr4390;
		case 116: goto tr4391;
		case 117: goto tr4392;
		case 119: goto tr4393;
		case 122: goto tr4394;
		case 2826: goto tr4291;
		case 2875: goto tr4292;
		case 3082: goto tr4301;
		case 3131: goto tr4302;
		case 3338: goto tr4303;
		case 3387: goto tr4304;
		case 3594: goto tr4305;
		case 3643: goto tr4306;
	}
	if ( _widec < 60 ) {
		if ( _widec < 11 ) {
			if ( _widec <= 8 )
				goto tr75;
		} else if ( _widec > 44 ) {
			if ( _widec > 47 ) {
				if ( 48 <= _widec && _widec <= 57 )
					goto tr4376;
			} else if ( _widec >= 45 )
				goto tr4299;
		} else
			goto tr75;
	} else if ( _widec > 63 ) {
		if ( _widec < 91 ) {
			if ( 64 <= _widec && _widec <= 89 )
				goto tr4299;
		} else if ( _widec > 96 ) {
			if ( _widec > 121 ) {
				if ( 123 <= _widec )
					goto tr75;
			} else if ( _widec >= 98 )
				goto tr4299;
		} else
			goto tr75;
	} else
		goto tr75;
	goto tr4375;
tr4296:
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 235;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 235;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 235;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 235;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 235;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 235;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 235;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 235;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 235;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 235;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 235;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 235;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 235;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 235;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 235;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 235;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 235;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 235;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 235;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 235;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 235;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 235;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 235;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 235;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 235;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 235;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 235;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 235;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 235;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 235;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 235;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 235;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	goto st235;
st235:
	if ( ++p == pe )
		goto _test_eof235;
case 235:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr86;
		case 32: goto tr86;
		case 40: goto tr87;
		case 41: goto tr88;
		case 73: goto tr774;
		case 79: goto tr775;
		case 84: goto tr776;
		case 105: goto tr774;
		case 111: goto tr775;
		case 116: goto tr776;
		case 1802: goto tr89;
		case 1851: goto tr90;
		case 2058: goto tr89;
		case 2107: goto tr90;
	}
	goto tr879;
tr775:
	{
		ERR(ZS_OK);
	}
	goto st236;
st236:
	if ( ++p == pe )
		goto _test_eof236;
case 236:
	switch( (*p) ) {
		case 82: goto st237;
		case 114: goto st237;
	}
	goto tr773;
st237:
	if ( ++p == pe )
		goto _test_eof237;
case 237:
	switch( (*p) ) {
		case 73: goto st238;
		case 105: goto st238;
	}
	goto tr773;
st238:
	if ( ++p == pe )
		goto _test_eof238;
case 238:
	switch( (*p) ) {
		case 71: goto st239;
		case 103: goto st239;
	}
	goto tr773;
st239:
	if ( ++p == pe )
		goto _test_eof239;
case 239:
	switch( (*p) ) {
		case 73: goto st240;
		case 105: goto st240;
	}
	goto tr773;
st240:
	if ( ++p == pe )
		goto _test_eof240;
case 240:
	switch( (*p) ) {
		case 78: goto st241;
		case 110: goto st241;
	}
	goto tr773;
st241:
	if ( ++p == pe )
		goto _test_eof241;
case 241:
	switch( (*p) ) {
		case 32: goto tr885;
		case 59: goto tr885;
	}
	if ( (*p) > 10 ) {
		if ( 40 <= (*p) && (*p) <= 41 )
			goto tr885;
	} else if ( (*p) >= 9 )
		goto tr885;
	goto tr773;
tr776:
	{
		ERR(ZS_OK);
	}
	goto st242;
st242:
	if ( ++p == pe )
		goto _test_eof242;
case 242:
	switch( (*p) ) {
		case 84: goto st243;
		case 116: goto st243;
	}
	goto tr773;
st243:
	if ( ++p == pe )
		goto _test_eof243;
case 243:
	switch( (*p) ) {
		case 76: goto st244;
		case 108: goto st244;
	}
	goto tr773;
st244:
	if ( ++p == pe )
		goto _test_eof244;
case 244:
	switch( (*p) ) {
		case 32: goto tr888;
		case 59: goto tr888;
	}
	if ( (*p) > 10 ) {
		if ( 40 <= (*p) && (*p) <= 41 )
			goto tr888;
	} else if ( (*p) >= 9 )
		goto tr888;
	goto tr773;
tr4299:
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 245;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 245;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 245;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 245;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 245;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 245;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 245;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 245;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 245;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 245;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 245;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 245;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 245;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 245;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 245;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 245;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 245;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 245;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 245;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 245;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 245;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 245;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 245;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 245;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 245;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 245;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 245;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 245;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 245;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 245;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 245;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 245;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	{
		s->dname = s->r_owner;
		s->r_owner_length = 0;
	}
	{ p--; {stack[top++] = 245;goto st318;} }
	goto st245;
st245:
	if ( ++p == pe )
		goto _test_eof245;
case 245:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr890;
		case 32: goto tr890;
		case 40: goto tr891;
		case 41: goto tr892;
		case 1802: goto tr89;
		case 1851: goto tr90;
		case 2058: goto tr893;
		case 2107: goto tr894;
	}
	goto tr889;
tr4376:
	{
		s->number64 = 0;
	}
	{
		// Overflow check: 10*(s->number64) + fc - '0' <= UINT64_MAX
		if ((s->number64 < (UINT64_MAX / 10)) ||   // Dominant fast check.
			((s->number64 == (UINT64_MAX / 10)) && // Marginal case.
			 ((uint8_t)(*p) <= (UINT64_MAX % 10) + '0')
			)
		   ) {
			s->number64 *= 10;
			s->number64 += digit_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_NUMBER64_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 246;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 246;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 246;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 246;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 246;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 246;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 246;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 246;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 246;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 246;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 246;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 246;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 246;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 246;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 246;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 246;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 246;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 246;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 246;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 246;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 246;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 246;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 246;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 246;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 246;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 246;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 246;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 246;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 246;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 246;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 246;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 246;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	{
		s->dname = s->r_owner;
		s->r_owner_length = 0;
	}
	{ p--; {stack[top++] = 246;goto st318;} }
	goto st246;
st246:
	if ( ++p == pe )
		goto _test_eof246;
case 246:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr896;
		case 32: goto tr896;
		case 40: goto tr897;
		case 41: goto tr898;
		case 68: goto tr32;
		case 72: goto tr33;
		case 77: goto tr34;
		case 83: goto st204;
		case 87: goto tr36;
		case 100: goto tr32;
		case 104: goto tr33;
		case 109: goto tr34;
		case 115: goto st204;
		case 119: goto tr36;
		case 1802: goto tr89;
		case 1851: goto tr90;
		case 2058: goto tr899;
		case 2107: goto tr900;
	}
	if ( 48 <= _widec && _widec <= 57 )
		goto tr31;
	goto tr895;
tr902:
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st247;
tr903:
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st247;
tr896:
	{
		s->r_owner_length = s->dname_tmp_length;
	}
	{
		if (s->number64 <= UINT32_MAX) {
			s->r_ttl = (uint32_t)(s->number64);
		} else {
			WARN(ZS_NUMBER32_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		s->buffer[0] = 0;
		s->buffer_length = 0;
	}
	goto st247;
tr897:
	{
		s->r_owner_length = s->dname_tmp_length;
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	{
		if (s->number64 <= UINT32_MAX) {
			s->r_ttl = (uint32_t)(s->number64);
		} else {
			WARN(ZS_NUMBER32_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		s->buffer[0] = 0;
		s->buffer_length = 0;
	}
	goto st247;
tr898:
	{
		s->r_owner_length = s->dname_tmp_length;
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	{
		if (s->number64 <= UINT32_MAX) {
			s->r_ttl = (uint32_t)(s->number64);
		} else {
			WARN(ZS_NUMBER32_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		s->buffer[0] = 0;
		s->buffer_length = 0;
	}
	goto st247;
st247:
	if ( ++p == pe )
		goto _test_eof247;
case 247:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto st247;
		case 32: goto st247;
		case 40: goto tr902;
		case 41: goto tr903;
		case 65: goto tr5;
		case 67: goto tr6;
		case 68: goto tr7;
		case 69: goto tr8;
		case 72: goto tr9;
		case 73: goto tr10;
		case 75: goto tr11;
		case 76: goto tr12;
		case 77: goto tr13;
		case 78: goto tr14;
		case 79: goto tr15;
		case 80: goto tr16;
		case 82: goto tr17;
		case 83: goto tr18;
		case 84: goto tr19;
		case 85: goto tr20;
		case 87: goto tr21;
		case 90: goto tr22;
		case 97: goto tr5;
		case 99: goto tr6;
		case 100: goto tr7;
		case 101: goto tr8;
		case 104: goto tr9;
		case 105: goto tr10;
		case 107: goto tr11;
		case 108: goto tr12;
		case 109: goto tr13;
		case 110: goto tr14;
		case 111: goto tr15;
		case 112: goto tr16;
		case 114: goto tr17;
		case 115: goto tr18;
		case 116: goto tr19;
		case 117: goto tr20;
		case 119: goto tr21;
		case 122: goto tr22;
		case 1802: goto tr95;
		case 1851: goto tr96;
		case 2058: goto tr904;
		case 2107: goto tr905;
	}
	if ( 48 <= _widec && _widec <= 57 )
		goto tr4;
	goto tr0;
tr905:
	{
		s->buffer_length = 0;
	}
	goto st248;
tr906:
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		}
	}
	goto st248;
tr900:
	{
		s->r_owner_length = s->dname_tmp_length;
	}
	{
		s->buffer_length = 0;
	}
	{
		if (s->number64 <= UINT32_MAX) {
			s->r_ttl = (uint32_t)(s->number64);
		} else {
			WARN(ZS_NUMBER32_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		s->buffer[0] = 0;
		s->buffer_length = 0;
	}
	goto st248;
st248:
	if ( ++p == pe )
		goto _test_eof248;
case 248:
	_widec = (*p);
	if ( (*p) < 10 ) {
		if ( (*p) <= 9 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) > 10 ) {
		if ( 11 <= (*p) )
 {			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 1802: goto tr98;
		case 2058: goto tr907;
	}
	if ( _widec > 1919 ) {
		if ( 1920 <= _widec && _widec <= 2175 )
			goto tr906;
	} else if ( _widec >= 1664 )
		goto tr97;
	goto tr154;
tr4377:
	{
		s->r_class = s->default_class;
	}
	{
		s->r_ttl = s->default_ttl;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 249;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 249;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 249;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 249;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 249;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 249;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 249;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 249;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 249;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 249;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 249;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 249;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 249;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 249;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 249;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 249;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 249;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 249;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 249;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 249;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 249;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 249;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 249;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 249;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 249;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 249;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 249;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 249;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 249;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 249;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 249;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 249;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	{
		s->dname = s->r_owner;
		s->r_owner_length = 0;
	}
	{ p--; {stack[top++] = 249;goto st318;} }
	goto st249;
st249:
	if ( ++p == pe )
		goto _test_eof249;
case 249:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(2688 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 !s->multiline  ) _widec += 512;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(2688 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		if (
 !s->multiline  ) _widec += 512;
	}
	switch( _widec ) {
		case 9: goto tr909;
		case 32: goto tr909;
		case 40: goto tr910;
		case 41: goto tr911;
		case 65: goto st274;
		case 70: goto st277;
		case 80: goto st281;
		case 97: goto st274;
		case 102: goto st277;
		case 112: goto st281;
		case 2826: goto tr89;
		case 2875: goto tr90;
		case 3082: goto tr912;
		case 3131: goto tr913;
		case 3338: goto tr847;
		case 3387: goto tr848;
		case 3594: goto tr914;
		case 3643: goto tr915;
	}
	goto tr908;
tr917:
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st250;
tr918:
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st250;
tr909:
	{
		s->r_owner_length = s->dname_tmp_length;
	}
	{ s->r_type = KNOT_RRTYPE_A; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->buffer[0] = 0;
		s->buffer_length = 0;
	}
	goto st250;
tr910:
	{
		s->r_owner_length = s->dname_tmp_length;
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	{ s->r_type = KNOT_RRTYPE_A; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->buffer[0] = 0;
		s->buffer_length = 0;
	}
	goto st250;
tr911:
	{
		s->r_owner_length = s->dname_tmp_length;
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	{ s->r_type = KNOT_RRTYPE_A; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->buffer[0] = 0;
		s->buffer_length = 0;
	}
	goto st250;
st250:
	if ( ++p == pe )
		goto _test_eof250;
case 250:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(2688 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 !s->multiline  ) _widec += 512;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(2688 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		if (
 !s->multiline  ) _widec += 512;
	}
	switch( _widec ) {
		case 9: goto st250;
		case 32: goto st250;
		case 40: goto tr917;
		case 41: goto tr918;
		case 58: goto tr75;
		case 65: goto tr124;
		case 67: goto tr125;
		case 68: goto tr126;
		case 69: goto tr127;
		case 72: goto tr128;
		case 73: goto tr129;
		case 75: goto tr130;
		case 76: goto tr131;
		case 77: goto tr132;
		case 78: goto tr133;
		case 79: goto tr134;
		case 80: goto tr135;
		case 82: goto tr136;
		case 83: goto tr137;
		case 84: goto tr138;
		case 85: goto tr139;
		case 87: goto tr140;
		case 90: goto tr141;
		case 92: goto tr80;
		case 97: goto tr124;
		case 99: goto tr125;
		case 100: goto tr126;
		case 101: goto tr127;
		case 104: goto tr128;
		case 105: goto tr129;
		case 107: goto tr130;
		case 108: goto tr131;
		case 109: goto tr132;
		case 110: goto tr133;
		case 111: goto tr134;
		case 112: goto tr135;
		case 114: goto tr136;
		case 115: goto tr137;
		case 116: goto tr138;
		case 117: goto tr139;
		case 119: goto tr140;
		case 122: goto tr141;
		case 2826: goto tr95;
		case 2875: goto tr96;
		case 3082: goto tr919;
		case 3131: goto tr875;
		case 3338: goto tr114;
		case 3387: goto tr115;
		case 3594: goto tr920;
		case 3643: goto tr876;
	}
	if ( _widec < 11 ) {
		if ( _widec <= 8 )
			goto tr75;
	} else if ( _widec > 47 ) {
		if ( _widec > 57 ) {
			if ( 60 <= _widec )
				goto tr75;
		} else if ( _widec >= 48 )
			goto tr123;
	} else
		goto tr75;
	goto tr120;
tr146:
	{
		s->line_counter++;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 1453;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 1453;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 1453;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 1453;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 1453;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 1453;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 1453;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 1453;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 1453;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 1453;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 1453;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 1453;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 1453;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 1453;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 1453;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 1453;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 1453;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 1453;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 1453;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 1453;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 1453;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 1453;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 1453;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 1453;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 1453;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 1453;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 1453;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 1453;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 1453;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 1453;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 1453;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 1453;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	goto st1453;
tr920:
	{
		s->line_counter++;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 1453;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 1453;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 1453;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 1453;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 1453;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 1453;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 1453;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 1453;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 1453;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 1453;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 1453;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 1453;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 1453;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 1453;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 1453;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 1453;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 1453;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 1453;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 1453;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 1453;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 1453;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 1453;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 1453;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 1453;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 1453;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 1453;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 1453;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 1453;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 1453;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 1453;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 1453;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 1453;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	{
		if (rdata_tail - s->r_data > UINT16_MAX) {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
		s->r_data_length = rdata_tail - s->r_data;

		s->state = ZS_STATE_DATA;

		// Execute the record callback.
		if (s->process.automatic) {
			if (s->process.record != NULL) {
				s->process.record(s);

				// Stop if required from the callback.
				if (s->state == ZS_STATE_STOP) {
					{p++; cs = 1453; goto _out;}
				}
			}
		} else {
			// Return if external processing.
			p--; {p++; cs = 1453; goto _out;}
		}
	}
	goto st1453;
tr914:
	{
		s->r_owner_length = s->dname_tmp_length;
	}
	{
		s->line_counter++;
	}
	{ s->r_type = KNOT_RRTYPE_A; }
	{
		rdata_tail = s->r_data;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 1453;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 1453;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 1453;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 1453;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 1453;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 1453;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 1453;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 1453;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 1453;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 1453;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 1453;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 1453;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 1453;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 1453;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 1453;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 1453;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 1453;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 1453;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 1453;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 1453;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 1453;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 1453;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 1453;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 1453;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 1453;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 1453;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 1453;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 1453;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 1453;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 1453;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 1453;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 1453;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	{
		s->buffer[0] = 0;
		s->buffer_length = 0;
	}
	{
		if (rdata_tail - s->r_data > UINT16_MAX) {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
		s->r_data_length = rdata_tail - s->r_data;

		s->state = ZS_STATE_DATA;

		// Execute the record callback.
		if (s->process.automatic) {
			if (s->process.record != NULL) {
				s->process.record(s);

				// Stop if required from the callback.
				if (s->state == ZS_STATE_STOP) {
					{p++; cs = 1453; goto _out;}
				}
			}
		} else {
			// Return if external processing.
			p--; {p++; cs = 1453; goto _out;}
		}
	}
	goto st1453;
tr4305:
	{
		s->line_counter++;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 1453;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 1453;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 1453;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 1453;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 1453;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 1453;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 1453;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 1453;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 1453;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 1453;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 1453;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 1453;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 1453;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 1453;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 1453;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 1453;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 1453;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 1453;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 1453;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 1453;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 1453;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 1453;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 1453;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 1453;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 1453;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 1453;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 1453;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 1453;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 1453;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 1453;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 1453;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 1453;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	{
		if (s->r_owner_length == 0) {
			WARN(ZS_BAD_PREVIOUS_OWNER);
			p--; {goto st316;}
		}
	}
	{
		s->buffer[0] = 0;
		s->buffer_length = 0;
	}
	goto st1453;
st1453:
	if ( ++p == pe )
		goto _test_eof1453;
case 1453:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(2688 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 !s->multiline  ) _widec += 512;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(2688 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		if (
 !s->multiline  ) _widec += 512;
	}
	switch( _widec ) {
		case 9: goto tr4370;
		case 32: goto tr4370;
		case 36: goto tr4296;
		case 40: goto tr4371;
		case 41: goto tr4372;
		case 42: goto tr4299;
		case 58: goto tr75;
		case 65: goto tr4377;
		case 67: goto tr4378;
		case 68: goto tr4379;
		case 69: goto tr4380;
		case 72: goto tr4381;
		case 73: goto tr4382;
		case 75: goto tr4383;
		case 76: goto tr4384;
		case 77: goto tr4385;
		case 78: goto tr4386;
		case 79: goto tr4387;
		case 80: goto tr4388;
		case 82: goto tr4389;
		case 83: goto tr4390;
		case 84: goto tr4391;
		case 85: goto tr4392;
		case 87: goto tr4393;
		case 90: goto tr4394;
		case 92: goto tr4300;
		case 95: goto tr4299;
		case 97: goto tr4377;
		case 99: goto tr4378;
		case 100: goto tr4379;
		case 101: goto tr4380;
		case 104: goto tr4381;
		case 105: goto tr4382;
		case 107: goto tr4383;
		case 108: goto tr4384;
		case 109: goto tr4385;
		case 110: goto tr4386;
		case 111: goto tr4387;
		case 112: goto tr4388;
		case 114: goto tr4389;
		case 115: goto tr4390;
		case 116: goto tr4391;
		case 117: goto tr4392;
		case 119: goto tr4393;
		case 122: goto tr4394;
		case 2826: goto tr89;
		case 2875: goto tr90;
		case 3082: goto tr4395;
		case 3131: goto tr4373;
		case 3338: goto tr107;
		case 3387: goto tr108;
		case 3594: goto tr4395;
		case 3643: goto tr4374;
	}
	if ( _widec < 60 ) {
		if ( _widec < 11 ) {
			if ( _widec <= 8 )
				goto tr75;
		} else if ( _widec > 44 ) {
			if ( _widec > 47 ) {
				if ( 48 <= _widec && _widec <= 57 )
					goto tr4376;
			} else if ( _widec >= 45 )
				goto tr4299;
		} else
			goto tr75;
	} else if ( _widec > 63 ) {
		if ( _widec < 91 ) {
			if ( 64 <= _widec && _widec <= 89 )
				goto tr4299;
		} else if ( _widec > 96 ) {
			if ( _widec > 121 ) {
				if ( 123 <= _widec )
					goto tr75;
			} else if ( _widec >= 98 )
				goto tr4299;
		} else
			goto tr75;
	} else
		goto tr75;
	goto tr4375;
tr4378:
	{
		s->r_class = s->default_class;
	}
	{
		s->r_ttl = s->default_ttl;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 251;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 251;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 251;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 251;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 251;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 251;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 251;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 251;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 251;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 251;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 251;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 251;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 251;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 251;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 251;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 251;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 251;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 251;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 251;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 251;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 251;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 251;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 251;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 251;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 251;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 251;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 251;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 251;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 251;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 251;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 251;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 251;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	{
		s->dname = s->r_owner;
		s->r_owner_length = 0;
	}
	{ p--; {stack[top++] = 251;goto st318;} }
	goto st251;
st251:
	if ( ++p == pe )
		goto _test_eof251;
case 251:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr890;
		case 32: goto tr890;
		case 40: goto tr891;
		case 41: goto tr892;
		case 65: goto st18;
		case 68: goto st22;
		case 69: goto st29;
		case 78: goto st32;
		case 83: goto st36;
		case 97: goto st18;
		case 100: goto st22;
		case 101: goto st29;
		case 110: goto st32;
		case 115: goto st36;
		case 1802: goto tr89;
		case 1851: goto tr90;
		case 2058: goto tr893;
		case 2107: goto tr894;
	}
	goto tr908;
tr4379:
	{
		s->r_class = s->default_class;
	}
	{
		s->r_ttl = s->default_ttl;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 252;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 252;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 252;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 252;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 252;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 252;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 252;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 252;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 252;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 252;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 252;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 252;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 252;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 252;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 252;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 252;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 252;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 252;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 252;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 252;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 252;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 252;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 252;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 252;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 252;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 252;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 252;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 252;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 252;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 252;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 252;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 252;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	{
		s->dname = s->r_owner;
		s->r_owner_length = 0;
	}
	{ p--; {stack[top++] = 252;goto st318;} }
	goto st252;
st252:
	if ( ++p == pe )
		goto _test_eof252;
case 252:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr890;
		case 32: goto tr890;
		case 40: goto tr891;
		case 41: goto tr892;
		case 72: goto st41;
		case 78: goto st45;
		case 83: goto st53;
		case 104: goto st41;
		case 110: goto st45;
		case 115: goto st53;
		case 1802: goto tr89;
		case 1851: goto tr90;
		case 2058: goto tr893;
		case 2107: goto tr894;
	}
	goto tr908;
tr4380:
	{
		s->r_class = s->default_class;
	}
	{
		s->r_ttl = s->default_ttl;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 253;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 253;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 253;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 253;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 253;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 253;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 253;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 253;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 253;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 253;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 253;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 253;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 253;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 253;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 253;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 253;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 253;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 253;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 253;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 253;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 253;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 253;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 253;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 253;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 253;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 253;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 253;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 253;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 253;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 253;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 253;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 253;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	{
		s->dname = s->r_owner;
		s->r_owner_length = 0;
	}
	{ p--; {stack[top++] = 253;goto st318;} }
	goto st253;
st253:
	if ( ++p == pe )
		goto _test_eof253;
case 253:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr890;
		case 32: goto tr890;
		case 40: goto tr891;
		case 41: goto tr892;
		case 85: goto st55;
		case 117: goto st55;
		case 1802: goto tr89;
		case 1851: goto tr90;
		case 2058: goto tr893;
		case 2107: goto tr894;
	}
	goto tr908;
tr4381:
	{
		s->r_class = s->default_class;
	}
	{
		s->r_ttl = s->default_ttl;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 254;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 254;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 254;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 254;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 254;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 254;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 254;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 254;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 254;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 254;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 254;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 254;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 254;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 254;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 254;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 254;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 254;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 254;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 254;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 254;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 254;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 254;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 254;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 254;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 254;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 254;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 254;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 254;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 254;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 254;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 254;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 254;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	{
		s->dname = s->r_owner;
		s->r_owner_length = 0;
	}
	{ p--; {stack[top++] = 254;goto st318;} }
	goto st254;
st254:
	if ( ++p == pe )
		goto _test_eof254;
case 254:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr890;
		case 32: goto tr890;
		case 40: goto tr891;
		case 41: goto tr892;
		case 73: goto st62;
		case 84: goto st66;
		case 105: goto st62;
		case 116: goto st66;
		case 1802: goto tr89;
		case 1851: goto tr90;
		case 2058: goto tr893;
		case 2107: goto tr894;
	}
	goto tr908;
tr4382:
	{
		s->r_class = s->default_class;
	}
	{
		s->r_ttl = s->default_ttl;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 255;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 255;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 255;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 255;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 255;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 255;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 255;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 255;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 255;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 255;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 255;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 255;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 255;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 255;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 255;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 255;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 255;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 255;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 255;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 255;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 255;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 255;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 255;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 255;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 255;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 255;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 255;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 255;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 255;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 255;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 255;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 255;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	{
		s->dname = s->r_owner;
		s->r_owner_length = 0;
	}
	{ p--; {stack[top++] = 255;goto st318;} }
	goto st255;
st255:
	if ( ++p == pe )
		goto _test_eof255;
case 255:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr890;
		case 32: goto tr890;
		case 40: goto tr891;
		case 41: goto tr892;
		case 78: goto st182;
		case 80: goto st74;
		case 110: goto st182;
		case 112: goto st74;
		case 1802: goto tr89;
		case 1851: goto tr90;
		case 2058: goto tr893;
		case 2107: goto tr894;
	}
	goto tr908;
tr4383:
	{
		s->r_class = s->default_class;
	}
	{
		s->r_ttl = s->default_ttl;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 256;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 256;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 256;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 256;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 256;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 256;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 256;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 256;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 256;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 256;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 256;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 256;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 256;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 256;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 256;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 256;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 256;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 256;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 256;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 256;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 256;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 256;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 256;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 256;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 256;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 256;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 256;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 256;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 256;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 256;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 256;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 256;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	{
		s->dname = s->r_owner;
		s->r_owner_length = 0;
	}
	{ p--; {stack[top++] = 256;goto st318;} }
	goto st256;
st256:
	if ( ++p == pe )
		goto _test_eof256;
case 256:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr890;
		case 32: goto tr890;
		case 40: goto tr891;
		case 41: goto tr892;
		case 69: goto st82;
		case 88: goto st84;
		case 101: goto st82;
		case 120: goto st84;
		case 1802: goto tr89;
		case 1851: goto tr90;
		case 2058: goto tr893;
		case 2107: goto tr894;
	}
	goto tr908;
tr4384:
	{
		s->r_class = s->default_class;
	}
	{
		s->r_ttl = s->default_ttl;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 257;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 257;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 257;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 257;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 257;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 257;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 257;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 257;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 257;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 257;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 257;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 257;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 257;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 257;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 257;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 257;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 257;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 257;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 257;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 257;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 257;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 257;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 257;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 257;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 257;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 257;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 257;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 257;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 257;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 257;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 257;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 257;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	{
		s->dname = s->r_owner;
		s->r_owner_length = 0;
	}
	{ p--; {stack[top++] = 257;goto st318;} }
	goto st257;
st257:
	if ( ++p == pe )
		goto _test_eof257;
case 257:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr890;
		case 32: goto tr890;
		case 40: goto tr891;
		case 41: goto tr892;
		case 51: goto st86;
		case 54: goto st88;
		case 79: goto st90;
		case 80: goto st92;
		case 111: goto st90;
		case 112: goto st92;
		case 1802: goto tr89;
		case 1851: goto tr90;
		case 2058: goto tr893;
		case 2107: goto tr894;
	}
	goto tr908;
tr4385:
	{
		s->r_class = s->default_class;
	}
	{
		s->r_ttl = s->default_ttl;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 258;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 258;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 258;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 258;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 258;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 258;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 258;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 258;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 258;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 258;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 258;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 258;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 258;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 258;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 258;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 258;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 258;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 258;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 258;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 258;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 258;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 258;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 258;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 258;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 258;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 258;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 258;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 258;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 258;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 258;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 258;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 258;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	{
		s->dname = s->r_owner;
		s->r_owner_length = 0;
	}
	{ p--; {stack[top++] = 258;goto st318;} }
	goto st258;
st258:
	if ( ++p == pe )
		goto _test_eof258;
case 258:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr890;
		case 32: goto tr890;
		case 40: goto tr891;
		case 41: goto tr892;
		case 73: goto st94;
		case 88: goto st98;
		case 105: goto st94;
		case 120: goto st98;
		case 1802: goto tr89;
		case 1851: goto tr90;
		case 2058: goto tr893;
		case 2107: goto tr894;
	}
	goto tr908;
tr4386:
	{
		s->r_class = s->default_class;
	}
	{
		s->r_ttl = s->default_ttl;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 259;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 259;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 259;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 259;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 259;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 259;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 259;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 259;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 259;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 259;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 259;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 259;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 259;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 259;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 259;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 259;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 259;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 259;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 259;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 259;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 259;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 259;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 259;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 259;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 259;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 259;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 259;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 259;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 259;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 259;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 259;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 259;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	{
		s->dname = s->r_owner;
		s->r_owner_length = 0;
	}
	{ p--; {stack[top++] = 259;goto st318;} }
	goto st259;
st259:
	if ( ++p == pe )
		goto _test_eof259;
case 259:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr890;
		case 32: goto tr890;
		case 40: goto tr891;
		case 41: goto tr892;
		case 65: goto st100;
		case 73: goto st104;
		case 83: goto st106;
		case 97: goto st100;
		case 105: goto st104;
		case 115: goto st106;
		case 1802: goto tr89;
		case 1851: goto tr90;
		case 2058: goto tr893;
		case 2107: goto tr894;
	}
	goto tr908;
tr4387:
	{
		s->r_class = s->default_class;
	}
	{
		s->r_ttl = s->default_ttl;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 260;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 260;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 260;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 260;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 260;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 260;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 260;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 260;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 260;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 260;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 260;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 260;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 260;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 260;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 260;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 260;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 260;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 260;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 260;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 260;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 260;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 260;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 260;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 260;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 260;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 260;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 260;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 260;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 260;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 260;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 260;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 260;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	{
		s->dname = s->r_owner;
		s->r_owner_length = 0;
	}
	{ p--; {stack[top++] = 260;goto st318;} }
	goto st260;
st260:
	if ( ++p == pe )
		goto _test_eof260;
case 260:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr890;
		case 32: goto tr890;
		case 40: goto tr891;
		case 41: goto tr892;
		case 80: goto st116;
		case 112: goto st116;
		case 1802: goto tr89;
		case 1851: goto tr90;
		case 2058: goto tr893;
		case 2107: goto tr894;
	}
	goto tr908;
tr4388:
	{
		s->r_class = s->default_class;
	}
	{
		s->r_ttl = s->default_ttl;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 261;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 261;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 261;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 261;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 261;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 261;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 261;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 261;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 261;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 261;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 261;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 261;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 261;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 261;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 261;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 261;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 261;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 261;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 261;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 261;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 261;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 261;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 261;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 261;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 261;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 261;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 261;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 261;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 261;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 261;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 261;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 261;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	{
		s->dname = s->r_owner;
		s->r_owner_length = 0;
	}
	{ p--; {stack[top++] = 261;goto st318;} }
	goto st261;
st261:
	if ( ++p == pe )
		goto _test_eof261;
case 261:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr890;
		case 32: goto tr890;
		case 40: goto tr891;
		case 41: goto tr892;
		case 84: goto st126;
		case 116: goto st126;
		case 1802: goto tr89;
		case 1851: goto tr90;
		case 2058: goto tr893;
		case 2107: goto tr894;
	}
	goto tr908;
tr4389:
	{
		s->r_class = s->default_class;
	}
	{
		s->r_ttl = s->default_ttl;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 262;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 262;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 262;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 262;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 262;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 262;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 262;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 262;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 262;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 262;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 262;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 262;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 262;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 262;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 262;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 262;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 262;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 262;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 262;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 262;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 262;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 262;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 262;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 262;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 262;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 262;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 262;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 262;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 262;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 262;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 262;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 262;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	{
		s->dname = s->r_owner;
		s->r_owner_length = 0;
	}
	{ p--; {stack[top++] = 262;goto st318;} }
	goto st262;
st262:
	if ( ++p == pe )
		goto _test_eof262;
case 262:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr890;
		case 32: goto tr890;
		case 40: goto tr891;
		case 41: goto tr892;
		case 80: goto st129;
		case 82: goto st130;
		case 84: goto st134;
		case 112: goto st129;
		case 114: goto st130;
		case 116: goto st134;
		case 1802: goto tr89;
		case 1851: goto tr90;
		case 2058: goto tr893;
		case 2107: goto tr894;
	}
	goto tr908;
tr4390:
	{
		s->r_class = s->default_class;
	}
	{
		s->r_ttl = s->default_ttl;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 263;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 263;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 263;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 263;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 263;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 263;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 263;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 263;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 263;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 263;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 263;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 263;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 263;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 263;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 263;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 263;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 263;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 263;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 263;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 263;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 263;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 263;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 263;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 263;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 263;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 263;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 263;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 263;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 263;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 263;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 263;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 263;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	{
		s->dname = s->r_owner;
		s->r_owner_length = 0;
	}
	{ p--; {stack[top++] = 263;goto st318;} }
	goto st263;
st263:
	if ( ++p == pe )
		goto _test_eof263;
case 263:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr890;
		case 32: goto tr890;
		case 40: goto tr891;
		case 41: goto tr892;
		case 77: goto st136;
		case 79: goto st141;
		case 80: goto st143;
		case 82: goto st145;
		case 83: goto st147;
		case 86: goto st151;
		case 109: goto st136;
		case 111: goto st141;
		case 112: goto st143;
		case 114: goto st145;
		case 115: goto st147;
		case 118: goto st151;
		case 1802: goto tr89;
		case 1851: goto tr90;
		case 2058: goto tr893;
		case 2107: goto tr894;
	}
	goto tr908;
tr4391:
	{
		s->r_class = s->default_class;
	}
	{
		s->r_ttl = s->default_ttl;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 264;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 264;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 264;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 264;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 264;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 264;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 264;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 264;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 264;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 264;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 264;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 264;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 264;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 264;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 264;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 264;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 264;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 264;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 264;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 264;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 264;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 264;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 264;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 264;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 264;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 264;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 264;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 264;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 264;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 264;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 264;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 264;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	{
		s->dname = s->r_owner;
		s->r_owner_length = 0;
	}
	{ p--; {stack[top++] = 264;goto st318;} }
	goto st264;
st264:
	if ( ++p == pe )
		goto _test_eof264;
case 264:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr890;
		case 32: goto tr890;
		case 40: goto tr891;
		case 41: goto tr892;
		case 76: goto st155;
		case 88: goto st158;
		case 89: goto st160;
		case 108: goto st155;
		case 120: goto st158;
		case 121: goto st160;
		case 1802: goto tr89;
		case 1851: goto tr90;
		case 2058: goto tr893;
		case 2107: goto tr894;
	}
	goto tr908;
tr4392:
	{
		s->r_class = s->default_class;
	}
	{
		s->r_ttl = s->default_ttl;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 265;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 265;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 265;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 265;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 265;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 265;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 265;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 265;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 265;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 265;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 265;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 265;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 265;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 265;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 265;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 265;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 265;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 265;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 265;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 265;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 265;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 265;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 265;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 265;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 265;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 265;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 265;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 265;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 265;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 265;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 265;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 265;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	{
		s->dname = s->r_owner;
		s->r_owner_length = 0;
	}
	{ p--; {stack[top++] = 265;goto st318;} }
	goto st265;
st265:
	if ( ++p == pe )
		goto _test_eof265;
case 265:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr890;
		case 32: goto tr890;
		case 40: goto tr891;
		case 41: goto tr892;
		case 82: goto st165;
		case 114: goto st165;
		case 1802: goto tr89;
		case 1851: goto tr90;
		case 2058: goto tr893;
		case 2107: goto tr894;
	}
	goto tr908;
tr4393:
	{
		s->r_class = s->default_class;
	}
	{
		s->r_ttl = s->default_ttl;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 266;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 266;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 266;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 266;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 266;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 266;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 266;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 266;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 266;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 266;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 266;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 266;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 266;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 266;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 266;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 266;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 266;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 266;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 266;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 266;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 266;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 266;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 266;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 266;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 266;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 266;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 266;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 266;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 266;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 266;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 266;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 266;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	{
		s->dname = s->r_owner;
		s->r_owner_length = 0;
	}
	{ p--; {stack[top++] = 266;goto st318;} }
	goto st266;
st266:
	if ( ++p == pe )
		goto _test_eof266;
case 266:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr890;
		case 32: goto tr890;
		case 40: goto tr891;
		case 41: goto tr892;
		case 65: goto st168;
		case 97: goto st168;
		case 1802: goto tr89;
		case 1851: goto tr90;
		case 2058: goto tr893;
		case 2107: goto tr894;
	}
	goto tr908;
tr4394:
	{
		s->r_class = s->default_class;
	}
	{
		s->r_ttl = s->default_ttl;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 267;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 267;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 267;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 267;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 267;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 267;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 267;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 267;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 267;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 267;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 267;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 267;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 267;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 267;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 267;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 267;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 267;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 267;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 267;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 267;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 267;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 267;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 267;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 267;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 267;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 267;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 267;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 267;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 267;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 267;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 267;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 267;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	{
		s->dname = s->r_owner;
		s->r_owner_length = 0;
	}
	{ p--; {stack[top++] = 267;goto st318;} }
	goto st267;
st267:
	if ( ++p == pe )
		goto _test_eof267;
case 267:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr890;
		case 32: goto tr890;
		case 40: goto tr891;
		case 41: goto tr892;
		case 79: goto st174;
		case 111: goto st174;
		case 1802: goto tr89;
		case 1851: goto tr90;
		case 2058: goto tr893;
		case 2107: goto tr894;
	}
	goto tr908;
tr4300:
	{
		if (pe - p == 1) {
			*wrap = WRAP_DETECTED;
		}
	}
	{
		s->dname = s->r_owner;
		s->r_owner_length = 0;
	}
	{ p--; {stack[top++] = 268;goto st318;} }
	goto st268;
st268:
	if ( ++p == pe )
		goto _test_eof268;
case 268:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr921;
		case 32: goto tr921;
		case 35: goto tr100;
		case 40: goto tr923;
		case 41: goto tr924;
		case 1802: goto tr99;
		case 1851: goto tr99;
		case 2058: goto tr925;
		case 2107: goto tr926;
	}
	if ( _widec < 11 ) {
		if ( _widec <= 8 )
			goto tr99;
	} else if ( _widec > 58 ) {
		if ( 60 <= _widec )
			goto tr99;
	} else
		goto tr99;
	goto tr922;
tr921:
	{
		s->r_owner_length = s->dname_tmp_length;
	}
	{
		if (*wrap == WRAP_NONE) {
			p--;
		}
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 269;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 269;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 269;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 269;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 269;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 269;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 269;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 269;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 269;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 269;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 269;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 269;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 269;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 269;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 269;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 269;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 269;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 269;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 269;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 269;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 269;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 269;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 269;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 269;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 269;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 269;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 269;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 269;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 269;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 269;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 269;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 269;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	goto st269;
tr923:
	{
		s->r_owner_length = s->dname_tmp_length;
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	{
		if (*wrap == WRAP_NONE) {
			p--;
		}
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 269;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 269;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 269;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 269;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 269;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 269;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 269;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 269;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 269;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 269;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 269;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 269;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 269;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 269;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 269;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 269;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 269;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 269;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 269;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 269;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 269;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 269;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 269;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 269;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 269;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 269;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 269;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 269;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 269;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 269;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 269;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 269;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	goto st269;
tr924:
	{
		s->r_owner_length = s->dname_tmp_length;
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	{
		if (*wrap == WRAP_NONE) {
			p--;
		}
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 269;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 269;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 269;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 269;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 269;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 269;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 269;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 269;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 269;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 269;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 269;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 269;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 269;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 269;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 269;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 269;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 269;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 269;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 269;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 269;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 269;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 269;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 269;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 269;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 269;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 269;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 269;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 269;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 269;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 269;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 269;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 269;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	goto st269;
tr925:
	{
		s->r_owner_length = s->dname_tmp_length;
	}
	{
		s->line_counter++;
	}
	{
		if (*wrap == WRAP_NONE) {
			p--;
		}
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 269;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 269;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 269;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 269;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 269;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 269;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 269;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 269;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 269;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 269;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 269;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 269;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 269;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 269;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 269;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 269;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 269;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 269;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 269;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 269;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 269;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 269;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 269;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 269;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 269;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 269;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 269;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 269;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 269;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 269;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 269;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 269;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	goto st269;
st269:
	if ( ++p == pe )
		goto _test_eof269;
case 269:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr927;
		case 32: goto tr927;
		case 40: goto tr928;
		case 41: goto tr929;
		case 65: goto tr5;
		case 67: goto tr6;
		case 68: goto tr7;
		case 69: goto tr8;
		case 72: goto tr9;
		case 73: goto tr10;
		case 75: goto tr11;
		case 76: goto tr12;
		case 77: goto tr13;
		case 78: goto tr14;
		case 79: goto tr15;
		case 80: goto tr16;
		case 82: goto tr17;
		case 83: goto tr18;
		case 84: goto tr19;
		case 85: goto tr20;
		case 87: goto tr21;
		case 90: goto tr22;
		case 97: goto tr5;
		case 99: goto tr6;
		case 100: goto tr7;
		case 101: goto tr8;
		case 104: goto tr9;
		case 105: goto tr10;
		case 107: goto tr11;
		case 108: goto tr12;
		case 109: goto tr13;
		case 110: goto tr14;
		case 111: goto tr15;
		case 112: goto tr16;
		case 114: goto tr17;
		case 115: goto tr18;
		case 116: goto tr19;
		case 117: goto tr20;
		case 119: goto tr21;
		case 122: goto tr22;
		case 1802: goto tr89;
		case 1851: goto tr90;
		case 2058: goto tr930;
		case 2107: goto tr931;
	}
	if ( 48 <= _widec && _widec <= 57 )
		goto tr4;
	goto tr120;
tr926:
	{
		s->r_owner_length = s->dname_tmp_length;
	}
	{
		s->buffer_length = 0;
	}
	{
		if (*wrap == WRAP_NONE) {
			p--;
		}
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 270;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 270;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 270;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 270;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 270;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 270;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 270;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 270;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 270;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 270;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 270;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 270;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 270;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 270;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 270;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 270;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 270;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 270;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 270;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 270;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 270;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 270;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 270;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 270;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 270;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 270;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 270;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 270;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 270;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 270;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 270;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 270;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	goto st270;
st270:
	if ( ++p == pe )
		goto _test_eof270;
case 270:
	_widec = (*p);
	if ( (*p) < 11 ) {
		if ( (*p) > 9 ) {
			if ( 10 <= (*p) && (*p) <= 10 ) {
				_widec = (short)(1664 + ((*p) - -128));
				if (
 s->multiline  ) _widec += 256;
			}
		} else {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) > 58 ) {
		if ( (*p) > 59 ) {
			if ( 60 <= (*p) )
 {				_widec = (short)(1664 + ((*p) - -128));
				if (
 s->multiline  ) _widec += 256;
			}
		} else if ( (*p) >= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 1801: goto tr86;
		case 1802: goto tr89;
		case 1824: goto tr86;
		case 1832: goto tr87;
		case 1833: goto tr88;
		case 1851: goto tr90;
		case 2057: goto tr932;
		case 2058: goto tr933;
		case 2080: goto tr932;
		case 2088: goto tr934;
		case 2089: goto tr935;
		case 2107: goto tr936;
	}
	if ( 1920 <= _widec && _widec <= 2175 )
		goto tr795;
	goto tr85;
tr937:
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		}
	}
	goto st271;
tr932:
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		}
	}
	{
		s->buffer[0] = 0;
		s->buffer_length = 0;
	}
	goto st271;
tr934:
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		}
	}
	{
		s->buffer[0] = 0;
		s->buffer_length = 0;
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st271;
tr935:
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		}
	}
	{
		s->buffer[0] = 0;
		s->buffer_length = 0;
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st271;
tr938:
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		}
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st271;
tr939:
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		}
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st271;
st271:
	if ( ++p == pe )
		goto _test_eof271;
case 271:
	_widec = (*p);
	if ( (*p) < 11 ) {
		if ( (*p) > 9 ) {
			if ( 10 <= (*p) && (*p) <= 10 ) {
				_widec = (short)(1664 + ((*p) - -128));
				if (
 s->multiline  ) _widec += 256;
			}
		} else {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) > 58 ) {
		if ( (*p) > 59 ) {
			if ( 60 <= (*p) )
 {				_widec = (short)(1664 + ((*p) - -128));
				if (
 s->multiline  ) _widec += 256;
			}
		} else if ( (*p) >= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 1801: goto st7;
		case 1802: goto tr95;
		case 1824: goto st7;
		case 1832: goto tr93;
		case 1833: goto tr94;
		case 1851: goto tr96;
		case 2057: goto tr937;
		case 2058: goto tr862;
		case 2080: goto tr937;
		case 2088: goto tr938;
		case 2089: goto tr939;
		case 2107: goto tr940;
	}
	if ( 1920 <= _widec && _widec <= 2175 )
		goto tr795;
	goto tr91;
tr876:
	{
		s->buffer_length = 0;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 272;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 272;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 272;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 272;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 272;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 272;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 272;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 272;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 272;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 272;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 272;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 272;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 272;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 272;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 272;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 272;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 272;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 272;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 272;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 272;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 272;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 272;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 272;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 272;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 272;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 272;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 272;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 272;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 272;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 272;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 272;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 272;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	goto st272;
tr1007:
	{
		s->buffer_length = 0;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 272;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 272;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 272;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 272;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 272;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 272;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 272;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 272;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 272;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 272;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 272;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 272;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 272;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 272;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 272;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 272;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 272;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 272;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 272;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 272;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 272;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 272;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 272;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 272;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 272;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 272;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 272;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 272;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 272;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 272;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 272;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 272;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	{
		s->buffer[0] = 0;
		s->buffer_length = 0;
	}
	goto st272;
tr915:
	{
		s->r_owner_length = s->dname_tmp_length;
	}
	{
		s->buffer_length = 0;
	}
	{ s->r_type = KNOT_RRTYPE_A; }
	{
		rdata_tail = s->r_data;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 272;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 272;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 272;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 272;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 272;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 272;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 272;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 272;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 272;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 272;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 272;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 272;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 272;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 272;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 272;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 272;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 272;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 272;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 272;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 272;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 272;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 272;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 272;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 272;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 272;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 272;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 272;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 272;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 272;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 272;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 272;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 272;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	{
		s->buffer[0] = 0;
		s->buffer_length = 0;
	}
	goto st272;
tr4374:
	{
		s->buffer_length = 0;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 272;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 272;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 272;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 272;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 272;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 272;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 272;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 272;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 272;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 272;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 272;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 272;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 272;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 272;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 272;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 272;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 272;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 272;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 272;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 272;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 272;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 272;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 272;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 272;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 272;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 272;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 272;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 272;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 272;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 272;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 272;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 272;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	{
		s->buffer[0] = 0;
		s->buffer_length = 0;
	}
	{
		if (s->r_owner_length == 0) {
			WARN(ZS_BAD_PREVIOUS_OWNER);
			p--; {goto st316;}
		}
	}
	goto st272;
st272:
	if ( ++p == pe )
		goto _test_eof272;
case 272:
	_widec = (*p);
	if ( (*p) < 11 ) {
		if ( (*p) > 9 ) {
			if ( 10 <= (*p) && (*p) <= 10 ) {
				_widec = (short)(1664 + ((*p) - -128));
				if (
 s->multiline  ) _widec += 256;
			}
		} else {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) > 58 ) {
		if ( (*p) > 59 ) {
			if ( 60 <= (*p) )
 {				_widec = (short)(1664 + ((*p) - -128));
				if (
 s->multiline  ) _widec += 256;
			}
		} else if ( (*p) >= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 1801: goto tr863;
		case 1802: goto tr866;
		case 1824: goto tr863;
		case 1832: goto tr864;
		case 1833: goto tr865;
		case 1851: goto tr867;
		case 2057: goto tr941;
		case 2058: goto tr933;
		case 2080: goto tr941;
		case 2088: goto tr942;
		case 2089: goto tr943;
		case 2107: goto tr944;
	}
	if ( _widec > 1919 ) {
		if ( 1920 <= _widec && _widec <= 2175 )
			goto tr877;
	} else if ( _widec >= 1664 )
		goto tr97;
	goto tr85;
tr945:
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		}
	}
	goto st273;
tr941:
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		}
	}
	{
		s->buffer[0] = 0;
		s->buffer_length = 0;
	}
	goto st273;
tr942:
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		}
	}
	{
		s->buffer[0] = 0;
		s->buffer_length = 0;
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st273;
tr943:
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		}
	}
	{
		s->buffer[0] = 0;
		s->buffer_length = 0;
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st273;
tr946:
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		}
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st273;
tr947:
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		}
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st273;
st273:
	if ( ++p == pe )
		goto _test_eof273;
case 273:
	_widec = (*p);
	if ( (*p) < 11 ) {
		if ( (*p) > 9 ) {
			if ( 10 <= (*p) && (*p) <= 10 ) {
				_widec = (short)(1664 + ((*p) - -128));
				if (
 s->multiline  ) _widec += 256;
			}
		} else {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) > 58 ) {
		if ( (*p) > 59 ) {
			if ( 60 <= (*p) )
 {				_widec = (short)(1664 + ((*p) - -128));
				if (
 s->multiline  ) _widec += 256;
			}
		} else if ( (*p) >= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 1801: goto tr868;
		case 1802: goto tr98;
		case 1824: goto tr868;
		case 1832: goto tr869;
		case 1833: goto tr870;
		case 1851: goto tr871;
		case 2057: goto tr945;
		case 2058: goto tr862;
		case 2080: goto tr945;
		case 2088: goto tr946;
		case 2089: goto tr947;
		case 2107: goto tr948;
	}
	if ( _widec > 1919 ) {
		if ( 1920 <= _widec && _widec <= 2175 )
			goto tr877;
	} else if ( _widec >= 1664 )
		goto tr97;
	goto tr85;
st274:
	if ( ++p == pe )
		goto _test_eof274;
case 274:
	switch( (*p) ) {
		case 65: goto st275;
		case 97: goto st275;
	}
	goto tr39;
st275:
	if ( ++p == pe )
		goto _test_eof275;
case 275:
	switch( (*p) ) {
		case 65: goto st276;
		case 97: goto st276;
	}
	goto tr39;
st276:
	if ( ++p == pe )
		goto _test_eof276;
case 276:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(2688 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 !s->multiline  ) _widec += 512;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(2688 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		if (
 !s->multiline  ) _widec += 512;
	}
	switch( _widec ) {
		case 9: goto tr951;
		case 32: goto tr951;
		case 40: goto tr952;
		case 41: goto tr953;
		case 3082: goto tr954;
		case 3131: goto tr955;
		case 3338: goto tr956;
		case 3387: goto tr956;
		case 3594: goto tr957;
		case 3643: goto tr958;
	}
	goto tr63;
st277:
	if ( ++p == pe )
		goto _test_eof277;
case 277:
	switch( (*p) ) {
		case 83: goto st278;
		case 115: goto st278;
	}
	goto tr39;
st278:
	if ( ++p == pe )
		goto _test_eof278;
case 278:
	switch( (*p) ) {
		case 68: goto st279;
		case 100: goto st279;
	}
	goto tr39;
st279:
	if ( ++p == pe )
		goto _test_eof279;
case 279:
	switch( (*p) ) {
		case 66: goto st280;
		case 98: goto st280;
	}
	goto tr39;
st280:
	if ( ++p == pe )
		goto _test_eof280;
case 280:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(2688 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 !s->multiline  ) _widec += 512;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(2688 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		if (
 !s->multiline  ) _widec += 512;
	}
	switch( _widec ) {
		case 9: goto tr962;
		case 32: goto tr962;
		case 40: goto tr963;
		case 41: goto tr964;
		case 3082: goto tr965;
		case 3131: goto tr966;
		case 3338: goto tr967;
		case 3387: goto tr967;
		case 3594: goto tr968;
		case 3643: goto tr969;
	}
	goto tr63;
st281:
	if ( ++p == pe )
		goto _test_eof281;
case 281:
	switch( (*p) ) {
		case 76: goto st282;
		case 108: goto st282;
	}
	goto tr39;
st282:
	if ( ++p == pe )
		goto _test_eof282;
case 282:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(2688 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 !s->multiline  ) _widec += 512;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(2688 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		if (
 !s->multiline  ) _widec += 512;
	}
	switch( _widec ) {
		case 9: goto tr971;
		case 32: goto tr971;
		case 40: goto tr972;
		case 41: goto tr973;
		case 3082: goto tr974;
		case 3131: goto tr975;
		case 3338: goto tr976;
		case 3387: goto tr976;
		case 3594: goto tr977;
		case 3643: goto tr978;
	}
	goto tr63;
tr143:
	{
		s->buffer_length = 0;
	}
	goto st283;
tr979:
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		}
	}
	goto st283;
tr4302:
	{
		s->buffer_length = 0;
	}
	{
		if (s->r_owner_length == 0) {
			WARN(ZS_BAD_PREVIOUS_OWNER);
			p--; {goto st316;}
		}
	}
	{
		s->buffer[0] = 0;
		s->buffer_length = 0;
	}
	goto st283;
st283:
	if ( ++p == pe )
		goto _test_eof283;
case 283:
	_widec = (*p);
	if ( (*p) < 10 ) {
		if ( (*p) <= 9 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) > 10 ) {
		if ( 11 <= (*p) )
 {			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 1802: goto tr772;
		case 2058: goto tr980;
	}
	if ( _widec > 1919 ) {
		if ( 1920 <= _widec && _widec <= 2175 )
			goto tr979;
	} else if ( _widec >= 1664 )
		goto tr771;
	goto tr85;
tr4304:
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 284;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 284;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 284;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 284;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 284;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 284;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 284;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 284;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 284;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 284;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 284;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 284;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 284;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 284;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 284;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 284;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 284;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 284;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 284;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 284;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 284;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 284;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 284;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 284;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 284;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 284;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 284;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 284;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 284;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 284;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 284;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 284;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	{
		s->buffer[0] = 0;
		s->buffer_length = 0;
	}
	{
		s->buffer_length = 0;
	}
	goto st284;
tr145:
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 284;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 284;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 284;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 284;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 284;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 284;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 284;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 284;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 284;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 284;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 284;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 284;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 284;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 284;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 284;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 284;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 284;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 284;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 284;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 284;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 284;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 284;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 284;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 284;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 284;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 284;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 284;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 284;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 284;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 284;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 284;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 284;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	{
		s->buffer_length = 0;
	}
	goto st284;
st284:
	if ( ++p == pe )
		goto _test_eof284;
case 284:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr981;
		case 32: goto tr981;
		case 40: goto tr982;
		case 41: goto tr983;
		case 1802: goto tr984;
		case 1851: goto tr867;
		case 2058: goto tr984;
		case 2107: goto tr867;
	}
	if ( _widec < 11 ) {
		if ( _widec <= 8 )
			goto tr771;
	} else if ( _widec > 58 ) {
		if ( 60 <= _widec )
			goto tr771;
	} else
		goto tr771;
	goto tr85;
tr985:
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		}
	}
	goto st285;
tr981:
	{
		s->buffer[0] = 0;
		s->buffer_length = 0;
	}
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		}
	}
	goto st285;
tr982:
	{
		s->buffer[0] = 0;
		s->buffer_length = 0;
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		}
	}
	goto st285;
tr983:
	{
		s->buffer[0] = 0;
		s->buffer_length = 0;
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		}
	}
	goto st285;
tr986:
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		}
	}
	goto st285;
tr987:
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		}
	}
	goto st285;
st285:
	if ( ++p == pe )
		goto _test_eof285;
case 285:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr985;
		case 32: goto tr985;
		case 40: goto tr986;
		case 41: goto tr987;
		case 1802: goto tr988;
		case 1851: goto tr871;
		case 2058: goto tr988;
		case 2107: goto tr871;
	}
	if ( _widec < 11 ) {
		if ( _widec <= 8 )
			goto tr771;
	} else if ( _widec > 58 ) {
		if ( 60 <= _widec )
			goto tr771;
	} else
		goto tr771;
	goto tr91;
tr147:
	{
		s->buffer_length = 0;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 286;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 286;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 286;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 286;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 286;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 286;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 286;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 286;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 286;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 286;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 286;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 286;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 286;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 286;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 286;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 286;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 286;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 286;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 286;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 286;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 286;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 286;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 286;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 286;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 286;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 286;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 286;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 286;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 286;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 286;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 286;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 286;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	goto st286;
tr4306:
	{
		s->buffer_length = 0;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 286;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 286;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 286;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 286;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 286;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 286;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 286;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 286;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 286;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 286;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 286;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 286;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 286;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 286;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 286;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 286;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 286;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 286;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 286;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 286;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 286;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 286;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 286;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 286;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 286;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 286;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 286;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 286;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 286;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 286;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 286;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 286;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	{
		if (s->r_owner_length == 0) {
			WARN(ZS_BAD_PREVIOUS_OWNER);
			p--; {goto st316;}
		}
	}
	{
		s->buffer[0] = 0;
		s->buffer_length = 0;
	}
	goto st286;
st286:
	if ( ++p == pe )
		goto _test_eof286;
case 286:
	_widec = (*p);
	if ( (*p) < 11 ) {
		if ( (*p) > 9 ) {
			if ( 10 <= (*p) && (*p) <= 10 ) {
				_widec = (short)(1664 + ((*p) - -128));
				if (
 s->multiline  ) _widec += 256;
			}
		} else {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) > 58 ) {
		if ( (*p) > 59 ) {
			if ( 60 <= (*p) )
 {				_widec = (short)(1664 + ((*p) - -128));
				if (
 s->multiline  ) _widec += 256;
			}
		} else if ( (*p) >= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 1801: goto tr981;
		case 1802: goto tr984;
		case 1824: goto tr981;
		case 1832: goto tr982;
		case 1833: goto tr983;
		case 1851: goto tr867;
		case 2057: goto tr989;
		case 2058: goto tr933;
		case 2080: goto tr989;
		case 2088: goto tr990;
		case 2089: goto tr991;
		case 2107: goto tr944;
	}
	if ( _widec > 1919 ) {
		if ( 1920 <= _widec && _widec <= 2175 )
			goto tr979;
	} else if ( _widec >= 1664 )
		goto tr771;
	goto tr85;
tr992:
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		}
	}
	goto st287;
tr989:
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		}
	}
	{
		s->buffer[0] = 0;
		s->buffer_length = 0;
	}
	goto st287;
tr990:
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		}
	}
	{
		s->buffer[0] = 0;
		s->buffer_length = 0;
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st287;
tr991:
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		}
	}
	{
		s->buffer[0] = 0;
		s->buffer_length = 0;
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st287;
tr993:
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		}
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st287;
tr994:
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		}
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st287;
st287:
	if ( ++p == pe )
		goto _test_eof287;
case 287:
	_widec = (*p);
	if ( (*p) < 11 ) {
		if ( (*p) > 9 ) {
			if ( 10 <= (*p) && (*p) <= 10 ) {
				_widec = (short)(1664 + ((*p) - -128));
				if (
 s->multiline  ) _widec += 256;
			}
		} else {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) > 58 ) {
		if ( (*p) > 59 ) {
			if ( 60 <= (*p) )
 {				_widec = (short)(1664 + ((*p) - -128));
				if (
 s->multiline  ) _widec += 256;
			}
		} else if ( (*p) >= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 1801: goto tr985;
		case 1802: goto tr988;
		case 1824: goto tr985;
		case 1832: goto tr986;
		case 1833: goto tr987;
		case 1851: goto tr871;
		case 2057: goto tr992;
		case 2058: goto tr862;
		case 2080: goto tr992;
		case 2088: goto tr993;
		case 2089: goto tr994;
		case 2107: goto tr948;
	}
	if ( _widec > 1919 ) {
		if ( 1920 <= _widec && _widec <= 2175 )
			goto tr979;
	} else if ( _widec >= 1664 )
		goto tr771;
	goto tr85;
tr116:
	{
		s->buffer_length = 0;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 288;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 288;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 288;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 288;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 288;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 288;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 288;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 288;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 288;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 288;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 288;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 288;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 288;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 288;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 288;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 288;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 288;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 288;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 288;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 288;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 288;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 288;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 288;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 288;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 288;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 288;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 288;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 288;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 288;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 288;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 288;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 288;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	goto st288;
tr109:
	{
		s->buffer_length = 0;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 288;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 288;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 288;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 288;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 288;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 288;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 288;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 288;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 288;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 288;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 288;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 288;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 288;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 288;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 288;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 288;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 288;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 288;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 288;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 288;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 288;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 288;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 288;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 288;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 288;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 288;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 288;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 288;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 288;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 288;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 288;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 288;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	{
		s->buffer[0] = 0;
		s->buffer_length = 0;
	}
	goto st288;
tr850:
	{ s->r_type = KNOT_RRTYPE_A; }
	{
		rdata_tail = s->r_data;
	}
	{
		s->buffer_length = 0;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 288;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 288;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 288;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 288;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 288;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 288;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 288;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 288;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 288;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 288;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 288;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 288;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 288;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 288;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 288;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 288;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 288;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 288;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 288;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 288;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 288;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 288;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 288;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 288;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 288;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 288;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 288;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 288;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 288;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 288;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 288;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 288;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	{
		s->buffer[0] = 0;
		s->buffer_length = 0;
	}
	goto st288;
st288:
	if ( ++p == pe )
		goto _test_eof288;
case 288:
	_widec = (*p);
	if ( (*p) < 11 ) {
		if ( (*p) > 9 ) {
			if ( 10 <= (*p) && (*p) <= 10 ) {
				_widec = (short)(1664 + ((*p) - -128));
				if (
 s->multiline  ) _widec += 256;
			}
		} else {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) > 58 ) {
		if ( (*p) > 59 ) {
			if ( 60 <= (*p) )
 {				_widec = (short)(1664 + ((*p) - -128));
				if (
 s->multiline  ) _widec += 256;
			}
		} else if ( (*p) >= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 1801: goto tr863;
		case 1802: goto tr866;
		case 1824: goto tr863;
		case 1832: goto tr864;
		case 1833: goto tr865;
		case 1851: goto tr867;
		case 2057: goto tr995;
		case 2058: goto tr866;
		case 2080: goto tr995;
		case 2088: goto tr996;
		case 2089: goto tr997;
		case 2107: goto tr177;
	}
	if ( _widec > 1919 ) {
		if ( 1920 <= _widec && _widec <= 2175 )
			goto tr117;
	} else if ( _widec >= 1664 )
		goto tr97;
	goto tr85;
tr998:
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		}
	}
	goto st289;
tr995:
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		}
	}
	{
		s->buffer[0] = 0;
		s->buffer_length = 0;
	}
	goto st289;
tr996:
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		}
	}
	{
		s->buffer[0] = 0;
		s->buffer_length = 0;
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st289;
tr997:
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		}
	}
	{
		s->buffer[0] = 0;
		s->buffer_length = 0;
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st289;
tr999:
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		}
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st289;
tr1000:
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		}
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st289;
st289:
	if ( ++p == pe )
		goto _test_eof289;
case 289:
	_widec = (*p);
	if ( (*p) < 11 ) {
		if ( (*p) > 9 ) {
			if ( 10 <= (*p) && (*p) <= 10 ) {
				_widec = (short)(1664 + ((*p) - -128));
				if (
 s->multiline  ) _widec += 256;
			}
		} else {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) > 58 ) {
		if ( (*p) > 59 ) {
			if ( 60 <= (*p) )
 {				_widec = (short)(1664 + ((*p) - -128));
				if (
 s->multiline  ) _widec += 256;
			}
		} else if ( (*p) >= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 1801: goto tr868;
		case 1802: goto tr98;
		case 1824: goto tr868;
		case 1832: goto tr869;
		case 1833: goto tr870;
		case 1851: goto tr871;
		case 2057: goto tr998;
		case 2058: goto tr98;
		case 2080: goto tr998;
		case 2088: goto tr999;
		case 2089: goto tr1000;
		case 2107: goto tr181;
	}
	if ( _widec > 1919 ) {
		if ( 1920 <= _widec && _widec <= 2175 )
			goto tr117;
	} else if ( _widec >= 1664 )
		goto tr97;
	goto tr85;
tr838:
	{
		s->buffer_length = 0;
	}
	goto st290;
tr1001:
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		}
	}
	goto st290;
tr831:
	{
		s->r_owner_length = s->dname_tmp_length;
	}
	{
		s->buffer_length = 0;
	}
	{ s->r_type = KNOT_RRTYPE_A; }
	{
		rdata_tail = s->r_data;
	}
	goto st290;
st290:
	if ( ++p == pe )
		goto _test_eof290;
case 290:
	_widec = (*p);
	if ( (*p) < 10 ) {
		if ( (*p) <= 9 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) > 10 ) {
		if ( 11 <= (*p) )
 {			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	if ( _widec == 2058 )
		goto tr1002;
	if ( 1920 <= _widec && _widec <= 2175 )
		goto tr1001;
	goto tr77;
tr839:
	{
		s->line_counter++;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 291;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 291;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 291;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 291;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 291;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 291;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 291;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 291;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 291;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 291;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 291;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 291;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 291;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 291;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 291;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 291;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 291;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 291;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 291;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 291;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 291;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 291;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 291;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 291;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 291;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 291;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 291;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 291;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 291;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 291;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 291;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 291;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	goto st291;
tr832:
	{
		s->r_owner_length = s->dname_tmp_length;
	}
	{
		s->line_counter++;
	}
	{ s->r_type = KNOT_RRTYPE_A; }
	{
		rdata_tail = s->r_data;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 291;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 291;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 291;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 291;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 291;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 291;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 291;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 291;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 291;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 291;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 291;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 291;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 291;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 291;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 291;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 291;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 291;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 291;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 291;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 291;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 291;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 291;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 291;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 291;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 291;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 291;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 291;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 291;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 291;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 291;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 291;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 291;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	goto st291;
st291:
	if ( ++p == pe )
		goto _test_eof291;
case 291:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(2688 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 !s->multiline  ) _widec += 512;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(2688 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		if (
 !s->multiline  ) _widec += 512;
	}
	switch( _widec ) {
		case 9: goto tr1003;
		case 32: goto tr1003;
		case 40: goto tr1004;
		case 41: goto tr1005;
		case 58: goto tr75;
		case 65: goto tr124;
		case 67: goto tr125;
		case 68: goto tr126;
		case 69: goto tr127;
		case 72: goto tr128;
		case 73: goto tr129;
		case 75: goto tr130;
		case 76: goto tr131;
		case 77: goto tr132;
		case 78: goto tr133;
		case 79: goto tr134;
		case 80: goto tr135;
		case 82: goto tr136;
		case 83: goto tr137;
		case 84: goto tr138;
		case 85: goto tr139;
		case 87: goto tr140;
		case 90: goto tr141;
		case 92: goto tr80;
		case 97: goto tr124;
		case 99: goto tr125;
		case 100: goto tr126;
		case 101: goto tr127;
		case 104: goto tr128;
		case 105: goto tr129;
		case 107: goto tr130;
		case 108: goto tr131;
		case 109: goto tr132;
		case 110: goto tr133;
		case 111: goto tr134;
		case 112: goto tr135;
		case 114: goto tr136;
		case 115: goto tr137;
		case 116: goto tr138;
		case 117: goto tr139;
		case 119: goto tr140;
		case 122: goto tr141;
		case 2826: goto tr89;
		case 2875: goto tr90;
		case 3082: goto tr930;
		case 3131: goto tr1006;
		case 3338: goto tr107;
		case 3387: goto tr108;
		case 3594: goto tr930;
		case 3643: goto tr1007;
	}
	if ( _widec < 11 ) {
		if ( _widec <= 8 )
			goto tr75;
	} else if ( _widec > 47 ) {
		if ( _widec > 57 ) {
			if ( 60 <= _widec )
				goto tr75;
		} else if ( _widec >= 48 )
			goto tr123;
	} else
		goto tr75;
	goto tr120;
tr840:
	{
		s->buffer_length = 0;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 292;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 292;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 292;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 292;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 292;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 292;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 292;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 292;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 292;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 292;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 292;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 292;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 292;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 292;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 292;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 292;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 292;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 292;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 292;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 292;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 292;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 292;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 292;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 292;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 292;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 292;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 292;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 292;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 292;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 292;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 292;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 292;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	goto st292;
tr833:
	{
		s->r_owner_length = s->dname_tmp_length;
	}
	{
		s->buffer_length = 0;
	}
	{ s->r_type = KNOT_RRTYPE_A; }
	{
		rdata_tail = s->r_data;
	}
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = 292;goto st886;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = 292;goto st888;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = 292;goto st890;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = 292;goto st922;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = 292;goto st927;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = 292;goto st932;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_WALLET:
			{stack[top++] = 292;goto st937;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = 292;goto st941;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = 292;goto st943;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = 292;goto st998;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = 292;goto st1009;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = 292;goto st1026;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = 292;goto st1037;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = 292;goto st1048;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = 292;goto st1061;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = 292;goto st1071;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = 292;goto st1110;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = 292;goto st1302;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = 292;goto st1305;}
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_OPENPGPKEY:
			{stack[top++] = 292;goto st1316;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = 292;goto st1318;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = 292;goto st1347;}
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_SMIMEA:
			{stack[top++] = 292;goto st1360;}
		case KNOT_RRTYPE_CSYNC:
			{stack[top++] = 292;goto st1373;}
		case KNOT_RRTYPE_ZONEMD:
			{stack[top++] = 292;goto st1379;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = 292;goto st1397;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = 292;goto st1392;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = 292;goto st1410;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = 292;goto st1416;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = 292;goto st1422;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = 292;goto st1430;}
		case KNOT_RRTYPE_SVCB:
		case KNOT_RRTYPE_HTTPS:
			{stack[top++] = 292;goto st1438;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{goto st316;}
		}
	}
	goto st292;
st292:
	if ( ++p == pe )
		goto _test_eof292;
case 292:
	_widec = (*p);
	if ( (*p) < 11 ) {
		if ( (*p) > 9 ) {
			if ( 10 <= (*p) && (*p) <= 10 ) {
				_widec = (short)(1664 + ((*p) - -128));
				if (
 s->multiline  ) _widec += 256;
			}
		} else {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) > 58 ) {
		if ( (*p) > 59 ) {
			if ( 60 <= (*p) )
 {				_widec = (short)(1664 + ((*p) - -128));
				if (
 s->multiline  ) _widec += 256;
			}
		} else if ( (*p) >= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 1801: goto tr86;
		case 1802: goto tr89;
		case 1824: goto tr86;
		case 1832: goto tr87;
		case 1833: goto tr88;
		case 1851: goto tr90;
		case 2057: goto tr1008;
		case 2058: goto tr933;
		case 2080: goto tr1008;
		case 2088: goto tr1009;
		case 2089: goto tr1010;
		case 2107: goto tr944;
	}
	if ( 1920 <= _widec && _widec <= 2175 )
		goto tr1001;
	goto tr85;
tr1011:
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		}
	}
	goto st293;
tr1008:
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		}
	}
	{
		s->buffer[0] = 0;
		s->buffer_length = 0;
	}
	goto st293;
tr1009:
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		}
	}
	{
		s->buffer[0] = 0;
		s->buffer_length = 0;
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st293;
tr1010:
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		}
	}
	{
		s->buffer[0] = 0;
		s->buffer_length = 0;
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st293;
tr1012:
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		}
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st293;
tr1013:
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		}
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st293;
st293:
	if ( ++p == pe )
		goto _test_eof293;
case 293:
	_widec = (*p);
	if ( (*p) < 11 ) {
		if ( (*p) > 9 ) {
			if ( 10 <= (*p) && (*p) <= 10 ) {
				_widec = (short)(1664 + ((*p) - -128));
				if (
 s->multiline  ) _widec += 256;
			}
		} else {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) > 58 ) {
		if ( (*p) > 59 ) {
			if ( 60 <= (*p) )
 {				_widec = (short)(1664 + ((*p) - -128));
				if (
 s->multiline  ) _widec += 256;
			}
		} else if ( (*p) >= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 1801: goto st7;
		case 1802: goto tr95;
		case 1824: goto st7;
		case 1832: goto tr93;
		case 1833: goto tr94;
		case 1851: goto tr96;
		case 2057: goto tr1011;
		case 2058: goto tr862;
		case 2080: goto tr1011;
		case 2088: goto tr1012;
		case 2089: goto tr1013;
		case 2107: goto tr948;
	}
	if ( 1920 <= _widec && _widec <= 2175 )
		goto tr1001;
	goto tr85;
tr4312:
	{
		s->r_class = s->default_class;
	}
	{
		s->dname = s->r_owner;
		s->r_owner_length = 0;
	}
	{ p--; {stack[top++] = 294;goto st318;} }
	goto st294;
tr4334:
	{
		s->r_class = s->default_class;
	}
	{
		s->r_ttl = s->default_ttl;
	}
	{
		s->dname = s->r_owner;
		s->r_owner_length = 0;
	}
	{ p--; {stack[top++] = 294;goto st318;} }
	goto st294;
st294:
	if ( ++p == pe )
		goto _test_eof294;
case 294:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr785;
		case 32: goto tr785;
		case 40: goto tr786;
		case 41: goto tr787;
		case 65: goto st18;
		case 68: goto st22;
		case 69: goto st29;
		case 78: goto st32;
		case 83: goto st36;
		case 97: goto st18;
		case 100: goto st22;
		case 101: goto st29;
		case 110: goto st32;
		case 115: goto st36;
		case 2058: goto tr788;
		case 2107: goto tr789;
	}
	goto tr1014;
tr4313:
	{
		s->r_class = s->default_class;
	}
	{
		s->dname = s->r_owner;
		s->r_owner_length = 0;
	}
	{ p--; {stack[top++] = 295;goto st318;} }
	goto st295;
tr4335:
	{
		s->r_class = s->default_class;
	}
	{
		s->r_ttl = s->default_ttl;
	}
	{
		s->dname = s->r_owner;
		s->r_owner_length = 0;
	}
	{ p--; {stack[top++] = 295;goto st318;} }
	goto st295;
st295:
	if ( ++p == pe )
		goto _test_eof295;
case 295:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr785;
		case 32: goto tr785;
		case 40: goto tr786;
		case 41: goto tr787;
		case 72: goto st41;
		case 78: goto st45;
		case 83: goto st53;
		case 104: goto st41;
		case 110: goto st45;
		case 115: goto st53;
		case 2058: goto tr788;
		case 2107: goto tr789;
	}
	goto tr1014;
tr4314:
	{
		s->r_class = s->default_class;
	}
	{
		s->dname = s->r_owner;
		s->r_owner_length = 0;
	}
	{ p--; {stack[top++] = 296;goto st318;} }
	goto st296;
tr4336:
	{
		s->r_class = s->default_class;
	}
	{
		s->r_ttl = s->default_ttl;
	}
	{
		s->dname = s->r_owner;
		s->r_owner_length = 0;
	}
	{ p--; {stack[top++] = 296;goto st318;} }
	goto st296;
st296:
	if ( ++p == pe )
		goto _test_eof296;
case 296:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr785;
		case 32: goto tr785;
		case 40: goto tr786;
		case 41: goto tr787;
		case 85: goto st55;
		case 117: goto st55;
		case 2058: goto tr788;
		case 2107: goto tr789;
	}
	goto tr1014;
tr4315:
	{
		s->r_class = s->default_class;
	}
	{
		s->dname = s->r_owner;
		s->r_owner_length = 0;
	}
	{ p--; {stack[top++] = 297;goto st318;} }
	goto st297;
tr4337:
	{
		s->r_class = s->default_class;
	}
	{
		s->r_ttl = s->default_ttl;
	}
	{
		s->dname = s->r_owner;
		s->r_owner_length = 0;
	}
	{ p--; {stack[top++] = 297;goto st318;} }
	goto st297;
st297:
	if ( ++p == pe )
		goto _test_eof297;
case 297:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr785;
		case 32: goto tr785;
		case 40: goto tr786;
		case 41: goto tr787;
		case 73: goto st62;
		case 84: goto st66;
		case 105: goto st62;
		case 116: goto st66;
		case 2058: goto tr788;
		case 2107: goto tr789;
	}
	goto tr1014;
tr4338:
	{
		s->r_class = s->default_class;
	}
	{
		s->r_ttl = s->default_ttl;
	}
	{
		s->dname = s->r_owner;
		s->r_owner_length = 0;
	}
	{ p--; {stack[top++] = 298;goto st318;} }
	goto st298;
st298:
	if ( ++p == pe )
		goto _test_eof298;
case 298:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr785;
		case 32: goto tr785;
		case 40: goto tr786;
		case 41: goto tr787;
		case 78: goto st182;
		case 80: goto st74;
		case 110: goto st182;
		case 112: goto st74;
		case 2058: goto tr788;
		case 2107: goto tr789;
	}
	goto tr1014;
tr4317:
	{
		s->r_class = s->default_class;
	}
	{
		s->dname = s->r_owner;
		s->r_owner_length = 0;
	}
	{ p--; {stack[top++] = 299;goto st318;} }
	goto st299;
tr4339:
	{
		s->r_class = s->default_class;
	}
	{
		s->r_ttl = s->default_ttl;
	}
	{
		s->dname = s->r_owner;
		s->r_owner_length = 0;
	}
	{ p--; {stack[top++] = 299;goto st318;} }
	goto st299;
st299:
	if ( ++p == pe )
		goto _test_eof299;
case 299:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr785;
		case 32: goto tr785;
		case 40: goto tr786;
		case 41: goto tr787;
		case 69: goto st82;
		case 88: goto st84;
		case 101: goto st82;
		case 120: goto st84;
		case 2058: goto tr788;
		case 2107: goto tr789;
	}
	goto tr1014;
tr4318:
	{
		s->r_class = s->default_class;
	}
	{
		s->dname = s->r_owner;
		s->r_owner_length = 0;
	}
	{ p--; {stack[top++] = 300;goto st318;} }
	goto st300;
tr4340:
	{
		s->r_class = s->default_class;
	}
	{
		s->r_ttl = s->default_ttl;
	}
	{
		s->dname = s->r_owner;
		s->r_owner_length = 0;
	}
	{ p--; {stack[top++] = 300;goto st318;} }
	goto st300;
st300:
	if ( ++p == pe )
		goto _test_eof300;
case 300:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr785;
		case 32: goto tr785;
		case 40: goto tr786;
		case 41: goto tr787;
		case 51: goto st86;
		case 54: goto st88;
		case 79: goto st90;
		case 80: goto st92;
		case 111: goto st90;
		case 112: goto st92;
		case 2058: goto tr788;
		case 2107: goto tr789;
	}
	goto tr1014;
tr4319:
	{
		s->r_class = s->default_class;
	}
	{
		s->dname = s->r_owner;
		s->r_owner_length = 0;
	}
	{ p--; {stack[top++] = 301;goto st318;} }
	goto st301;
tr4341:
	{
		s->r_class = s->default_class;
	}
	{
		s->r_ttl = s->default_ttl;
	}
	{
		s->dname = s->r_owner;
		s->r_owner_length = 0;
	}
	{ p--; {stack[top++] = 301;goto st318;} }
	goto st301;
st301:
	if ( ++p == pe )
		goto _test_eof301;
case 301:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr785;
		case 32: goto tr785;
		case 40: goto tr786;
		case 41: goto tr787;
		case 73: goto st94;
		case 88: goto st98;
		case 105: goto st94;
		case 120: goto st98;
		case 2058: goto tr788;
		case 2107: goto tr789;
	}
	goto tr1014;
tr4320:
	{
		s->r_class = s->default_class;
	}
	{
		s->dname = s->r_owner;
		s->r_owner_length = 0;
	}
	{ p--; {stack[top++] = 302;goto st318;} }
	goto st302;
tr4342:
	{
		s->r_class = s->default_class;
	}
	{
		s->r_ttl = s->default_ttl;
	}
	{
		s->dname = s->r_owner;
		s->r_owner_length = 0;
	}
	{ p--; {stack[top++] = 302;goto st318;} }
	goto st302;
st302:
	if ( ++p == pe )
		goto _test_eof302;
case 302:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr785;
		case 32: goto tr785;
		case 40: goto tr786;
		case 41: goto tr787;
		case 65: goto st100;
		case 73: goto st104;
		case 83: goto st106;
		case 97: goto st100;
		case 105: goto st104;
		case 115: goto st106;
		case 2058: goto tr788;
		case 2107: goto tr789;
	}
	goto tr1014;
tr4321:
	{
		s->r_class = s->default_class;
	}
	{
		s->dname = s->r_owner;
		s->r_owner_length = 0;
	}
	{ p--; {stack[top++] = 303;goto st318;} }
	goto st303;
tr4343:
	{
		s->r_class = s->default_class;
	}
	{
		s->r_ttl = s->default_ttl;
	}
	{
		s->dname = s->r_owner;
		s->r_owner_length = 0;
	}
	{ p--; {stack[top++] = 303;goto st318;} }
	goto st303;
st303:
	if ( ++p == pe )
		goto _test_eof303;
case 303:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr785;
		case 32: goto tr785;
		case 40: goto tr786;
		case 41: goto tr787;
		case 80: goto st116;
		case 112: goto st116;
		case 2058: goto tr788;
		case 2107: goto tr789;
	}
	goto tr1014;
tr4322:
	{
		s->r_class = s->default_class;
	}
	{
		s->dname = s->r_owner;
		s->r_owner_length = 0;
	}
	{ p--; {stack[top++] = 304;goto st318;} }
	goto st304;
tr4344:
	{
		s->r_class = s->default_class;
	}
	{
		s->r_ttl = s->default_ttl;
	}
	{
		s->dname = s->r_owner;
		s->r_owner_length = 0;
	}
	{ p--; {stack[top++] = 304;goto st318;} }
	goto st304;
st304:
	if ( ++p == pe )
		goto _test_eof304;
case 304:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr785;
		case 32: goto tr785;
		case 40: goto tr786;
		case 41: goto tr787;
		case 84: goto st126;
		case 116: goto st126;
		case 2058: goto tr788;
		case 2107: goto tr789;
	}
	goto tr1014;
tr4323:
	{
		s->r_class = s->default_class;
	}
	{
		s->dname = s->r_owner;
		s->r_owner_length = 0;
	}
	{ p--; {stack[top++] = 305;goto st318;} }
	goto st305;
tr4345:
	{
		s->r_class = s->default_class;
	}
	{
		s->r_ttl = s->default_ttl;
	}
	{
		s->dname = s->r_owner;
		s->r_owner_length = 0;
	}
	{ p--; {stack[top++] = 305;goto st318;} }
	goto st305;
st305:
	if ( ++p == pe )
		goto _test_eof305;
case 305:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr785;
		case 32: goto tr785;
		case 40: goto tr786;
		case 41: goto tr787;
		case 80: goto st129;
		case 82: goto st130;
		case 84: goto st134;
		case 112: goto st129;
		case 114: goto st130;
		case 116: goto st134;
		case 2058: goto tr788;
		case 2107: goto tr789;
	}
	goto tr1014;
tr4324:
	{
		s->r_class = s->default_class;
	}
	{
		s->dname = s->r_owner;
		s->r_owner_length = 0;
	}
	{ p--; {stack[top++] = 306;goto st318;} }
	goto st306;
tr4346:
	{
		s->r_class = s->default_class;
	}
	{
		s->r_ttl = s->default_ttl;
	}
	{
		s->dname = s->r_owner;
		s->r_owner_length = 0;
	}
	{ p--; {stack[top++] = 306;goto st318;} }
	goto st306;
st306:
	if ( ++p == pe )
		goto _test_eof306;
case 306:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr785;
		case 32: goto tr785;
		case 40: goto tr786;
		case 41: goto tr787;
		case 77: goto st136;
		case 79: goto st141;
		case 80: goto st143;
		case 82: goto st145;
		case 83: goto st147;
		case 86: goto st151;
		case 109: goto st136;
		case 111: goto st141;
		case 112: goto st143;
		case 114: goto st145;
		case 115: goto st147;
		case 118: goto st151;
		case 2058: goto tr788;
		case 2107: goto tr789;
	}
	goto tr1014;
tr4325:
	{
		s->r_class = s->default_class;
	}
	{
		s->dname = s->r_owner;
		s->r_owner_length = 0;
	}
	{ p--; {stack[top++] = 307;goto st318;} }
	goto st307;
tr4347:
	{
		s->r_class = s->default_class;
	}
	{
		s->r_ttl = s->default_ttl;
	}
	{
		s->dname = s->r_owner;
		s->r_owner_length = 0;
	}
	{ p--; {stack[top++] = 307;goto st318;} }
	goto st307;
st307:
	if ( ++p == pe )
		goto _test_eof307;
case 307:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr785;
		case 32: goto tr785;
		case 40: goto tr786;
		case 41: goto tr787;
		case 76: goto st155;
		case 88: goto st158;
		case 89: goto st160;
		case 108: goto st155;
		case 120: goto st158;
		case 121: goto st160;
		case 2058: goto tr788;
		case 2107: goto tr789;
	}
	goto tr1014;
tr4326:
	{
		s->r_class = s->default_class;
	}
	{
		s->dname = s->r_owner;
		s->r_owner_length = 0;
	}
	{ p--; {stack[top++] = 308;goto st318;} }
	goto st308;
tr4348:
	{
		s->r_class = s->default_class;
	}
	{
		s->r_ttl = s->default_ttl;
	}
	{
		s->dname = s->r_owner;
		s->r_owner_length = 0;
	}
	{ p--; {stack[top++] = 308;goto st318;} }
	goto st308;
st308:
	if ( ++p == pe )
		goto _test_eof308;
case 308:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr785;
		case 32: goto tr785;
		case 40: goto tr786;
		case 41: goto tr787;
		case 82: goto st165;
		case 114: goto st165;
		case 2058: goto tr788;
		case 2107: goto tr789;
	}
	goto tr1014;
tr4327:
	{
		s->r_class = s->default_class;
	}
	{
		s->dname = s->r_owner;
		s->r_owner_length = 0;
	}
	{ p--; {stack[top++] = 309;goto st318;} }
	goto st309;
tr4349:
	{
		s->r_class = s->default_class;
	}
	{
		s->r_ttl = s->default_ttl;
	}
	{
		s->dname = s->r_owner;
		s->r_owner_length = 0;
	}
	{ p--; {stack[top++] = 309;goto st318;} }
	goto st309;
st309:
	if ( ++p == pe )
		goto _test_eof309;
case 309:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr785;
		case 32: goto tr785;
		case 40: goto tr786;
		case 41: goto tr787;
		case 65: goto st168;
		case 97: goto st168;
		case 2058: goto tr788;
		case 2107: goto tr789;
	}
	goto tr1014;
tr4328:
	{
		s->r_class = s->default_class;
	}
	{
		s->dname = s->r_owner;
		s->r_owner_length = 0;
	}
	{ p--; {stack[top++] = 310;goto st318;} }
	goto st310;
tr4350:
	{
		s->r_class = s->default_class;
	}
	{
		s->r_ttl = s->default_ttl;
	}
	{
		s->dname = s->r_owner;
		s->r_owner_length = 0;
	}
	{ p--; {stack[top++] = 310;goto st318;} }
	goto st310;
st310:
	if ( ++p == pe )
		goto _test_eof310;
case 310:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr785;
		case 32: goto tr785;
		case 40: goto tr786;
		case 41: goto tr787;
		case 79: goto st174;
		case 111: goto st174;
		case 2058: goto tr788;
		case 2107: goto tr789;
	}
	goto tr1014;
tr26:
	{
		s->buffer_length = 0;
	}
	goto st311;
tr1015:
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		}
	}
	goto st311;
tr4294:
	{
		if (s->r_owner_length == 0) {
			WARN(ZS_BAD_PREVIOUS_OWNER);
			p--; {goto st316;}
		}
	}
	{
		s->buffer_length = 0;
	}
	{
		s->buffer[0] = 0;
		s->buffer_length = 0;
	}
	goto st311;
tr4364:
	{
		s->buffer_length = 0;
	}
	{
		if (s->r_owner_length == 0) {
			WARN(ZS_BAD_PREVIOUS_OWNER);
			p--; {goto st316;}
		}
	}
	{
		s->buffer[0] = 0;
		s->buffer_length = 0;
	}
	goto st311;
tr4360:
	{
		NOERR;
	}
	{
		if (s->r_owner_length == 0) {
			WARN(ZS_BAD_PREVIOUS_OWNER);
			p--; {goto st316;}
		}
	}
	{
		s->buffer_length = 0;
	}
	{
		s->buffer[0] = 0;
		s->buffer_length = 0;
	}
	goto st311;
st311:
	if ( ++p == pe )
		goto _test_eof311;
case 311:
	_widec = (*p);
	if ( (*p) < 10 ) {
		if ( (*p) <= 9 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) > 10 ) {
		if ( 11 <= (*p) )
 {			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 1802: goto tr772;
		case 2058: goto tr1016;
	}
	if ( _widec > 1919 ) {
		if ( 1920 <= _widec && _widec <= 2175 )
			goto tr1015;
	} else if ( _widec >= 1664 )
		goto tr771;
	goto tr91;
tr714:
	{
		s->buffer_length = 0;
	}
	goto st312;
tr1017:
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		}
	}
	goto st312;
tr4330:
	{
		s->buffer_length = 0;
	}
	{
		if (s->r_owner_length == 0) {
			WARN(ZS_BAD_PREVIOUS_OWNER);
			p--; {goto st316;}
		}
	}
	{
		s->buffer[0] = 0;
		s->buffer_length = 0;
	}
	goto st312;
st312:
	if ( ++p == pe )
		goto _test_eof312;
case 312:
	_widec = (*p);
	if ( (*p) < 10 ) {
		if ( (*p) <= 9 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) > 10 ) {
		if ( 11 <= (*p) )
 {			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 1802: goto tr772;
		case 2058: goto tr1018;
	}
	if ( _widec > 1919 ) {
		if ( 1920 <= _widec && _widec <= 2175 )
			goto tr1017;
	} else if ( _widec >= 1664 )
		goto tr771;
	goto tr154;
tr4316:
	{
		s->r_class = s->default_class;
	}
	{
		s->dname = s->r_owner;
		s->r_owner_length = 0;
	}
	{ p--; {stack[top++] = 313;goto st318;} }
	goto st313;
st313:
	if ( ++p == pe )
		goto _test_eof313;
case 313:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr785;
		case 32: goto tr785;
		case 40: goto tr786;
		case 41: goto tr787;
		case 78: goto st71;
		case 80: goto st74;
		case 110: goto st71;
		case 112: goto st74;
		case 2058: goto tr788;
		case 2107: goto tr789;
	}
	goto tr1014;
tr159:
	{
		s->buffer_length = 0;
	}
	goto st314;
tr1019:
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		}
	}
	goto st314;
tr153:
	{
		if (s->number64 <= UINT32_MAX) {
			s->r_ttl = (uint32_t)(s->number64);
		} else {
			WARN(ZS_NUMBER32_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		s->buffer_length = 0;
	}
	{
		s->buffer[0] = 0;
		s->buffer_length = 0;
	}
	goto st314;
st314:
	if ( ++p == pe )
		goto _test_eof314;
case 314:
	_widec = (*p);
	if ( (*p) < 10 ) {
		if ( (*p) <= 9 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) > 10 ) {
		if ( 11 <= (*p) )
 {			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 1802: goto tr98;
		case 2058: goto tr1020;
	}
	if ( _widec > 1919 ) {
		if ( 1920 <= _widec && _widec <= 2175 )
			goto tr1019;
	} else if ( _widec >= 1664 )
		goto tr97;
	goto tr154;
tr1024:
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st315;
tr1023:
	{
		s->line_counter++;
	}
	goto st315;
st315:
	if ( ++p == pe )
		goto _test_eof315;
case 315:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 41 <= (*p) && (*p) <= 41 ) {
			_widec = (short)(640 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(128 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 266: goto tr1022;
		case 522: goto tr1023;
		case 1065: goto tr1024;
	}
	if ( _widec < 11 ) {
		if ( _widec <= 9 )
			goto st315;
	} else if ( _widec > 40 ) {
		if ( 42 <= _widec )
			goto st315;
	} else
		goto st315;
	goto st0;
tr1022:
	{ p--; {stack[top++] = 1454;goto st1444;} }
	{
		s->line_counter++;
	}
	goto st1454;
st1454:
	if ( ++p == pe )
		goto _test_eof1454;
case 1454:
	goto st0;
st316:
	if ( ++p == pe )
		goto _test_eof316;
case 316:
	if ( (*p) == 10 )
		goto tr1026;
	goto tr1025;
tr1025:
	{
		s->buffer_length = 0;
	}
	{
		if ((*p) == '\r') {
			ERR(ZS_DOS_NEWLINE);
		}

		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		}
	}
	goto st317;
tr1027:
	{
		if ((*p) == '\r') {
			ERR(ZS_DOS_NEWLINE);
		}

		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		}
	}
	goto st317;
st317:
	if ( ++p == pe )
		goto _test_eof317;
case 317:
	if ( (*p) == 10 )
		goto tr1028;
	goto tr1027;
tr1026:
	cs = 1455;
	{
		s->buffer_length = 0;
	}
	{
		// Terminate the error context string.
		s->buffer[s->buffer_length++] = 0;

		// Error counter incrementation.
		s->error.counter++;

		// Initialize the fcall stack.
		top = 0;

		// Reset per-record contexts.
		s->long_string = false;
		s->comma_list = false;
		s->pending_backslash = false;

		s->state = ZS_STATE_ERROR;

		// Execute the error callback.
		if (s->process.automatic) {
			p--;
			if (s->process.error != NULL) {
				s->process.error(s);

				// Stop if required from the callback.
				if (s->state == ZS_STATE_STOP) {
					{p++; goto _out;}
				}
			}

			// Stop the scanner if fatal error.
			if (s->error.fatal) {
				{p++; goto _out;}
			}
			{goto st315;}
		} else {
			// Return if external processing.
			p--; cs = 315; {p++; goto _out;}
		}
	}
	{
		s->line_counter++;
	}
	goto _again;
tr1028:
	cs = 1455;
	{
		// Terminate the error context string.
		s->buffer[s->buffer_length++] = 0;

		// Error counter incrementation.
		s->error.counter++;

		// Initialize the fcall stack.
		top = 0;

		// Reset per-record contexts.
		s->long_string = false;
		s->comma_list = false;
		s->pending_backslash = false;

		s->state = ZS_STATE_ERROR;

		// Execute the error callback.
		if (s->process.automatic) {
			p--;
			if (s->process.error != NULL) {
				s->process.error(s);

				// Stop if required from the callback.
				if (s->state == ZS_STATE_STOP) {
					{p++; goto _out;}
				}
			}

			// Stop the scanner if fatal error.
			if (s->error.fatal) {
				{p++; goto _out;}
			}
			{goto st315;}
		} else {
			// Return if external processing.
			p--; cs = 315; {p++; goto _out;}
		}
	}
	{
		s->line_counter++;
	}
	goto _again;
st1455:
	if ( ++p == pe )
		goto _test_eof1455;
case 1455:
	goto st0;
st318:
	if ( ++p == pe )
		goto _test_eof318;
case 318:
	switch( (*p) ) {
		case 42: goto tr1030;
		case 46: goto tr1031;
		case 64: goto st326;
		case 92: goto tr1033;
		case 95: goto tr1030;
	}
	if ( (*p) < 65 ) {
		if ( 45 <= (*p) && (*p) <= 57 )
			goto tr1030;
	} else if ( (*p) > 90 ) {
		if ( 97 <= (*p) && (*p) <= 122 )
			goto tr1030;
	} else
		goto tr1030;
	goto tr1029;
tr1030:
	{
		s->item_length_position = 0;
		s->dname_tmp_length = 0;
	}
	{
		s->item_length = 0;
		s->item_length_position = s->dname_tmp_length++;
	}
	{
		// Check for maximum dname label length.
		if (s->item_length < ZS_MAX_LABEL_LENGTH) {
			(s->dname)[s->dname_tmp_length++] = (*p);
			s->item_length++;
		} else {
			WARN(ZS_LABEL_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st319;
tr1035:
	{
		// Check for maximum dname label length.
		if (s->item_length < ZS_MAX_LABEL_LENGTH) {
			(s->dname)[s->dname_tmp_length++] = (*p);
			s->item_length++;
		} else {
			WARN(ZS_LABEL_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st319;
tr1039:
	{
		s->item_length = 0;
		s->item_length_position = s->dname_tmp_length++;
	}
	{
		// Check for maximum dname label length.
		if (s->item_length < ZS_MAX_LABEL_LENGTH) {
			(s->dname)[s->dname_tmp_length++] = (*p);
			s->item_length++;
		} else {
			WARN(ZS_LABEL_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st319;
tr1046:
	{
		s->dname_tmp_length++;
	}
	{
		// Check for maximum dname label length.
		if (s->item_length < ZS_MAX_LABEL_LENGTH) {
			(s->dname)[s->dname_tmp_length++] = (*p);
			s->item_length++;
		} else {
			WARN(ZS_LABEL_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st319;
st319:
	if ( ++p == pe )
		goto _test_eof319;
case 319:
	switch( (*p) ) {
		case 32: goto tr1034;
		case 42: goto tr1035;
		case 46: goto tr1036;
		case 59: goto tr1034;
		case 92: goto st321;
		case 95: goto tr1035;
	}
	if ( (*p) < 45 ) {
		if ( (*p) > 10 ) {
			if ( 40 <= (*p) && (*p) <= 41 )
				goto tr1034;
		} else if ( (*p) >= 9 )
			goto tr1034;
	} else if ( (*p) > 57 ) {
		if ( (*p) > 90 ) {
			if ( 97 <= (*p) && (*p) <= 122 )
				goto tr1035;
		} else if ( (*p) >= 65 )
			goto tr1035;
	} else
		goto tr1035;
	goto tr1029;
tr1034:
	{
		// Check for maximum dname length overflow after each label.
		// (at least the next label length must follow).
		if (s->dname_tmp_length < ZS_MAX_DNAME_LENGTH) {
			(s->dname)[s->item_length_position] =
				(uint8_t)(s->item_length);
		} else {
			WARN(ZS_DNAME_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		// Check for (relative + origin) dname length overflow.
		if (s->dname_tmp_length + s->zone_origin_length <= ZS_MAX_DNAME_LENGTH) {
			memcpy(s->dname + s->dname_tmp_length,
			       s->zone_origin,
			       s->zone_origin_length);

			s->dname_tmp_length += s->zone_origin_length;
		} else {
			WARN(ZS_DNAME_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1456;
tr1038:
	{
		// Enough room for the terminal label is guaranteed (_label_exit).
		(s->dname)[s->dname_tmp_length++] = 0;
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1456;
tr1045:
	{
		s->dname_tmp_length++;
	}
	{
		// Check for maximum dname length overflow after each label.
		// (at least the next label length must follow).
		if (s->dname_tmp_length < ZS_MAX_DNAME_LENGTH) {
			(s->dname)[s->item_length_position] =
				(uint8_t)(s->item_length);
		} else {
			WARN(ZS_DNAME_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		// Check for (relative + origin) dname length overflow.
		if (s->dname_tmp_length + s->zone_origin_length <= ZS_MAX_DNAME_LENGTH) {
			memcpy(s->dname + s->dname_tmp_length,
			       s->zone_origin,
			       s->zone_origin_length);

			s->dname_tmp_length += s->zone_origin_length;
		} else {
			WARN(ZS_DNAME_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1456;
tr1049:
	{
		// Copy already verified zone origin.
		memcpy(s->dname,
		       s->zone_origin,
		       s->zone_origin_length);

		s->dname_tmp_length = s->zone_origin_length;
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1456;
st1456:
	if ( ++p == pe )
		goto _test_eof1456;
case 1456:
	goto st0;
tr1036:
	{
		// Check for maximum dname length overflow after each label.
		// (at least the next label length must follow).
		if (s->dname_tmp_length < ZS_MAX_DNAME_LENGTH) {
			(s->dname)[s->item_length_position] =
				(uint8_t)(s->item_length);
		} else {
			WARN(ZS_DNAME_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st320;
tr1047:
	{
		s->dname_tmp_length++;
	}
	{
		// Check for maximum dname length overflow after each label.
		// (at least the next label length must follow).
		if (s->dname_tmp_length < ZS_MAX_DNAME_LENGTH) {
			(s->dname)[s->item_length_position] =
				(uint8_t)(s->item_length);
		} else {
			WARN(ZS_DNAME_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st320;
st320:
	if ( ++p == pe )
		goto _test_eof320;
case 320:
	switch( (*p) ) {
		case 32: goto tr1038;
		case 42: goto tr1039;
		case 45: goto tr1039;
		case 59: goto tr1038;
		case 92: goto tr1040;
		case 95: goto tr1039;
	}
	if ( (*p) < 47 ) {
		if ( (*p) > 10 ) {
			if ( 40 <= (*p) && (*p) <= 41 )
				goto tr1038;
		} else if ( (*p) >= 9 )
			goto tr1038;
	} else if ( (*p) > 57 ) {
		if ( (*p) > 90 ) {
			if ( 97 <= (*p) && (*p) <= 122 )
				goto tr1039;
		} else if ( (*p) >= 65 )
			goto tr1039;
	} else
		goto tr1039;
	goto tr1029;
tr1033:
	{
		s->item_length_position = 0;
		s->dname_tmp_length = 0;
	}
	{
		s->item_length = 0;
		s->item_length_position = s->dname_tmp_length++;
	}
	goto st321;
tr1040:
	{
		s->item_length = 0;
		s->item_length_position = s->dname_tmp_length++;
	}
	goto st321;
tr1048:
	{
		s->dname_tmp_length++;
	}
	goto st321;
st321:
	if ( ++p == pe )
		goto _test_eof321;
case 321:
	if ( 48 <= (*p) && (*p) <= 57 )
		goto tr1041;
	goto tr1035;
tr1041:
	{
		if (s->item_length < ZS_MAX_LABEL_LENGTH) {
			(s->dname)[s->dname_tmp_length] = 0;
			s->item_length++;
		} else {
			WARN(ZS_LABEL_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		(s->dname)[s->dname_tmp_length] *= 10;
		(s->dname)[s->dname_tmp_length] += digit_to_num[(uint8_t)(*p)];
	}
	goto st322;
st322:
	if ( ++p == pe )
		goto _test_eof322;
case 322:
	if ( 48 <= (*p) && (*p) <= 57 )
		goto tr1043;
	goto tr1042;
tr1043:
	{
		(s->dname)[s->dname_tmp_length] *= 10;
		(s->dname)[s->dname_tmp_length] += digit_to_num[(uint8_t)(*p)];
	}
	goto st323;
st323:
	if ( ++p == pe )
		goto _test_eof323;
case 323:
	if ( 48 <= (*p) && (*p) <= 57 )
		goto tr1044;
	goto tr1042;
tr1044:
	{
		(s->dname)[s->dname_tmp_length] *= 10;
		(s->dname)[s->dname_tmp_length] += digit_to_num[(uint8_t)(*p)];
	}
	goto st324;
st324:
	if ( ++p == pe )
		goto _test_eof324;
case 324:
	switch( (*p) ) {
		case 32: goto tr1045;
		case 42: goto tr1046;
		case 46: goto tr1047;
		case 59: goto tr1045;
		case 92: goto tr1048;
		case 95: goto tr1046;
	}
	if ( (*p) < 45 ) {
		if ( (*p) > 10 ) {
			if ( 40 <= (*p) && (*p) <= 41 )
				goto tr1045;
		} else if ( (*p) >= 9 )
			goto tr1045;
	} else if ( (*p) > 57 ) {
		if ( (*p) > 90 ) {
			if ( 97 <= (*p) && (*p) <= 122 )
				goto tr1046;
		} else if ( (*p) >= 65 )
			goto tr1046;
	} else
		goto tr1046;
	goto tr1042;
tr1031:
	{
		s->item_length_position = 0;
		s->dname_tmp_length = 0;
	}
	goto st325;
st325:
	if ( ++p == pe )
		goto _test_eof325;
case 325:
	switch( (*p) ) {
		case 32: goto tr1038;
		case 59: goto tr1038;
	}
	if ( (*p) > 10 ) {
		if ( 40 <= (*p) && (*p) <= 41 )
			goto tr1038;
	} else if ( (*p) >= 9 )
		goto tr1038;
	goto tr1029;
st326:
	if ( ++p == pe )
		goto _test_eof326;
case 326:
	switch( (*p) ) {
		case 32: goto tr1049;
		case 59: goto tr1049;
	}
	if ( (*p) > 10 ) {
		if ( 40 <= (*p) && (*p) <= 41 )
			goto tr1049;
	} else if ( (*p) >= 9 )
		goto tr1049;
	goto tr1029;
st327:
	if ( ++p == pe )
		goto _test_eof327;
case 327:
	switch( (*p) ) {
		case 34: goto st333;
		case 92: goto st329;
	}
	if ( (*p) > 58 ) {
		if ( 60 <= (*p) && (*p) <= 126 )
			goto tr1051;
	} else if ( (*p) >= 33 )
		goto tr1051;
	goto tr1050;
tr1051:
	{
		if (rdata_tail <= rdata_stop) {
			// Split long string.
			if (s->long_string &&
			    rdata_tail - s->item_length_location == 1 + MAX_ITEM_LENGTH) {
				// _item_length_exit equivalent.
				*(s->item_length_location) = MAX_ITEM_LENGTH;
				// _item_length_init equivalent.
				s->item_length_location = rdata_tail++;

				if (rdata_tail > rdata_stop) {
					WARN(ZS_TEXT_OVERFLOW);
					p--; {goto st316;}
				}
			}

			*(rdata_tail++) = (*p);
		} else {
			WARN(ZS_TEXT_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st328;
tr1055:
	{
		if (s->comma_list) {
			uint8_t *last_two = rdata_tail - 2;
			uint16_t current_len = rdata_tail - s->item_length_location - 2;
			if (last_two[1] == ',') {
				if (current_len <= 1) {
					WARN(ZS_EMPTY_LIST_ITEM);
					p--; {goto st316;}
				} else if (last_two[0] != '\\' || !s->pending_backslash) { // Start a new item.
					*(s->item_length_location) = current_len;
					s->item_length_location = rdata_tail - 1;
				} else { // Remove backslash.
					last_two[0] = ',';
					rdata_tail--;
					s->pending_backslash = false;
				}
			} else if (last_two[1] == '\\') {
				if (s->pending_backslash) { // Remove backslash.
					rdata_tail--;
					s->pending_backslash = false;
				} else {
					s->pending_backslash = true;
				}
			} else if (s->pending_backslash) {
				WARN(ZS_BAD_ALPN_BACKSLASH);
				p--; {goto st316;}
			}
		}
	}
	{
		if (rdata_tail <= rdata_stop) {
			// Split long string.
			if (s->long_string &&
			    rdata_tail - s->item_length_location == 1 + MAX_ITEM_LENGTH) {
				// _item_length_exit equivalent.
				*(s->item_length_location) = MAX_ITEM_LENGTH;
				// _item_length_init equivalent.
				s->item_length_location = rdata_tail++;

				if (rdata_tail > rdata_stop) {
					WARN(ZS_TEXT_OVERFLOW);
					p--; {goto st316;}
				}
			}

			*(rdata_tail++) = (*p);
		} else {
			WARN(ZS_TEXT_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st328;
tr1063:
	{
		rdata_tail++;
	}
	{
		if (s->comma_list) {
			uint8_t *last_two = rdata_tail - 2;
			uint16_t current_len = rdata_tail - s->item_length_location - 2;
			if (last_two[1] == ',') {
				if (current_len <= 1) {
					WARN(ZS_EMPTY_LIST_ITEM);
					p--; {goto st316;}
				} else if (last_two[0] != '\\' || !s->pending_backslash) { // Start a new item.
					*(s->item_length_location) = current_len;
					s->item_length_location = rdata_tail - 1;
				} else { // Remove backslash.
					last_two[0] = ',';
					rdata_tail--;
					s->pending_backslash = false;
				}
			} else if (last_two[1] == '\\') {
				if (s->pending_backslash) { // Remove backslash.
					rdata_tail--;
					s->pending_backslash = false;
				} else {
					s->pending_backslash = true;
				}
			} else if (s->pending_backslash) {
				WARN(ZS_BAD_ALPN_BACKSLASH);
				p--; {goto st316;}
			}
		}
	}
	{
		if (rdata_tail <= rdata_stop) {
			// Split long string.
			if (s->long_string &&
			    rdata_tail - s->item_length_location == 1 + MAX_ITEM_LENGTH) {
				// _item_length_exit equivalent.
				*(s->item_length_location) = MAX_ITEM_LENGTH;
				// _item_length_init equivalent.
				s->item_length_location = rdata_tail++;

				if (rdata_tail > rdata_stop) {
					WARN(ZS_TEXT_OVERFLOW);
					p--; {goto st316;}
				}
			}

			*(rdata_tail++) = (*p);
		} else {
			WARN(ZS_TEXT_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st328;
st328:
	if ( ++p == pe )
		goto _test_eof328;
case 328:
	switch( (*p) ) {
		case 32: goto tr1054;
		case 33: goto tr1055;
		case 59: goto tr1054;
		case 92: goto tr1057;
	}
	if ( (*p) < 35 ) {
		if ( 9 <= (*p) && (*p) <= 10 )
			goto tr1054;
	} else if ( (*p) > 39 ) {
		if ( (*p) > 41 ) {
			if ( 42 <= (*p) && (*p) <= 126 )
				goto tr1055;
		} else if ( (*p) >= 40 )
			goto tr1056;
	} else
		goto tr1055;
	goto tr1050;
tr1054:
	{
		if (s->comma_list) {
			uint8_t *last_two = rdata_tail - 2;
			uint16_t current_len = rdata_tail - s->item_length_location - 2;
			if (last_two[1] == ',') {
				if (current_len <= 1) {
					WARN(ZS_EMPTY_LIST_ITEM);
					p--; {goto st316;}
				} else if (last_two[0] != '\\' || !s->pending_backslash) { // Start a new item.
					*(s->item_length_location) = current_len;
					s->item_length_location = rdata_tail - 1;
				} else { // Remove backslash.
					last_two[0] = ',';
					rdata_tail--;
					s->pending_backslash = false;
				}
			} else if (last_two[1] == '\\') {
				if (s->pending_backslash) { // Remove backslash.
					rdata_tail--;
					s->pending_backslash = false;
				} else {
					s->pending_backslash = true;
				}
			} else if (s->pending_backslash) {
				WARN(ZS_BAD_ALPN_BACKSLASH);
				p--; {goto st316;}
			}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1457;
tr1062:
	{
		rdata_tail++;
	}
	{
		if (s->comma_list) {
			uint8_t *last_two = rdata_tail - 2;
			uint16_t current_len = rdata_tail - s->item_length_location - 2;
			if (last_two[1] == ',') {
				if (current_len <= 1) {
					WARN(ZS_EMPTY_LIST_ITEM);
					p--; {goto st316;}
				} else if (last_two[0] != '\\' || !s->pending_backslash) { // Start a new item.
					*(s->item_length_location) = current_len;
					s->item_length_location = rdata_tail - 1;
				} else { // Remove backslash.
					last_two[0] = ',';
					rdata_tail--;
					s->pending_backslash = false;
				}
			} else if (last_two[1] == '\\') {
				if (s->pending_backslash) { // Remove backslash.
					rdata_tail--;
					s->pending_backslash = false;
				} else {
					s->pending_backslash = true;
				}
			} else if (s->pending_backslash) {
				WARN(ZS_BAD_ALPN_BACKSLASH);
				p--; {goto st316;}
			}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1457;
tr1075:
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1457;
st1457:
	if ( ++p == pe )
		goto _test_eof1457;
case 1457:
	goto st0;
tr1056:
	{
		if (s->comma_list) {
			uint8_t *last_two = rdata_tail - 2;
			uint16_t current_len = rdata_tail - s->item_length_location - 2;
			if (last_two[1] == ',') {
				if (current_len <= 1) {
					WARN(ZS_EMPTY_LIST_ITEM);
					p--; {goto st316;}
				} else if (last_two[0] != '\\' || !s->pending_backslash) { // Start a new item.
					*(s->item_length_location) = current_len;
					s->item_length_location = rdata_tail - 1;
				} else { // Remove backslash.
					last_two[0] = ',';
					rdata_tail--;
					s->pending_backslash = false;
				}
			} else if (last_two[1] == '\\') {
				if (s->pending_backslash) { // Remove backslash.
					rdata_tail--;
					s->pending_backslash = false;
				} else {
					s->pending_backslash = true;
				}
			} else if (s->pending_backslash) {
				WARN(ZS_BAD_ALPN_BACKSLASH);
				p--; {goto st316;}
			}
		}
	}
	{
		if (rdata_tail <= rdata_stop) {
			// Split long string.
			if (s->long_string &&
			    rdata_tail - s->item_length_location == 1 + MAX_ITEM_LENGTH) {
				// _item_length_exit equivalent.
				*(s->item_length_location) = MAX_ITEM_LENGTH;
				// _item_length_init equivalent.
				s->item_length_location = rdata_tail++;

				if (rdata_tail > rdata_stop) {
					WARN(ZS_TEXT_OVERFLOW);
					p--; {goto st316;}
				}
			}

			*(rdata_tail++) = (*p);
		} else {
			WARN(ZS_TEXT_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1458;
tr1064:
	{
		rdata_tail++;
	}
	{
		if (s->comma_list) {
			uint8_t *last_two = rdata_tail - 2;
			uint16_t current_len = rdata_tail - s->item_length_location - 2;
			if (last_two[1] == ',') {
				if (current_len <= 1) {
					WARN(ZS_EMPTY_LIST_ITEM);
					p--; {goto st316;}
				} else if (last_two[0] != '\\' || !s->pending_backslash) { // Start a new item.
					*(s->item_length_location) = current_len;
					s->item_length_location = rdata_tail - 1;
				} else { // Remove backslash.
					last_two[0] = ',';
					rdata_tail--;
					s->pending_backslash = false;
				}
			} else if (last_two[1] == '\\') {
				if (s->pending_backslash) { // Remove backslash.
					rdata_tail--;
					s->pending_backslash = false;
				} else {
					s->pending_backslash = true;
				}
			} else if (s->pending_backslash) {
				WARN(ZS_BAD_ALPN_BACKSLASH);
				p--; {goto st316;}
			}
		}
	}
	{
		if (rdata_tail <= rdata_stop) {
			// Split long string.
			if (s->long_string &&
			    rdata_tail - s->item_length_location == 1 + MAX_ITEM_LENGTH) {
				// _item_length_exit equivalent.
				*(s->item_length_location) = MAX_ITEM_LENGTH;
				// _item_length_init equivalent.
				s->item_length_location = rdata_tail++;

				if (rdata_tail > rdata_stop) {
					WARN(ZS_TEXT_OVERFLOW);
					p--; {goto st316;}
				}
			}

			*(rdata_tail++) = (*p);
		} else {
			WARN(ZS_TEXT_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1458;
st1458:
	if ( ++p == pe )
		goto _test_eof1458;
case 1458:
	switch( (*p) ) {
		case 32: goto tr1054;
		case 33: goto tr1055;
		case 59: goto tr1054;
		case 92: goto tr1057;
	}
	if ( (*p) < 35 ) {
		if ( 9 <= (*p) && (*p) <= 10 )
			goto tr1054;
	} else if ( (*p) > 39 ) {
		if ( (*p) > 41 ) {
			if ( 42 <= (*p) && (*p) <= 126 )
				goto tr1055;
		} else if ( (*p) >= 40 )
			goto tr1056;
	} else
		goto tr1055;
	goto tr1050;
tr1057:
	{
		if (s->comma_list) {
			uint8_t *last_two = rdata_tail - 2;
			uint16_t current_len = rdata_tail - s->item_length_location - 2;
			if (last_two[1] == ',') {
				if (current_len <= 1) {
					WARN(ZS_EMPTY_LIST_ITEM);
					p--; {goto st316;}
				} else if (last_two[0] != '\\' || !s->pending_backslash) { // Start a new item.
					*(s->item_length_location) = current_len;
					s->item_length_location = rdata_tail - 1;
				} else { // Remove backslash.
					last_two[0] = ',';
					rdata_tail--;
					s->pending_backslash = false;
				}
			} else if (last_two[1] == '\\') {
				if (s->pending_backslash) { // Remove backslash.
					rdata_tail--;
					s->pending_backslash = false;
				} else {
					s->pending_backslash = true;
				}
			} else if (s->pending_backslash) {
				WARN(ZS_BAD_ALPN_BACKSLASH);
				p--; {goto st316;}
			}
		}
	}
	goto st329;
tr1065:
	{
		rdata_tail++;
	}
	{
		if (s->comma_list) {
			uint8_t *last_two = rdata_tail - 2;
			uint16_t current_len = rdata_tail - s->item_length_location - 2;
			if (last_two[1] == ',') {
				if (current_len <= 1) {
					WARN(ZS_EMPTY_LIST_ITEM);
					p--; {goto st316;}
				} else if (last_two[0] != '\\' || !s->pending_backslash) { // Start a new item.
					*(s->item_length_location) = current_len;
					s->item_length_location = rdata_tail - 1;
				} else { // Remove backslash.
					last_two[0] = ',';
					rdata_tail--;
					s->pending_backslash = false;
				}
			} else if (last_two[1] == '\\') {
				if (s->pending_backslash) { // Remove backslash.
					rdata_tail--;
					s->pending_backslash = false;
				} else {
					s->pending_backslash = true;
				}
			} else if (s->pending_backslash) {
				WARN(ZS_BAD_ALPN_BACKSLASH);
				p--; {goto st316;}
			}
		}
	}
	goto st329;
st329:
	if ( ++p == pe )
		goto _test_eof329;
case 329:
	if ( (*p) < 48 ) {
		if ( 32 <= (*p) && (*p) <= 47 )
			goto tr1051;
	} else if ( (*p) > 57 ) {
		if ( 58 <= (*p) && (*p) <= 126 )
			goto tr1051;
	} else
		goto tr1059;
	goto tr1058;
tr1059:
	{
		if (rdata_tail <= rdata_stop) {
			// Split long string.
			if (s->long_string &&
			    rdata_tail - s->item_length_location == 1 + MAX_ITEM_LENGTH) {
				// _item_length_exit equivalent.
				*(s->item_length_location) = MAX_ITEM_LENGTH;
				// _item_length_init equivalent.
				s->item_length_location = rdata_tail++;

				if (rdata_tail > rdata_stop) {
					WARN(ZS_TEXT_OVERFLOW);
					p--; {goto st316;}
				}
			}

			*rdata_tail = 0;
			s->item_length++;
		} else {
			WARN(ZS_TEXT_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if ((*rdata_tail < (UINT8_MAX / 10)) ||   // Dominant fast check.
			((*rdata_tail == (UINT8_MAX / 10)) && // Marginal case.
			 ((*p) <= (UINT8_MAX % 10) + '0')
			)
		   ) {
			*rdata_tail *= 10;
			*rdata_tail += digit_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_NUMBER8_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st330;
st330:
	if ( ++p == pe )
		goto _test_eof330;
case 330:
	if ( 48 <= (*p) && (*p) <= 57 )
		goto tr1060;
	goto tr1058;
tr1060:
	{
		if ((*rdata_tail < (UINT8_MAX / 10)) ||   // Dominant fast check.
			((*rdata_tail == (UINT8_MAX / 10)) && // Marginal case.
			 ((*p) <= (UINT8_MAX % 10) + '0')
			)
		   ) {
			*rdata_tail *= 10;
			*rdata_tail += digit_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_NUMBER8_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st331;
st331:
	if ( ++p == pe )
		goto _test_eof331;
case 331:
	if ( 48 <= (*p) && (*p) <= 57 )
		goto tr1061;
	goto tr1058;
tr1061:
	{
		if ((*rdata_tail < (UINT8_MAX / 10)) ||   // Dominant fast check.
			((*rdata_tail == (UINT8_MAX / 10)) && // Marginal case.
			 ((*p) <= (UINT8_MAX % 10) + '0')
			)
		   ) {
			*rdata_tail *= 10;
			*rdata_tail += digit_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_NUMBER8_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st332;
st332:
	if ( ++p == pe )
		goto _test_eof332;
case 332:
	switch( (*p) ) {
		case 32: goto tr1062;
		case 33: goto tr1063;
		case 59: goto tr1062;
		case 92: goto tr1065;
	}
	if ( (*p) < 35 ) {
		if ( 9 <= (*p) && (*p) <= 10 )
			goto tr1062;
	} else if ( (*p) > 39 ) {
		if ( (*p) > 41 ) {
			if ( 42 <= (*p) && (*p) <= 126 )
				goto tr1063;
		} else if ( (*p) >= 40 )
			goto tr1064;
	} else
		goto tr1063;
	goto tr1058;
tr1066:
	{
		if (rdata_tail <= rdata_stop) {
			// Split long string.
			if (s->long_string &&
			    rdata_tail - s->item_length_location == 1 + MAX_ITEM_LENGTH) {
				// _item_length_exit equivalent.
				*(s->item_length_location) = MAX_ITEM_LENGTH;
				// _item_length_init equivalent.
				s->item_length_location = rdata_tail++;

				if (rdata_tail > rdata_stop) {
					WARN(ZS_TEXT_OVERFLOW);
					p--; {goto st316;}
				}
			}

			*(rdata_tail++) = (*p);
		} else {
			WARN(ZS_TEXT_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st333;
tr1070:
	{
		if (s->comma_list) {
			uint8_t *last_two = rdata_tail - 2;
			uint16_t current_len = rdata_tail - s->item_length_location - 2;
			if (last_two[1] == ',') {
				if (current_len <= 1) {
					WARN(ZS_EMPTY_LIST_ITEM);
					p--; {goto st316;}
				} else if (last_two[0] != '\\' || !s->pending_backslash) { // Start a new item.
					*(s->item_length_location) = current_len;
					s->item_length_location = rdata_tail - 1;
				} else { // Remove backslash.
					last_two[0] = ',';
					rdata_tail--;
					s->pending_backslash = false;
				}
			} else if (last_two[1] == '\\') {
				if (s->pending_backslash) { // Remove backslash.
					rdata_tail--;
					s->pending_backslash = false;
				} else {
					s->pending_backslash = true;
				}
			} else if (s->pending_backslash) {
				WARN(ZS_BAD_ALPN_BACKSLASH);
				p--; {goto st316;}
			}
		}
	}
	{
		if (rdata_tail <= rdata_stop) {
			// Split long string.
			if (s->long_string &&
			    rdata_tail - s->item_length_location == 1 + MAX_ITEM_LENGTH) {
				// _item_length_exit equivalent.
				*(s->item_length_location) = MAX_ITEM_LENGTH;
				// _item_length_init equivalent.
				s->item_length_location = rdata_tail++;

				if (rdata_tail > rdata_stop) {
					WARN(ZS_TEXT_OVERFLOW);
					p--; {goto st316;}
				}
			}

			*(rdata_tail++) = (*p);
		} else {
			WARN(ZS_TEXT_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st333;
tr1079:
	{
		rdata_tail++;
	}
	{
		if (s->comma_list) {
			uint8_t *last_two = rdata_tail - 2;
			uint16_t current_len = rdata_tail - s->item_length_location - 2;
			if (last_two[1] == ',') {
				if (current_len <= 1) {
					WARN(ZS_EMPTY_LIST_ITEM);
					p--; {goto st316;}
				} else if (last_two[0] != '\\' || !s->pending_backslash) { // Start a new item.
					*(s->item_length_location) = current_len;
					s->item_length_location = rdata_tail - 1;
				} else { // Remove backslash.
					last_two[0] = ',';
					rdata_tail--;
					s->pending_backslash = false;
				}
			} else if (last_two[1] == '\\') {
				if (s->pending_backslash) { // Remove backslash.
					rdata_tail--;
					s->pending_backslash = false;
				} else {
					s->pending_backslash = true;
				}
			} else if (s->pending_backslash) {
				WARN(ZS_BAD_ALPN_BACKSLASH);
				p--; {goto st316;}
			}
		}
	}
	{
		if (rdata_tail <= rdata_stop) {
			// Split long string.
			if (s->long_string &&
			    rdata_tail - s->item_length_location == 1 + MAX_ITEM_LENGTH) {
				// _item_length_exit equivalent.
				*(s->item_length_location) = MAX_ITEM_LENGTH;
				// _item_length_init equivalent.
				s->item_length_location = rdata_tail++;

				if (rdata_tail > rdata_stop) {
					WARN(ZS_TEXT_OVERFLOW);
					p--; {goto st316;}
				}
			}

			*(rdata_tail++) = (*p);
		} else {
			WARN(ZS_TEXT_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st333;
st333:
	if ( ++p == pe )
		goto _test_eof333;
case 333:
	_widec = (*p);
	if ( 10 <= (*p) && (*p) <= 10 ) {
		_widec = (short)(1152 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr1066;
		case 32: goto tr1066;
		case 34: goto st335;
		case 59: goto tr1066;
		case 92: goto st336;
		case 1546: goto tr1066;
	}
	if ( 33 <= _widec && _widec <= 126 )
		goto tr1067;
	goto tr1050;
tr1067:
	{
		if (rdata_tail <= rdata_stop) {
			// Split long string.
			if (s->long_string &&
			    rdata_tail - s->item_length_location == 1 + MAX_ITEM_LENGTH) {
				// _item_length_exit equivalent.
				*(s->item_length_location) = MAX_ITEM_LENGTH;
				// _item_length_init equivalent.
				s->item_length_location = rdata_tail++;

				if (rdata_tail > rdata_stop) {
					WARN(ZS_TEXT_OVERFLOW);
					p--; {goto st316;}
				}
			}

			*(rdata_tail++) = (*p);
		} else {
			WARN(ZS_TEXT_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st334;
tr1071:
	{
		if (s->comma_list) {
			uint8_t *last_two = rdata_tail - 2;
			uint16_t current_len = rdata_tail - s->item_length_location - 2;
			if (last_two[1] == ',') {
				if (current_len <= 1) {
					WARN(ZS_EMPTY_LIST_ITEM);
					p--; {goto st316;}
				} else if (last_two[0] != '\\' || !s->pending_backslash) { // Start a new item.
					*(s->item_length_location) = current_len;
					s->item_length_location = rdata_tail - 1;
				} else { // Remove backslash.
					last_two[0] = ',';
					rdata_tail--;
					s->pending_backslash = false;
				}
			} else if (last_two[1] == '\\') {
				if (s->pending_backslash) { // Remove backslash.
					rdata_tail--;
					s->pending_backslash = false;
				} else {
					s->pending_backslash = true;
				}
			} else if (s->pending_backslash) {
				WARN(ZS_BAD_ALPN_BACKSLASH);
				p--; {goto st316;}
			}
		}
	}
	{
		if (rdata_tail <= rdata_stop) {
			// Split long string.
			if (s->long_string &&
			    rdata_tail - s->item_length_location == 1 + MAX_ITEM_LENGTH) {
				// _item_length_exit equivalent.
				*(s->item_length_location) = MAX_ITEM_LENGTH;
				// _item_length_init equivalent.
				s->item_length_location = rdata_tail++;

				if (rdata_tail > rdata_stop) {
					WARN(ZS_TEXT_OVERFLOW);
					p--; {goto st316;}
				}
			}

			*(rdata_tail++) = (*p);
		} else {
			WARN(ZS_TEXT_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st334;
tr1080:
	{
		rdata_tail++;
	}
	{
		if (s->comma_list) {
			uint8_t *last_two = rdata_tail - 2;
			uint16_t current_len = rdata_tail - s->item_length_location - 2;
			if (last_two[1] == ',') {
				if (current_len <= 1) {
					WARN(ZS_EMPTY_LIST_ITEM);
					p--; {goto st316;}
				} else if (last_two[0] != '\\' || !s->pending_backslash) { // Start a new item.
					*(s->item_length_location) = current_len;
					s->item_length_location = rdata_tail - 1;
				} else { // Remove backslash.
					last_two[0] = ',';
					rdata_tail--;
					s->pending_backslash = false;
				}
			} else if (last_two[1] == '\\') {
				if (s->pending_backslash) { // Remove backslash.
					rdata_tail--;
					s->pending_backslash = false;
				} else {
					s->pending_backslash = true;
				}
			} else if (s->pending_backslash) {
				WARN(ZS_BAD_ALPN_BACKSLASH);
				p--; {goto st316;}
			}
		}
	}
	{
		if (rdata_tail <= rdata_stop) {
			// Split long string.
			if (s->long_string &&
			    rdata_tail - s->item_length_location == 1 + MAX_ITEM_LENGTH) {
				// _item_length_exit equivalent.
				*(s->item_length_location) = MAX_ITEM_LENGTH;
				// _item_length_init equivalent.
				s->item_length_location = rdata_tail++;

				if (rdata_tail > rdata_stop) {
					WARN(ZS_TEXT_OVERFLOW);
					p--; {goto st316;}
				}
			}

			*(rdata_tail++) = (*p);
		} else {
			WARN(ZS_TEXT_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st334;
st334:
	if ( ++p == pe )
		goto _test_eof334;
case 334:
	_widec = (*p);
	if ( 10 <= (*p) && (*p) <= 10 ) {
		_widec = (short)(1152 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr1070;
		case 32: goto tr1070;
		case 34: goto tr1072;
		case 59: goto tr1070;
		case 92: goto tr1073;
		case 1546: goto tr1070;
	}
	if ( 33 <= _widec && _widec <= 126 )
		goto tr1071;
	goto tr1050;
tr1072:
	{
		if (s->comma_list) {
			uint8_t *last_two = rdata_tail - 2;
			uint16_t current_len = rdata_tail - s->item_length_location - 2;
			if (last_two[1] == ',') {
				if (current_len <= 1) {
					WARN(ZS_EMPTY_LIST_ITEM);
					p--; {goto st316;}
				} else if (last_two[0] != '\\' || !s->pending_backslash) { // Start a new item.
					*(s->item_length_location) = current_len;
					s->item_length_location = rdata_tail - 1;
				} else { // Remove backslash.
					last_two[0] = ',';
					rdata_tail--;
					s->pending_backslash = false;
				}
			} else if (last_two[1] == '\\') {
				if (s->pending_backslash) { // Remove backslash.
					rdata_tail--;
					s->pending_backslash = false;
				} else {
					s->pending_backslash = true;
				}
			} else if (s->pending_backslash) {
				WARN(ZS_BAD_ALPN_BACKSLASH);
				p--; {goto st316;}
			}
		}
	}
	goto st335;
tr1081:
	{
		rdata_tail++;
	}
	{
		if (s->comma_list) {
			uint8_t *last_two = rdata_tail - 2;
			uint16_t current_len = rdata_tail - s->item_length_location - 2;
			if (last_two[1] == ',') {
				if (current_len <= 1) {
					WARN(ZS_EMPTY_LIST_ITEM);
					p--; {goto st316;}
				} else if (last_two[0] != '\\' || !s->pending_backslash) { // Start a new item.
					*(s->item_length_location) = current_len;
					s->item_length_location = rdata_tail - 1;
				} else { // Remove backslash.
					last_two[0] = ',';
					rdata_tail--;
					s->pending_backslash = false;
				}
			} else if (last_two[1] == '\\') {
				if (s->pending_backslash) { // Remove backslash.
					rdata_tail--;
					s->pending_backslash = false;
				} else {
					s->pending_backslash = true;
				}
			} else if (s->pending_backslash) {
				WARN(ZS_BAD_ALPN_BACKSLASH);
				p--; {goto st316;}
			}
		}
	}
	goto st335;
st335:
	if ( ++p == pe )
		goto _test_eof335;
case 335:
	switch( (*p) ) {
		case 32: goto tr1075;
		case 59: goto tr1075;
	}
	if ( (*p) > 10 ) {
		if ( 40 <= (*p) && (*p) <= 41 )
			goto tr1075;
	} else if ( (*p) >= 9 )
		goto tr1075;
	goto tr1074;
tr1073:
	{
		if (s->comma_list) {
			uint8_t *last_two = rdata_tail - 2;
			uint16_t current_len = rdata_tail - s->item_length_location - 2;
			if (last_two[1] == ',') {
				if (current_len <= 1) {
					WARN(ZS_EMPTY_LIST_ITEM);
					p--; {goto st316;}
				} else if (last_two[0] != '\\' || !s->pending_backslash) { // Start a new item.
					*(s->item_length_location) = current_len;
					s->item_length_location = rdata_tail - 1;
				} else { // Remove backslash.
					last_two[0] = ',';
					rdata_tail--;
					s->pending_backslash = false;
				}
			} else if (last_two[1] == '\\') {
				if (s->pending_backslash) { // Remove backslash.
					rdata_tail--;
					s->pending_backslash = false;
				} else {
					s->pending_backslash = true;
				}
			} else if (s->pending_backslash) {
				WARN(ZS_BAD_ALPN_BACKSLASH);
				p--; {goto st316;}
			}
		}
	}
	goto st336;
tr1082:
	{
		rdata_tail++;
	}
	{
		if (s->comma_list) {
			uint8_t *last_two = rdata_tail - 2;
			uint16_t current_len = rdata_tail - s->item_length_location - 2;
			if (last_two[1] == ',') {
				if (current_len <= 1) {
					WARN(ZS_EMPTY_LIST_ITEM);
					p--; {goto st316;}
				} else if (last_two[0] != '\\' || !s->pending_backslash) { // Start a new item.
					*(s->item_length_location) = current_len;
					s->item_length_location = rdata_tail - 1;
				} else { // Remove backslash.
					last_two[0] = ',';
					rdata_tail--;
					s->pending_backslash = false;
				}
			} else if (last_two[1] == '\\') {
				if (s->pending_backslash) { // Remove backslash.
					rdata_tail--;
					s->pending_backslash = false;
				} else {
					s->pending_backslash = true;
				}
			} else if (s->pending_backslash) {
				WARN(ZS_BAD_ALPN_BACKSLASH);
				p--; {goto st316;}
			}
		}
	}
	goto st336;
st336:
	if ( ++p == pe )
		goto _test_eof336;
case 336:
	if ( (*p) < 48 ) {
		if ( 32 <= (*p) && (*p) <= 47 )
			goto tr1067;
	} else if ( (*p) > 57 ) {
		if ( 58 <= (*p) && (*p) <= 126 )
			goto tr1067;
	} else
		goto tr1076;
	goto tr1058;
tr1076:
	{
		if (rdata_tail <= rdata_stop) {
			// Split long string.
			if (s->long_string &&
			    rdata_tail - s->item_length_location == 1 + MAX_ITEM_LENGTH) {
				// _item_length_exit equivalent.
				*(s->item_length_location) = MAX_ITEM_LENGTH;
				// _item_length_init equivalent.
				s->item_length_location = rdata_tail++;

				if (rdata_tail > rdata_stop) {
					WARN(ZS_TEXT_OVERFLOW);
					p--; {goto st316;}
				}
			}

			*rdata_tail = 0;
			s->item_length++;
		} else {
			WARN(ZS_TEXT_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if ((*rdata_tail < (UINT8_MAX / 10)) ||   // Dominant fast check.
			((*rdata_tail == (UINT8_MAX / 10)) && // Marginal case.
			 ((*p) <= (UINT8_MAX % 10) + '0')
			)
		   ) {
			*rdata_tail *= 10;
			*rdata_tail += digit_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_NUMBER8_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st337;
st337:
	if ( ++p == pe )
		goto _test_eof337;
case 337:
	if ( 48 <= (*p) && (*p) <= 57 )
		goto tr1077;
	goto tr1058;
tr1077:
	{
		if ((*rdata_tail < (UINT8_MAX / 10)) ||   // Dominant fast check.
			((*rdata_tail == (UINT8_MAX / 10)) && // Marginal case.
			 ((*p) <= (UINT8_MAX % 10) + '0')
			)
		   ) {
			*rdata_tail *= 10;
			*rdata_tail += digit_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_NUMBER8_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st338;
st338:
	if ( ++p == pe )
		goto _test_eof338;
case 338:
	if ( 48 <= (*p) && (*p) <= 57 )
		goto tr1078;
	goto tr1058;
tr1078:
	{
		if ((*rdata_tail < (UINT8_MAX / 10)) ||   // Dominant fast check.
			((*rdata_tail == (UINT8_MAX / 10)) && // Marginal case.
			 ((*p) <= (UINT8_MAX % 10) + '0')
			)
		   ) {
			*rdata_tail *= 10;
			*rdata_tail += digit_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_NUMBER8_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st339;
st339:
	if ( ++p == pe )
		goto _test_eof339;
case 339:
	_widec = (*p);
	if ( 10 <= (*p) && (*p) <= 10 ) {
		_widec = (short)(1152 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr1079;
		case 32: goto tr1079;
		case 34: goto tr1081;
		case 59: goto tr1079;
		case 92: goto tr1082;
		case 1546: goto tr1079;
	}
	if ( 33 <= _widec && _widec <= 126 )
		goto tr1080;
	goto tr1058;
st340:
	if ( ++p == pe )
		goto _test_eof340;
case 340:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto st341;
		case 32: goto st341;
		case 40: goto tr1085;
		case 41: goto tr1086;
		case 2058: goto tr1087;
		case 2107: goto tr1088;
	}
	goto tr1083;
tr1085:
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st341;
tr1086:
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st341;
tr1087:
	{
		s->line_counter++;
	}
	goto st341;
tr1126:
	{
		s->buffer[s->buffer_length++] = 0;

		// Execute the comment callback.
		if (s->process.automatic && s->process.comment != NULL) {
			s->process.comment(s);

			// Stop if required from the callback.
			if (s->state == ZS_STATE_STOP) {
				{p++; cs = 341; goto _out;}
			}
		}
	}
	{
		s->line_counter++;
	}
	goto st341;
st341:
	if ( ++p == pe )
		goto _test_eof341;
case 341:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto st341;
		case 32: goto st341;
		case 40: goto tr1085;
		case 41: goto tr1086;
		case 2058: goto tr1087;
		case 2107: goto tr1088;
	}
	if ( 48 <= _widec && _widec <= 57 )
		goto tr1090;
	goto tr1089;
tr1090:
	{
		s->number64 = 0;
	}
	{
		// Overflow check: 10*(s->number64) + fc - '0' <= UINT64_MAX
		if ((s->number64 < (UINT64_MAX / 10)) ||   // Dominant fast check.
			((s->number64 == (UINT64_MAX / 10)) && // Marginal case.
			 ((uint8_t)(*p) <= (UINT64_MAX % 10) + '0')
			)
		   ) {
			s->number64 *= 10;
			s->number64 += digit_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_NUMBER64_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st342;
tr1095:
	{
		// Overflow check: 10*(s->number64) + fc - '0' <= UINT64_MAX
		if ((s->number64 < (UINT64_MAX / 10)) ||   // Dominant fast check.
			((s->number64 == (UINT64_MAX / 10)) && // Marginal case.
			 ((uint8_t)(*p) <= (UINT64_MAX % 10) + '0')
			)
		   ) {
			s->number64 *= 10;
			s->number64 += digit_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_NUMBER64_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st342;
st342:
	if ( ++p == pe )
		goto _test_eof342;
case 342:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr1092;
		case 32: goto tr1092;
		case 40: goto tr1093;
		case 41: goto tr1094;
		case 68: goto tr1096;
		case 72: goto tr1097;
		case 77: goto tr1098;
		case 83: goto st345;
		case 87: goto tr1100;
		case 100: goto tr1096;
		case 104: goto tr1097;
		case 109: goto tr1098;
		case 115: goto st345;
		case 119: goto tr1100;
		case 1802: goto tr1101;
		case 1851: goto tr1102;
		case 2058: goto tr1101;
		case 2107: goto tr1102;
	}
	if ( 48 <= _widec && _widec <= 57 )
		goto tr1095;
	goto tr1091;
tr1105:
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st343;
tr1106:
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st343;
tr1092:
	{
		s->buffer[0] = 0;
		s->buffer_length = 0;
	}
	goto st343;
tr1093:
	{
		s->buffer[0] = 0;
		s->buffer_length = 0;
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st343;
tr1094:
	{
		s->buffer[0] = 0;
		s->buffer_length = 0;
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st343;
tr1119:
	{
		if (s->number64 + s->number64_tmp < UINT32_MAX) {
			s->number64 += s->number64_tmp;
		} else {
			WARN(ZS_NUMBER32_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		s->buffer[0] = 0;
		s->buffer_length = 0;
	}
	goto st343;
tr1120:
	{
		if (s->number64 + s->number64_tmp < UINT32_MAX) {
			s->number64 += s->number64_tmp;
		} else {
			WARN(ZS_NUMBER32_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		s->buffer[0] = 0;
		s->buffer_length = 0;
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st343;
tr1121:
	{
		if (s->number64 + s->number64_tmp < UINT32_MAX) {
			s->number64 += s->number64_tmp;
		} else {
			WARN(ZS_NUMBER32_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		s->buffer[0] = 0;
		s->buffer_length = 0;
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st343;
st343:
	if ( ++p == pe )
		goto _test_eof343;
case 343:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto st343;
		case 32: goto st343;
		case 40: goto tr1105;
		case 41: goto tr1106;
		case 1802: goto tr1107;
		case 1851: goto tr1108;
		case 2058: goto tr1107;
		case 2107: goto tr1108;
	}
	goto tr1103;
tr1101:
	{
		s->buffer[0] = 0;
		s->buffer_length = 0;
	}
	{
		if (s->number64 <= UINT32_MAX) {
			s->default_ttl = (uint32_t)(s->number64);
		} else {
			ERR(ZS_NUMBER32_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	{
		s->line_counter++;
	}
	goto st1459;
tr1107:
	{
		if (s->number64 <= UINT32_MAX) {
			s->default_ttl = (uint32_t)(s->number64);
		} else {
			ERR(ZS_NUMBER32_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	{
		s->line_counter++;
	}
	goto st1459;
tr1110:
	{
		s->buffer[s->buffer_length++] = 0;

		// Execute the comment callback.
		if (s->process.automatic && s->process.comment != NULL) {
			s->process.comment(s);

			// Stop if required from the callback.
			if (s->state == ZS_STATE_STOP) {
				{p++; cs = 1459; goto _out;}
			}
		}
	}
	{
		if (s->number64 <= UINT32_MAX) {
			s->default_ttl = (uint32_t)(s->number64);
		} else {
			ERR(ZS_NUMBER32_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	{
		s->line_counter++;
	}
	goto st1459;
tr1123:
	{
		if (s->number64 + s->number64_tmp < UINT32_MAX) {
			s->number64 += s->number64_tmp;
		} else {
			WARN(ZS_NUMBER32_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		s->buffer[0] = 0;
		s->buffer_length = 0;
	}
	{
		if (s->number64 <= UINT32_MAX) {
			s->default_ttl = (uint32_t)(s->number64);
		} else {
			ERR(ZS_NUMBER32_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	{
		s->line_counter++;
	}
	goto st1459;
st1459:
	if ( ++p == pe )
		goto _test_eof1459;
case 1459:
	goto st0;
tr1108:
	{
		s->buffer_length = 0;
	}
	goto st344;
tr1102:
	{
		s->buffer[0] = 0;
		s->buffer_length = 0;
	}
	{
		s->buffer_length = 0;
	}
	goto st344;
tr1109:
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		}
	}
	goto st344;
tr1124:
	{
		if (s->number64 + s->number64_tmp < UINT32_MAX) {
			s->number64 += s->number64_tmp;
		} else {
			WARN(ZS_NUMBER32_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		s->buffer[0] = 0;
		s->buffer_length = 0;
	}
	{
		s->buffer_length = 0;
	}
	goto st344;
st344:
	if ( ++p == pe )
		goto _test_eof344;
case 344:
	if ( (*p) == 10 )
		goto tr1110;
	goto tr1109;
tr1096:
	{ if (s->number64 <= (UINT32_MAX / 86400)) {
	                  s->number64 *= 86400;
	              } else {
	                  WARN(ZS_NUMBER32_OVERFLOW);
	                  p--; {goto st316;}
	              }
	            }
	goto st345;
tr1097:
	{ if (s->number64 <= (UINT32_MAX / 3600)) {
	                  s->number64 *= 3600;
	              } else {
	                  WARN(ZS_NUMBER32_OVERFLOW);
	                  p--; {goto st316;}
	              }
	            }
	goto st345;
tr1098:
	{ if (s->number64 <= (UINT32_MAX / 60)) {
	                  s->number64 *= 60;
	              } else {
	                  WARN(ZS_NUMBER32_OVERFLOW);
	                  p--; {goto st316;}
	              }
	            }
	goto st345;
tr1100:
	{ if (s->number64 <= (UINT32_MAX / 604800)) {
	                  s->number64 *= 604800;
	              } else {
	                  WARN(ZS_NUMBER32_OVERFLOW);
	                  p--; {goto st316;}
	              }
	            }
	goto st345;
st345:
	if ( ++p == pe )
		goto _test_eof345;
case 345:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr1092;
		case 32: goto tr1092;
		case 40: goto tr1093;
		case 41: goto tr1094;
		case 1802: goto tr1101;
		case 1851: goto tr1102;
		case 2058: goto tr1101;
		case 2107: goto tr1102;
	}
	if ( 48 <= _widec && _widec <= 57 )
		goto tr1111;
	goto tr1091;
tr1113:
	{
		// Overflow check: 10*(s->number64) + fc - '0' <= UINT64_MAX
		if ((s->number64 < (UINT64_MAX / 10)) ||   // Dominant fast check.
			((s->number64 == (UINT64_MAX / 10)) && // Marginal case.
			 ((uint8_t)(*p) <= (UINT64_MAX % 10) + '0')
			)
		   ) {
			s->number64 *= 10;
			s->number64 += digit_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_NUMBER64_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st346;
tr1111:
	{
		s->number64_tmp = s->number64;
	}
	{
		s->number64 = 0;
	}
	{
		// Overflow check: 10*(s->number64) + fc - '0' <= UINT64_MAX
		if ((s->number64 < (UINT64_MAX / 10)) ||   // Dominant fast check.
			((s->number64 == (UINT64_MAX / 10)) && // Marginal case.
			 ((uint8_t)(*p) <= (UINT64_MAX % 10) + '0')
			)
		   ) {
			s->number64 *= 10;
			s->number64 += digit_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_NUMBER64_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st346;
tr1122:
	{
		if (s->number64 + s->number64_tmp < UINT32_MAX) {
			s->number64 += s->number64_tmp;
		} else {
			WARN(ZS_NUMBER32_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		s->number64_tmp = s->number64;
	}
	{
		s->number64 = 0;
	}
	{
		// Overflow check: 10*(s->number64) + fc - '0' <= UINT64_MAX
		if ((s->number64 < (UINT64_MAX / 10)) ||   // Dominant fast check.
			((s->number64 == (UINT64_MAX / 10)) && // Marginal case.
			 ((uint8_t)(*p) <= (UINT64_MAX % 10) + '0')
			)
		   ) {
			s->number64 *= 10;
			s->number64 += digit_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_NUMBER64_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st346;
st346:
	if ( ++p == pe )
		goto _test_eof346;
case 346:
	switch( (*p) ) {
		case 68: goto tr1114;
		case 72: goto tr1115;
		case 77: goto tr1116;
		case 83: goto st347;
		case 87: goto tr1118;
		case 100: goto tr1114;
		case 104: goto tr1115;
		case 109: goto tr1116;
		case 115: goto st347;
		case 119: goto tr1118;
	}
	if ( 48 <= (*p) && (*p) <= 57 )
		goto tr1113;
	goto tr1112;
tr1114:
	{ if (s->number64 <= (UINT32_MAX / 86400)) {
	                  s->number64 *= 86400;
	              } else {
	                  WARN(ZS_NUMBER32_OVERFLOW);
	                  p--; {goto st316;}
	              }
	            }
	goto st347;
tr1115:
	{ if (s->number64 <= (UINT32_MAX / 3600)) {
	                  s->number64 *= 3600;
	              } else {
	                  WARN(ZS_NUMBER32_OVERFLOW);
	                  p--; {goto st316;}
	              }
	            }
	goto st347;
tr1116:
	{ if (s->number64 <= (UINT32_MAX / 60)) {
	                  s->number64 *= 60;
	              } else {
	                  WARN(ZS_NUMBER32_OVERFLOW);
	                  p--; {goto st316;}
	              }
	            }
	goto st347;
tr1118:
	{ if (s->number64 <= (UINT32_MAX / 604800)) {
	                  s->number64 *= 604800;
	              } else {
	                  WARN(ZS_NUMBER32_OVERFLOW);
	                  p--; {goto st316;}
	              }
	            }
	goto st347;
st347:
	if ( ++p == pe )
		goto _test_eof347;
case 347:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr1119;
		case 32: goto tr1119;
		case 40: goto tr1120;
		case 41: goto tr1121;
		case 1802: goto tr1123;
		case 1851: goto tr1124;
		case 2058: goto tr1123;
		case 2107: goto tr1124;
	}
	if ( 48 <= _widec && _widec <= 57 )
		goto tr1122;
	goto tr1091;
tr1088:
	{
		s->buffer_length = 0;
	}
	goto st348;
tr1125:
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		}
	}
	goto st348;
st348:
	if ( ++p == pe )
		goto _test_eof348;
case 348:
	_widec = (*p);
	if ( (*p) < 10 ) {
		if ( (*p) <= 9 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) > 10 ) {
		if ( 11 <= (*p) )
 {			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	if ( _widec == 2058 )
		goto tr1126;
	if ( 1920 <= _widec && _widec <= 2175 )
		goto tr1125;
	goto tr1083;
st349:
	if ( ++p == pe )
		goto _test_eof349;
case 349:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto st350;
		case 32: goto st350;
		case 40: goto tr1129;
		case 41: goto tr1130;
		case 2058: goto tr1131;
		case 2107: goto tr1132;
	}
	goto tr1127;
tr1129:
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st350;
tr1130:
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st350;
tr1131:
	{
		s->line_counter++;
	}
	goto st350;
tr1162:
	{
		s->buffer[s->buffer_length++] = 0;

		// Execute the comment callback.
		if (s->process.automatic && s->process.comment != NULL) {
			s->process.comment(s);

			// Stop if required from the callback.
			if (s->state == ZS_STATE_STOP) {
				{p++; cs = 350; goto _out;}
			}
		}
	}
	{
		s->line_counter++;
	}
	goto st350;
st350:
	if ( ++p == pe )
		goto _test_eof350;
case 350:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto st350;
		case 32: goto st350;
		case 40: goto tr1129;
		case 41: goto tr1130;
		case 42: goto tr1133;
		case 46: goto tr1134;
		case 92: goto tr1135;
		case 95: goto tr1133;
		case 2058: goto tr1131;
		case 2107: goto tr1132;
	}
	if ( _widec < 65 ) {
		if ( 45 <= _widec && _widec <= 57 )
			goto tr1133;
	} else if ( _widec > 90 ) {
		if ( 97 <= _widec && _widec <= 122 )
			goto tr1133;
	} else
		goto tr1133;
	goto tr1127;
tr1136:
	{
		// Check for maximum dname label length.
		if (s->item_length < ZS_MAX_LABEL_LENGTH) {
			(s->dname)[s->dname_tmp_length++] = (*p);
			s->item_length++;
		} else {
			WARN(ZS_LABEL_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st351;
tr1143:
	{
		s->item_length = 0;
		s->item_length_position = s->dname_tmp_length++;
	}
	{
		// Check for maximum dname label length.
		if (s->item_length < ZS_MAX_LABEL_LENGTH) {
			(s->dname)[s->dname_tmp_length++] = (*p);
			s->item_length++;
		} else {
			WARN(ZS_LABEL_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st351;
tr1158:
	{
		s->dname_tmp_length++;
	}
	{
		// Check for maximum dname label length.
		if (s->item_length < ZS_MAX_LABEL_LENGTH) {
			(s->dname)[s->dname_tmp_length++] = (*p);
			s->item_length++;
		} else {
			WARN(ZS_LABEL_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st351;
tr1133:
	{
		s->dname = s->zone_origin;
	}
	{
		s->item_length_position = 0;
		s->dname_tmp_length = 0;
	}
	{
		s->item_length = 0;
		s->item_length_position = s->dname_tmp_length++;
	}
	{
		// Check for maximum dname label length.
		if (s->item_length < ZS_MAX_LABEL_LENGTH) {
			(s->dname)[s->dname_tmp_length++] = (*p);
			s->item_length++;
		} else {
			WARN(ZS_LABEL_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st351;
st351:
	if ( ++p == pe )
		goto _test_eof351;
case 351:
	switch( (*p) ) {
		case 42: goto tr1136;
		case 46: goto tr1137;
		case 92: goto st355;
		case 95: goto tr1136;
	}
	if ( (*p) < 65 ) {
		if ( 45 <= (*p) && (*p) <= 57 )
			goto tr1136;
	} else if ( (*p) > 90 ) {
		if ( 97 <= (*p) && (*p) <= 122 )
			goto tr1136;
	} else
		goto tr1136;
	goto tr1127;
tr1137:
	{
		// Check for maximum dname length overflow after each label.
		// (at least the next label length must follow).
		if (s->dname_tmp_length < ZS_MAX_DNAME_LENGTH) {
			(s->dname)[s->item_length_position] =
				(uint8_t)(s->item_length);
		} else {
			WARN(ZS_DNAME_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st352;
tr1159:
	{
		s->dname_tmp_length++;
	}
	{
		// Check for maximum dname length overflow after each label.
		// (at least the next label length must follow).
		if (s->dname_tmp_length < ZS_MAX_DNAME_LENGTH) {
			(s->dname)[s->item_length_position] =
				(uint8_t)(s->item_length);
		} else {
			WARN(ZS_DNAME_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st352;
st352:
	if ( ++p == pe )
		goto _test_eof352;
case 352:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr1140;
		case 32: goto tr1140;
		case 40: goto tr1141;
		case 41: goto tr1142;
		case 42: goto tr1143;
		case 45: goto tr1143;
		case 92: goto tr1144;
		case 95: goto tr1143;
		case 1802: goto tr1145;
		case 1851: goto tr1146;
		case 2058: goto tr1145;
		case 2107: goto tr1146;
	}
	if ( _widec < 65 ) {
		if ( 47 <= _widec && _widec <= 57 )
			goto tr1143;
	} else if ( _widec > 90 ) {
		if ( 97 <= _widec && _widec <= 122 )
			goto tr1143;
	} else
		goto tr1143;
	goto tr1139;
tr1148:
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st353;
tr1149:
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st353;
tr1140:
	{
		// Enough room for the terminal label is guaranteed (_label_exit).
		(s->dname)[s->dname_tmp_length++] = 0;
	}
	{
		s->buffer[0] = 0;
		s->buffer_length = 0;
	}
	goto st353;
tr1141:
	{
		// Enough room for the terminal label is guaranteed (_label_exit).
		(s->dname)[s->dname_tmp_length++] = 0;
	}
	{
		s->buffer[0] = 0;
		s->buffer_length = 0;
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st353;
tr1142:
	{
		// Enough room for the terminal label is guaranteed (_label_exit).
		(s->dname)[s->dname_tmp_length++] = 0;
	}
	{
		s->buffer[0] = 0;
		s->buffer_length = 0;
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st353;
st353:
	if ( ++p == pe )
		goto _test_eof353;
case 353:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto st353;
		case 32: goto st353;
		case 40: goto tr1148;
		case 41: goto tr1149;
		case 1802: goto tr1150;
		case 1851: goto tr1151;
		case 2058: goto tr1150;
		case 2107: goto tr1151;
	}
	goto tr1139;
tr1145:
	{
		// Enough room for the terminal label is guaranteed (_label_exit).
		(s->dname)[s->dname_tmp_length++] = 0;
	}
	{
		s->buffer[0] = 0;
		s->buffer_length = 0;
	}
	{
		s->zone_origin_length = s->dname_tmp_length;
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	{
		s->line_counter++;
	}
	goto st1460;
tr1150:
	{
		s->zone_origin_length = s->dname_tmp_length;
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	{
		s->line_counter++;
	}
	goto st1460;
tr1153:
	{
		s->buffer[s->buffer_length++] = 0;

		// Execute the comment callback.
		if (s->process.automatic && s->process.comment != NULL) {
			s->process.comment(s);

			// Stop if required from the callback.
			if (s->state == ZS_STATE_STOP) {
				{p++; cs = 1460; goto _out;}
			}
		}
	}
	{
		s->zone_origin_length = s->dname_tmp_length;
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	{
		s->line_counter++;
	}
	goto st1460;
st1460:
	if ( ++p == pe )
		goto _test_eof1460;
case 1460:
	goto st0;
tr1151:
	{
		s->buffer_length = 0;
	}
	goto st354;
tr1152:
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		}
	}
	goto st354;
tr1146:
	{
		// Enough room for the terminal label is guaranteed (_label_exit).
		(s->dname)[s->dname_tmp_length++] = 0;
	}
	{
		s->buffer[0] = 0;
		s->buffer_length = 0;
	}
	{
		s->buffer_length = 0;
	}
	goto st354;
st354:
	if ( ++p == pe )
		goto _test_eof354;
case 354:
	if ( (*p) == 10 )
		goto tr1153;
	goto tr1152;
tr1144:
	{
		s->item_length = 0;
		s->item_length_position = s->dname_tmp_length++;
	}
	goto st355;
tr1160:
	{
		s->dname_tmp_length++;
	}
	goto st355;
tr1135:
	{
		s->dname = s->zone_origin;
	}
	{
		s->item_length_position = 0;
		s->dname_tmp_length = 0;
	}
	{
		s->item_length = 0;
		s->item_length_position = s->dname_tmp_length++;
	}
	goto st355;
st355:
	if ( ++p == pe )
		goto _test_eof355;
case 355:
	if ( 48 <= (*p) && (*p) <= 57 )
		goto tr1154;
	goto tr1136;
tr1154:
	{
		if (s->item_length < ZS_MAX_LABEL_LENGTH) {
			(s->dname)[s->dname_tmp_length] = 0;
			s->item_length++;
		} else {
			WARN(ZS_LABEL_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		(s->dname)[s->dname_tmp_length] *= 10;
		(s->dname)[s->dname_tmp_length] += digit_to_num[(uint8_t)(*p)];
	}
	goto st356;
st356:
	if ( ++p == pe )
		goto _test_eof356;
case 356:
	if ( 48 <= (*p) && (*p) <= 57 )
		goto tr1156;
	goto tr1155;
tr1156:
	{
		(s->dname)[s->dname_tmp_length] *= 10;
		(s->dname)[s->dname_tmp_length] += digit_to_num[(uint8_t)(*p)];
	}
	goto st357;
st357:
	if ( ++p == pe )
		goto _test_eof357;
case 357:
	if ( 48 <= (*p) && (*p) <= 57 )
		goto tr1157;
	goto tr1155;
tr1157:
	{
		(s->dname)[s->dname_tmp_length] *= 10;
		(s->dname)[s->dname_tmp_length] += digit_to_num[(uint8_t)(*p)];
	}
	goto st358;
st358:
	if ( ++p == pe )
		goto _test_eof358;
case 358:
	switch( (*p) ) {
		case 42: goto tr1158;
		case 46: goto tr1159;
		case 92: goto tr1160;
		case 95: goto tr1158;
	}
	if ( (*p) < 65 ) {
		if ( 45 <= (*p) && (*p) <= 57 )
			goto tr1158;
	} else if ( (*p) > 90 ) {
		if ( 97 <= (*p) && (*p) <= 122 )
			goto tr1158;
	} else
		goto tr1158;
	goto tr1155;
tr1134:
	{
		s->dname = s->zone_origin;
	}
	{
		s->item_length_position = 0;
		s->dname_tmp_length = 0;
	}
	goto st359;
st359:
	if ( ++p == pe )
		goto _test_eof359;
case 359:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr1140;
		case 32: goto tr1140;
		case 40: goto tr1141;
		case 41: goto tr1142;
		case 1802: goto tr1145;
		case 1851: goto tr1146;
		case 2058: goto tr1145;
		case 2107: goto tr1146;
	}
	goto tr1139;
tr1132:
	{
		s->buffer_length = 0;
	}
	goto st360;
tr1161:
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		}
	}
	goto st360;
st360:
	if ( ++p == pe )
		goto _test_eof360;
case 360:
	_widec = (*p);
	if ( (*p) < 10 ) {
		if ( (*p) <= 9 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) > 10 ) {
		if ( 11 <= (*p) )
 {			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	if ( _widec == 2058 )
		goto tr1162;
	if ( 1920 <= _widec && _widec <= 2175 )
		goto tr1161;
	goto tr1127;
st361:
	if ( ++p == pe )
		goto _test_eof361;
case 361:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto st362;
		case 32: goto st362;
		case 40: goto tr1164;
		case 41: goto tr1165;
		case 2058: goto tr1166;
		case 2107: goto tr1167;
	}
	goto st0;
tr1164:
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st362;
tr1165:
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st362;
tr1166:
	{
		s->line_counter++;
	}
	goto st362;
tr1220:
	{
		s->buffer[s->buffer_length++] = 0;

		// Execute the comment callback.
		if (s->process.automatic && s->process.comment != NULL) {
			s->process.comment(s);

			// Stop if required from the callback.
			if (s->state == ZS_STATE_STOP) {
				{p++; cs = 362; goto _out;}
			}
		}
	}
	{
		s->line_counter++;
	}
	goto st362;
st362:
	if ( ++p == pe )
		goto _test_eof362;
case 362:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto st362;
		case 32: goto st362;
		case 40: goto tr1164;
		case 41: goto tr1165;
		case 2058: goto tr1166;
		case 2107: goto tr1167;
	}
	if ( _widec < 11 ) {
		if ( _widec <= 8 )
			goto tr1168;
	} else if ( _widec > 58 ) {
		if ( 60 <= _widec )
			goto tr1168;
	} else
		goto tr1168;
	goto tr1169;
tr1168:
	{
		rdata_tail = s->r_data;
	}
	{ p--; {stack[top++] = 363;goto st327;} }
	goto st363;
st363:
	if ( ++p == pe )
		goto _test_eof363;
case 363:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr1171;
		case 32: goto tr1171;
		case 40: goto tr1172;
		case 41: goto tr1173;
		case 1802: goto tr1174;
		case 1851: goto tr1175;
		case 2058: goto tr1174;
		case 2107: goto tr1176;
	}
	goto tr1170;
tr1179:
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st364;
tr1180:
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st364;
tr1171:
	{
		size_t len = rdata_tail - s->r_data;
		if (len >= sizeof(s->include_filename)) {
			ERR(ZS_BAD_INCLUDE_FILENAME);
			p--; {goto st316;}
		}

		// Store zero terminated include filename.
		memcpy(s->include_filename, s->r_data, len);
		s->include_filename[len] = '\0';

		// For detection whether origin is not present.
		s->dname = NULL;
	}
	{
		s->buffer[0] = 0;
		s->buffer_length = 0;
	}
	goto st364;
tr1172:
	{
		size_t len = rdata_tail - s->r_data;
		if (len >= sizeof(s->include_filename)) {
			ERR(ZS_BAD_INCLUDE_FILENAME);
			p--; {goto st316;}
		}

		// Store zero terminated include filename.
		memcpy(s->include_filename, s->r_data, len);
		s->include_filename[len] = '\0';

		// For detection whether origin is not present.
		s->dname = NULL;
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	{
		s->buffer[0] = 0;
		s->buffer_length = 0;
	}
	goto st364;
tr1173:
	{
		size_t len = rdata_tail - s->r_data;
		if (len >= sizeof(s->include_filename)) {
			ERR(ZS_BAD_INCLUDE_FILENAME);
			p--; {goto st316;}
		}

		// Store zero terminated include filename.
		memcpy(s->include_filename, s->r_data, len);
		s->include_filename[len] = '\0';

		// For detection whether origin is not present.
		s->dname = NULL;
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	{
		s->buffer[0] = 0;
		s->buffer_length = 0;
	}
	goto st364;
st364:
	if ( ++p == pe )
		goto _test_eof364;
case 364:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto st364;
		case 32: goto st364;
		case 40: goto tr1179;
		case 41: goto tr1180;
		case 42: goto tr1181;
		case 46: goto tr1182;
		case 92: goto tr1183;
		case 95: goto tr1181;
		case 1802: goto tr1184;
		case 1851: goto tr1185;
		case 2058: goto tr1184;
		case 2107: goto tr1186;
	}
	if ( _widec < 65 ) {
		if ( 45 <= _widec && _widec <= 57 )
			goto tr1181;
	} else if ( _widec > 90 ) {
		if ( 97 <= _widec && _widec <= 122 )
			goto tr1181;
	} else
		goto tr1181;
	goto tr1177;
tr1188:
	{
		// Check for maximum dname label length.
		if (s->item_length < ZS_MAX_LABEL_LENGTH) {
			(s->dname)[s->dname_tmp_length++] = (*p);
			s->item_length++;
		} else {
			WARN(ZS_LABEL_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st365;
tr1194:
	{
		s->item_length = 0;
		s->item_length_position = s->dname_tmp_length++;
	}
	{
		// Check for maximum dname label length.
		if (s->item_length < ZS_MAX_LABEL_LENGTH) {
			(s->dname)[s->dname_tmp_length++] = (*p);
			s->item_length++;
		} else {
			WARN(ZS_LABEL_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st365;
tr1207:
	{
		s->dname_tmp_length++;
	}
	{
		// Check for maximum dname label length.
		if (s->item_length < ZS_MAX_LABEL_LENGTH) {
			(s->dname)[s->dname_tmp_length++] = (*p);
			s->item_length++;
		} else {
			WARN(ZS_LABEL_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st365;
tr1181:
	{
		s->dname = s->r_data;
	}
	{
		s->item_length_position = 0;
		s->dname_tmp_length = 0;
	}
	{
		s->item_length = 0;
		s->item_length_position = s->dname_tmp_length++;
	}
	{
		// Check for maximum dname label length.
		if (s->item_length < ZS_MAX_LABEL_LENGTH) {
			(s->dname)[s->dname_tmp_length++] = (*p);
			s->item_length++;
		} else {
			WARN(ZS_LABEL_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st365;
st365:
	if ( ++p == pe )
		goto _test_eof365;
case 365:
	switch( (*p) ) {
		case 42: goto tr1188;
		case 46: goto tr1189;
		case 92: goto st369;
		case 95: goto tr1188;
	}
	if ( (*p) < 65 ) {
		if ( 45 <= (*p) && (*p) <= 57 )
			goto tr1188;
	} else if ( (*p) > 90 ) {
		if ( 97 <= (*p) && (*p) <= 122 )
			goto tr1188;
	} else
		goto tr1188;
	goto tr1187;
tr1189:
	{
		// Check for maximum dname length overflow after each label.
		// (at least the next label length must follow).
		if (s->dname_tmp_length < ZS_MAX_DNAME_LENGTH) {
			(s->dname)[s->item_length_position] =
				(uint8_t)(s->item_length);
		} else {
			WARN(ZS_DNAME_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st366;
tr1208:
	{
		s->dname_tmp_length++;
	}
	{
		// Check for maximum dname length overflow after each label.
		// (at least the next label length must follow).
		if (s->dname_tmp_length < ZS_MAX_DNAME_LENGTH) {
			(s->dname)[s->item_length_position] =
				(uint8_t)(s->item_length);
		} else {
			WARN(ZS_DNAME_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st366;
st366:
	if ( ++p == pe )
		goto _test_eof366;
case 366:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr1191;
		case 32: goto tr1191;
		case 40: goto tr1192;
		case 41: goto tr1193;
		case 42: goto tr1194;
		case 45: goto tr1194;
		case 92: goto tr1195;
		case 95: goto tr1194;
		case 1802: goto tr1196;
		case 1851: goto tr1197;
		case 2058: goto tr1196;
		case 2107: goto tr1197;
	}
	if ( _widec < 65 ) {
		if ( 47 <= _widec && _widec <= 57 )
			goto tr1194;
	} else if ( _widec > 90 ) {
		if ( 97 <= _widec && _widec <= 122 )
			goto tr1194;
	} else
		goto tr1194;
	goto tr1177;
tr1199:
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st367;
tr1200:
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st367;
tr1191:
	{
		// Enough room for the terminal label is guaranteed (_label_exit).
		(s->dname)[s->dname_tmp_length++] = 0;
	}
	{
		s->r_data_length = s->dname_tmp_length;
	}
	{
		s->buffer[0] = 0;
		s->buffer_length = 0;
	}
	goto st367;
tr1192:
	{
		// Enough room for the terminal label is guaranteed (_label_exit).
		(s->dname)[s->dname_tmp_length++] = 0;
	}
	{
		s->r_data_length = s->dname_tmp_length;
	}
	{
		s->buffer[0] = 0;
		s->buffer_length = 0;
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st367;
tr1193:
	{
		// Enough room for the terminal label is guaranteed (_label_exit).
		(s->dname)[s->dname_tmp_length++] = 0;
	}
	{
		s->r_data_length = s->dname_tmp_length;
	}
	{
		s->buffer[0] = 0;
		s->buffer_length = 0;
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st367;
st367:
	if ( ++p == pe )
		goto _test_eof367;
case 367:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto st367;
		case 32: goto st367;
		case 40: goto tr1199;
		case 41: goto tr1200;
		case 1802: goto tr1184;
		case 1851: goto tr1185;
		case 2058: goto tr1184;
		case 2107: goto tr1185;
	}
	goto tr91;
tr1174:
	cs = 1461;
	{
		size_t len = rdata_tail - s->r_data;
		if (len >= sizeof(s->include_filename)) {
			ERR(ZS_BAD_INCLUDE_FILENAME);
			p--; {goto st316;}
		}

		// Store zero terminated include filename.
		memcpy(s->include_filename, s->r_data, len);
		s->include_filename[len] = '\0';

		// For detection whether origin is not present.
		s->dname = NULL;
	}
	{
		s->buffer[0] = 0;
		s->buffer_length = 0;
	}
	{
		// Extend relative file path.
		if (s->include_filename[0] != '/') {
			int ret = snprintf((char *)(s->buffer), sizeof(s->buffer),
			                   "%s/%s", s->path, s->include_filename);
			if (ret <= 0 || ret >= sizeof(s->buffer)) {
				ERR(ZS_BAD_INCLUDE_FILENAME);
				p--; {goto st316;}
			}
			memcpy(s->include_filename, s->buffer, ret + 1);
		}

		// Origin conversion from wire to text form in \DDD notation.
		if (s->dname == NULL) { // Use current origin.
			wire_dname_to_str(s->zone_origin,
			                  s->zone_origin_length,
			                  (char *)s->buffer);
		} else { // Use specified origin.
			wire_dname_to_str(s->r_data,
			                  s->r_data_length,
			                  (char *)s->buffer);
		}

		// Let the caller to solve the include.
		if (s->process.automatic) {
			// Create new scanner for included zone file.
			zs_scanner_t *ss = malloc(sizeof(zs_scanner_t));
			if (ss == NULL) {
				ERR(ZS_UNPROCESSED_INCLUDE);
				p--; {goto st316;}
			}

			// Parse included zone file.
			if (zs_init(ss, (char *)s->buffer, s->default_class,
			            s->default_ttl) != 0 ||
			    zs_set_input_file(ss, (char *)(s->include_filename)) != 0 ||
			    zs_set_processing(ss, s->process.record, s->process.error,
			                      s->process.data) != 0 ||
			    zs_parse_all(ss) != 0) {
				// File internal errors are handled by error callback.
				if (ss->error.counter > 0) {
					s->error.counter += ss->error.counter;
					ERR(ZS_UNPROCESSED_INCLUDE);
				// General include file error.
				} else {
					ERR(ss->error.code);
				}
				zs_deinit(ss);
				free(ss);
				p--; {goto st316;}
			}
			zs_deinit(ss);
			free(ss);
		} else {
			s->state = ZS_STATE_INCLUDE;
			p--; cs = 1444; {p++; goto _out;}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	{
		s->line_counter++;
	}
	goto _again;
tr1184:
	cs = 1461;
	{
		// Extend relative file path.
		if (s->include_filename[0] != '/') {
			int ret = snprintf((char *)(s->buffer), sizeof(s->buffer),
			                   "%s/%s", s->path, s->include_filename);
			if (ret <= 0 || ret >= sizeof(s->buffer)) {
				ERR(ZS_BAD_INCLUDE_FILENAME);
				p--; {goto st316;}
			}
			memcpy(s->include_filename, s->buffer, ret + 1);
		}

		// Origin conversion from wire to text form in \DDD notation.
		if (s->dname == NULL) { // Use current origin.
			wire_dname_to_str(s->zone_origin,
			                  s->zone_origin_length,
			                  (char *)s->buffer);
		} else { // Use specified origin.
			wire_dname_to_str(s->r_data,
			                  s->r_data_length,
			                  (char *)s->buffer);
		}

		// Let the caller to solve the include.
		if (s->process.automatic) {
			// Create new scanner for included zone file.
			zs_scanner_t *ss = malloc(sizeof(zs_scanner_t));
			if (ss == NULL) {
				ERR(ZS_UNPROCESSED_INCLUDE);
				p--; {goto st316;}
			}

			// Parse included zone file.
			if (zs_init(ss, (char *)s->buffer, s->default_class,
			            s->default_ttl) != 0 ||
			    zs_set_input_file(ss, (char *)(s->include_filename)) != 0 ||
			    zs_set_processing(ss, s->process.record, s->process.error,
			                      s->process.data) != 0 ||
			    zs_parse_all(ss) != 0) {
				// File internal errors are handled by error callback.
				if (ss->error.counter > 0) {
					s->error.counter += ss->error.counter;
					ERR(ZS_UNPROCESSED_INCLUDE);
				// General include file error.
				} else {
					ERR(ss->error.code);
				}
				zs_deinit(ss);
				free(ss);
				p--; {goto st316;}
			}
			zs_deinit(ss);
			free(ss);
		} else {
			s->state = ZS_STATE_INCLUDE;
			p--; cs = 1444; {p++; goto _out;}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	{
		s->line_counter++;
	}
	goto _again;
tr1196:
	cs = 1461;
	{
		// Enough room for the terminal label is guaranteed (_label_exit).
		(s->dname)[s->dname_tmp_length++] = 0;
	}
	{
		s->r_data_length = s->dname_tmp_length;
	}
	{
		s->buffer[0] = 0;
		s->buffer_length = 0;
	}
	{
		// Extend relative file path.
		if (s->include_filename[0] != '/') {
			int ret = snprintf((char *)(s->buffer), sizeof(s->buffer),
			                   "%s/%s", s->path, s->include_filename);
			if (ret <= 0 || ret >= sizeof(s->buffer)) {
				ERR(ZS_BAD_INCLUDE_FILENAME);
				p--; {goto st316;}
			}
			memcpy(s->include_filename, s->buffer, ret + 1);
		}

		// Origin conversion from wire to text form in \DDD notation.
		if (s->dname == NULL) { // Use current origin.
			wire_dname_to_str(s->zone_origin,
			                  s->zone_origin_length,
			                  (char *)s->buffer);
		} else { // Use specified origin.
			wire_dname_to_str(s->r_data,
			                  s->r_data_length,
			                  (char *)s->buffer);
		}

		// Let the caller to solve the include.
		if (s->process.automatic) {
			// Create new scanner for included zone file.
			zs_scanner_t *ss = malloc(sizeof(zs_scanner_t));
			if (ss == NULL) {
				ERR(ZS_UNPROCESSED_INCLUDE);
				p--; {goto st316;}
			}

			// Parse included zone file.
			if (zs_init(ss, (char *)s->buffer, s->default_class,
			            s->default_ttl) != 0 ||
			    zs_set_input_file(ss, (char *)(s->include_filename)) != 0 ||
			    zs_set_processing(ss, s->process.record, s->process.error,
			                      s->process.data) != 0 ||
			    zs_parse_all(ss) != 0) {
				// File internal errors are handled by error callback.
				if (ss->error.counter > 0) {
					s->error.counter += ss->error.counter;
					ERR(ZS_UNPROCESSED_INCLUDE);
				// General include file error.
				} else {
					ERR(ss->error.code);
				}
				zs_deinit(ss);
				free(ss);
				p--; {goto st316;}
			}
			zs_deinit(ss);
			free(ss);
		} else {
			s->state = ZS_STATE_INCLUDE;
			p--; cs = 1444; {p++; goto _out;}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	{
		s->line_counter++;
	}
	goto _again;
tr1202:
	cs = 1461;
	{
		s->buffer[s->buffer_length++] = 0;

		// Execute the comment callback.
		if (s->process.automatic && s->process.comment != NULL) {
			s->process.comment(s);

			// Stop if required from the callback.
			if (s->state == ZS_STATE_STOP) {
				{p++; goto _out;}
			}
		}
	}
	{
		// Extend relative file path.
		if (s->include_filename[0] != '/') {
			int ret = snprintf((char *)(s->buffer), sizeof(s->buffer),
			                   "%s/%s", s->path, s->include_filename);
			if (ret <= 0 || ret >= sizeof(s->buffer)) {
				ERR(ZS_BAD_INCLUDE_FILENAME);
				p--; {goto st316;}
			}
			memcpy(s->include_filename, s->buffer, ret + 1);
		}

		// Origin conversion from wire to text form in \DDD notation.
		if (s->dname == NULL) { // Use current origin.
			wire_dname_to_str(s->zone_origin,
			                  s->zone_origin_length,
			                  (char *)s->buffer);
		} else { // Use specified origin.
			wire_dname_to_str(s->r_data,
			                  s->r_data_length,
			                  (char *)s->buffer);
		}

		// Let the caller to solve the include.
		if (s->process.automatic) {
			// Create new scanner for included zone file.
			zs_scanner_t *ss = malloc(sizeof(zs_scanner_t));
			if (ss == NULL) {
				ERR(ZS_UNPROCESSED_INCLUDE);
				p--; {goto st316;}
			}

			// Parse included zone file.
			if (zs_init(ss, (char *)s->buffer, s->default_class,
			            s->default_ttl) != 0 ||
			    zs_set_input_file(ss, (char *)(s->include_filename)) != 0 ||
			    zs_set_processing(ss, s->process.record, s->process.error,
			                      s->process.data) != 0 ||
			    zs_parse_all(ss) != 0) {
				// File internal errors are handled by error callback.
				if (ss->error.counter > 0) {
					s->error.counter += ss->error.counter;
					ERR(ZS_UNPROCESSED_INCLUDE);
				// General include file error.
				} else {
					ERR(ss->error.code);
				}
				zs_deinit(ss);
				free(ss);
				p--; {goto st316;}
			}
			zs_deinit(ss);
			free(ss);
		} else {
			s->state = ZS_STATE_INCLUDE;
			p--; cs = 1444; {p++; goto _out;}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	{
		s->line_counter++;
	}
	goto _again;
st1461:
	if ( ++p == pe )
		goto _test_eof1461;
case 1461:
	goto st0;
tr1185:
	{
		s->buffer_length = 0;
	}
	goto st368;
tr1201:
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		}
	}
	goto st368;
tr1175:
	{
		size_t len = rdata_tail - s->r_data;
		if (len >= sizeof(s->include_filename)) {
			ERR(ZS_BAD_INCLUDE_FILENAME);
			p--; {goto st316;}
		}

		// Store zero terminated include filename.
		memcpy(s->include_filename, s->r_data, len);
		s->include_filename[len] = '\0';

		// For detection whether origin is not present.
		s->dname = NULL;
	}
	{
		s->buffer[0] = 0;
		s->buffer_length = 0;
	}
	{
		s->buffer_length = 0;
	}
	goto st368;
tr1197:
	{
		// Enough room for the terminal label is guaranteed (_label_exit).
		(s->dname)[s->dname_tmp_length++] = 0;
	}
	{
		s->r_data_length = s->dname_tmp_length;
	}
	{
		s->buffer[0] = 0;
		s->buffer_length = 0;
	}
	{
		s->buffer_length = 0;
	}
	goto st368;
st368:
	if ( ++p == pe )
		goto _test_eof368;
case 368:
	if ( (*p) == 10 )
		goto tr1202;
	goto tr1201;
tr1195:
	{
		s->item_length = 0;
		s->item_length_position = s->dname_tmp_length++;
	}
	goto st369;
tr1209:
	{
		s->dname_tmp_length++;
	}
	goto st369;
tr1183:
	{
		s->dname = s->r_data;
	}
	{
		s->item_length_position = 0;
		s->dname_tmp_length = 0;
	}
	{
		s->item_length = 0;
		s->item_length_position = s->dname_tmp_length++;
	}
	goto st369;
st369:
	if ( ++p == pe )
		goto _test_eof369;
case 369:
	if ( 48 <= (*p) && (*p) <= 57 )
		goto tr1203;
	goto tr1188;
tr1203:
	{
		if (s->item_length < ZS_MAX_LABEL_LENGTH) {
			(s->dname)[s->dname_tmp_length] = 0;
			s->item_length++;
		} else {
			WARN(ZS_LABEL_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		(s->dname)[s->dname_tmp_length] *= 10;
		(s->dname)[s->dname_tmp_length] += digit_to_num[(uint8_t)(*p)];
	}
	goto st370;
st370:
	if ( ++p == pe )
		goto _test_eof370;
case 370:
	if ( 48 <= (*p) && (*p) <= 57 )
		goto tr1205;
	goto tr1204;
tr1205:
	{
		(s->dname)[s->dname_tmp_length] *= 10;
		(s->dname)[s->dname_tmp_length] += digit_to_num[(uint8_t)(*p)];
	}
	goto st371;
st371:
	if ( ++p == pe )
		goto _test_eof371;
case 371:
	if ( 48 <= (*p) && (*p) <= 57 )
		goto tr1206;
	goto tr1204;
tr1206:
	{
		(s->dname)[s->dname_tmp_length] *= 10;
		(s->dname)[s->dname_tmp_length] += digit_to_num[(uint8_t)(*p)];
	}
	goto st372;
st372:
	if ( ++p == pe )
		goto _test_eof372;
case 372:
	switch( (*p) ) {
		case 42: goto tr1207;
		case 46: goto tr1208;
		case 92: goto tr1209;
		case 95: goto tr1207;
	}
	if ( (*p) < 65 ) {
		if ( 45 <= (*p) && (*p) <= 57 )
			goto tr1207;
	} else if ( (*p) > 90 ) {
		if ( 97 <= (*p) && (*p) <= 122 )
			goto tr1207;
	} else
		goto tr1207;
	goto tr1204;
tr1182:
	{
		s->dname = s->r_data;
	}
	{
		s->item_length_position = 0;
		s->dname_tmp_length = 0;
	}
	goto st373;
st373:
	if ( ++p == pe )
		goto _test_eof373;
case 373:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr1191;
		case 32: goto tr1191;
		case 40: goto tr1192;
		case 41: goto tr1193;
		case 1802: goto tr1196;
		case 1851: goto tr1197;
		case 2058: goto tr1196;
		case 2107: goto tr1197;
	}
	goto tr1177;
tr1186:
	{
		s->buffer_length = 0;
	}
	goto st374;
tr1210:
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		}
	}
	goto st374;
tr1176:
	{
		size_t len = rdata_tail - s->r_data;
		if (len >= sizeof(s->include_filename)) {
			ERR(ZS_BAD_INCLUDE_FILENAME);
			p--; {goto st316;}
		}

		// Store zero terminated include filename.
		memcpy(s->include_filename, s->r_data, len);
		s->include_filename[len] = '\0';

		// For detection whether origin is not present.
		s->dname = NULL;
	}
	{
		s->buffer_length = 0;
	}
	{
		s->buffer[0] = 0;
		s->buffer_length = 0;
	}
	goto st374;
st374:
	if ( ++p == pe )
		goto _test_eof374;
case 374:
	_widec = (*p);
	if ( (*p) < 10 ) {
		if ( (*p) <= 9 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) > 10 ) {
		if ( 11 <= (*p) )
 {			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 1802: goto tr1202;
		case 2058: goto tr1211;
	}
	if ( _widec > 1919 ) {
		if ( 1920 <= _widec && _widec <= 2175 )
			goto tr1210;
	} else if ( _widec >= 1664 )
		goto tr1201;
	goto tr91;
tr1211:
	cs = 1462;
	{
		s->buffer[s->buffer_length++] = 0;

		// Execute the comment callback.
		if (s->process.automatic && s->process.comment != NULL) {
			s->process.comment(s);

			// Stop if required from the callback.
			if (s->state == ZS_STATE_STOP) {
				{p++; goto _out;}
			}
		}
	}
	{
		s->line_counter++;
	}
	{
		// Extend relative file path.
		if (s->include_filename[0] != '/') {
			int ret = snprintf((char *)(s->buffer), sizeof(s->buffer),
			                   "%s/%s", s->path, s->include_filename);
			if (ret <= 0 || ret >= sizeof(s->buffer)) {
				ERR(ZS_BAD_INCLUDE_FILENAME);
				p--; {goto st316;}
			}
			memcpy(s->include_filename, s->buffer, ret + 1);
		}

		// Origin conversion from wire to text form in \DDD notation.
		if (s->dname == NULL) { // Use current origin.
			wire_dname_to_str(s->zone_origin,
			                  s->zone_origin_length,
			                  (char *)s->buffer);
		} else { // Use specified origin.
			wire_dname_to_str(s->r_data,
			                  s->r_data_length,
			                  (char *)s->buffer);
		}

		// Let the caller to solve the include.
		if (s->process.automatic) {
			// Create new scanner for included zone file.
			zs_scanner_t *ss = malloc(sizeof(zs_scanner_t));
			if (ss == NULL) {
				ERR(ZS_UNPROCESSED_INCLUDE);
				p--; {goto st316;}
			}

			// Parse included zone file.
			if (zs_init(ss, (char *)s->buffer, s->default_class,
			            s->default_ttl) != 0 ||
			    zs_set_input_file(ss, (char *)(s->include_filename)) != 0 ||
			    zs_set_processing(ss, s->process.record, s->process.error,
			                      s->process.data) != 0 ||
			    zs_parse_all(ss) != 0) {
				// File internal errors are handled by error callback.
				if (ss->error.counter > 0) {
					s->error.counter += ss->error.counter;
					ERR(ZS_UNPROCESSED_INCLUDE);
				// General include file error.
				} else {
					ERR(ss->error.code);
				}
				zs_deinit(ss);
				free(ss);
				p--; {goto st316;}
			}
			zs_deinit(ss);
			free(ss);
		} else {
			s->state = ZS_STATE_INCLUDE;
			p--; cs = 1444; {p++; goto _out;}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto _again;
st1462:
	if ( ++p == pe )
		goto _test_eof1462;
case 1462:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto st375;
		case 32: goto st375;
		case 40: goto tr1213;
		case 41: goto tr1214;
		case 42: goto tr1181;
		case 46: goto tr1182;
		case 92: goto tr1183;
		case 95: goto tr1181;
		case 2058: goto tr1215;
		case 2107: goto tr1216;
	}
	if ( _widec < 65 ) {
		if ( 45 <= _widec && _widec <= 57 )
			goto tr1181;
	} else if ( _widec > 90 ) {
		if ( 97 <= _widec && _widec <= 122 )
			goto tr1181;
	} else
		goto tr1181;
	goto tr1187;
tr1213:
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st375;
tr1214:
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st375;
tr1215:
	{
		s->line_counter++;
	}
	goto st375;
tr1218:
	{
		s->buffer[s->buffer_length++] = 0;

		// Execute the comment callback.
		if (s->process.automatic && s->process.comment != NULL) {
			s->process.comment(s);

			// Stop if required from the callback.
			if (s->state == ZS_STATE_STOP) {
				{p++; cs = 375; goto _out;}
			}
		}
	}
	{
		s->line_counter++;
	}
	goto st375;
st375:
	if ( ++p == pe )
		goto _test_eof375;
case 375:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto st375;
		case 32: goto st375;
		case 40: goto tr1213;
		case 41: goto tr1214;
		case 42: goto tr1181;
		case 46: goto tr1182;
		case 92: goto tr1183;
		case 95: goto tr1181;
		case 2058: goto tr1215;
		case 2107: goto tr1216;
	}
	if ( _widec < 65 ) {
		if ( 45 <= _widec && _widec <= 57 )
			goto tr1181;
	} else if ( _widec > 90 ) {
		if ( 97 <= _widec && _widec <= 122 )
			goto tr1181;
	} else
		goto tr1181;
	goto tr1187;
tr1216:
	{
		s->buffer_length = 0;
	}
	goto st376;
tr1217:
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		}
	}
	goto st376;
st376:
	if ( ++p == pe )
		goto _test_eof376;
case 376:
	_widec = (*p);
	if ( (*p) < 10 ) {
		if ( (*p) <= 9 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) > 10 ) {
		if ( 11 <= (*p) )
 {			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	if ( _widec == 2058 )
		goto tr1218;
	if ( 1920 <= _widec && _widec <= 2175 )
		goto tr1217;
	goto st0;
tr1167:
	{
		s->buffer_length = 0;
	}
	goto st377;
tr1219:
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		}
	}
	goto st377;
st377:
	if ( ++p == pe )
		goto _test_eof377;
case 377:
	_widec = (*p);
	if ( (*p) < 10 ) {
		if ( (*p) <= 9 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) > 10 ) {
		if ( 11 <= (*p) )
 {			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	if ( _widec == 2058 )
		goto tr1220;
	if ( 1920 <= _widec && _widec <= 2175 )
		goto tr1219;
	goto st0;
st378:
	if ( ++p == pe )
		goto _test_eof378;
case 378:
	if ( (*p) == 43 )
		goto tr1222;
	if ( (*p) < 65 ) {
		if ( 47 <= (*p) && (*p) <= 57 )
			goto tr1222;
	} else if ( (*p) > 90 ) {
		if ( 97 <= (*p) && (*p) <= 122 )
			goto tr1222;
	} else
		goto tr1222;
	goto tr1221;
tr1222:
	{
		if (rdata_tail <= rdata_stop) {
			*rdata_tail = first_base64_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st379;
st379:
	if ( ++p == pe )
		goto _test_eof379;
case 379:
	if ( (*p) == 43 )
		goto tr1223;
	if ( (*p) < 65 ) {
		if ( 47 <= (*p) && (*p) <= 57 )
			goto tr1223;
	} else if ( (*p) > 90 ) {
		if ( 97 <= (*p) && (*p) <= 122 )
			goto tr1223;
	} else
		goto tr1223;
	goto tr1221;
tr1223:
	{
		*(rdata_tail++) += second_left_base64_to_num[(uint8_t)(*p)];

		if (rdata_tail <= rdata_stop) {
			*rdata_tail = second_right_base64_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st380;
st380:
	if ( ++p == pe )
		goto _test_eof380;
case 380:
	switch( (*p) ) {
		case 43: goto tr1224;
		case 61: goto st384;
	}
	if ( (*p) < 65 ) {
		if ( 47 <= (*p) && (*p) <= 57 )
			goto tr1224;
	} else if ( (*p) > 90 ) {
		if ( 97 <= (*p) && (*p) <= 122 )
			goto tr1224;
	} else
		goto tr1224;
	goto tr1221;
tr1224:
	{
		*(rdata_tail++) += third_left_base64_to_num[(uint8_t)(*p)];

		if (rdata_tail <= rdata_stop) {
			*rdata_tail = third_right_base64_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st381;
st381:
	if ( ++p == pe )
		goto _test_eof381;
case 381:
	switch( (*p) ) {
		case 43: goto tr1226;
		case 61: goto st382;
	}
	if ( (*p) < 65 ) {
		if ( 47 <= (*p) && (*p) <= 57 )
			goto tr1226;
	} else if ( (*p) > 90 ) {
		if ( 97 <= (*p) && (*p) <= 122 )
			goto tr1226;
	} else
		goto tr1226;
	goto tr1221;
tr1228:
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st382;
tr1229:
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st382;
tr1230:
	{
		s->line_counter++;
	}
	goto st382;
tr1236:
	{
		s->buffer[s->buffer_length++] = 0;

		// Execute the comment callback.
		if (s->process.automatic && s->process.comment != NULL) {
			s->process.comment(s);

			// Stop if required from the callback.
			if (s->state == ZS_STATE_STOP) {
				{p++; cs = 382; goto _out;}
			}
		}
	}
	{
		s->line_counter++;
	}
	goto st382;
tr1226:
	{
		*(rdata_tail++) += fourth_base64_to_num[(uint8_t)(*p)];
	}
	goto st382;
st382:
	if ( ++p == pe )
		goto _test_eof382;
case 382:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(2688 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 !s->multiline  ) _widec += 512;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(2688 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		if (
 !s->multiline  ) _widec += 512;
	}
	switch( _widec ) {
		case 9: goto st382;
		case 32: goto st382;
		case 40: goto tr1228;
		case 41: goto tr1229;
		case 43: goto tr1222;
		case 3082: goto tr1230;
		case 3131: goto tr1231;
		case 3338: goto tr1232;
		case 3387: goto tr1232;
		case 3594: goto tr1233;
		case 3643: goto tr1234;
	}
	if ( _widec < 65 ) {
		if ( 47 <= _widec && _widec <= 57 )
			goto tr1222;
	} else if ( _widec > 90 ) {
		if ( 97 <= _widec && _widec <= 122 )
			goto tr1222;
	} else
		goto tr1222;
	goto tr1221;
tr1231:
	{
		s->buffer_length = 0;
	}
	goto st383;
tr1235:
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		}
	}
	goto st383;
st383:
	if ( ++p == pe )
		goto _test_eof383;
case 383:
	_widec = (*p);
	if ( (*p) < 10 ) {
		if ( (*p) <= 9 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) > 10 ) {
		if ( 11 <= (*p) )
 {			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	if ( _widec == 2058 )
		goto tr1236;
	if ( 1920 <= _widec && _widec <= 2175 )
		goto tr1235;
	goto tr1221;
tr1232:
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1463;
st1463:
	if ( ++p == pe )
		goto _test_eof1463;
case 1463:
	goto st0;
tr1233:
	{
		s->line_counter++;
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1464;
st1464:
	if ( ++p == pe )
		goto _test_eof1464;
case 1464:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(2688 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 !s->multiline  ) _widec += 512;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(2688 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		if (
 !s->multiline  ) _widec += 512;
	}
	switch( _widec ) {
		case 9: goto st382;
		case 32: goto st382;
		case 40: goto tr1228;
		case 41: goto tr1229;
		case 43: goto tr1222;
		case 3082: goto tr1230;
		case 3131: goto tr1231;
		case 3338: goto tr1232;
		case 3387: goto tr1232;
		case 3594: goto tr1233;
		case 3643: goto tr1234;
	}
	if ( _widec < 65 ) {
		if ( 47 <= _widec && _widec <= 57 )
			goto tr1222;
	} else if ( _widec > 90 ) {
		if ( 97 <= _widec && _widec <= 122 )
			goto tr1222;
	} else
		goto tr1222;
	goto tr1221;
tr1234:
	{
		s->buffer_length = 0;
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1465;
st1465:
	if ( ++p == pe )
		goto _test_eof1465;
case 1465:
	_widec = (*p);
	if ( (*p) < 10 ) {
		if ( (*p) <= 9 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) > 10 ) {
		if ( 11 <= (*p) )
 {			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	if ( _widec == 2058 )
		goto tr1236;
	if ( 1920 <= _widec && _widec <= 2175 )
		goto tr1235;
	goto tr1221;
st384:
	if ( ++p == pe )
		goto _test_eof384;
case 384:
	if ( (*p) == 61 )
		goto st382;
	goto tr1221;
st385:
	if ( ++p == pe )
		goto _test_eof385;
case 385:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(2688 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 !s->multiline  ) _widec += 512;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(2688 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		if (
 !s->multiline  ) _widec += 512;
	}
	switch( _widec ) {
		case 9: goto tr1238;
		case 32: goto tr1238;
		case 40: goto tr1239;
		case 41: goto tr1240;
		case 3082: goto tr1241;
		case 3131: goto tr1242;
		case 3338: goto tr1243;
		case 3387: goto tr1243;
		case 3594: goto tr1244;
		case 3643: goto tr1245;
	}
	goto tr1237;
tr1247:
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st386;
tr1248:
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st386;
tr1267:
	{
		s->line_counter++;
	}
	goto st386;
tr1294:
	{
		s->buffer[s->buffer_length++] = 0;

		// Execute the comment callback.
		if (s->process.automatic && s->process.comment != NULL) {
			s->process.comment(s);

			// Stop if required from the callback.
			if (s->state == ZS_STATE_STOP) {
				{p++; cs = 386; goto _out;}
			}
		}
	}
	{
		s->line_counter++;
	}
	goto st386;
tr1238:
	{
		memset(s->windows, 0, sizeof(s->windows));
		s->last_window = -1;
	}
	goto st386;
tr1239:
	{
		memset(s->windows, 0, sizeof(s->windows));
		s->last_window = -1;
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st386;
tr1240:
	{
		memset(s->windows, 0, sizeof(s->windows));
		s->last_window = -1;
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st386;
tr1241:
	{
		memset(s->windows, 0, sizeof(s->windows));
		s->last_window = -1;
	}
	{
		s->line_counter++;
	}
	goto st386;
tr1272:
	{ window_add_bit(KNOT_RRTYPE_A, s); }
	goto st386;
tr1273:
	{ window_add_bit(KNOT_RRTYPE_A, s); }
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st386;
tr1274:
	{ window_add_bit(KNOT_RRTYPE_A, s); }
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st386;
tr1278:
	{ window_add_bit(KNOT_RRTYPE_A, s); }
	{
		s->line_counter++;
	}
	goto st386;
tr1285:
	{ window_add_bit(KNOT_RRTYPE_AAAA, s); }
	goto st386;
tr1286:
	{ window_add_bit(KNOT_RRTYPE_AAAA, s); }
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st386;
tr1287:
	{ window_add_bit(KNOT_RRTYPE_AAAA, s); }
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st386;
tr1288:
	{ window_add_bit(KNOT_RRTYPE_AAAA, s); }
	{
		s->line_counter++;
	}
	goto st386;
tr1301:
	{ window_add_bit(KNOT_RRTYPE_CAA, s); }
	goto st386;
tr1302:
	{ window_add_bit(KNOT_RRTYPE_CAA, s); }
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st386;
tr1303:
	{ window_add_bit(KNOT_RRTYPE_CAA, s); }
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st386;
tr1304:
	{ window_add_bit(KNOT_RRTYPE_CAA, s); }
	{
		s->line_counter++;
	}
	goto st386;
tr1315:
	{ window_add_bit(KNOT_RRTYPE_CDNSKEY, s); }
	goto st386;
tr1316:
	{ window_add_bit(KNOT_RRTYPE_CDNSKEY, s); }
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st386;
tr1317:
	{ window_add_bit(KNOT_RRTYPE_CDNSKEY, s); }
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st386;
tr1318:
	{ window_add_bit(KNOT_RRTYPE_CDNSKEY, s); }
	{
		s->line_counter++;
	}
	goto st386;
tr1323:
	{ window_add_bit(KNOT_RRTYPE_CDS, s); }
	goto st386;
tr1324:
	{ window_add_bit(KNOT_RRTYPE_CDS, s); }
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st386;
tr1325:
	{ window_add_bit(KNOT_RRTYPE_CDS, s); }
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st386;
tr1326:
	{ window_add_bit(KNOT_RRTYPE_CDS, s); }
	{
		s->line_counter++;
	}
	goto st386;
tr1333:
	{ window_add_bit(KNOT_RRTYPE_CERT, s); }
	goto st386;
tr1334:
	{ window_add_bit(KNOT_RRTYPE_CERT, s); }
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st386;
tr1335:
	{ window_add_bit(KNOT_RRTYPE_CERT, s); }
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st386;
tr1336:
	{ window_add_bit(KNOT_RRTYPE_CERT, s); }
	{
		s->line_counter++;
	}
	goto st386;
tr1344:
	{ window_add_bit(KNOT_RRTYPE_CNAME, s); }
	goto st386;
tr1345:
	{ window_add_bit(KNOT_RRTYPE_CNAME, s); }
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st386;
tr1346:
	{ window_add_bit(KNOT_RRTYPE_CNAME, s); }
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st386;
tr1347:
	{ window_add_bit(KNOT_RRTYPE_CNAME, s); }
	{
		s->line_counter++;
	}
	goto st386;
tr1355:
	{ window_add_bit(KNOT_RRTYPE_CSYNC, s); }
	goto st386;
tr1356:
	{ window_add_bit(KNOT_RRTYPE_CSYNC, s); }
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st386;
tr1357:
	{ window_add_bit(KNOT_RRTYPE_CSYNC, s); }
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st386;
tr1358:
	{ window_add_bit(KNOT_RRTYPE_CSYNC, s); }
	{
		s->line_counter++;
	}
	goto st386;
tr1369:
	{ window_add_bit(KNOT_RRTYPE_DHCID, s); }
	goto st386;
tr1370:
	{ window_add_bit(KNOT_RRTYPE_DHCID, s); }
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st386;
tr1371:
	{ window_add_bit(KNOT_RRTYPE_DHCID, s); }
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st386;
tr1372:
	{ window_add_bit(KNOT_RRTYPE_DHCID, s); }
	{
		s->line_counter++;
	}
	goto st386;
tr1381:
	{ window_add_bit(KNOT_RRTYPE_DNAME, s); }
	goto st386;
tr1382:
	{ window_add_bit(KNOT_RRTYPE_DNAME, s); }
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st386;
tr1383:
	{ window_add_bit(KNOT_RRTYPE_DNAME, s); }
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st386;
tr1384:
	{ window_add_bit(KNOT_RRTYPE_DNAME, s); }
	{
		s->line_counter++;
	}
	goto st386;
tr1392:
	{ window_add_bit(KNOT_RRTYPE_DNSKEY, s); }
	goto st386;
tr1393:
	{ window_add_bit(KNOT_RRTYPE_DNSKEY, s); }
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st386;
tr1394:
	{ window_add_bit(KNOT_RRTYPE_DNSKEY, s); }
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st386;
tr1395:
	{ window_add_bit(KNOT_RRTYPE_DNSKEY, s); }
	{
		s->line_counter++;
	}
	goto st386;
tr1400:
	{ window_add_bit(KNOT_RRTYPE_DS, s); }
	goto st386;
tr1401:
	{ window_add_bit(KNOT_RRTYPE_DS, s); }
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st386;
tr1402:
	{ window_add_bit(KNOT_RRTYPE_DS, s); }
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st386;
tr1403:
	{ window_add_bit(KNOT_RRTYPE_DS, s); }
	{
		s->line_counter++;
	}
	goto st386;
tr1413:
	{ window_add_bit(KNOT_RRTYPE_EUI48, s); }
	goto st386;
tr1414:
	{ window_add_bit(KNOT_RRTYPE_EUI48, s); }
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st386;
tr1415:
	{ window_add_bit(KNOT_RRTYPE_EUI48, s); }
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st386;
tr1416:
	{ window_add_bit(KNOT_RRTYPE_EUI48, s); }
	{
		s->line_counter++;
	}
	goto st386;
tr1422:
	{ window_add_bit(KNOT_RRTYPE_EUI64, s); }
	goto st386;
tr1423:
	{ window_add_bit(KNOT_RRTYPE_EUI64, s); }
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st386;
tr1424:
	{ window_add_bit(KNOT_RRTYPE_EUI64, s); }
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st386;
tr1425:
	{ window_add_bit(KNOT_RRTYPE_EUI64, s); }
	{
		s->line_counter++;
	}
	goto st386;
tr1435:
	{ window_add_bit(KNOT_RRTYPE_HINFO, s); }
	goto st386;
tr1436:
	{ window_add_bit(KNOT_RRTYPE_HINFO, s); }
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st386;
tr1437:
	{ window_add_bit(KNOT_RRTYPE_HINFO, s); }
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st386;
tr1438:
	{ window_add_bit(KNOT_RRTYPE_HINFO, s); }
	{
		s->line_counter++;
	}
	goto st386;
tr1446:
	{ window_add_bit(KNOT_RRTYPE_HTTPS, s); }
	goto st386;
tr1447:
	{ window_add_bit(KNOT_RRTYPE_HTTPS, s); }
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st386;
tr1448:
	{ window_add_bit(KNOT_RRTYPE_HTTPS, s); }
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st386;
tr1449:
	{ window_add_bit(KNOT_RRTYPE_HTTPS, s); }
	{
		s->line_counter++;
	}
	goto st386;
tr1461:
	{ window_add_bit(KNOT_RRTYPE_IPSECKEY, s); }
	goto st386;
tr1462:
	{ window_add_bit(KNOT_RRTYPE_IPSECKEY, s); }
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st386;
tr1463:
	{ window_add_bit(KNOT_RRTYPE_IPSECKEY, s); }
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st386;
tr1464:
	{ window_add_bit(KNOT_RRTYPE_IPSECKEY, s); }
	{
		s->line_counter++;
	}
	goto st386;
tr1472:
	{ window_add_bit(KNOT_RRTYPE_KEY, s); }
	goto st386;
tr1473:
	{ window_add_bit(KNOT_RRTYPE_KEY, s); }
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st386;
tr1474:
	{ window_add_bit(KNOT_RRTYPE_KEY, s); }
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st386;
tr1475:
	{ window_add_bit(KNOT_RRTYPE_KEY, s); }
	{
		s->line_counter++;
	}
	goto st386;
tr1480:
	{ window_add_bit(KNOT_RRTYPE_KX, s); }
	goto st386;
tr1481:
	{ window_add_bit(KNOT_RRTYPE_KX, s); }
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st386;
tr1482:
	{ window_add_bit(KNOT_RRTYPE_KX, s); }
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st386;
tr1483:
	{ window_add_bit(KNOT_RRTYPE_KX, s); }
	{
		s->line_counter++;
	}
	goto st386;
tr1493:
	{ window_add_bit(KNOT_RRTYPE_L32, s); }
	goto st386;
tr1494:
	{ window_add_bit(KNOT_RRTYPE_L32, s); }
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st386;
tr1495:
	{ window_add_bit(KNOT_RRTYPE_L32, s); }
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st386;
tr1496:
	{ window_add_bit(KNOT_RRTYPE_L32, s); }
	{
		s->line_counter++;
	}
	goto st386;
tr1502:
	{ window_add_bit(KNOT_RRTYPE_L64, s); }
	goto st386;
tr1503:
	{ window_add_bit(KNOT_RRTYPE_L64, s); }
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st386;
tr1504:
	{ window_add_bit(KNOT_RRTYPE_L64, s); }
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st386;
tr1505:
	{ window_add_bit(KNOT_RRTYPE_L64, s); }
	{
		s->line_counter++;
	}
	goto st386;
tr1511:
	{ window_add_bit(KNOT_RRTYPE_LOC, s); }
	goto st386;
tr1512:
	{ window_add_bit(KNOT_RRTYPE_LOC, s); }
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st386;
tr1513:
	{ window_add_bit(KNOT_RRTYPE_LOC, s); }
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st386;
tr1514:
	{ window_add_bit(KNOT_RRTYPE_LOC, s); }
	{
		s->line_counter++;
	}
	goto st386;
tr1519:
	{ window_add_bit(KNOT_RRTYPE_LP, s); }
	goto st386;
tr1520:
	{ window_add_bit(KNOT_RRTYPE_LP, s); }
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st386;
tr1521:
	{ window_add_bit(KNOT_RRTYPE_LP, s); }
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st386;
tr1522:
	{ window_add_bit(KNOT_RRTYPE_LP, s); }
	{
		s->line_counter++;
	}
	goto st386;
tr1532:
	{ window_add_bit(KNOT_RRTYPE_MINFO, s); }
	goto st386;
tr1533:
	{ window_add_bit(KNOT_RRTYPE_MINFO, s); }
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st386;
tr1534:
	{ window_add_bit(KNOT_RRTYPE_MINFO, s); }
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st386;
tr1535:
	{ window_add_bit(KNOT_RRTYPE_MINFO, s); }
	{
		s->line_counter++;
	}
	goto st386;
tr1540:
	{ window_add_bit(KNOT_RRTYPE_MX, s); }
	goto st386;
tr1541:
	{ window_add_bit(KNOT_RRTYPE_MX, s); }
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st386;
tr1542:
	{ window_add_bit(KNOT_RRTYPE_MX, s); }
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st386;
tr1543:
	{ window_add_bit(KNOT_RRTYPE_MX, s); }
	{
		s->line_counter++;
	}
	goto st386;
tr1554:
	{ window_add_bit(KNOT_RRTYPE_NAPTR, s); }
	goto st386;
tr1555:
	{ window_add_bit(KNOT_RRTYPE_NAPTR, s); }
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st386;
tr1556:
	{ window_add_bit(KNOT_RRTYPE_NAPTR, s); }
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st386;
tr1557:
	{ window_add_bit(KNOT_RRTYPE_NAPTR, s); }
	{
		s->line_counter++;
	}
	goto st386;
tr1563:
	{ window_add_bit(KNOT_RRTYPE_NID, s); }
	goto st386;
tr1564:
	{ window_add_bit(KNOT_RRTYPE_NID, s); }
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st386;
tr1565:
	{ window_add_bit(KNOT_RRTYPE_NID, s); }
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st386;
tr1566:
	{ window_add_bit(KNOT_RRTYPE_NID, s); }
	{
		s->line_counter++;
	}
	goto st386;
tr1571:
	{ window_add_bit(KNOT_RRTYPE_NS, s); }
	goto st386;
tr1572:
	{ window_add_bit(KNOT_RRTYPE_NS, s); }
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st386;
tr1573:
	{ window_add_bit(KNOT_RRTYPE_NS, s); }
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st386;
tr1575:
	{ window_add_bit(KNOT_RRTYPE_NS, s); }
	{
		s->line_counter++;
	}
	goto st386;
tr1581:
	{ window_add_bit(KNOT_RRTYPE_NSEC, s); }
	goto st386;
tr1582:
	{ window_add_bit(KNOT_RRTYPE_NSEC, s); }
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st386;
tr1583:
	{ window_add_bit(KNOT_RRTYPE_NSEC, s); }
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st386;
tr1585:
	{ window_add_bit(KNOT_RRTYPE_NSEC, s); }
	{
		s->line_counter++;
	}
	goto st386;
tr1590:
	{ window_add_bit(KNOT_RRTYPE_NSEC3, s); }
	goto st386;
tr1591:
	{ window_add_bit(KNOT_RRTYPE_NSEC3, s); }
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st386;
tr1592:
	{ window_add_bit(KNOT_RRTYPE_NSEC3, s); }
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st386;
tr1594:
	{ window_add_bit(KNOT_RRTYPE_NSEC3, s); }
	{
		s->line_counter++;
	}
	goto st386;
tr1603:
	{ window_add_bit(KNOT_RRTYPE_NSEC3PARAM, s); }
	goto st386;
tr1604:
	{ window_add_bit(KNOT_RRTYPE_NSEC3PARAM, s); }
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st386;
tr1605:
	{ window_add_bit(KNOT_RRTYPE_NSEC3PARAM, s); }
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st386;
tr1606:
	{ window_add_bit(KNOT_RRTYPE_NSEC3PARAM, s); }
	{
		s->line_counter++;
	}
	goto st386;
tr1620:
	{ window_add_bit(KNOT_RRTYPE_OPENPGPKEY, s); }
	goto st386;
tr1621:
	{ window_add_bit(KNOT_RRTYPE_OPENPGPKEY, s); }
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st386;
tr1622:
	{ window_add_bit(KNOT_RRTYPE_OPENPGPKEY, s); }
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st386;
tr1623:
	{ window_add_bit(KNOT_RRTYPE_OPENPGPKEY, s); }
	{
		s->line_counter++;
	}
	goto st386;
tr1630:
	{ window_add_bit(KNOT_RRTYPE_PTR, s); }
	goto st386;
tr1631:
	{ window_add_bit(KNOT_RRTYPE_PTR, s); }
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st386;
tr1632:
	{ window_add_bit(KNOT_RRTYPE_PTR, s); }
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st386;
tr1633:
	{ window_add_bit(KNOT_RRTYPE_PTR, s); }
	{
		s->line_counter++;
	}
	goto st386;
tr1641:
	{ window_add_bit(KNOT_RRTYPE_RP, s); }
	goto st386;
tr1642:
	{ window_add_bit(KNOT_RRTYPE_RP, s); }
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st386;
tr1643:
	{ window_add_bit(KNOT_RRTYPE_RP, s); }
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st386;
tr1644:
	{ window_add_bit(KNOT_RRTYPE_RP, s); }
	{
		s->line_counter++;
	}
	goto st386;
tr1652:
	{ window_add_bit(KNOT_RRTYPE_RRSIG, s); }
	goto st386;
tr1653:
	{ window_add_bit(KNOT_RRTYPE_RRSIG, s); }
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st386;
tr1654:
	{ window_add_bit(KNOT_RRTYPE_RRSIG, s); }
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st386;
tr1655:
	{ window_add_bit(KNOT_RRTYPE_RRSIG, s); }
	{
		s->line_counter++;
	}
	goto st386;
tr1660:
	{ window_add_bit(KNOT_RRTYPE_RT, s); }
	goto st386;
tr1661:
	{ window_add_bit(KNOT_RRTYPE_RT, s); }
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st386;
tr1662:
	{ window_add_bit(KNOT_RRTYPE_RT, s); }
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st386;
tr1663:
	{ window_add_bit(KNOT_RRTYPE_RT, s); }
	{
		s->line_counter++;
	}
	goto st386;
tr1678:
	{ window_add_bit(KNOT_RRTYPE_SMIMEA, s); }
	goto st386;
tr1679:
	{ window_add_bit(KNOT_RRTYPE_SMIMEA, s); }
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st386;
tr1680:
	{ window_add_bit(KNOT_RRTYPE_SMIMEA, s); }
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st386;
tr1681:
	{ window_add_bit(KNOT_RRTYPE_SMIMEA, s); }
	{
		s->line_counter++;
	}
	goto st386;
tr1687:
	{ window_add_bit(KNOT_RRTYPE_SOA, s); }
	goto st386;
tr1688:
	{ window_add_bit(KNOT_RRTYPE_SOA, s); }
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st386;
tr1689:
	{ window_add_bit(KNOT_RRTYPE_SOA, s); }
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st386;
tr1690:
	{ window_add_bit(KNOT_RRTYPE_SOA, s); }
	{
		s->line_counter++;
	}
	goto st386;
tr1696:
	{ window_add_bit(KNOT_RRTYPE_SPF, s); }
	goto st386;
tr1697:
	{ window_add_bit(KNOT_RRTYPE_SPF, s); }
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st386;
tr1698:
	{ window_add_bit(KNOT_RRTYPE_SPF, s); }
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st386;
tr1699:
	{ window_add_bit(KNOT_RRTYPE_SPF, s); }
	{
		s->line_counter++;
	}
	goto st386;
tr1705:
	{ window_add_bit(KNOT_RRTYPE_SRV, s); }
	goto st386;
tr1706:
	{ window_add_bit(KNOT_RRTYPE_SRV, s); }
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st386;
tr1707:
	{ window_add_bit(KNOT_RRTYPE_SRV, s); }
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st386;
tr1708:
	{ window_add_bit(KNOT_RRTYPE_SRV, s); }
	{
		s->line_counter++;
	}
	goto st386;
tr1716:
	{ window_add_bit(KNOT_RRTYPE_SSHFP, s); }
	goto st386;
tr1717:
	{ window_add_bit(KNOT_RRTYPE_SSHFP, s); }
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st386;
tr1718:
	{ window_add_bit(KNOT_RRTYPE_SSHFP, s); }
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st386;
tr1719:
	{ window_add_bit(KNOT_RRTYPE_SSHFP, s); }
	{
		s->line_counter++;
	}
	goto st386;
tr1726:
	{ window_add_bit(KNOT_RRTYPE_SVCB, s); }
	goto st386;
tr1727:
	{ window_add_bit(KNOT_RRTYPE_SVCB, s); }
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st386;
tr1728:
	{ window_add_bit(KNOT_RRTYPE_SVCB, s); }
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st386;
tr1729:
	{ window_add_bit(KNOT_RRTYPE_SVCB, s); }
	{
		s->line_counter++;
	}
	goto st386;
tr1739:
	{ window_add_bit(KNOT_RRTYPE_TLSA, s); }
	goto st386;
tr1740:
	{ window_add_bit(KNOT_RRTYPE_TLSA, s); }
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st386;
tr1741:
	{ window_add_bit(KNOT_RRTYPE_TLSA, s); }
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st386;
tr1742:
	{ window_add_bit(KNOT_RRTYPE_TLSA, s); }
	{
		s->line_counter++;
	}
	goto st386;
tr1748:
	{ window_add_bit(KNOT_RRTYPE_TXT, s); }
	goto st386;
tr1749:
	{ window_add_bit(KNOT_RRTYPE_TXT, s); }
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st386;
tr1750:
	{ window_add_bit(KNOT_RRTYPE_TXT, s); }
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st386;
tr1751:
	{ window_add_bit(KNOT_RRTYPE_TXT, s); }
	{
		s->line_counter++;
	}
	goto st386;
tr1759:
	{
		if (s->number64 <= UINT16_MAX) {
			window_add_bit(s->number64, s);
		} else {
			WARN(ZS_NUMBER16_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st386;
tr1760:
	{
		if (s->number64 <= UINT16_MAX) {
			window_add_bit(s->number64, s);
		} else {
			WARN(ZS_NUMBER16_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st386;
tr1761:
	{
		if (s->number64 <= UINT16_MAX) {
			window_add_bit(s->number64, s);
		} else {
			WARN(ZS_NUMBER16_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st386;
tr1763:
	{
		if (s->number64 <= UINT16_MAX) {
			window_add_bit(s->number64, s);
		} else {
			WARN(ZS_NUMBER16_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		s->line_counter++;
	}
	goto st386;
tr1770:
	{ window_add_bit(KNOT_RRTYPE_URI, s); }
	goto st386;
tr1771:
	{ window_add_bit(KNOT_RRTYPE_URI, s); }
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st386;
tr1772:
	{ window_add_bit(KNOT_RRTYPE_URI, s); }
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st386;
tr1773:
	{ window_add_bit(KNOT_RRTYPE_URI, s); }
	{
		s->line_counter++;
	}
	goto st386;
tr1783:
	{ window_add_bit(KNOT_RRTYPE_WALLET, s); }
	goto st386;
tr1784:
	{ window_add_bit(KNOT_RRTYPE_WALLET, s); }
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st386;
tr1785:
	{ window_add_bit(KNOT_RRTYPE_WALLET, s); }
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st386;
tr1786:
	{ window_add_bit(KNOT_RRTYPE_WALLET, s); }
	{
		s->line_counter++;
	}
	goto st386;
tr1796:
	{ window_add_bit(KNOT_RRTYPE_ZONEMD, s); }
	goto st386;
tr1797:
	{ window_add_bit(KNOT_RRTYPE_ZONEMD, s); }
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st386;
tr1798:
	{ window_add_bit(KNOT_RRTYPE_ZONEMD, s); }
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st386;
tr1799:
	{ window_add_bit(KNOT_RRTYPE_ZONEMD, s); }
	{
		s->line_counter++;
	}
	goto st386;
tr1807:
	{ window_add_bit(KNOT_RRTYPE_AFSDB, s); }
	goto st386;
tr1808:
	{ window_add_bit(KNOT_RRTYPE_AFSDB, s); }
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st386;
tr1809:
	{ window_add_bit(KNOT_RRTYPE_AFSDB, s); }
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st386;
tr1810:
	{ window_add_bit(KNOT_RRTYPE_AFSDB, s); }
	{
		s->line_counter++;
	}
	goto st386;
tr1816:
	{ window_add_bit(KNOT_RRTYPE_APL, s); }
	goto st386;
tr1817:
	{ window_add_bit(KNOT_RRTYPE_APL, s); }
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st386;
tr1818:
	{ window_add_bit(KNOT_RRTYPE_APL, s); }
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st386;
tr1819:
	{ window_add_bit(KNOT_RRTYPE_APL, s); }
	{
		s->line_counter++;
	}
	goto st386;
st386:
	if ( ++p == pe )
		goto _test_eof386;
case 386:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(2688 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 !s->multiline  ) _widec += 512;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(2688 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		if (
 !s->multiline  ) _widec += 512;
	}
	switch( _widec ) {
		case 9: goto st386;
		case 32: goto st386;
		case 40: goto tr1247;
		case 41: goto tr1248;
		case 65: goto st387;
		case 67: goto st392;
		case 68: goto st413;
		case 69: goto st427;
		case 72: goto st434;
		case 73: goto st443;
		case 75: goto st451;
		case 76: goto st455;
		case 77: goto st463;
		case 78: goto st469;
		case 79: goto st485;
		case 80: goto st495;
		case 82: goto st498;
		case 83: goto st505;
		case 84: goto st524;
		case 85: goto st534;
		case 87: goto st537;
		case 90: goto st543;
		case 97: goto st387;
		case 99: goto st392;
		case 100: goto st413;
		case 101: goto st427;
		case 104: goto st434;
		case 105: goto st443;
		case 107: goto st451;
		case 108: goto st455;
		case 109: goto st463;
		case 110: goto st469;
		case 111: goto st485;
		case 112: goto st495;
		case 114: goto st498;
		case 115: goto st505;
		case 116: goto st524;
		case 117: goto st534;
		case 119: goto st537;
		case 122: goto st543;
		case 3082: goto tr1267;
		case 3131: goto tr1268;
		case 3338: goto tr1269;
		case 3387: goto tr1269;
		case 3594: goto tr1270;
		case 3643: goto tr1271;
	}
	goto tr1237;
st387:
	if ( ++p == pe )
		goto _test_eof387;
case 387:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(2688 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 !s->multiline  ) _widec += 512;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(2688 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		if (
 !s->multiline  ) _widec += 512;
	}
	switch( _widec ) {
		case 9: goto tr1272;
		case 32: goto tr1272;
		case 40: goto tr1273;
		case 41: goto tr1274;
		case 65: goto st388;
		case 70: goto st549;
		case 80: goto st553;
		case 97: goto st388;
		case 102: goto st549;
		case 112: goto st553;
		case 3082: goto tr1278;
		case 3131: goto tr1279;
		case 3338: goto tr1280;
		case 3387: goto tr1280;
		case 3594: goto tr1281;
		case 3643: goto tr1282;
	}
	goto tr1237;
st388:
	if ( ++p == pe )
		goto _test_eof388;
case 388:
	switch( (*p) ) {
		case 65: goto st389;
		case 97: goto st389;
	}
	goto tr1237;
st389:
	if ( ++p == pe )
		goto _test_eof389;
case 389:
	switch( (*p) ) {
		case 65: goto st390;
		case 97: goto st390;
	}
	goto tr1237;
st390:
	if ( ++p == pe )
		goto _test_eof390;
case 390:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(2688 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 !s->multiline  ) _widec += 512;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(2688 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		if (
 !s->multiline  ) _widec += 512;
	}
	switch( _widec ) {
		case 9: goto tr1285;
		case 32: goto tr1285;
		case 40: goto tr1286;
		case 41: goto tr1287;
		case 3082: goto tr1288;
		case 3131: goto tr1289;
		case 3338: goto tr1290;
		case 3387: goto tr1290;
		case 3594: goto tr1291;
		case 3643: goto tr1292;
	}
	goto tr1237;
tr1268:
	{
		s->buffer_length = 0;
	}
	goto st391;
tr1293:
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		}
	}
	goto st391;
tr1242:
	{
		memset(s->windows, 0, sizeof(s->windows));
		s->last_window = -1;
	}
	{
		s->buffer_length = 0;
	}
	goto st391;
tr1279:
	{ window_add_bit(KNOT_RRTYPE_A, s); }
	{
		s->buffer_length = 0;
	}
	goto st391;
tr1289:
	{ window_add_bit(KNOT_RRTYPE_AAAA, s); }
	{
		s->buffer_length = 0;
	}
	goto st391;
tr1305:
	{ window_add_bit(KNOT_RRTYPE_CAA, s); }
	{
		s->buffer_length = 0;
	}
	goto st391;
tr1319:
	{ window_add_bit(KNOT_RRTYPE_CDNSKEY, s); }
	{
		s->buffer_length = 0;
	}
	goto st391;
tr1327:
	{ window_add_bit(KNOT_RRTYPE_CDS, s); }
	{
		s->buffer_length = 0;
	}
	goto st391;
tr1337:
	{ window_add_bit(KNOT_RRTYPE_CERT, s); }
	{
		s->buffer_length = 0;
	}
	goto st391;
tr1348:
	{ window_add_bit(KNOT_RRTYPE_CNAME, s); }
	{
		s->buffer_length = 0;
	}
	goto st391;
tr1359:
	{ window_add_bit(KNOT_RRTYPE_CSYNC, s); }
	{
		s->buffer_length = 0;
	}
	goto st391;
tr1373:
	{ window_add_bit(KNOT_RRTYPE_DHCID, s); }
	{
		s->buffer_length = 0;
	}
	goto st391;
tr1385:
	{ window_add_bit(KNOT_RRTYPE_DNAME, s); }
	{
		s->buffer_length = 0;
	}
	goto st391;
tr1396:
	{ window_add_bit(KNOT_RRTYPE_DNSKEY, s); }
	{
		s->buffer_length = 0;
	}
	goto st391;
tr1404:
	{ window_add_bit(KNOT_RRTYPE_DS, s); }
	{
		s->buffer_length = 0;
	}
	goto st391;
tr1417:
	{ window_add_bit(KNOT_RRTYPE_EUI48, s); }
	{
		s->buffer_length = 0;
	}
	goto st391;
tr1426:
	{ window_add_bit(KNOT_RRTYPE_EUI64, s); }
	{
		s->buffer_length = 0;
	}
	goto st391;
tr1439:
	{ window_add_bit(KNOT_RRTYPE_HINFO, s); }
	{
		s->buffer_length = 0;
	}
	goto st391;
tr1450:
	{ window_add_bit(KNOT_RRTYPE_HTTPS, s); }
	{
		s->buffer_length = 0;
	}
	goto st391;
tr1465:
	{ window_add_bit(KNOT_RRTYPE_IPSECKEY, s); }
	{
		s->buffer_length = 0;
	}
	goto st391;
tr1476:
	{ window_add_bit(KNOT_RRTYPE_KEY, s); }
	{
		s->buffer_length = 0;
	}
	goto st391;
tr1484:
	{ window_add_bit(KNOT_RRTYPE_KX, s); }
	{
		s->buffer_length = 0;
	}
	goto st391;
tr1497:
	{ window_add_bit(KNOT_RRTYPE_L32, s); }
	{
		s->buffer_length = 0;
	}
	goto st391;
tr1506:
	{ window_add_bit(KNOT_RRTYPE_L64, s); }
	{
		s->buffer_length = 0;
	}
	goto st391;
tr1515:
	{ window_add_bit(KNOT_RRTYPE_LOC, s); }
	{
		s->buffer_length = 0;
	}
	goto st391;
tr1523:
	{ window_add_bit(KNOT_RRTYPE_LP, s); }
	{
		s->buffer_length = 0;
	}
	goto st391;
tr1536:
	{ window_add_bit(KNOT_RRTYPE_MINFO, s); }
	{
		s->buffer_length = 0;
	}
	goto st391;
tr1544:
	{ window_add_bit(KNOT_RRTYPE_MX, s); }
	{
		s->buffer_length = 0;
	}
	goto st391;
tr1558:
	{ window_add_bit(KNOT_RRTYPE_NAPTR, s); }
	{
		s->buffer_length = 0;
	}
	goto st391;
tr1567:
	{ window_add_bit(KNOT_RRTYPE_NID, s); }
	{
		s->buffer_length = 0;
	}
	goto st391;
tr1576:
	{ window_add_bit(KNOT_RRTYPE_NS, s); }
	{
		s->buffer_length = 0;
	}
	goto st391;
tr1586:
	{ window_add_bit(KNOT_RRTYPE_NSEC, s); }
	{
		s->buffer_length = 0;
	}
	goto st391;
tr1595:
	{ window_add_bit(KNOT_RRTYPE_NSEC3, s); }
	{
		s->buffer_length = 0;
	}
	goto st391;
tr1607:
	{ window_add_bit(KNOT_RRTYPE_NSEC3PARAM, s); }
	{
		s->buffer_length = 0;
	}
	goto st391;
tr1624:
	{ window_add_bit(KNOT_RRTYPE_OPENPGPKEY, s); }
	{
		s->buffer_length = 0;
	}
	goto st391;
tr1634:
	{ window_add_bit(KNOT_RRTYPE_PTR, s); }
	{
		s->buffer_length = 0;
	}
	goto st391;
tr1645:
	{ window_add_bit(KNOT_RRTYPE_RP, s); }
	{
		s->buffer_length = 0;
	}
	goto st391;
tr1656:
	{ window_add_bit(KNOT_RRTYPE_RRSIG, s); }
	{
		s->buffer_length = 0;
	}
	goto st391;
tr1664:
	{ window_add_bit(KNOT_RRTYPE_RT, s); }
	{
		s->buffer_length = 0;
	}
	goto st391;
tr1682:
	{ window_add_bit(KNOT_RRTYPE_SMIMEA, s); }
	{
		s->buffer_length = 0;
	}
	goto st391;
tr1691:
	{ window_add_bit(KNOT_RRTYPE_SOA, s); }
	{
		s->buffer_length = 0;
	}
	goto st391;
tr1700:
	{ window_add_bit(KNOT_RRTYPE_SPF, s); }
	{
		s->buffer_length = 0;
	}
	goto st391;
tr1709:
	{ window_add_bit(KNOT_RRTYPE_SRV, s); }
	{
		s->buffer_length = 0;
	}
	goto st391;
tr1720:
	{ window_add_bit(KNOT_RRTYPE_SSHFP, s); }
	{
		s->buffer_length = 0;
	}
	goto st391;
tr1730:
	{ window_add_bit(KNOT_RRTYPE_SVCB, s); }
	{
		s->buffer_length = 0;
	}
	goto st391;
tr1743:
	{ window_add_bit(KNOT_RRTYPE_TLSA, s); }
	{
		s->buffer_length = 0;
	}
	goto st391;
tr1752:
	{ window_add_bit(KNOT_RRTYPE_TXT, s); }
	{
		s->buffer_length = 0;
	}
	goto st391;
tr1764:
	{
		if (s->number64 <= UINT16_MAX) {
			window_add_bit(s->number64, s);
		} else {
			WARN(ZS_NUMBER16_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		s->buffer_length = 0;
	}
	goto st391;
tr1774:
	{ window_add_bit(KNOT_RRTYPE_URI, s); }
	{
		s->buffer_length = 0;
	}
	goto st391;
tr1787:
	{ window_add_bit(KNOT_RRTYPE_WALLET, s); }
	{
		s->buffer_length = 0;
	}
	goto st391;
tr1800:
	{ window_add_bit(KNOT_RRTYPE_ZONEMD, s); }
	{
		s->buffer_length = 0;
	}
	goto st391;
tr1811:
	{ window_add_bit(KNOT_RRTYPE_AFSDB, s); }
	{
		s->buffer_length = 0;
	}
	goto st391;
tr1820:
	{ window_add_bit(KNOT_RRTYPE_APL, s); }
	{
		s->buffer_length = 0;
	}
	goto st391;
st391:
	if ( ++p == pe )
		goto _test_eof391;
case 391:
	_widec = (*p);
	if ( (*p) < 10 ) {
		if ( (*p) <= 9 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) > 10 ) {
		if ( 11 <= (*p) )
 {			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	if ( _widec == 2058 )
		goto tr1294;
	if ( 1920 <= _widec && _widec <= 2175 )
		goto tr1293;
	goto tr1237;
tr1243:
	{
		memset(s->windows, 0, sizeof(s->windows));
		s->last_window = -1;
	}
	{
		for (uint16_t window = 0; window <= s->last_window; window++) {
			if ((s->windows[window]).length > 0) {
				if (rdata_tail + 2 + (s->windows[window]).length <= rdata_stop)
				{
					// Window number.
					*rdata_tail = (uint8_t)window;
					rdata_tail += 1;
					// Bitmap length.
					*rdata_tail = (s->windows[window]).length;
					rdata_tail += 1;
					// Copying bitmap.
					memcpy(rdata_tail,
					       (s->windows[window]).bitmap,
					       (s->windows[window]).length);
					rdata_tail += (s->windows[window]).length;
				} else {
					WARN(ZS_RDATA_OVERFLOW);
					p--; {goto st316;}
				}
			}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1466;
tr1269:
	{
		for (uint16_t window = 0; window <= s->last_window; window++) {
			if ((s->windows[window]).length > 0) {
				if (rdata_tail + 2 + (s->windows[window]).length <= rdata_stop)
				{
					// Window number.
					*rdata_tail = (uint8_t)window;
					rdata_tail += 1;
					// Bitmap length.
					*rdata_tail = (s->windows[window]).length;
					rdata_tail += 1;
					// Copying bitmap.
					memcpy(rdata_tail,
					       (s->windows[window]).bitmap,
					       (s->windows[window]).length);
					rdata_tail += (s->windows[window]).length;
				} else {
					WARN(ZS_RDATA_OVERFLOW);
					p--; {goto st316;}
				}
			}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1466;
tr1280:
	{ window_add_bit(KNOT_RRTYPE_A, s); }
	{
		for (uint16_t window = 0; window <= s->last_window; window++) {
			if ((s->windows[window]).length > 0) {
				if (rdata_tail + 2 + (s->windows[window]).length <= rdata_stop)
				{
					// Window number.
					*rdata_tail = (uint8_t)window;
					rdata_tail += 1;
					// Bitmap length.
					*rdata_tail = (s->windows[window]).length;
					rdata_tail += 1;
					// Copying bitmap.
					memcpy(rdata_tail,
					       (s->windows[window]).bitmap,
					       (s->windows[window]).length);
					rdata_tail += (s->windows[window]).length;
				} else {
					WARN(ZS_RDATA_OVERFLOW);
					p--; {goto st316;}
				}
			}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1466;
tr1290:
	{ window_add_bit(KNOT_RRTYPE_AAAA, s); }
	{
		for (uint16_t window = 0; window <= s->last_window; window++) {
			if ((s->windows[window]).length > 0) {
				if (rdata_tail + 2 + (s->windows[window]).length <= rdata_stop)
				{
					// Window number.
					*rdata_tail = (uint8_t)window;
					rdata_tail += 1;
					// Bitmap length.
					*rdata_tail = (s->windows[window]).length;
					rdata_tail += 1;
					// Copying bitmap.
					memcpy(rdata_tail,
					       (s->windows[window]).bitmap,
					       (s->windows[window]).length);
					rdata_tail += (s->windows[window]).length;
				} else {
					WARN(ZS_RDATA_OVERFLOW);
					p--; {goto st316;}
				}
			}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1466;
tr1306:
	{ window_add_bit(KNOT_RRTYPE_CAA, s); }
	{
		for (uint16_t window = 0; window <= s->last_window; window++) {
			if ((s->windows[window]).length > 0) {
				if (rdata_tail + 2 + (s->windows[window]).length <= rdata_stop)
				{
					// Window number.
					*rdata_tail = (uint8_t)window;
					rdata_tail += 1;
					// Bitmap length.
					*rdata_tail = (s->windows[window]).length;
					rdata_tail += 1;
					// Copying bitmap.
					memcpy(rdata_tail,
					       (s->windows[window]).bitmap,
					       (s->windows[window]).length);
					rdata_tail += (s->windows[window]).length;
				} else {
					WARN(ZS_RDATA_OVERFLOW);
					p--; {goto st316;}
				}
			}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1466;
tr1320:
	{ window_add_bit(KNOT_RRTYPE_CDNSKEY, s); }
	{
		for (uint16_t window = 0; window <= s->last_window; window++) {
			if ((s->windows[window]).length > 0) {
				if (rdata_tail + 2 + (s->windows[window]).length <= rdata_stop)
				{
					// Window number.
					*rdata_tail = (uint8_t)window;
					rdata_tail += 1;
					// Bitmap length.
					*rdata_tail = (s->windows[window]).length;
					rdata_tail += 1;
					// Copying bitmap.
					memcpy(rdata_tail,
					       (s->windows[window]).bitmap,
					       (s->windows[window]).length);
					rdata_tail += (s->windows[window]).length;
				} else {
					WARN(ZS_RDATA_OVERFLOW);
					p--; {goto st316;}
				}
			}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1466;
tr1328:
	{ window_add_bit(KNOT_RRTYPE_CDS, s); }
	{
		for (uint16_t window = 0; window <= s->last_window; window++) {
			if ((s->windows[window]).length > 0) {
				if (rdata_tail + 2 + (s->windows[window]).length <= rdata_stop)
				{
					// Window number.
					*rdata_tail = (uint8_t)window;
					rdata_tail += 1;
					// Bitmap length.
					*rdata_tail = (s->windows[window]).length;
					rdata_tail += 1;
					// Copying bitmap.
					memcpy(rdata_tail,
					       (s->windows[window]).bitmap,
					       (s->windows[window]).length);
					rdata_tail += (s->windows[window]).length;
				} else {
					WARN(ZS_RDATA_OVERFLOW);
					p--; {goto st316;}
				}
			}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1466;
tr1338:
	{ window_add_bit(KNOT_RRTYPE_CERT, s); }
	{
		for (uint16_t window = 0; window <= s->last_window; window++) {
			if ((s->windows[window]).length > 0) {
				if (rdata_tail + 2 + (s->windows[window]).length <= rdata_stop)
				{
					// Window number.
					*rdata_tail = (uint8_t)window;
					rdata_tail += 1;
					// Bitmap length.
					*rdata_tail = (s->windows[window]).length;
					rdata_tail += 1;
					// Copying bitmap.
					memcpy(rdata_tail,
					       (s->windows[window]).bitmap,
					       (s->windows[window]).length);
					rdata_tail += (s->windows[window]).length;
				} else {
					WARN(ZS_RDATA_OVERFLOW);
					p--; {goto st316;}
				}
			}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1466;
tr1349:
	{ window_add_bit(KNOT_RRTYPE_CNAME, s); }
	{
		for (uint16_t window = 0; window <= s->last_window; window++) {
			if ((s->windows[window]).length > 0) {
				if (rdata_tail + 2 + (s->windows[window]).length <= rdata_stop)
				{
					// Window number.
					*rdata_tail = (uint8_t)window;
					rdata_tail += 1;
					// Bitmap length.
					*rdata_tail = (s->windows[window]).length;
					rdata_tail += 1;
					// Copying bitmap.
					memcpy(rdata_tail,
					       (s->windows[window]).bitmap,
					       (s->windows[window]).length);
					rdata_tail += (s->windows[window]).length;
				} else {
					WARN(ZS_RDATA_OVERFLOW);
					p--; {goto st316;}
				}
			}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1466;
tr1360:
	{ window_add_bit(KNOT_RRTYPE_CSYNC, s); }
	{
		for (uint16_t window = 0; window <= s->last_window; window++) {
			if ((s->windows[window]).length > 0) {
				if (rdata_tail + 2 + (s->windows[window]).length <= rdata_stop)
				{
					// Window number.
					*rdata_tail = (uint8_t)window;
					rdata_tail += 1;
					// Bitmap length.
					*rdata_tail = (s->windows[window]).length;
					rdata_tail += 1;
					// Copying bitmap.
					memcpy(rdata_tail,
					       (s->windows[window]).bitmap,
					       (s->windows[window]).length);
					rdata_tail += (s->windows[window]).length;
				} else {
					WARN(ZS_RDATA_OVERFLOW);
					p--; {goto st316;}
				}
			}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1466;
tr1374:
	{ window_add_bit(KNOT_RRTYPE_DHCID, s); }
	{
		for (uint16_t window = 0; window <= s->last_window; window++) {
			if ((s->windows[window]).length > 0) {
				if (rdata_tail + 2 + (s->windows[window]).length <= rdata_stop)
				{
					// Window number.
					*rdata_tail = (uint8_t)window;
					rdata_tail += 1;
					// Bitmap length.
					*rdata_tail = (s->windows[window]).length;
					rdata_tail += 1;
					// Copying bitmap.
					memcpy(rdata_tail,
					       (s->windows[window]).bitmap,
					       (s->windows[window]).length);
					rdata_tail += (s->windows[window]).length;
				} else {
					WARN(ZS_RDATA_OVERFLOW);
					p--; {goto st316;}
				}
			}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1466;
tr1386:
	{ window_add_bit(KNOT_RRTYPE_DNAME, s); }
	{
		for (uint16_t window = 0; window <= s->last_window; window++) {
			if ((s->windows[window]).length > 0) {
				if (rdata_tail + 2 + (s->windows[window]).length <= rdata_stop)
				{
					// Window number.
					*rdata_tail = (uint8_t)window;
					rdata_tail += 1;
					// Bitmap length.
					*rdata_tail = (s->windows[window]).length;
					rdata_tail += 1;
					// Copying bitmap.
					memcpy(rdata_tail,
					       (s->windows[window]).bitmap,
					       (s->windows[window]).length);
					rdata_tail += (s->windows[window]).length;
				} else {
					WARN(ZS_RDATA_OVERFLOW);
					p--; {goto st316;}
				}
			}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1466;
tr1397:
	{ window_add_bit(KNOT_RRTYPE_DNSKEY, s); }
	{
		for (uint16_t window = 0; window <= s->last_window; window++) {
			if ((s->windows[window]).length > 0) {
				if (rdata_tail + 2 + (s->windows[window]).length <= rdata_stop)
				{
					// Window number.
					*rdata_tail = (uint8_t)window;
					rdata_tail += 1;
					// Bitmap length.
					*rdata_tail = (s->windows[window]).length;
					rdata_tail += 1;
					// Copying bitmap.
					memcpy(rdata_tail,
					       (s->windows[window]).bitmap,
					       (s->windows[window]).length);
					rdata_tail += (s->windows[window]).length;
				} else {
					WARN(ZS_RDATA_OVERFLOW);
					p--; {goto st316;}
				}
			}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1466;
tr1405:
	{ window_add_bit(KNOT_RRTYPE_DS, s); }
	{
		for (uint16_t window = 0; window <= s->last_window; window++) {
			if ((s->windows[window]).length > 0) {
				if (rdata_tail + 2 + (s->windows[window]).length <= rdata_stop)
				{
					// Window number.
					*rdata_tail = (uint8_t)window;
					rdata_tail += 1;
					// Bitmap length.
					*rdata_tail = (s->windows[window]).length;
					rdata_tail += 1;
					// Copying bitmap.
					memcpy(rdata_tail,
					       (s->windows[window]).bitmap,
					       (s->windows[window]).length);
					rdata_tail += (s->windows[window]).length;
				} else {
					WARN(ZS_RDATA_OVERFLOW);
					p--; {goto st316;}
				}
			}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1466;
tr1418:
	{ window_add_bit(KNOT_RRTYPE_EUI48, s); }
	{
		for (uint16_t window = 0; window <= s->last_window; window++) {
			if ((s->windows[window]).length > 0) {
				if (rdata_tail + 2 + (s->windows[window]).length <= rdata_stop)
				{
					// Window number.
					*rdata_tail = (uint8_t)window;
					rdata_tail += 1;
					// Bitmap length.
					*rdata_tail = (s->windows[window]).length;
					rdata_tail += 1;
					// Copying bitmap.
					memcpy(rdata_tail,
					       (s->windows[window]).bitmap,
					       (s->windows[window]).length);
					rdata_tail += (s->windows[window]).length;
				} else {
					WARN(ZS_RDATA_OVERFLOW);
					p--; {goto st316;}
				}
			}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1466;
tr1427:
	{ window_add_bit(KNOT_RRTYPE_EUI64, s); }
	{
		for (uint16_t window = 0; window <= s->last_window; window++) {
			if ((s->windows[window]).length > 0) {
				if (rdata_tail + 2 + (s->windows[window]).length <= rdata_stop)
				{
					// Window number.
					*rdata_tail = (uint8_t)window;
					rdata_tail += 1;
					// Bitmap length.
					*rdata_tail = (s->windows[window]).length;
					rdata_tail += 1;
					// Copying bitmap.
					memcpy(rdata_tail,
					       (s->windows[window]).bitmap,
					       (s->windows[window]).length);
					rdata_tail += (s->windows[window]).length;
				} else {
					WARN(ZS_RDATA_OVERFLOW);
					p--; {goto st316;}
				}
			}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1466;
tr1440:
	{ window_add_bit(KNOT_RRTYPE_HINFO, s); }
	{
		for (uint16_t window = 0; window <= s->last_window; window++) {
			if ((s->windows[window]).length > 0) {
				if (rdata_tail + 2 + (s->windows[window]).length <= rdata_stop)
				{
					// Window number.
					*rdata_tail = (uint8_t)window;
					rdata_tail += 1;
					// Bitmap length.
					*rdata_tail = (s->windows[window]).length;
					rdata_tail += 1;
					// Copying bitmap.
					memcpy(rdata_tail,
					       (s->windows[window]).bitmap,
					       (s->windows[window]).length);
					rdata_tail += (s->windows[window]).length;
				} else {
					WARN(ZS_RDATA_OVERFLOW);
					p--; {goto st316;}
				}
			}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1466;
tr1451:
	{ window_add_bit(KNOT_RRTYPE_HTTPS, s); }
	{
		for (uint16_t window = 0; window <= s->last_window; window++) {
			if ((s->windows[window]).length > 0) {
				if (rdata_tail + 2 + (s->windows[window]).length <= rdata_stop)
				{
					// Window number.
					*rdata_tail = (uint8_t)window;
					rdata_tail += 1;
					// Bitmap length.
					*rdata_tail = (s->windows[window]).length;
					rdata_tail += 1;
					// Copying bitmap.
					memcpy(rdata_tail,
					       (s->windows[window]).bitmap,
					       (s->windows[window]).length);
					rdata_tail += (s->windows[window]).length;
				} else {
					WARN(ZS_RDATA_OVERFLOW);
					p--; {goto st316;}
				}
			}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1466;
tr1466:
	{ window_add_bit(KNOT_RRTYPE_IPSECKEY, s); }
	{
		for (uint16_t window = 0; window <= s->last_window; window++) {
			if ((s->windows[window]).length > 0) {
				if (rdata_tail + 2 + (s->windows[window]).length <= rdata_stop)
				{
					// Window number.
					*rdata_tail = (uint8_t)window;
					rdata_tail += 1;
					// Bitmap length.
					*rdata_tail = (s->windows[window]).length;
					rdata_tail += 1;
					// Copying bitmap.
					memcpy(rdata_tail,
					       (s->windows[window]).bitmap,
					       (s->windows[window]).length);
					rdata_tail += (s->windows[window]).length;
				} else {
					WARN(ZS_RDATA_OVERFLOW);
					p--; {goto st316;}
				}
			}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1466;
tr1477:
	{ window_add_bit(KNOT_RRTYPE_KEY, s); }
	{
		for (uint16_t window = 0; window <= s->last_window; window++) {
			if ((s->windows[window]).length > 0) {
				if (rdata_tail + 2 + (s->windows[window]).length <= rdata_stop)
				{
					// Window number.
					*rdata_tail = (uint8_t)window;
					rdata_tail += 1;
					// Bitmap length.
					*rdata_tail = (s->windows[window]).length;
					rdata_tail += 1;
					// Copying bitmap.
					memcpy(rdata_tail,
					       (s->windows[window]).bitmap,
					       (s->windows[window]).length);
					rdata_tail += (s->windows[window]).length;
				} else {
					WARN(ZS_RDATA_OVERFLOW);
					p--; {goto st316;}
				}
			}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1466;
tr1485:
	{ window_add_bit(KNOT_RRTYPE_KX, s); }
	{
		for (uint16_t window = 0; window <= s->last_window; window++) {
			if ((s->windows[window]).length > 0) {
				if (rdata_tail + 2 + (s->windows[window]).length <= rdata_stop)
				{
					// Window number.
					*rdata_tail = (uint8_t)window;
					rdata_tail += 1;
					// Bitmap length.
					*rdata_tail = (s->windows[window]).length;
					rdata_tail += 1;
					// Copying bitmap.
					memcpy(rdata_tail,
					       (s->windows[window]).bitmap,
					       (s->windows[window]).length);
					rdata_tail += (s->windows[window]).length;
				} else {
					WARN(ZS_RDATA_OVERFLOW);
					p--; {goto st316;}
				}
			}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1466;
tr1498:
	{ window_add_bit(KNOT_RRTYPE_L32, s); }
	{
		for (uint16_t window = 0; window <= s->last_window; window++) {
			if ((s->windows[window]).length > 0) {
				if (rdata_tail + 2 + (s->windows[window]).length <= rdata_stop)
				{
					// Window number.
					*rdata_tail = (uint8_t)window;
					rdata_tail += 1;
					// Bitmap length.
					*rdata_tail = (s->windows[window]).length;
					rdata_tail += 1;
					// Copying bitmap.
					memcpy(rdata_tail,
					       (s->windows[window]).bitmap,
					       (s->windows[window]).length);
					rdata_tail += (s->windows[window]).length;
				} else {
					WARN(ZS_RDATA_OVERFLOW);
					p--; {goto st316;}
				}
			}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1466;
tr1507:
	{ window_add_bit(KNOT_RRTYPE_L64, s); }
	{
		for (uint16_t window = 0; window <= s->last_window; window++) {
			if ((s->windows[window]).length > 0) {
				if (rdata_tail + 2 + (s->windows[window]).length <= rdata_stop)
				{
					// Window number.
					*rdata_tail = (uint8_t)window;
					rdata_tail += 1;
					// Bitmap length.
					*rdata_tail = (s->windows[window]).length;
					rdata_tail += 1;
					// Copying bitmap.
					memcpy(rdata_tail,
					       (s->windows[window]).bitmap,
					       (s->windows[window]).length);
					rdata_tail += (s->windows[window]).length;
				} else {
					WARN(ZS_RDATA_OVERFLOW);
					p--; {goto st316;}
				}
			}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1466;
tr1516:
	{ window_add_bit(KNOT_RRTYPE_LOC, s); }
	{
		for (uint16_t window = 0; window <= s->last_window; window++) {
			if ((s->windows[window]).length > 0) {
				if (rdata_tail + 2 + (s->windows[window]).length <= rdata_stop)
				{
					// Window number.
					*rdata_tail = (uint8_t)window;
					rdata_tail += 1;
					// Bitmap length.
					*rdata_tail = (s->windows[window]).length;
					rdata_tail += 1;
					// Copying bitmap.
					memcpy(rdata_tail,
					       (s->windows[window]).bitmap,
					       (s->windows[window]).length);
					rdata_tail += (s->windows[window]).length;
				} else {
					WARN(ZS_RDATA_OVERFLOW);
					p--; {goto st316;}
				}
			}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1466;
tr1524:
	{ window_add_bit(KNOT_RRTYPE_LP, s); }
	{
		for (uint16_t window = 0; window <= s->last_window; window++) {
			if ((s->windows[window]).length > 0) {
				if (rdata_tail + 2 + (s->windows[window]).length <= rdata_stop)
				{
					// Window number.
					*rdata_tail = (uint8_t)window;
					rdata_tail += 1;
					// Bitmap length.
					*rdata_tail = (s->windows[window]).length;
					rdata_tail += 1;
					// Copying bitmap.
					memcpy(rdata_tail,
					       (s->windows[window]).bitmap,
					       (s->windows[window]).length);
					rdata_tail += (s->windows[window]).length;
				} else {
					WARN(ZS_RDATA_OVERFLOW);
					p--; {goto st316;}
				}
			}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1466;
tr1537:
	{ window_add_bit(KNOT_RRTYPE_MINFO, s); }
	{
		for (uint16_t window = 0; window <= s->last_window; window++) {
			if ((s->windows[window]).length > 0) {
				if (rdata_tail + 2 + (s->windows[window]).length <= rdata_stop)
				{
					// Window number.
					*rdata_tail = (uint8_t)window;
					rdata_tail += 1;
					// Bitmap length.
					*rdata_tail = (s->windows[window]).length;
					rdata_tail += 1;
					// Copying bitmap.
					memcpy(rdata_tail,
					       (s->windows[window]).bitmap,
					       (s->windows[window]).length);
					rdata_tail += (s->windows[window]).length;
				} else {
					WARN(ZS_RDATA_OVERFLOW);
					p--; {goto st316;}
				}
			}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1466;
tr1545:
	{ window_add_bit(KNOT_RRTYPE_MX, s); }
	{
		for (uint16_t window = 0; window <= s->last_window; window++) {
			if ((s->windows[window]).length > 0) {
				if (rdata_tail + 2 + (s->windows[window]).length <= rdata_stop)
				{
					// Window number.
					*rdata_tail = (uint8_t)window;
					rdata_tail += 1;
					// Bitmap length.
					*rdata_tail = (s->windows[window]).length;
					rdata_tail += 1;
					// Copying bitmap.
					memcpy(rdata_tail,
					       (s->windows[window]).bitmap,
					       (s->windows[window]).length);
					rdata_tail += (s->windows[window]).length;
				} else {
					WARN(ZS_RDATA_OVERFLOW);
					p--; {goto st316;}
				}
			}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1466;
tr1559:
	{ window_add_bit(KNOT_RRTYPE_NAPTR, s); }
	{
		for (uint16_t window = 0; window <= s->last_window; window++) {
			if ((s->windows[window]).length > 0) {
				if (rdata_tail + 2 + (s->windows[window]).length <= rdata_stop)
				{
					// Window number.
					*rdata_tail = (uint8_t)window;
					rdata_tail += 1;
					// Bitmap length.
					*rdata_tail = (s->windows[window]).length;
					rdata_tail += 1;
					// Copying bitmap.
					memcpy(rdata_tail,
					       (s->windows[window]).bitmap,
					       (s->windows[window]).length);
					rdata_tail += (s->windows[window]).length;
				} else {
					WARN(ZS_RDATA_OVERFLOW);
					p--; {goto st316;}
				}
			}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1466;
tr1568:
	{ window_add_bit(KNOT_RRTYPE_NID, s); }
	{
		for (uint16_t window = 0; window <= s->last_window; window++) {
			if ((s->windows[window]).length > 0) {
				if (rdata_tail + 2 + (s->windows[window]).length <= rdata_stop)
				{
					// Window number.
					*rdata_tail = (uint8_t)window;
					rdata_tail += 1;
					// Bitmap length.
					*rdata_tail = (s->windows[window]).length;
					rdata_tail += 1;
					// Copying bitmap.
					memcpy(rdata_tail,
					       (s->windows[window]).bitmap,
					       (s->windows[window]).length);
					rdata_tail += (s->windows[window]).length;
				} else {
					WARN(ZS_RDATA_OVERFLOW);
					p--; {goto st316;}
				}
			}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1466;
tr1577:
	{ window_add_bit(KNOT_RRTYPE_NS, s); }
	{
		for (uint16_t window = 0; window <= s->last_window; window++) {
			if ((s->windows[window]).length > 0) {
				if (rdata_tail + 2 + (s->windows[window]).length <= rdata_stop)
				{
					// Window number.
					*rdata_tail = (uint8_t)window;
					rdata_tail += 1;
					// Bitmap length.
					*rdata_tail = (s->windows[window]).length;
					rdata_tail += 1;
					// Copying bitmap.
					memcpy(rdata_tail,
					       (s->windows[window]).bitmap,
					       (s->windows[window]).length);
					rdata_tail += (s->windows[window]).length;
				} else {
					WARN(ZS_RDATA_OVERFLOW);
					p--; {goto st316;}
				}
			}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1466;
tr1587:
	{ window_add_bit(KNOT_RRTYPE_NSEC, s); }
	{
		for (uint16_t window = 0; window <= s->last_window; window++) {
			if ((s->windows[window]).length > 0) {
				if (rdata_tail + 2 + (s->windows[window]).length <= rdata_stop)
				{
					// Window number.
					*rdata_tail = (uint8_t)window;
					rdata_tail += 1;
					// Bitmap length.
					*rdata_tail = (s->windows[window]).length;
					rdata_tail += 1;
					// Copying bitmap.
					memcpy(rdata_tail,
					       (s->windows[window]).bitmap,
					       (s->windows[window]).length);
					rdata_tail += (s->windows[window]).length;
				} else {
					WARN(ZS_RDATA_OVERFLOW);
					p--; {goto st316;}
				}
			}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1466;
tr1596:
	{ window_add_bit(KNOT_RRTYPE_NSEC3, s); }
	{
		for (uint16_t window = 0; window <= s->last_window; window++) {
			if ((s->windows[window]).length > 0) {
				if (rdata_tail + 2 + (s->windows[window]).length <= rdata_stop)
				{
					// Window number.
					*rdata_tail = (uint8_t)window;
					rdata_tail += 1;
					// Bitmap length.
					*rdata_tail = (s->windows[window]).length;
					rdata_tail += 1;
					// Copying bitmap.
					memcpy(rdata_tail,
					       (s->windows[window]).bitmap,
					       (s->windows[window]).length);
					rdata_tail += (s->windows[window]).length;
				} else {
					WARN(ZS_RDATA_OVERFLOW);
					p--; {goto st316;}
				}
			}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1466;
tr1608:
	{ window_add_bit(KNOT_RRTYPE_NSEC3PARAM, s); }
	{
		for (uint16_t window = 0; window <= s->last_window; window++) {
			if ((s->windows[window]).length > 0) {
				if (rdata_tail + 2 + (s->windows[window]).length <= rdata_stop)
				{
					// Window number.
					*rdata_tail = (uint8_t)window;
					rdata_tail += 1;
					// Bitmap length.
					*rdata_tail = (s->windows[window]).length;
					rdata_tail += 1;
					// Copying bitmap.
					memcpy(rdata_tail,
					       (s->windows[window]).bitmap,
					       (s->windows[window]).length);
					rdata_tail += (s->windows[window]).length;
				} else {
					WARN(ZS_RDATA_OVERFLOW);
					p--; {goto st316;}
				}
			}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1466;
tr1625:
	{ window_add_bit(KNOT_RRTYPE_OPENPGPKEY, s); }
	{
		for (uint16_t window = 0; window <= s->last_window; window++) {
			if ((s->windows[window]).length > 0) {
				if (rdata_tail + 2 + (s->windows[window]).length <= rdata_stop)
				{
					// Window number.
					*rdata_tail = (uint8_t)window;
					rdata_tail += 1;
					// Bitmap length.
					*rdata_tail = (s->windows[window]).length;
					rdata_tail += 1;
					// Copying bitmap.
					memcpy(rdata_tail,
					       (s->windows[window]).bitmap,
					       (s->windows[window]).length);
					rdata_tail += (s->windows[window]).length;
				} else {
					WARN(ZS_RDATA_OVERFLOW);
					p--; {goto st316;}
				}
			}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1466;
tr1635:
	{ window_add_bit(KNOT_RRTYPE_PTR, s); }
	{
		for (uint16_t window = 0; window <= s->last_window; window++) {
			if ((s->windows[window]).length > 0) {
				if (rdata_tail + 2 + (s->windows[window]).length <= rdata_stop)
				{
					// Window number.
					*rdata_tail = (uint8_t)window;
					rdata_tail += 1;
					// Bitmap length.
					*rdata_tail = (s->windows[window]).length;
					rdata_tail += 1;
					// Copying bitmap.
					memcpy(rdata_tail,
					       (s->windows[window]).bitmap,
					       (s->windows[window]).length);
					rdata_tail += (s->windows[window]).length;
				} else {
					WARN(ZS_RDATA_OVERFLOW);
					p--; {goto st316;}
				}
			}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1466;
tr1646:
	{ window_add_bit(KNOT_RRTYPE_RP, s); }
	{
		for (uint16_t window = 0; window <= s->last_window; window++) {
			if ((s->windows[window]).length > 0) {
				if (rdata_tail + 2 + (s->windows[window]).length <= rdata_stop)
				{
					// Window number.
					*rdata_tail = (uint8_t)window;
					rdata_tail += 1;
					// Bitmap length.
					*rdata_tail = (s->windows[window]).length;
					rdata_tail += 1;
					// Copying bitmap.
					memcpy(rdata_tail,
					       (s->windows[window]).bitmap,
					       (s->windows[window]).length);
					rdata_tail += (s->windows[window]).length;
				} else {
					WARN(ZS_RDATA_OVERFLOW);
					p--; {goto st316;}
				}
			}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1466;
tr1657:
	{ window_add_bit(KNOT_RRTYPE_RRSIG, s); }
	{
		for (uint16_t window = 0; window <= s->last_window; window++) {
			if ((s->windows[window]).length > 0) {
				if (rdata_tail + 2 + (s->windows[window]).length <= rdata_stop)
				{
					// Window number.
					*rdata_tail = (uint8_t)window;
					rdata_tail += 1;
					// Bitmap length.
					*rdata_tail = (s->windows[window]).length;
					rdata_tail += 1;
					// Copying bitmap.
					memcpy(rdata_tail,
					       (s->windows[window]).bitmap,
					       (s->windows[window]).length);
					rdata_tail += (s->windows[window]).length;
				} else {
					WARN(ZS_RDATA_OVERFLOW);
					p--; {goto st316;}
				}
			}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1466;
tr1665:
	{ window_add_bit(KNOT_RRTYPE_RT, s); }
	{
		for (uint16_t window = 0; window <= s->last_window; window++) {
			if ((s->windows[window]).length > 0) {
				if (rdata_tail + 2 + (s->windows[window]).length <= rdata_stop)
				{
					// Window number.
					*rdata_tail = (uint8_t)window;
					rdata_tail += 1;
					// Bitmap length.
					*rdata_tail = (s->windows[window]).length;
					rdata_tail += 1;
					// Copying bitmap.
					memcpy(rdata_tail,
					       (s->windows[window]).bitmap,
					       (s->windows[window]).length);
					rdata_tail += (s->windows[window]).length;
				} else {
					WARN(ZS_RDATA_OVERFLOW);
					p--; {goto st316;}
				}
			}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1466;
tr1683:
	{ window_add_bit(KNOT_RRTYPE_SMIMEA, s); }
	{
		for (uint16_t window = 0; window <= s->last_window; window++) {
			if ((s->windows[window]).length > 0) {
				if (rdata_tail + 2 + (s->windows[window]).length <= rdata_stop)
				{
					// Window number.
					*rdata_tail = (uint8_t)window;
					rdata_tail += 1;
					// Bitmap length.
					*rdata_tail = (s->windows[window]).length;
					rdata_tail += 1;
					// Copying bitmap.
					memcpy(rdata_tail,
					       (s->windows[window]).bitmap,
					       (s->windows[window]).length);
					rdata_tail += (s->windows[window]).length;
				} else {
					WARN(ZS_RDATA_OVERFLOW);
					p--; {goto st316;}
				}
			}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1466;
tr1692:
	{ window_add_bit(KNOT_RRTYPE_SOA, s); }
	{
		for (uint16_t window = 0; window <= s->last_window; window++) {
			if ((s->windows[window]).length > 0) {
				if (rdata_tail + 2 + (s->windows[window]).length <= rdata_stop)
				{
					// Window number.
					*rdata_tail = (uint8_t)window;
					rdata_tail += 1;
					// Bitmap length.
					*rdata_tail = (s->windows[window]).length;
					rdata_tail += 1;
					// Copying bitmap.
					memcpy(rdata_tail,
					       (s->windows[window]).bitmap,
					       (s->windows[window]).length);
					rdata_tail += (s->windows[window]).length;
				} else {
					WARN(ZS_RDATA_OVERFLOW);
					p--; {goto st316;}
				}
			}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1466;
tr1701:
	{ window_add_bit(KNOT_RRTYPE_SPF, s); }
	{
		for (uint16_t window = 0; window <= s->last_window; window++) {
			if ((s->windows[window]).length > 0) {
				if (rdata_tail + 2 + (s->windows[window]).length <= rdata_stop)
				{
					// Window number.
					*rdata_tail = (uint8_t)window;
					rdata_tail += 1;
					// Bitmap length.
					*rdata_tail = (s->windows[window]).length;
					rdata_tail += 1;
					// Copying bitmap.
					memcpy(rdata_tail,
					       (s->windows[window]).bitmap,
					       (s->windows[window]).length);
					rdata_tail += (s->windows[window]).length;
				} else {
					WARN(ZS_RDATA_OVERFLOW);
					p--; {goto st316;}
				}
			}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1466;
tr1710:
	{ window_add_bit(KNOT_RRTYPE_SRV, s); }
	{
		for (uint16_t window = 0; window <= s->last_window; window++) {
			if ((s->windows[window]).length > 0) {
				if (rdata_tail + 2 + (s->windows[window]).length <= rdata_stop)
				{
					// Window number.
					*rdata_tail = (uint8_t)window;
					rdata_tail += 1;
					// Bitmap length.
					*rdata_tail = (s->windows[window]).length;
					rdata_tail += 1;
					// Copying bitmap.
					memcpy(rdata_tail,
					       (s->windows[window]).bitmap,
					       (s->windows[window]).length);
					rdata_tail += (s->windows[window]).length;
				} else {
					WARN(ZS_RDATA_OVERFLOW);
					p--; {goto st316;}
				}
			}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1466;
tr1721:
	{ window_add_bit(KNOT_RRTYPE_SSHFP, s); }
	{
		for (uint16_t window = 0; window <= s->last_window; window++) {
			if ((s->windows[window]).length > 0) {
				if (rdata_tail + 2 + (s->windows[window]).length <= rdata_stop)
				{
					// Window number.
					*rdata_tail = (uint8_t)window;
					rdata_tail += 1;
					// Bitmap length.
					*rdata_tail = (s->windows[window]).length;
					rdata_tail += 1;
					// Copying bitmap.
					memcpy(rdata_tail,
					       (s->windows[window]).bitmap,
					       (s->windows[window]).length);
					rdata_tail += (s->windows[window]).length;
				} else {
					WARN(ZS_RDATA_OVERFLOW);
					p--; {goto st316;}
				}
			}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1466;
tr1731:
	{ window_add_bit(KNOT_RRTYPE_SVCB, s); }
	{
		for (uint16_t window = 0; window <= s->last_window; window++) {
			if ((s->windows[window]).length > 0) {
				if (rdata_tail + 2 + (s->windows[window]).length <= rdata_stop)
				{
					// Window number.
					*rdata_tail = (uint8_t)window;
					rdata_tail += 1;
					// Bitmap length.
					*rdata_tail = (s->windows[window]).length;
					rdata_tail += 1;
					// Copying bitmap.
					memcpy(rdata_tail,
					       (s->windows[window]).bitmap,
					       (s->windows[window]).length);
					rdata_tail += (s->windows[window]).length;
				} else {
					WARN(ZS_RDATA_OVERFLOW);
					p--; {goto st316;}
				}
			}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1466;
tr1744:
	{ window_add_bit(KNOT_RRTYPE_TLSA, s); }
	{
		for (uint16_t window = 0; window <= s->last_window; window++) {
			if ((s->windows[window]).length > 0) {
				if (rdata_tail + 2 + (s->windows[window]).length <= rdata_stop)
				{
					// Window number.
					*rdata_tail = (uint8_t)window;
					rdata_tail += 1;
					// Bitmap length.
					*rdata_tail = (s->windows[window]).length;
					rdata_tail += 1;
					// Copying bitmap.
					memcpy(rdata_tail,
					       (s->windows[window]).bitmap,
					       (s->windows[window]).length);
					rdata_tail += (s->windows[window]).length;
				} else {
					WARN(ZS_RDATA_OVERFLOW);
					p--; {goto st316;}
				}
			}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1466;
tr1753:
	{ window_add_bit(KNOT_RRTYPE_TXT, s); }
	{
		for (uint16_t window = 0; window <= s->last_window; window++) {
			if ((s->windows[window]).length > 0) {
				if (rdata_tail + 2 + (s->windows[window]).length <= rdata_stop)
				{
					// Window number.
					*rdata_tail = (uint8_t)window;
					rdata_tail += 1;
					// Bitmap length.
					*rdata_tail = (s->windows[window]).length;
					rdata_tail += 1;
					// Copying bitmap.
					memcpy(rdata_tail,
					       (s->windows[window]).bitmap,
					       (s->windows[window]).length);
					rdata_tail += (s->windows[window]).length;
				} else {
					WARN(ZS_RDATA_OVERFLOW);
					p--; {goto st316;}
				}
			}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1466;
tr1765:
	{
		if (s->number64 <= UINT16_MAX) {
			window_add_bit(s->number64, s);
		} else {
			WARN(ZS_NUMBER16_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		for (uint16_t window = 0; window <= s->last_window; window++) {
			if ((s->windows[window]).length > 0) {
				if (rdata_tail + 2 + (s->windows[window]).length <= rdata_stop)
				{
					// Window number.
					*rdata_tail = (uint8_t)window;
					rdata_tail += 1;
					// Bitmap length.
					*rdata_tail = (s->windows[window]).length;
					rdata_tail += 1;
					// Copying bitmap.
					memcpy(rdata_tail,
					       (s->windows[window]).bitmap,
					       (s->windows[window]).length);
					rdata_tail += (s->windows[window]).length;
				} else {
					WARN(ZS_RDATA_OVERFLOW);
					p--; {goto st316;}
				}
			}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1466;
tr1775:
	{ window_add_bit(KNOT_RRTYPE_URI, s); }
	{
		for (uint16_t window = 0; window <= s->last_window; window++) {
			if ((s->windows[window]).length > 0) {
				if (rdata_tail + 2 + (s->windows[window]).length <= rdata_stop)
				{
					// Window number.
					*rdata_tail = (uint8_t)window;
					rdata_tail += 1;
					// Bitmap length.
					*rdata_tail = (s->windows[window]).length;
					rdata_tail += 1;
					// Copying bitmap.
					memcpy(rdata_tail,
					       (s->windows[window]).bitmap,
					       (s->windows[window]).length);
					rdata_tail += (s->windows[window]).length;
				} else {
					WARN(ZS_RDATA_OVERFLOW);
					p--; {goto st316;}
				}
			}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1466;
tr1788:
	{ window_add_bit(KNOT_RRTYPE_WALLET, s); }
	{
		for (uint16_t window = 0; window <= s->last_window; window++) {
			if ((s->windows[window]).length > 0) {
				if (rdata_tail + 2 + (s->windows[window]).length <= rdata_stop)
				{
					// Window number.
					*rdata_tail = (uint8_t)window;
					rdata_tail += 1;
					// Bitmap length.
					*rdata_tail = (s->windows[window]).length;
					rdata_tail += 1;
					// Copying bitmap.
					memcpy(rdata_tail,
					       (s->windows[window]).bitmap,
					       (s->windows[window]).length);
					rdata_tail += (s->windows[window]).length;
				} else {
					WARN(ZS_RDATA_OVERFLOW);
					p--; {goto st316;}
				}
			}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1466;
tr1801:
	{ window_add_bit(KNOT_RRTYPE_ZONEMD, s); }
	{
		for (uint16_t window = 0; window <= s->last_window; window++) {
			if ((s->windows[window]).length > 0) {
				if (rdata_tail + 2 + (s->windows[window]).length <= rdata_stop)
				{
					// Window number.
					*rdata_tail = (uint8_t)window;
					rdata_tail += 1;
					// Bitmap length.
					*rdata_tail = (s->windows[window]).length;
					rdata_tail += 1;
					// Copying bitmap.
					memcpy(rdata_tail,
					       (s->windows[window]).bitmap,
					       (s->windows[window]).length);
					rdata_tail += (s->windows[window]).length;
				} else {
					WARN(ZS_RDATA_OVERFLOW);
					p--; {goto st316;}
				}
			}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1466;
tr1812:
	{ window_add_bit(KNOT_RRTYPE_AFSDB, s); }
	{
		for (uint16_t window = 0; window <= s->last_window; window++) {
			if ((s->windows[window]).length > 0) {
				if (rdata_tail + 2 + (s->windows[window]).length <= rdata_stop)
				{
					// Window number.
					*rdata_tail = (uint8_t)window;
					rdata_tail += 1;
					// Bitmap length.
					*rdata_tail = (s->windows[window]).length;
					rdata_tail += 1;
					// Copying bitmap.
					memcpy(rdata_tail,
					       (s->windows[window]).bitmap,
					       (s->windows[window]).length);
					rdata_tail += (s->windows[window]).length;
				} else {
					WARN(ZS_RDATA_OVERFLOW);
					p--; {goto st316;}
				}
			}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1466;
tr1821:
	{ window_add_bit(KNOT_RRTYPE_APL, s); }
	{
		for (uint16_t window = 0; window <= s->last_window; window++) {
			if ((s->windows[window]).length > 0) {
				if (rdata_tail + 2 + (s->windows[window]).length <= rdata_stop)
				{
					// Window number.
					*rdata_tail = (uint8_t)window;
					rdata_tail += 1;
					// Bitmap length.
					*rdata_tail = (s->windows[window]).length;
					rdata_tail += 1;
					// Copying bitmap.
					memcpy(rdata_tail,
					       (s->windows[window]).bitmap,
					       (s->windows[window]).length);
					rdata_tail += (s->windows[window]).length;
				} else {
					WARN(ZS_RDATA_OVERFLOW);
					p--; {goto st316;}
				}
			}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1466;
st1466:
	if ( ++p == pe )
		goto _test_eof1466;
case 1466:
	goto st0;
tr1244:
	{
		memset(s->windows, 0, sizeof(s->windows));
		s->last_window = -1;
	}
	{
		s->line_counter++;
	}
	{
		for (uint16_t window = 0; window <= s->last_window; window++) {
			if ((s->windows[window]).length > 0) {
				if (rdata_tail + 2 + (s->windows[window]).length <= rdata_stop)
				{
					// Window number.
					*rdata_tail = (uint8_t)window;
					rdata_tail += 1;
					// Bitmap length.
					*rdata_tail = (s->windows[window]).length;
					rdata_tail += 1;
					// Copying bitmap.
					memcpy(rdata_tail,
					       (s->windows[window]).bitmap,
					       (s->windows[window]).length);
					rdata_tail += (s->windows[window]).length;
				} else {
					WARN(ZS_RDATA_OVERFLOW);
					p--; {goto st316;}
				}
			}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1467;
tr1270:
	{
		s->line_counter++;
	}
	{
		for (uint16_t window = 0; window <= s->last_window; window++) {
			if ((s->windows[window]).length > 0) {
				if (rdata_tail + 2 + (s->windows[window]).length <= rdata_stop)
				{
					// Window number.
					*rdata_tail = (uint8_t)window;
					rdata_tail += 1;
					// Bitmap length.
					*rdata_tail = (s->windows[window]).length;
					rdata_tail += 1;
					// Copying bitmap.
					memcpy(rdata_tail,
					       (s->windows[window]).bitmap,
					       (s->windows[window]).length);
					rdata_tail += (s->windows[window]).length;
				} else {
					WARN(ZS_RDATA_OVERFLOW);
					p--; {goto st316;}
				}
			}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1467;
tr1281:
	{ window_add_bit(KNOT_RRTYPE_A, s); }
	{
		s->line_counter++;
	}
	{
		for (uint16_t window = 0; window <= s->last_window; window++) {
			if ((s->windows[window]).length > 0) {
				if (rdata_tail + 2 + (s->windows[window]).length <= rdata_stop)
				{
					// Window number.
					*rdata_tail = (uint8_t)window;
					rdata_tail += 1;
					// Bitmap length.
					*rdata_tail = (s->windows[window]).length;
					rdata_tail += 1;
					// Copying bitmap.
					memcpy(rdata_tail,
					       (s->windows[window]).bitmap,
					       (s->windows[window]).length);
					rdata_tail += (s->windows[window]).length;
				} else {
					WARN(ZS_RDATA_OVERFLOW);
					p--; {goto st316;}
				}
			}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1467;
tr1291:
	{ window_add_bit(KNOT_RRTYPE_AAAA, s); }
	{
		s->line_counter++;
	}
	{
		for (uint16_t window = 0; window <= s->last_window; window++) {
			if ((s->windows[window]).length > 0) {
				if (rdata_tail + 2 + (s->windows[window]).length <= rdata_stop)
				{
					// Window number.
					*rdata_tail = (uint8_t)window;
					rdata_tail += 1;
					// Bitmap length.
					*rdata_tail = (s->windows[window]).length;
					rdata_tail += 1;
					// Copying bitmap.
					memcpy(rdata_tail,
					       (s->windows[window]).bitmap,
					       (s->windows[window]).length);
					rdata_tail += (s->windows[window]).length;
				} else {
					WARN(ZS_RDATA_OVERFLOW);
					p--; {goto st316;}
				}
			}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1467;
tr1307:
	{ window_add_bit(KNOT_RRTYPE_CAA, s); }
	{
		s->line_counter++;
	}
	{
		for (uint16_t window = 0; window <= s->last_window; window++) {
			if ((s->windows[window]).length > 0) {
				if (rdata_tail + 2 + (s->windows[window]).length <= rdata_stop)
				{
					// Window number.
					*rdata_tail = (uint8_t)window;
					rdata_tail += 1;
					// Bitmap length.
					*rdata_tail = (s->windows[window]).length;
					rdata_tail += 1;
					// Copying bitmap.
					memcpy(rdata_tail,
					       (s->windows[window]).bitmap,
					       (s->windows[window]).length);
					rdata_tail += (s->windows[window]).length;
				} else {
					WARN(ZS_RDATA_OVERFLOW);
					p--; {goto st316;}
				}
			}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1467;
tr1321:
	{ window_add_bit(KNOT_RRTYPE_CDNSKEY, s); }
	{
		s->line_counter++;
	}
	{
		for (uint16_t window = 0; window <= s->last_window; window++) {
			if ((s->windows[window]).length > 0) {
				if (rdata_tail + 2 + (s->windows[window]).length <= rdata_stop)
				{
					// Window number.
					*rdata_tail = (uint8_t)window;
					rdata_tail += 1;
					// Bitmap length.
					*rdata_tail = (s->windows[window]).length;
					rdata_tail += 1;
					// Copying bitmap.
					memcpy(rdata_tail,
					       (s->windows[window]).bitmap,
					       (s->windows[window]).length);
					rdata_tail += (s->windows[window]).length;
				} else {
					WARN(ZS_RDATA_OVERFLOW);
					p--; {goto st316;}
				}
			}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1467;
tr1329:
	{ window_add_bit(KNOT_RRTYPE_CDS, s); }
	{
		s->line_counter++;
	}
	{
		for (uint16_t window = 0; window <= s->last_window; window++) {
			if ((s->windows[window]).length > 0) {
				if (rdata_tail + 2 + (s->windows[window]).length <= rdata_stop)
				{
					// Window number.
					*rdata_tail = (uint8_t)window;
					rdata_tail += 1;
					// Bitmap length.
					*rdata_tail = (s->windows[window]).length;
					rdata_tail += 1;
					// Copying bitmap.
					memcpy(rdata_tail,
					       (s->windows[window]).bitmap,
					       (s->windows[window]).length);
					rdata_tail += (s->windows[window]).length;
				} else {
					WARN(ZS_RDATA_OVERFLOW);
					p--; {goto st316;}
				}
			}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1467;
tr1339:
	{ window_add_bit(KNOT_RRTYPE_CERT, s); }
	{
		s->line_counter++;
	}
	{
		for (uint16_t window = 0; window <= s->last_window; window++) {
			if ((s->windows[window]).length > 0) {
				if (rdata_tail + 2 + (s->windows[window]).length <= rdata_stop)
				{
					// Window number.
					*rdata_tail = (uint8_t)window;
					rdata_tail += 1;
					// Bitmap length.
					*rdata_tail = (s->windows[window]).length;
					rdata_tail += 1;
					// Copying bitmap.
					memcpy(rdata_tail,
					       (s->windows[window]).bitmap,
					       (s->windows[window]).length);
					rdata_tail += (s->windows[window]).length;
				} else {
					WARN(ZS_RDATA_OVERFLOW);
					p--; {goto st316;}
				}
			}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1467;
tr1350:
	{ window_add_bit(KNOT_RRTYPE_CNAME, s); }
	{
		s->line_counter++;
	}
	{
		for (uint16_t window = 0; window <= s->last_window; window++) {
			if ((s->windows[window]).length > 0) {
				if (rdata_tail + 2 + (s->windows[window]).length <= rdata_stop)
				{
					// Window number.
					*rdata_tail = (uint8_t)window;
					rdata_tail += 1;
					// Bitmap length.
					*rdata_tail = (s->windows[window]).length;
					rdata_tail += 1;
					// Copying bitmap.
					memcpy(rdata_tail,
					       (s->windows[window]).bitmap,
					       (s->windows[window]).length);
					rdata_tail += (s->windows[window]).length;
				} else {
					WARN(ZS_RDATA_OVERFLOW);
					p--; {goto st316;}
				}
			}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1467;
tr1361:
	{ window_add_bit(KNOT_RRTYPE_CSYNC, s); }
	{
		s->line_counter++;
	}
	{
		for (uint16_t window = 0; window <= s->last_window; window++) {
			if ((s->windows[window]).length > 0) {
				if (rdata_tail + 2 + (s->windows[window]).length <= rdata_stop)
				{
					// Window number.
					*rdata_tail = (uint8_t)window;
					rdata_tail += 1;
					// Bitmap length.
					*rdata_tail = (s->windows[window]).length;
					rdata_tail += 1;
					// Copying bitmap.
					memcpy(rdata_tail,
					       (s->windows[window]).bitmap,
					       (s->windows[window]).length);
					rdata_tail += (s->windows[window]).length;
				} else {
					WARN(ZS_RDATA_OVERFLOW);
					p--; {goto st316;}
				}
			}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1467;
tr1375:
	{ window_add_bit(KNOT_RRTYPE_DHCID, s); }
	{
		s->line_counter++;
	}
	{
		for (uint16_t window = 0; window <= s->last_window; window++) {
			if ((s->windows[window]).length > 0) {
				if (rdata_tail + 2 + (s->windows[window]).length <= rdata_stop)
				{
					// Window number.
					*rdata_tail = (uint8_t)window;
					rdata_tail += 1;
					// Bitmap length.
					*rdata_tail = (s->windows[window]).length;
					rdata_tail += 1;
					// Copying bitmap.
					memcpy(rdata_tail,
					       (s->windows[window]).bitmap,
					       (s->windows[window]).length);
					rdata_tail += (s->windows[window]).length;
				} else {
					WARN(ZS_RDATA_OVERFLOW);
					p--; {goto st316;}
				}
			}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1467;
tr1387:
	{ window_add_bit(KNOT_RRTYPE_DNAME, s); }
	{
		s->line_counter++;
	}
	{
		for (uint16_t window = 0; window <= s->last_window; window++) {
			if ((s->windows[window]).length > 0) {
				if (rdata_tail + 2 + (s->windows[window]).length <= rdata_stop)
				{
					// Window number.
					*rdata_tail = (uint8_t)window;
					rdata_tail += 1;
					// Bitmap length.
					*rdata_tail = (s->windows[window]).length;
					rdata_tail += 1;
					// Copying bitmap.
					memcpy(rdata_tail,
					       (s->windows[window]).bitmap,
					       (s->windows[window]).length);
					rdata_tail += (s->windows[window]).length;
				} else {
					WARN(ZS_RDATA_OVERFLOW);
					p--; {goto st316;}
				}
			}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1467;
tr1398:
	{ window_add_bit(KNOT_RRTYPE_DNSKEY, s); }
	{
		s->line_counter++;
	}
	{
		for (uint16_t window = 0; window <= s->last_window; window++) {
			if ((s->windows[window]).length > 0) {
				if (rdata_tail + 2 + (s->windows[window]).length <= rdata_stop)
				{
					// Window number.
					*rdata_tail = (uint8_t)window;
					rdata_tail += 1;
					// Bitmap length.
					*rdata_tail = (s->windows[window]).length;
					rdata_tail += 1;
					// Copying bitmap.
					memcpy(rdata_tail,
					       (s->windows[window]).bitmap,
					       (s->windows[window]).length);
					rdata_tail += (s->windows[window]).length;
				} else {
					WARN(ZS_RDATA_OVERFLOW);
					p--; {goto st316;}
				}
			}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1467;
tr1406:
	{ window_add_bit(KNOT_RRTYPE_DS, s); }
	{
		s->line_counter++;
	}
	{
		for (uint16_t window = 0; window <= s->last_window; window++) {
			if ((s->windows[window]).length > 0) {
				if (rdata_tail + 2 + (s->windows[window]).length <= rdata_stop)
				{
					// Window number.
					*rdata_tail = (uint8_t)window;
					rdata_tail += 1;
					// Bitmap length.
					*rdata_tail = (s->windows[window]).length;
					rdata_tail += 1;
					// Copying bitmap.
					memcpy(rdata_tail,
					       (s->windows[window]).bitmap,
					       (s->windows[window]).length);
					rdata_tail += (s->windows[window]).length;
				} else {
					WARN(ZS_RDATA_OVERFLOW);
					p--; {goto st316;}
				}
			}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1467;
tr1419:
	{ window_add_bit(KNOT_RRTYPE_EUI48, s); }
	{
		s->line_counter++;
	}
	{
		for (uint16_t window = 0; window <= s->last_window; window++) {
			if ((s->windows[window]).length > 0) {
				if (rdata_tail + 2 + (s->windows[window]).length <= rdata_stop)
				{
					// Window number.
					*rdata_tail = (uint8_t)window;
					rdata_tail += 1;
					// Bitmap length.
					*rdata_tail = (s->windows[window]).length;
					rdata_tail += 1;
					// Copying bitmap.
					memcpy(rdata_tail,
					       (s->windows[window]).bitmap,
					       (s->windows[window]).length);
					rdata_tail += (s->windows[window]).length;
				} else {
					WARN(ZS_RDATA_OVERFLOW);
					p--; {goto st316;}
				}
			}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1467;
tr1428:
	{ window_add_bit(KNOT_RRTYPE_EUI64, s); }
	{
		s->line_counter++;
	}
	{
		for (uint16_t window = 0; window <= s->last_window; window++) {
			if ((s->windows[window]).length > 0) {
				if (rdata_tail + 2 + (s->windows[window]).length <= rdata_stop)
				{
					// Window number.
					*rdata_tail = (uint8_t)window;
					rdata_tail += 1;
					// Bitmap length.
					*rdata_tail = (s->windows[window]).length;
					rdata_tail += 1;
					// Copying bitmap.
					memcpy(rdata_tail,
					       (s->windows[window]).bitmap,
					       (s->windows[window]).length);
					rdata_tail += (s->windows[window]).length;
				} else {
					WARN(ZS_RDATA_OVERFLOW);
					p--; {goto st316;}
				}
			}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1467;
tr1441:
	{ window_add_bit(KNOT_RRTYPE_HINFO, s); }
	{
		s->line_counter++;
	}
	{
		for (uint16_t window = 0; window <= s->last_window; window++) {
			if ((s->windows[window]).length > 0) {
				if (rdata_tail + 2 + (s->windows[window]).length <= rdata_stop)
				{
					// Window number.
					*rdata_tail = (uint8_t)window;
					rdata_tail += 1;
					// Bitmap length.
					*rdata_tail = (s->windows[window]).length;
					rdata_tail += 1;
					// Copying bitmap.
					memcpy(rdata_tail,
					       (s->windows[window]).bitmap,
					       (s->windows[window]).length);
					rdata_tail += (s->windows[window]).length;
				} else {
					WARN(ZS_RDATA_OVERFLOW);
					p--; {goto st316;}
				}
			}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1467;
tr1452:
	{ window_add_bit(KNOT_RRTYPE_HTTPS, s); }
	{
		s->line_counter++;
	}
	{
		for (uint16_t window = 0; window <= s->last_window; window++) {
			if ((s->windows[window]).length > 0) {
				if (rdata_tail + 2 + (s->windows[window]).length <= rdata_stop)
				{
					// Window number.
					*rdata_tail = (uint8_t)window;
					rdata_tail += 1;
					// Bitmap length.
					*rdata_tail = (s->windows[window]).length;
					rdata_tail += 1;
					// Copying bitmap.
					memcpy(rdata_tail,
					       (s->windows[window]).bitmap,
					       (s->windows[window]).length);
					rdata_tail += (s->windows[window]).length;
				} else {
					WARN(ZS_RDATA_OVERFLOW);
					p--; {goto st316;}
				}
			}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1467;
tr1467:
	{ window_add_bit(KNOT_RRTYPE_IPSECKEY, s); }
	{
		s->line_counter++;
	}
	{
		for (uint16_t window = 0; window <= s->last_window; window++) {
			if ((s->windows[window]).length > 0) {
				if (rdata_tail + 2 + (s->windows[window]).length <= rdata_stop)
				{
					// Window number.
					*rdata_tail = (uint8_t)window;
					rdata_tail += 1;
					// Bitmap length.
					*rdata_tail = (s->windows[window]).length;
					rdata_tail += 1;
					// Copying bitmap.
					memcpy(rdata_tail,
					       (s->windows[window]).bitmap,
					       (s->windows[window]).length);
					rdata_tail += (s->windows[window]).length;
				} else {
					WARN(ZS_RDATA_OVERFLOW);
					p--; {goto st316;}
				}
			}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1467;
tr1478:
	{ window_add_bit(KNOT_RRTYPE_KEY, s); }
	{
		s->line_counter++;
	}
	{
		for (uint16_t window = 0; window <= s->last_window; window++) {
			if ((s->windows[window]).length > 0) {
				if (rdata_tail + 2 + (s->windows[window]).length <= rdata_stop)
				{
					// Window number.
					*rdata_tail = (uint8_t)window;
					rdata_tail += 1;
					// Bitmap length.
					*rdata_tail = (s->windows[window]).length;
					rdata_tail += 1;
					// Copying bitmap.
					memcpy(rdata_tail,
					       (s->windows[window]).bitmap,
					       (s->windows[window]).length);
					rdata_tail += (s->windows[window]).length;
				} else {
					WARN(ZS_RDATA_OVERFLOW);
					p--; {goto st316;}
				}
			}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1467;
tr1486:
	{ window_add_bit(KNOT_RRTYPE_KX, s); }
	{
		s->line_counter++;
	}
	{
		for (uint16_t window = 0; window <= s->last_window; window++) {
			if ((s->windows[window]).length > 0) {
				if (rdata_tail + 2 + (s->windows[window]).length <= rdata_stop)
				{
					// Window number.
					*rdata_tail = (uint8_t)window;
					rdata_tail += 1;
					// Bitmap length.
					*rdata_tail = (s->windows[window]).length;
					rdata_tail += 1;
					// Copying bitmap.
					memcpy(rdata_tail,
					       (s->windows[window]).bitmap,
					       (s->windows[window]).length);
					rdata_tail += (s->windows[window]).length;
				} else {
					WARN(ZS_RDATA_OVERFLOW);
					p--; {goto st316;}
				}
			}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1467;
tr1499:
	{ window_add_bit(KNOT_RRTYPE_L32, s); }
	{
		s->line_counter++;
	}
	{
		for (uint16_t window = 0; window <= s->last_window; window++) {
			if ((s->windows[window]).length > 0) {
				if (rdata_tail + 2 + (s->windows[window]).length <= rdata_stop)
				{
					// Window number.
					*rdata_tail = (uint8_t)window;
					rdata_tail += 1;
					// Bitmap length.
					*rdata_tail = (s->windows[window]).length;
					rdata_tail += 1;
					// Copying bitmap.
					memcpy(rdata_tail,
					       (s->windows[window]).bitmap,
					       (s->windows[window]).length);
					rdata_tail += (s->windows[window]).length;
				} else {
					WARN(ZS_RDATA_OVERFLOW);
					p--; {goto st316;}
				}
			}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1467;
tr1508:
	{ window_add_bit(KNOT_RRTYPE_L64, s); }
	{
		s->line_counter++;
	}
	{
		for (uint16_t window = 0; window <= s->last_window; window++) {
			if ((s->windows[window]).length > 0) {
				if (rdata_tail + 2 + (s->windows[window]).length <= rdata_stop)
				{
					// Window number.
					*rdata_tail = (uint8_t)window;
					rdata_tail += 1;
					// Bitmap length.
					*rdata_tail = (s->windows[window]).length;
					rdata_tail += 1;
					// Copying bitmap.
					memcpy(rdata_tail,
					       (s->windows[window]).bitmap,
					       (s->windows[window]).length);
					rdata_tail += (s->windows[window]).length;
				} else {
					WARN(ZS_RDATA_OVERFLOW);
					p--; {goto st316;}
				}
			}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1467;
tr1517:
	{ window_add_bit(KNOT_RRTYPE_LOC, s); }
	{
		s->line_counter++;
	}
	{
		for (uint16_t window = 0; window <= s->last_window; window++) {
			if ((s->windows[window]).length > 0) {
				if (rdata_tail + 2 + (s->windows[window]).length <= rdata_stop)
				{
					// Window number.
					*rdata_tail = (uint8_t)window;
					rdata_tail += 1;
					// Bitmap length.
					*rdata_tail = (s->windows[window]).length;
					rdata_tail += 1;
					// Copying bitmap.
					memcpy(rdata_tail,
					       (s->windows[window]).bitmap,
					       (s->windows[window]).length);
					rdata_tail += (s->windows[window]).length;
				} else {
					WARN(ZS_RDATA_OVERFLOW);
					p--; {goto st316;}
				}
			}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1467;
tr1525:
	{ window_add_bit(KNOT_RRTYPE_LP, s); }
	{
		s->line_counter++;
	}
	{
		for (uint16_t window = 0; window <= s->last_window; window++) {
			if ((s->windows[window]).length > 0) {
				if (rdata_tail + 2 + (s->windows[window]).length <= rdata_stop)
				{
					// Window number.
					*rdata_tail = (uint8_t)window;
					rdata_tail += 1;
					// Bitmap length.
					*rdata_tail = (s->windows[window]).length;
					rdata_tail += 1;
					// Copying bitmap.
					memcpy(rdata_tail,
					       (s->windows[window]).bitmap,
					       (s->windows[window]).length);
					rdata_tail += (s->windows[window]).length;
				} else {
					WARN(ZS_RDATA_OVERFLOW);
					p--; {goto st316;}
				}
			}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1467;
tr1538:
	{ window_add_bit(KNOT_RRTYPE_MINFO, s); }
	{
		s->line_counter++;
	}
	{
		for (uint16_t window = 0; window <= s->last_window; window++) {
			if ((s->windows[window]).length > 0) {
				if (rdata_tail + 2 + (s->windows[window]).length <= rdata_stop)
				{
					// Window number.
					*rdata_tail = (uint8_t)window;
					rdata_tail += 1;
					// Bitmap length.
					*rdata_tail = (s->windows[window]).length;
					rdata_tail += 1;
					// Copying bitmap.
					memcpy(rdata_tail,
					       (s->windows[window]).bitmap,
					       (s->windows[window]).length);
					rdata_tail += (s->windows[window]).length;
				} else {
					WARN(ZS_RDATA_OVERFLOW);
					p--; {goto st316;}
				}
			}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1467;
tr1546:
	{ window_add_bit(KNOT_RRTYPE_MX, s); }
	{
		s->line_counter++;
	}
	{
		for (uint16_t window = 0; window <= s->last_window; window++) {
			if ((s->windows[window]).length > 0) {
				if (rdata_tail + 2 + (s->windows[window]).length <= rdata_stop)
				{
					// Window number.
					*rdata_tail = (uint8_t)window;
					rdata_tail += 1;
					// Bitmap length.
					*rdata_tail = (s->windows[window]).length;
					rdata_tail += 1;
					// Copying bitmap.
					memcpy(rdata_tail,
					       (s->windows[window]).bitmap,
					       (s->windows[window]).length);
					rdata_tail += (s->windows[window]).length;
				} else {
					WARN(ZS_RDATA_OVERFLOW);
					p--; {goto st316;}
				}
			}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1467;
tr1560:
	{ window_add_bit(KNOT_RRTYPE_NAPTR, s); }
	{
		s->line_counter++;
	}
	{
		for (uint16_t window = 0; window <= s->last_window; window++) {
			if ((s->windows[window]).length > 0) {
				if (rdata_tail + 2 + (s->windows[window]).length <= rdata_stop)
				{
					// Window number.
					*rdata_tail = (uint8_t)window;
					rdata_tail += 1;
					// Bitmap length.
					*rdata_tail = (s->windows[window]).length;
					rdata_tail += 1;
					// Copying bitmap.
					memcpy(rdata_tail,
					       (s->windows[window]).bitmap,
					       (s->windows[window]).length);
					rdata_tail += (s->windows[window]).length;
				} else {
					WARN(ZS_RDATA_OVERFLOW);
					p--; {goto st316;}
				}
			}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1467;
tr1569:
	{ window_add_bit(KNOT_RRTYPE_NID, s); }
	{
		s->line_counter++;
	}
	{
		for (uint16_t window = 0; window <= s->last_window; window++) {
			if ((s->windows[window]).length > 0) {
				if (rdata_tail + 2 + (s->windows[window]).length <= rdata_stop)
				{
					// Window number.
					*rdata_tail = (uint8_t)window;
					rdata_tail += 1;
					// Bitmap length.
					*rdata_tail = (s->windows[window]).length;
					rdata_tail += 1;
					// Copying bitmap.
					memcpy(rdata_tail,
					       (s->windows[window]).bitmap,
					       (s->windows[window]).length);
					rdata_tail += (s->windows[window]).length;
				} else {
					WARN(ZS_RDATA_OVERFLOW);
					p--; {goto st316;}
				}
			}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1467;
tr1578:
	{ window_add_bit(KNOT_RRTYPE_NS, s); }
	{
		s->line_counter++;
	}
	{
		for (uint16_t window = 0; window <= s->last_window; window++) {
			if ((s->windows[window]).length > 0) {
				if (rdata_tail + 2 + (s->windows[window]).length <= rdata_stop)
				{
					// Window number.
					*rdata_tail = (uint8_t)window;
					rdata_tail += 1;
					// Bitmap length.
					*rdata_tail = (s->windows[window]).length;
					rdata_tail += 1;
					// Copying bitmap.
					memcpy(rdata_tail,
					       (s->windows[window]).bitmap,
					       (s->windows[window]).length);
					rdata_tail += (s->windows[window]).length;
				} else {
					WARN(ZS_RDATA_OVERFLOW);
					p--; {goto st316;}
				}
			}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1467;
tr1588:
	{ window_add_bit(KNOT_RRTYPE_NSEC, s); }
	{
		s->line_counter++;
	}
	{
		for (uint16_t window = 0; window <= s->last_window; window++) {
			if ((s->windows[window]).length > 0) {
				if (rdata_tail + 2 + (s->windows[window]).length <= rdata_stop)
				{
					// Window number.
					*rdata_tail = (uint8_t)window;
					rdata_tail += 1;
					// Bitmap length.
					*rdata_tail = (s->windows[window]).length;
					rdata_tail += 1;
					// Copying bitmap.
					memcpy(rdata_tail,
					       (s->windows[window]).bitmap,
					       (s->windows[window]).length);
					rdata_tail += (s->windows[window]).length;
				} else {
					WARN(ZS_RDATA_OVERFLOW);
					p--; {goto st316;}
				}
			}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1467;
tr1597:
	{ window_add_bit(KNOT_RRTYPE_NSEC3, s); }
	{
		s->line_counter++;
	}
	{
		for (uint16_t window = 0; window <= s->last_window; window++) {
			if ((s->windows[window]).length > 0) {
				if (rdata_tail + 2 + (s->windows[window]).length <= rdata_stop)
				{
					// Window number.
					*rdata_tail = (uint8_t)window;
					rdata_tail += 1;
					// Bitmap length.
					*rdata_tail = (s->windows[window]).length;
					rdata_tail += 1;
					// Copying bitmap.
					memcpy(rdata_tail,
					       (s->windows[window]).bitmap,
					       (s->windows[window]).length);
					rdata_tail += (s->windows[window]).length;
				} else {
					WARN(ZS_RDATA_OVERFLOW);
					p--; {goto st316;}
				}
			}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1467;
tr1609:
	{ window_add_bit(KNOT_RRTYPE_NSEC3PARAM, s); }
	{
		s->line_counter++;
	}
	{
		for (uint16_t window = 0; window <= s->last_window; window++) {
			if ((s->windows[window]).length > 0) {
				if (rdata_tail + 2 + (s->windows[window]).length <= rdata_stop)
				{
					// Window number.
					*rdata_tail = (uint8_t)window;
					rdata_tail += 1;
					// Bitmap length.
					*rdata_tail = (s->windows[window]).length;
					rdata_tail += 1;
					// Copying bitmap.
					memcpy(rdata_tail,
					       (s->windows[window]).bitmap,
					       (s->windows[window]).length);
					rdata_tail += (s->windows[window]).length;
				} else {
					WARN(ZS_RDATA_OVERFLOW);
					p--; {goto st316;}
				}
			}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1467;
tr1626:
	{ window_add_bit(KNOT_RRTYPE_OPENPGPKEY, s); }
	{
		s->line_counter++;
	}
	{
		for (uint16_t window = 0; window <= s->last_window; window++) {
			if ((s->windows[window]).length > 0) {
				if (rdata_tail + 2 + (s->windows[window]).length <= rdata_stop)
				{
					// Window number.
					*rdata_tail = (uint8_t)window;
					rdata_tail += 1;
					// Bitmap length.
					*rdata_tail = (s->windows[window]).length;
					rdata_tail += 1;
					// Copying bitmap.
					memcpy(rdata_tail,
					       (s->windows[window]).bitmap,
					       (s->windows[window]).length);
					rdata_tail += (s->windows[window]).length;
				} else {
					WARN(ZS_RDATA_OVERFLOW);
					p--; {goto st316;}
				}
			}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1467;
tr1636:
	{ window_add_bit(KNOT_RRTYPE_PTR, s); }
	{
		s->line_counter++;
	}
	{
		for (uint16_t window = 0; window <= s->last_window; window++) {
			if ((s->windows[window]).length > 0) {
				if (rdata_tail + 2 + (s->windows[window]).length <= rdata_stop)
				{
					// Window number.
					*rdata_tail = (uint8_t)window;
					rdata_tail += 1;
					// Bitmap length.
					*rdata_tail = (s->windows[window]).length;
					rdata_tail += 1;
					// Copying bitmap.
					memcpy(rdata_tail,
					       (s->windows[window]).bitmap,
					       (s->windows[window]).length);
					rdata_tail += (s->windows[window]).length;
				} else {
					WARN(ZS_RDATA_OVERFLOW);
					p--; {goto st316;}
				}
			}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1467;
tr1647:
	{ window_add_bit(KNOT_RRTYPE_RP, s); }
	{
		s->line_counter++;
	}
	{
		for (uint16_t window = 0; window <= s->last_window; window++) {
			if ((s->windows[window]).length > 0) {
				if (rdata_tail + 2 + (s->windows[window]).length <= rdata_stop)
				{
					// Window number.
					*rdata_tail = (uint8_t)window;
					rdata_tail += 1;
					// Bitmap length.
					*rdata_tail = (s->windows[window]).length;
					rdata_tail += 1;
					// Copying bitmap.
					memcpy(rdata_tail,
					       (s->windows[window]).bitmap,
					       (s->windows[window]).length);
					rdata_tail += (s->windows[window]).length;
				} else {
					WARN(ZS_RDATA_OVERFLOW);
					p--; {goto st316;}
				}
			}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1467;
tr1658:
	{ window_add_bit(KNOT_RRTYPE_RRSIG, s); }
	{
		s->line_counter++;
	}
	{
		for (uint16_t window = 0; window <= s->last_window; window++) {
			if ((s->windows[window]).length > 0) {
				if (rdata_tail + 2 + (s->windows[window]).length <= rdata_stop)
				{
					// Window number.
					*rdata_tail = (uint8_t)window;
					rdata_tail += 1;
					// Bitmap length.
					*rdata_tail = (s->windows[window]).length;
					rdata_tail += 1;
					// Copying bitmap.
					memcpy(rdata_tail,
					       (s->windows[window]).bitmap,
					       (s->windows[window]).length);
					rdata_tail += (s->windows[window]).length;
				} else {
					WARN(ZS_RDATA_OVERFLOW);
					p--; {goto st316;}
				}
			}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1467;
tr1666:
	{ window_add_bit(KNOT_RRTYPE_RT, s); }
	{
		s->line_counter++;
	}
	{
		for (uint16_t window = 0; window <= s->last_window; window++) {
			if ((s->windows[window]).length > 0) {
				if (rdata_tail + 2 + (s->windows[window]).length <= rdata_stop)
				{
					// Window number.
					*rdata_tail = (uint8_t)window;
					rdata_tail += 1;
					// Bitmap length.
					*rdata_tail = (s->windows[window]).length;
					rdata_tail += 1;
					// Copying bitmap.
					memcpy(rdata_tail,
					       (s->windows[window]).bitmap,
					       (s->windows[window]).length);
					rdata_tail += (s->windows[window]).length;
				} else {
					WARN(ZS_RDATA_OVERFLOW);
					p--; {goto st316;}
				}
			}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1467;
tr1684:
	{ window_add_bit(KNOT_RRTYPE_SMIMEA, s); }
	{
		s->line_counter++;
	}
	{
		for (uint16_t window = 0; window <= s->last_window; window++) {
			if ((s->windows[window]).length > 0) {
				if (rdata_tail + 2 + (s->windows[window]).length <= rdata_stop)
				{
					// Window number.
					*rdata_tail = (uint8_t)window;
					rdata_tail += 1;
					// Bitmap length.
					*rdata_tail = (s->windows[window]).length;
					rdata_tail += 1;
					// Copying bitmap.
					memcpy(rdata_tail,
					       (s->windows[window]).bitmap,
					       (s->windows[window]).length);
					rdata_tail += (s->windows[window]).length;
				} else {
					WARN(ZS_RDATA_OVERFLOW);
					p--; {goto st316;}
				}
			}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1467;
tr1693:
	{ window_add_bit(KNOT_RRTYPE_SOA, s); }
	{
		s->line_counter++;
	}
	{
		for (uint16_t window = 0; window <= s->last_window; window++) {
			if ((s->windows[window]).length > 0) {
				if (rdata_tail + 2 + (s->windows[window]).length <= rdata_stop)
				{
					// Window number.
					*rdata_tail = (uint8_t)window;
					rdata_tail += 1;
					// Bitmap length.
					*rdata_tail = (s->windows[window]).length;
					rdata_tail += 1;
					// Copying bitmap.
					memcpy(rdata_tail,
					       (s->windows[window]).bitmap,
					       (s->windows[window]).length);
					rdata_tail += (s->windows[window]).length;
				} else {
					WARN(ZS_RDATA_OVERFLOW);
					p--; {goto st316;}
				}
			}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1467;
tr1702:
	{ window_add_bit(KNOT_RRTYPE_SPF, s); }
	{
		s->line_counter++;
	}
	{
		for (uint16_t window = 0; window <= s->last_window; window++) {
			if ((s->windows[window]).length > 0) {
				if (rdata_tail + 2 + (s->windows[window]).length <= rdata_stop)
				{
					// Window number.
					*rdata_tail = (uint8_t)window;
					rdata_tail += 1;
					// Bitmap length.
					*rdata_tail = (s->windows[window]).length;
					rdata_tail += 1;
					// Copying bitmap.
					memcpy(rdata_tail,
					       (s->windows[window]).bitmap,
					       (s->windows[window]).length);
					rdata_tail += (s->windows[window]).length;
				} else {
					WARN(ZS_RDATA_OVERFLOW);
					p--; {goto st316;}
				}
			}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1467;
tr1711:
	{ window_add_bit(KNOT_RRTYPE_SRV, s); }
	{
		s->line_counter++;
	}
	{
		for (uint16_t window = 0; window <= s->last_window; window++) {
			if ((s->windows[window]).length > 0) {
				if (rdata_tail + 2 + (s->windows[window]).length <= rdata_stop)
				{
					// Window number.
					*rdata_tail = (uint8_t)window;
					rdata_tail += 1;
					// Bitmap length.
					*rdata_tail = (s->windows[window]).length;
					rdata_tail += 1;
					// Copying bitmap.
					memcpy(rdata_tail,
					       (s->windows[window]).bitmap,
					       (s->windows[window]).length);
					rdata_tail += (s->windows[window]).length;
				} else {
					WARN(ZS_RDATA_OVERFLOW);
					p--; {goto st316;}
				}
			}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1467;
tr1722:
	{ window_add_bit(KNOT_RRTYPE_SSHFP, s); }
	{
		s->line_counter++;
	}
	{
		for (uint16_t window = 0; window <= s->last_window; window++) {
			if ((s->windows[window]).length > 0) {
				if (rdata_tail + 2 + (s->windows[window]).length <= rdata_stop)
				{
					// Window number.
					*rdata_tail = (uint8_t)window;
					rdata_tail += 1;
					// Bitmap length.
					*rdata_tail = (s->windows[window]).length;
					rdata_tail += 1;
					// Copying bitmap.
					memcpy(rdata_tail,
					       (s->windows[window]).bitmap,
					       (s->windows[window]).length);
					rdata_tail += (s->windows[window]).length;
				} else {
					WARN(ZS_RDATA_OVERFLOW);
					p--; {goto st316;}
				}
			}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1467;
tr1732:
	{ window_add_bit(KNOT_RRTYPE_SVCB, s); }
	{
		s->line_counter++;
	}
	{
		for (uint16_t window = 0; window <= s->last_window; window++) {
			if ((s->windows[window]).length > 0) {
				if (rdata_tail + 2 + (s->windows[window]).length <= rdata_stop)
				{
					// Window number.
					*rdata_tail = (uint8_t)window;
					rdata_tail += 1;
					// Bitmap length.
					*rdata_tail = (s->windows[window]).length;
					rdata_tail += 1;
					// Copying bitmap.
					memcpy(rdata_tail,
					       (s->windows[window]).bitmap,
					       (s->windows[window]).length);
					rdata_tail += (s->windows[window]).length;
				} else {
					WARN(ZS_RDATA_OVERFLOW);
					p--; {goto st316;}
				}
			}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1467;
tr1745:
	{ window_add_bit(KNOT_RRTYPE_TLSA, s); }
	{
		s->line_counter++;
	}
	{
		for (uint16_t window = 0; window <= s->last_window; window++) {
			if ((s->windows[window]).length > 0) {
				if (rdata_tail + 2 + (s->windows[window]).length <= rdata_stop)
				{
					// Window number.
					*rdata_tail = (uint8_t)window;
					rdata_tail += 1;
					// Bitmap length.
					*rdata_tail = (s->windows[window]).length;
					rdata_tail += 1;
					// Copying bitmap.
					memcpy(rdata_tail,
					       (s->windows[window]).bitmap,
					       (s->windows[window]).length);
					rdata_tail += (s->windows[window]).length;
				} else {
					WARN(ZS_RDATA_OVERFLOW);
					p--; {goto st316;}
				}
			}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1467;
tr1754:
	{ window_add_bit(KNOT_RRTYPE_TXT, s); }
	{
		s->line_counter++;
	}
	{
		for (uint16_t window = 0; window <= s->last_window; window++) {
			if ((s->windows[window]).length > 0) {
				if (rdata_tail + 2 + (s->windows[window]).length <= rdata_stop)
				{
					// Window number.
					*rdata_tail = (uint8_t)window;
					rdata_tail += 1;
					// Bitmap length.
					*rdata_tail = (s->windows[window]).length;
					rdata_tail += 1;
					// Copying bitmap.
					memcpy(rdata_tail,
					       (s->windows[window]).bitmap,
					       (s->windows[window]).length);
					rdata_tail += (s->windows[window]).length;
				} else {
					WARN(ZS_RDATA_OVERFLOW);
					p--; {goto st316;}
				}
			}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1467;
tr1766:
	{
		if (s->number64 <= UINT16_MAX) {
			window_add_bit(s->number64, s);
		} else {
			WARN(ZS_NUMBER16_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		s->line_counter++;
	}
	{
		for (uint16_t window = 0; window <= s->last_window; window++) {
			if ((s->windows[window]).length > 0) {
				if (rdata_tail + 2 + (s->windows[window]).length <= rdata_stop)
				{
					// Window number.
					*rdata_tail = (uint8_t)window;
					rdata_tail += 1;
					// Bitmap length.
					*rdata_tail = (s->windows[window]).length;
					rdata_tail += 1;
					// Copying bitmap.
					memcpy(rdata_tail,
					       (s->windows[window]).bitmap,
					       (s->windows[window]).length);
					rdata_tail += (s->windows[window]).length;
				} else {
					WARN(ZS_RDATA_OVERFLOW);
					p--; {goto st316;}
				}
			}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1467;
tr1776:
	{ window_add_bit(KNOT_RRTYPE_URI, s); }
	{
		s->line_counter++;
	}
	{
		for (uint16_t window = 0; window <= s->last_window; window++) {
			if ((s->windows[window]).length > 0) {
				if (rdata_tail + 2 + (s->windows[window]).length <= rdata_stop)
				{
					// Window number.
					*rdata_tail = (uint8_t)window;
					rdata_tail += 1;
					// Bitmap length.
					*rdata_tail = (s->windows[window]).length;
					rdata_tail += 1;
					// Copying bitmap.
					memcpy(rdata_tail,
					       (s->windows[window]).bitmap,
					       (s->windows[window]).length);
					rdata_tail += (s->windows[window]).length;
				} else {
					WARN(ZS_RDATA_OVERFLOW);
					p--; {goto st316;}
				}
			}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1467;
tr1789:
	{ window_add_bit(KNOT_RRTYPE_WALLET, s); }
	{
		s->line_counter++;
	}
	{
		for (uint16_t window = 0; window <= s->last_window; window++) {
			if ((s->windows[window]).length > 0) {
				if (rdata_tail + 2 + (s->windows[window]).length <= rdata_stop)
				{
					// Window number.
					*rdata_tail = (uint8_t)window;
					rdata_tail += 1;
					// Bitmap length.
					*rdata_tail = (s->windows[window]).length;
					rdata_tail += 1;
					// Copying bitmap.
					memcpy(rdata_tail,
					       (s->windows[window]).bitmap,
					       (s->windows[window]).length);
					rdata_tail += (s->windows[window]).length;
				} else {
					WARN(ZS_RDATA_OVERFLOW);
					p--; {goto st316;}
				}
			}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1467;
tr1802:
	{ window_add_bit(KNOT_RRTYPE_ZONEMD, s); }
	{
		s->line_counter++;
	}
	{
		for (uint16_t window = 0; window <= s->last_window; window++) {
			if ((s->windows[window]).length > 0) {
				if (rdata_tail + 2 + (s->windows[window]).length <= rdata_stop)
				{
					// Window number.
					*rdata_tail = (uint8_t)window;
					rdata_tail += 1;
					// Bitmap length.
					*rdata_tail = (s->windows[window]).length;
					rdata_tail += 1;
					// Copying bitmap.
					memcpy(rdata_tail,
					       (s->windows[window]).bitmap,
					       (s->windows[window]).length);
					rdata_tail += (s->windows[window]).length;
				} else {
					WARN(ZS_RDATA_OVERFLOW);
					p--; {goto st316;}
				}
			}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1467;
tr1813:
	{ window_add_bit(KNOT_RRTYPE_AFSDB, s); }
	{
		s->line_counter++;
	}
	{
		for (uint16_t window = 0; window <= s->last_window; window++) {
			if ((s->windows[window]).length > 0) {
				if (rdata_tail + 2 + (s->windows[window]).length <= rdata_stop)
				{
					// Window number.
					*rdata_tail = (uint8_t)window;
					rdata_tail += 1;
					// Bitmap length.
					*rdata_tail = (s->windows[window]).length;
					rdata_tail += 1;
					// Copying bitmap.
					memcpy(rdata_tail,
					       (s->windows[window]).bitmap,
					       (s->windows[window]).length);
					rdata_tail += (s->windows[window]).length;
				} else {
					WARN(ZS_RDATA_OVERFLOW);
					p--; {goto st316;}
				}
			}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1467;
tr1822:
	{ window_add_bit(KNOT_RRTYPE_APL, s); }
	{
		s->line_counter++;
	}
	{
		for (uint16_t window = 0; window <= s->last_window; window++) {
			if ((s->windows[window]).length > 0) {
				if (rdata_tail + 2 + (s->windows[window]).length <= rdata_stop)
				{
					// Window number.
					*rdata_tail = (uint8_t)window;
					rdata_tail += 1;
					// Bitmap length.
					*rdata_tail = (s->windows[window]).length;
					rdata_tail += 1;
					// Copying bitmap.
					memcpy(rdata_tail,
					       (s->windows[window]).bitmap,
					       (s->windows[window]).length);
					rdata_tail += (s->windows[window]).length;
				} else {
					WARN(ZS_RDATA_OVERFLOW);
					p--; {goto st316;}
				}
			}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1467;
st1467:
	if ( ++p == pe )
		goto _test_eof1467;
case 1467:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(2688 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 !s->multiline  ) _widec += 512;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(2688 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		if (
 !s->multiline  ) _widec += 512;
	}
	switch( _widec ) {
		case 9: goto st386;
		case 32: goto st386;
		case 40: goto tr1247;
		case 41: goto tr1248;
		case 65: goto st387;
		case 67: goto st392;
		case 68: goto st413;
		case 69: goto st427;
		case 72: goto st434;
		case 73: goto st443;
		case 75: goto st451;
		case 76: goto st455;
		case 77: goto st463;
		case 78: goto st469;
		case 79: goto st485;
		case 80: goto st495;
		case 82: goto st498;
		case 83: goto st505;
		case 84: goto st524;
		case 85: goto st534;
		case 87: goto st537;
		case 90: goto st543;
		case 97: goto st387;
		case 99: goto st392;
		case 100: goto st413;
		case 101: goto st427;
		case 104: goto st434;
		case 105: goto st443;
		case 107: goto st451;
		case 108: goto st455;
		case 109: goto st463;
		case 110: goto st469;
		case 111: goto st485;
		case 112: goto st495;
		case 114: goto st498;
		case 115: goto st505;
		case 116: goto st524;
		case 117: goto st534;
		case 119: goto st537;
		case 122: goto st543;
		case 3082: goto tr1267;
		case 3131: goto tr1268;
		case 3338: goto tr1269;
		case 3387: goto tr1269;
		case 3594: goto tr1270;
		case 3643: goto tr1271;
	}
	goto tr1237;
st392:
	if ( ++p == pe )
		goto _test_eof392;
case 392:
	switch( (*p) ) {
		case 65: goto st393;
		case 68: goto st395;
		case 69: goto st402;
		case 78: goto st405;
		case 83: goto st409;
		case 97: goto st393;
		case 100: goto st395;
		case 101: goto st402;
		case 110: goto st405;
		case 115: goto st409;
	}
	goto tr1237;
st393:
	if ( ++p == pe )
		goto _test_eof393;
case 393:
	switch( (*p) ) {
		case 65: goto st394;
		case 97: goto st394;
	}
	goto tr1237;
st394:
	if ( ++p == pe )
		goto _test_eof394;
case 394:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(2688 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 !s->multiline  ) _widec += 512;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(2688 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		if (
 !s->multiline  ) _widec += 512;
	}
	switch( _widec ) {
		case 9: goto tr1301;
		case 32: goto tr1301;
		case 40: goto tr1302;
		case 41: goto tr1303;
		case 3082: goto tr1304;
		case 3131: goto tr1305;
		case 3338: goto tr1306;
		case 3387: goto tr1306;
		case 3594: goto tr1307;
		case 3643: goto tr1308;
	}
	goto tr1237;
tr1245:
	{
		memset(s->windows, 0, sizeof(s->windows));
		s->last_window = -1;
	}
	{
		s->buffer_length = 0;
	}
	{
		for (uint16_t window = 0; window <= s->last_window; window++) {
			if ((s->windows[window]).length > 0) {
				if (rdata_tail + 2 + (s->windows[window]).length <= rdata_stop)
				{
					// Window number.
					*rdata_tail = (uint8_t)window;
					rdata_tail += 1;
					// Bitmap length.
					*rdata_tail = (s->windows[window]).length;
					rdata_tail += 1;
					// Copying bitmap.
					memcpy(rdata_tail,
					       (s->windows[window]).bitmap,
					       (s->windows[window]).length);
					rdata_tail += (s->windows[window]).length;
				} else {
					WARN(ZS_RDATA_OVERFLOW);
					p--; {goto st316;}
				}
			}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1468;
tr1271:
	{
		s->buffer_length = 0;
	}
	{
		for (uint16_t window = 0; window <= s->last_window; window++) {
			if ((s->windows[window]).length > 0) {
				if (rdata_tail + 2 + (s->windows[window]).length <= rdata_stop)
				{
					// Window number.
					*rdata_tail = (uint8_t)window;
					rdata_tail += 1;
					// Bitmap length.
					*rdata_tail = (s->windows[window]).length;
					rdata_tail += 1;
					// Copying bitmap.
					memcpy(rdata_tail,
					       (s->windows[window]).bitmap,
					       (s->windows[window]).length);
					rdata_tail += (s->windows[window]).length;
				} else {
					WARN(ZS_RDATA_OVERFLOW);
					p--; {goto st316;}
				}
			}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1468;
tr1282:
	{ window_add_bit(KNOT_RRTYPE_A, s); }
	{
		s->buffer_length = 0;
	}
	{
		for (uint16_t window = 0; window <= s->last_window; window++) {
			if ((s->windows[window]).length > 0) {
				if (rdata_tail + 2 + (s->windows[window]).length <= rdata_stop)
				{
					// Window number.
					*rdata_tail = (uint8_t)window;
					rdata_tail += 1;
					// Bitmap length.
					*rdata_tail = (s->windows[window]).length;
					rdata_tail += 1;
					// Copying bitmap.
					memcpy(rdata_tail,
					       (s->windows[window]).bitmap,
					       (s->windows[window]).length);
					rdata_tail += (s->windows[window]).length;
				} else {
					WARN(ZS_RDATA_OVERFLOW);
					p--; {goto st316;}
				}
			}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1468;
tr1292:
	{ window_add_bit(KNOT_RRTYPE_AAAA, s); }
	{
		s->buffer_length = 0;
	}
	{
		for (uint16_t window = 0; window <= s->last_window; window++) {
			if ((s->windows[window]).length > 0) {
				if (rdata_tail + 2 + (s->windows[window]).length <= rdata_stop)
				{
					// Window number.
					*rdata_tail = (uint8_t)window;
					rdata_tail += 1;
					// Bitmap length.
					*rdata_tail = (s->windows[window]).length;
					rdata_tail += 1;
					// Copying bitmap.
					memcpy(rdata_tail,
					       (s->windows[window]).bitmap,
					       (s->windows[window]).length);
					rdata_tail += (s->windows[window]).length;
				} else {
					WARN(ZS_RDATA_OVERFLOW);
					p--; {goto st316;}
				}
			}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1468;
tr1308:
	{ window_add_bit(KNOT_RRTYPE_CAA, s); }
	{
		s->buffer_length = 0;
	}
	{
		for (uint16_t window = 0; window <= s->last_window; window++) {
			if ((s->windows[window]).length > 0) {
				if (rdata_tail + 2 + (s->windows[window]).length <= rdata_stop)
				{
					// Window number.
					*rdata_tail = (uint8_t)window;
					rdata_tail += 1;
					// Bitmap length.
					*rdata_tail = (s->windows[window]).length;
					rdata_tail += 1;
					// Copying bitmap.
					memcpy(rdata_tail,
					       (s->windows[window]).bitmap,
					       (s->windows[window]).length);
					rdata_tail += (s->windows[window]).length;
				} else {
					WARN(ZS_RDATA_OVERFLOW);
					p--; {goto st316;}
				}
			}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1468;
tr1322:
	{ window_add_bit(KNOT_RRTYPE_CDNSKEY, s); }
	{
		s->buffer_length = 0;
	}
	{
		for (uint16_t window = 0; window <= s->last_window; window++) {
			if ((s->windows[window]).length > 0) {
				if (rdata_tail + 2 + (s->windows[window]).length <= rdata_stop)
				{
					// Window number.
					*rdata_tail = (uint8_t)window;
					rdata_tail += 1;
					// Bitmap length.
					*rdata_tail = (s->windows[window]).length;
					rdata_tail += 1;
					// Copying bitmap.
					memcpy(rdata_tail,
					       (s->windows[window]).bitmap,
					       (s->windows[window]).length);
					rdata_tail += (s->windows[window]).length;
				} else {
					WARN(ZS_RDATA_OVERFLOW);
					p--; {goto st316;}
				}
			}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1468;
tr1330:
	{ window_add_bit(KNOT_RRTYPE_CDS, s); }
	{
		s->buffer_length = 0;
	}
	{
		for (uint16_t window = 0; window <= s->last_window; window++) {
			if ((s->windows[window]).length > 0) {
				if (rdata_tail + 2 + (s->windows[window]).length <= rdata_stop)
				{
					// Window number.
					*rdata_tail = (uint8_t)window;
					rdata_tail += 1;
					// Bitmap length.
					*rdata_tail = (s->windows[window]).length;
					rdata_tail += 1;
					// Copying bitmap.
					memcpy(rdata_tail,
					       (s->windows[window]).bitmap,
					       (s->windows[window]).length);
					rdata_tail += (s->windows[window]).length;
				} else {
					WARN(ZS_RDATA_OVERFLOW);
					p--; {goto st316;}
				}
			}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1468;
tr1340:
	{ window_add_bit(KNOT_RRTYPE_CERT, s); }
	{
		s->buffer_length = 0;
	}
	{
		for (uint16_t window = 0; window <= s->last_window; window++) {
			if ((s->windows[window]).length > 0) {
				if (rdata_tail + 2 + (s->windows[window]).length <= rdata_stop)
				{
					// Window number.
					*rdata_tail = (uint8_t)window;
					rdata_tail += 1;
					// Bitmap length.
					*rdata_tail = (s->windows[window]).length;
					rdata_tail += 1;
					// Copying bitmap.
					memcpy(rdata_tail,
					       (s->windows[window]).bitmap,
					       (s->windows[window]).length);
					rdata_tail += (s->windows[window]).length;
				} else {
					WARN(ZS_RDATA_OVERFLOW);
					p--; {goto st316;}
				}
			}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1468;
tr1351:
	{ window_add_bit(KNOT_RRTYPE_CNAME, s); }
	{
		s->buffer_length = 0;
	}
	{
		for (uint16_t window = 0; window <= s->last_window; window++) {
			if ((s->windows[window]).length > 0) {
				if (rdata_tail + 2 + (s->windows[window]).length <= rdata_stop)
				{
					// Window number.
					*rdata_tail = (uint8_t)window;
					rdata_tail += 1;
					// Bitmap length.
					*rdata_tail = (s->windows[window]).length;
					rdata_tail += 1;
					// Copying bitmap.
					memcpy(rdata_tail,
					       (s->windows[window]).bitmap,
					       (s->windows[window]).length);
					rdata_tail += (s->windows[window]).length;
				} else {
					WARN(ZS_RDATA_OVERFLOW);
					p--; {goto st316;}
				}
			}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1468;
tr1362:
	{ window_add_bit(KNOT_RRTYPE_CSYNC, s); }
	{
		s->buffer_length = 0;
	}
	{
		for (uint16_t window = 0; window <= s->last_window; window++) {
			if ((s->windows[window]).length > 0) {
				if (rdata_tail + 2 + (s->windows[window]).length <= rdata_stop)
				{
					// Window number.
					*rdata_tail = (uint8_t)window;
					rdata_tail += 1;
					// Bitmap length.
					*rdata_tail = (s->windows[window]).length;
					rdata_tail += 1;
					// Copying bitmap.
					memcpy(rdata_tail,
					       (s->windows[window]).bitmap,
					       (s->windows[window]).length);
					rdata_tail += (s->windows[window]).length;
				} else {
					WARN(ZS_RDATA_OVERFLOW);
					p--; {goto st316;}
				}
			}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1468;
tr1376:
	{ window_add_bit(KNOT_RRTYPE_DHCID, s); }
	{
		s->buffer_length = 0;
	}
	{
		for (uint16_t window = 0; window <= s->last_window; window++) {
			if ((s->windows[window]).length > 0) {
				if (rdata_tail + 2 + (s->windows[window]).length <= rdata_stop)
				{
					// Window number.
					*rdata_tail = (uint8_t)window;
					rdata_tail += 1;
					// Bitmap length.
					*rdata_tail = (s->windows[window]).length;
					rdata_tail += 1;
					// Copying bitmap.
					memcpy(rdata_tail,
					       (s->windows[window]).bitmap,
					       (s->windows[window]).length);
					rdata_tail += (s->windows[window]).length;
				} else {
					WARN(ZS_RDATA_OVERFLOW);
					p--; {goto st316;}
				}
			}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1468;
tr1388:
	{ window_add_bit(KNOT_RRTYPE_DNAME, s); }
	{
		s->buffer_length = 0;
	}
	{
		for (uint16_t window = 0; window <= s->last_window; window++) {
			if ((s->windows[window]).length > 0) {
				if (rdata_tail + 2 + (s->windows[window]).length <= rdata_stop)
				{
					// Window number.
					*rdata_tail = (uint8_t)window;
					rdata_tail += 1;
					// Bitmap length.
					*rdata_tail = (s->windows[window]).length;
					rdata_tail += 1;
					// Copying bitmap.
					memcpy(rdata_tail,
					       (s->windows[window]).bitmap,
					       (s->windows[window]).length);
					rdata_tail += (s->windows[window]).length;
				} else {
					WARN(ZS_RDATA_OVERFLOW);
					p--; {goto st316;}
				}
			}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1468;
tr1399:
	{ window_add_bit(KNOT_RRTYPE_DNSKEY, s); }
	{
		s->buffer_length = 0;
	}
	{
		for (uint16_t window = 0; window <= s->last_window; window++) {
			if ((s->windows[window]).length > 0) {
				if (rdata_tail + 2 + (s->windows[window]).length <= rdata_stop)
				{
					// Window number.
					*rdata_tail = (uint8_t)window;
					rdata_tail += 1;
					// Bitmap length.
					*rdata_tail = (s->windows[window]).length;
					rdata_tail += 1;
					// Copying bitmap.
					memcpy(rdata_tail,
					       (s->windows[window]).bitmap,
					       (s->windows[window]).length);
					rdata_tail += (s->windows[window]).length;
				} else {
					WARN(ZS_RDATA_OVERFLOW);
					p--; {goto st316;}
				}
			}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1468;
tr1407:
	{ window_add_bit(KNOT_RRTYPE_DS, s); }
	{
		s->buffer_length = 0;
	}
	{
		for (uint16_t window = 0; window <= s->last_window; window++) {
			if ((s->windows[window]).length > 0) {
				if (rdata_tail + 2 + (s->windows[window]).length <= rdata_stop)
				{
					// Window number.
					*rdata_tail = (uint8_t)window;
					rdata_tail += 1;
					// Bitmap length.
					*rdata_tail = (s->windows[window]).length;
					rdata_tail += 1;
					// Copying bitmap.
					memcpy(rdata_tail,
					       (s->windows[window]).bitmap,
					       (s->windows[window]).length);
					rdata_tail += (s->windows[window]).length;
				} else {
					WARN(ZS_RDATA_OVERFLOW);
					p--; {goto st316;}
				}
			}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1468;
tr1420:
	{ window_add_bit(KNOT_RRTYPE_EUI48, s); }
	{
		s->buffer_length = 0;
	}
	{
		for (uint16_t window = 0; window <= s->last_window; window++) {
			if ((s->windows[window]).length > 0) {
				if (rdata_tail + 2 + (s->windows[window]).length <= rdata_stop)
				{
					// Window number.
					*rdata_tail = (uint8_t)window;
					rdata_tail += 1;
					// Bitmap length.
					*rdata_tail = (s->windows[window]).length;
					rdata_tail += 1;
					// Copying bitmap.
					memcpy(rdata_tail,
					       (s->windows[window]).bitmap,
					       (s->windows[window]).length);
					rdata_tail += (s->windows[window]).length;
				} else {
					WARN(ZS_RDATA_OVERFLOW);
					p--; {goto st316;}
				}
			}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1468;
tr1429:
	{ window_add_bit(KNOT_RRTYPE_EUI64, s); }
	{
		s->buffer_length = 0;
	}
	{
		for (uint16_t window = 0; window <= s->last_window; window++) {
			if ((s->windows[window]).length > 0) {
				if (rdata_tail + 2 + (s->windows[window]).length <= rdata_stop)
				{
					// Window number.
					*rdata_tail = (uint8_t)window;
					rdata_tail += 1;
					// Bitmap length.
					*rdata_tail = (s->windows[window]).length;
					rdata_tail += 1;
					// Copying bitmap.
					memcpy(rdata_tail,
					       (s->windows[window]).bitmap,
					       (s->windows[window]).length);
					rdata_tail += (s->windows[window]).length;
				} else {
					WARN(ZS_RDATA_OVERFLOW);
					p--; {goto st316;}
				}
			}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1468;
tr1442:
	{ window_add_bit(KNOT_RRTYPE_HINFO, s); }
	{
		s->buffer_length = 0;
	}
	{
		for (uint16_t window = 0; window <= s->last_window; window++) {
			if ((s->windows[window]).length > 0) {
				if (rdata_tail + 2 + (s->windows[window]).length <= rdata_stop)
				{
					// Window number.
					*rdata_tail = (uint8_t)window;
					rdata_tail += 1;
					// Bitmap length.
					*rdata_tail = (s->windows[window]).length;
					rdata_tail += 1;
					// Copying bitmap.
					memcpy(rdata_tail,
					       (s->windows[window]).bitmap,
					       (s->windows[window]).length);
					rdata_tail += (s->windows[window]).length;
				} else {
					WARN(ZS_RDATA_OVERFLOW);
					p--; {goto st316;}
				}
			}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1468;
tr1453:
	{ window_add_bit(KNOT_RRTYPE_HTTPS, s); }
	{
		s->buffer_length = 0;
	}
	{
		for (uint16_t window = 0; window <= s->last_window; window++) {
			if ((s->windows[window]).length > 0) {
				if (rdata_tail + 2 + (s->windows[window]).length <= rdata_stop)
				{
					// Window number.
					*rdata_tail = (uint8_t)window;
					rdata_tail += 1;
					// Bitmap length.
					*rdata_tail = (s->windows[window]).length;
					rdata_tail += 1;
					// Copying bitmap.
					memcpy(rdata_tail,
					       (s->windows[window]).bitmap,
					       (s->windows[window]).length);
					rdata_tail += (s->windows[window]).length;
				} else {
					WARN(ZS_RDATA_OVERFLOW);
					p--; {goto st316;}
				}
			}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1468;
tr1468:
	{ window_add_bit(KNOT_RRTYPE_IPSECKEY, s); }
	{
		s->buffer_length = 0;
	}
	{
		for (uint16_t window = 0; window <= s->last_window; window++) {
			if ((s->windows[window]).length > 0) {
				if (rdata_tail + 2 + (s->windows[window]).length <= rdata_stop)
				{
					// Window number.
					*rdata_tail = (uint8_t)window;
					rdata_tail += 1;
					// Bitmap length.
					*rdata_tail = (s->windows[window]).length;
					rdata_tail += 1;
					// Copying bitmap.
					memcpy(rdata_tail,
					       (s->windows[window]).bitmap,
					       (s->windows[window]).length);
					rdata_tail += (s->windows[window]).length;
				} else {
					WARN(ZS_RDATA_OVERFLOW);
					p--; {goto st316;}
				}
			}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1468;
tr1479:
	{ window_add_bit(KNOT_RRTYPE_KEY, s); }
	{
		s->buffer_length = 0;
	}
	{
		for (uint16_t window = 0; window <= s->last_window; window++) {
			if ((s->windows[window]).length > 0) {
				if (rdata_tail + 2 + (s->windows[window]).length <= rdata_stop)
				{
					// Window number.
					*rdata_tail = (uint8_t)window;
					rdata_tail += 1;
					// Bitmap length.
					*rdata_tail = (s->windows[window]).length;
					rdata_tail += 1;
					// Copying bitmap.
					memcpy(rdata_tail,
					       (s->windows[window]).bitmap,
					       (s->windows[window]).length);
					rdata_tail += (s->windows[window]).length;
				} else {
					WARN(ZS_RDATA_OVERFLOW);
					p--; {goto st316;}
				}
			}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1468;
tr1487:
	{ window_add_bit(KNOT_RRTYPE_KX, s); }
	{
		s->buffer_length = 0;
	}
	{
		for (uint16_t window = 0; window <= s->last_window; window++) {
			if ((s->windows[window]).length > 0) {
				if (rdata_tail + 2 + (s->windows[window]).length <= rdata_stop)
				{
					// Window number.
					*rdata_tail = (uint8_t)window;
					rdata_tail += 1;
					// Bitmap length.
					*rdata_tail = (s->windows[window]).length;
					rdata_tail += 1;
					// Copying bitmap.
					memcpy(rdata_tail,
					       (s->windows[window]).bitmap,
					       (s->windows[window]).length);
					rdata_tail += (s->windows[window]).length;
				} else {
					WARN(ZS_RDATA_OVERFLOW);
					p--; {goto st316;}
				}
			}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1468;
tr1500:
	{ window_add_bit(KNOT_RRTYPE_L32, s); }
	{
		s->buffer_length = 0;
	}
	{
		for (uint16_t window = 0; window <= s->last_window; window++) {
			if ((s->windows[window]).length > 0) {
				if (rdata_tail + 2 + (s->windows[window]).length <= rdata_stop)
				{
					// Window number.
					*rdata_tail = (uint8_t)window;
					rdata_tail += 1;
					// Bitmap length.
					*rdata_tail = (s->windows[window]).length;
					rdata_tail += 1;
					// Copying bitmap.
					memcpy(rdata_tail,
					       (s->windows[window]).bitmap,
					       (s->windows[window]).length);
					rdata_tail += (s->windows[window]).length;
				} else {
					WARN(ZS_RDATA_OVERFLOW);
					p--; {goto st316;}
				}
			}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1468;
tr1509:
	{ window_add_bit(KNOT_RRTYPE_L64, s); }
	{
		s->buffer_length = 0;
	}
	{
		for (uint16_t window = 0; window <= s->last_window; window++) {
			if ((s->windows[window]).length > 0) {
				if (rdata_tail + 2 + (s->windows[window]).length <= rdata_stop)
				{
					// Window number.
					*rdata_tail = (uint8_t)window;
					rdata_tail += 1;
					// Bitmap length.
					*rdata_tail = (s->windows[window]).length;
					rdata_tail += 1;
					// Copying bitmap.
					memcpy(rdata_tail,
					       (s->windows[window]).bitmap,
					       (s->windows[window]).length);
					rdata_tail += (s->windows[window]).length;
				} else {
					WARN(ZS_RDATA_OVERFLOW);
					p--; {goto st316;}
				}
			}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1468;
tr1518:
	{ window_add_bit(KNOT_RRTYPE_LOC, s); }
	{
		s->buffer_length = 0;
	}
	{
		for (uint16_t window = 0; window <= s->last_window; window++) {
			if ((s->windows[window]).length > 0) {
				if (rdata_tail + 2 + (s->windows[window]).length <= rdata_stop)
				{
					// Window number.
					*rdata_tail = (uint8_t)window;
					rdata_tail += 1;
					// Bitmap length.
					*rdata_tail = (s->windows[window]).length;
					rdata_tail += 1;
					// Copying bitmap.
					memcpy(rdata_tail,
					       (s->windows[window]).bitmap,
					       (s->windows[window]).length);
					rdata_tail += (s->windows[window]).length;
				} else {
					WARN(ZS_RDATA_OVERFLOW);
					p--; {goto st316;}
				}
			}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1468;
tr1526:
	{ window_add_bit(KNOT_RRTYPE_LP, s); }
	{
		s->buffer_length = 0;
	}
	{
		for (uint16_t window = 0; window <= s->last_window; window++) {
			if ((s->windows[window]).length > 0) {
				if (rdata_tail + 2 + (s->windows[window]).length <= rdata_stop)
				{
					// Window number.
					*rdata_tail = (uint8_t)window;
					rdata_tail += 1;
					// Bitmap length.
					*rdata_tail = (s->windows[window]).length;
					rdata_tail += 1;
					// Copying bitmap.
					memcpy(rdata_tail,
					       (s->windows[window]).bitmap,
					       (s->windows[window]).length);
					rdata_tail += (s->windows[window]).length;
				} else {
					WARN(ZS_RDATA_OVERFLOW);
					p--; {goto st316;}
				}
			}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1468;
tr1539:
	{ window_add_bit(KNOT_RRTYPE_MINFO, s); }
	{
		s->buffer_length = 0;
	}
	{
		for (uint16_t window = 0; window <= s->last_window; window++) {
			if ((s->windows[window]).length > 0) {
				if (rdata_tail + 2 + (s->windows[window]).length <= rdata_stop)
				{
					// Window number.
					*rdata_tail = (uint8_t)window;
					rdata_tail += 1;
					// Bitmap length.
					*rdata_tail = (s->windows[window]).length;
					rdata_tail += 1;
					// Copying bitmap.
					memcpy(rdata_tail,
					       (s->windows[window]).bitmap,
					       (s->windows[window]).length);
					rdata_tail += (s->windows[window]).length;
				} else {
					WARN(ZS_RDATA_OVERFLOW);
					p--; {goto st316;}
				}
			}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1468;
tr1547:
	{ window_add_bit(KNOT_RRTYPE_MX, s); }
	{
		s->buffer_length = 0;
	}
	{
		for (uint16_t window = 0; window <= s->last_window; window++) {
			if ((s->windows[window]).length > 0) {
				if (rdata_tail + 2 + (s->windows[window]).length <= rdata_stop)
				{
					// Window number.
					*rdata_tail = (uint8_t)window;
					rdata_tail += 1;
					// Bitmap length.
					*rdata_tail = (s->windows[window]).length;
					rdata_tail += 1;
					// Copying bitmap.
					memcpy(rdata_tail,
					       (s->windows[window]).bitmap,
					       (s->windows[window]).length);
					rdata_tail += (s->windows[window]).length;
				} else {
					WARN(ZS_RDATA_OVERFLOW);
					p--; {goto st316;}
				}
			}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1468;
tr1561:
	{ window_add_bit(KNOT_RRTYPE_NAPTR, s); }
	{
		s->buffer_length = 0;
	}
	{
		for (uint16_t window = 0; window <= s->last_window; window++) {
			if ((s->windows[window]).length > 0) {
				if (rdata_tail + 2 + (s->windows[window]).length <= rdata_stop)
				{
					// Window number.
					*rdata_tail = (uint8_t)window;
					rdata_tail += 1;
					// Bitmap length.
					*rdata_tail = (s->windows[window]).length;
					rdata_tail += 1;
					// Copying bitmap.
					memcpy(rdata_tail,
					       (s->windows[window]).bitmap,
					       (s->windows[window]).length);
					rdata_tail += (s->windows[window]).length;
				} else {
					WARN(ZS_RDATA_OVERFLOW);
					p--; {goto st316;}
				}
			}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1468;
tr1570:
	{ window_add_bit(KNOT_RRTYPE_NID, s); }
	{
		s->buffer_length = 0;
	}
	{
		for (uint16_t window = 0; window <= s->last_window; window++) {
			if ((s->windows[window]).length > 0) {
				if (rdata_tail + 2 + (s->windows[window]).length <= rdata_stop)
				{
					// Window number.
					*rdata_tail = (uint8_t)window;
					rdata_tail += 1;
					// Bitmap length.
					*rdata_tail = (s->windows[window]).length;
					rdata_tail += 1;
					// Copying bitmap.
					memcpy(rdata_tail,
					       (s->windows[window]).bitmap,
					       (s->windows[window]).length);
					rdata_tail += (s->windows[window]).length;
				} else {
					WARN(ZS_RDATA_OVERFLOW);
					p--; {goto st316;}
				}
			}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1468;
tr1579:
	{ window_add_bit(KNOT_RRTYPE_NS, s); }
	{
		s->buffer_length = 0;
	}
	{
		for (uint16_t window = 0; window <= s->last_window; window++) {
			if ((s->windows[window]).length > 0) {
				if (rdata_tail + 2 + (s->windows[window]).length <= rdata_stop)
				{
					// Window number.
					*rdata_tail = (uint8_t)window;
					rdata_tail += 1;
					// Bitmap length.
					*rdata_tail = (s->windows[window]).length;
					rdata_tail += 1;
					// Copying bitmap.
					memcpy(rdata_tail,
					       (s->windows[window]).bitmap,
					       (s->windows[window]).length);
					rdata_tail += (s->windows[window]).length;
				} else {
					WARN(ZS_RDATA_OVERFLOW);
					p--; {goto st316;}
				}
			}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1468;
tr1589:
	{ window_add_bit(KNOT_RRTYPE_NSEC, s); }
	{
		s->buffer_length = 0;
	}
	{
		for (uint16_t window = 0; window <= s->last_window; window++) {
			if ((s->windows[window]).length > 0) {
				if (rdata_tail + 2 + (s->windows[window]).length <= rdata_stop)
				{
					// Window number.
					*rdata_tail = (uint8_t)window;
					rdata_tail += 1;
					// Bitmap length.
					*rdata_tail = (s->windows[window]).length;
					rdata_tail += 1;
					// Copying bitmap.
					memcpy(rdata_tail,
					       (s->windows[window]).bitmap,
					       (s->windows[window]).length);
					rdata_tail += (s->windows[window]).length;
				} else {
					WARN(ZS_RDATA_OVERFLOW);
					p--; {goto st316;}
				}
			}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1468;
tr1598:
	{ window_add_bit(KNOT_RRTYPE_NSEC3, s); }
	{
		s->buffer_length = 0;
	}
	{
		for (uint16_t window = 0; window <= s->last_window; window++) {
			if ((s->windows[window]).length > 0) {
				if (rdata_tail + 2 + (s->windows[window]).length <= rdata_stop)
				{
					// Window number.
					*rdata_tail = (uint8_t)window;
					rdata_tail += 1;
					// Bitmap length.
					*rdata_tail = (s->windows[window]).length;
					rdata_tail += 1;
					// Copying bitmap.
					memcpy(rdata_tail,
					       (s->windows[window]).bitmap,
					       (s->windows[window]).length);
					rdata_tail += (s->windows[window]).length;
				} else {
					WARN(ZS_RDATA_OVERFLOW);
					p--; {goto st316;}
				}
			}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1468;
tr1610:
	{ window_add_bit(KNOT_RRTYPE_NSEC3PARAM, s); }
	{
		s->buffer_length = 0;
	}
	{
		for (uint16_t window = 0; window <= s->last_window; window++) {
			if ((s->windows[window]).length > 0) {
				if (rdata_tail + 2 + (s->windows[window]).length <= rdata_stop)
				{
					// Window number.
					*rdata_tail = (uint8_t)window;
					rdata_tail += 1;
					// Bitmap length.
					*rdata_tail = (s->windows[window]).length;
					rdata_tail += 1;
					// Copying bitmap.
					memcpy(rdata_tail,
					       (s->windows[window]).bitmap,
					       (s->windows[window]).length);
					rdata_tail += (s->windows[window]).length;
				} else {
					WARN(ZS_RDATA_OVERFLOW);
					p--; {goto st316;}
				}
			}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1468;
tr1627:
	{ window_add_bit(KNOT_RRTYPE_OPENPGPKEY, s); }
	{
		s->buffer_length = 0;
	}
	{
		for (uint16_t window = 0; window <= s->last_window; window++) {
			if ((s->windows[window]).length > 0) {
				if (rdata_tail + 2 + (s->windows[window]).length <= rdata_stop)
				{
					// Window number.
					*rdata_tail = (uint8_t)window;
					rdata_tail += 1;
					// Bitmap length.
					*rdata_tail = (s->windows[window]).length;
					rdata_tail += 1;
					// Copying bitmap.
					memcpy(rdata_tail,
					       (s->windows[window]).bitmap,
					       (s->windows[window]).length);
					rdata_tail += (s->windows[window]).length;
				} else {
					WARN(ZS_RDATA_OVERFLOW);
					p--; {goto st316;}
				}
			}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1468;
tr1637:
	{ window_add_bit(KNOT_RRTYPE_PTR, s); }
	{
		s->buffer_length = 0;
	}
	{
		for (uint16_t window = 0; window <= s->last_window; window++) {
			if ((s->windows[window]).length > 0) {
				if (rdata_tail + 2 + (s->windows[window]).length <= rdata_stop)
				{
					// Window number.
					*rdata_tail = (uint8_t)window;
					rdata_tail += 1;
					// Bitmap length.
					*rdata_tail = (s->windows[window]).length;
					rdata_tail += 1;
					// Copying bitmap.
					memcpy(rdata_tail,
					       (s->windows[window]).bitmap,
					       (s->windows[window]).length);
					rdata_tail += (s->windows[window]).length;
				} else {
					WARN(ZS_RDATA_OVERFLOW);
					p--; {goto st316;}
				}
			}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1468;
tr1648:
	{ window_add_bit(KNOT_RRTYPE_RP, s); }
	{
		s->buffer_length = 0;
	}
	{
		for (uint16_t window = 0; window <= s->last_window; window++) {
			if ((s->windows[window]).length > 0) {
				if (rdata_tail + 2 + (s->windows[window]).length <= rdata_stop)
				{
					// Window number.
					*rdata_tail = (uint8_t)window;
					rdata_tail += 1;
					// Bitmap length.
					*rdata_tail = (s->windows[window]).length;
					rdata_tail += 1;
					// Copying bitmap.
					memcpy(rdata_tail,
					       (s->windows[window]).bitmap,
					       (s->windows[window]).length);
					rdata_tail += (s->windows[window]).length;
				} else {
					WARN(ZS_RDATA_OVERFLOW);
					p--; {goto st316;}
				}
			}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1468;
tr1659:
	{ window_add_bit(KNOT_RRTYPE_RRSIG, s); }
	{
		s->buffer_length = 0;
	}
	{
		for (uint16_t window = 0; window <= s->last_window; window++) {
			if ((s->windows[window]).length > 0) {
				if (rdata_tail + 2 + (s->windows[window]).length <= rdata_stop)
				{
					// Window number.
					*rdata_tail = (uint8_t)window;
					rdata_tail += 1;
					// Bitmap length.
					*rdata_tail = (s->windows[window]).length;
					rdata_tail += 1;
					// Copying bitmap.
					memcpy(rdata_tail,
					       (s->windows[window]).bitmap,
					       (s->windows[window]).length);
					rdata_tail += (s->windows[window]).length;
				} else {
					WARN(ZS_RDATA_OVERFLOW);
					p--; {goto st316;}
				}
			}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1468;
tr1667:
	{ window_add_bit(KNOT_RRTYPE_RT, s); }
	{
		s->buffer_length = 0;
	}
	{
		for (uint16_t window = 0; window <= s->last_window; window++) {
			if ((s->windows[window]).length > 0) {
				if (rdata_tail + 2 + (s->windows[window]).length <= rdata_stop)
				{
					// Window number.
					*rdata_tail = (uint8_t)window;
					rdata_tail += 1;
					// Bitmap length.
					*rdata_tail = (s->windows[window]).length;
					rdata_tail += 1;
					// Copying bitmap.
					memcpy(rdata_tail,
					       (s->windows[window]).bitmap,
					       (s->windows[window]).length);
					rdata_tail += (s->windows[window]).length;
				} else {
					WARN(ZS_RDATA_OVERFLOW);
					p--; {goto st316;}
				}
			}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1468;
tr1685:
	{ window_add_bit(KNOT_RRTYPE_SMIMEA, s); }
	{
		s->buffer_length = 0;
	}
	{
		for (uint16_t window = 0; window <= s->last_window; window++) {
			if ((s->windows[window]).length > 0) {
				if (rdata_tail + 2 + (s->windows[window]).length <= rdata_stop)
				{
					// Window number.
					*rdata_tail = (uint8_t)window;
					rdata_tail += 1;
					// Bitmap length.
					*rdata_tail = (s->windows[window]).length;
					rdata_tail += 1;
					// Copying bitmap.
					memcpy(rdata_tail,
					       (s->windows[window]).bitmap,
					       (s->windows[window]).length);
					rdata_tail += (s->windows[window]).length;
				} else {
					WARN(ZS_RDATA_OVERFLOW);
					p--; {goto st316;}
				}
			}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1468;
tr1694:
	{ window_add_bit(KNOT_RRTYPE_SOA, s); }
	{
		s->buffer_length = 0;
	}
	{
		for (uint16_t window = 0; window <= s->last_window; window++) {
			if ((s->windows[window]).length > 0) {
				if (rdata_tail + 2 + (s->windows[window]).length <= rdata_stop)
				{
					// Window number.
					*rdata_tail = (uint8_t)window;
					rdata_tail += 1;
					// Bitmap length.
					*rdata_tail = (s->windows[window]).length;
					rdata_tail += 1;
					// Copying bitmap.
					memcpy(rdata_tail,
					       (s->windows[window]).bitmap,
					       (s->windows[window]).length);
					rdata_tail += (s->windows[window]).length;
				} else {
					WARN(ZS_RDATA_OVERFLOW);
					p--; {goto st316;}
				}
			}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1468;
tr1703:
	{ window_add_bit(KNOT_RRTYPE_SPF, s); }
	{
		s->buffer_length = 0;
	}
	{
		for (uint16_t window = 0; window <= s->last_window; window++) {
			if ((s->windows[window]).length > 0) {
				if (rdata_tail + 2 + (s->windows[window]).length <= rdata_stop)
				{
					// Window number.
					*rdata_tail = (uint8_t)window;
					rdata_tail += 1;
					// Bitmap length.
					*rdata_tail = (s->windows[window]).length;
					rdata_tail += 1;
					// Copying bitmap.
					memcpy(rdata_tail,
					       (s->windows[window]).bitmap,
					       (s->windows[window]).length);
					rdata_tail += (s->windows[window]).length;
				} else {
					WARN(ZS_RDATA_OVERFLOW);
					p--; {goto st316;}
				}
			}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1468;
tr1712:
	{ window_add_bit(KNOT_RRTYPE_SRV, s); }
	{
		s->buffer_length = 0;
	}
	{
		for (uint16_t window = 0; window <= s->last_window; window++) {
			if ((s->windows[window]).length > 0) {
				if (rdata_tail + 2 + (s->windows[window]).length <= rdata_stop)
				{
					// Window number.
					*rdata_tail = (uint8_t)window;
					rdata_tail += 1;
					// Bitmap length.
					*rdata_tail = (s->windows[window]).length;
					rdata_tail += 1;
					// Copying bitmap.
					memcpy(rdata_tail,
					       (s->windows[window]).bitmap,
					       (s->windows[window]).length);
					rdata_tail += (s->windows[window]).length;
				} else {
					WARN(ZS_RDATA_OVERFLOW);
					p--; {goto st316;}
				}
			}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1468;
tr1723:
	{ window_add_bit(KNOT_RRTYPE_SSHFP, s); }
	{
		s->buffer_length = 0;
	}
	{
		for (uint16_t window = 0; window <= s->last_window; window++) {
			if ((s->windows[window]).length > 0) {
				if (rdata_tail + 2 + (s->windows[window]).length <= rdata_stop)
				{
					// Window number.
					*rdata_tail = (uint8_t)window;
					rdata_tail += 1;
					// Bitmap length.
					*rdata_tail = (s->windows[window]).length;
					rdata_tail += 1;
					// Copying bitmap.
					memcpy(rdata_tail,
					       (s->windows[window]).bitmap,
					       (s->windows[window]).length);
					rdata_tail += (s->windows[window]).length;
				} else {
					WARN(ZS_RDATA_OVERFLOW);
					p--; {goto st316;}
				}
			}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1468;
tr1733:
	{ window_add_bit(KNOT_RRTYPE_SVCB, s); }
	{
		s->buffer_length = 0;
	}
	{
		for (uint16_t window = 0; window <= s->last_window; window++) {
			if ((s->windows[window]).length > 0) {
				if (rdata_tail + 2 + (s->windows[window]).length <= rdata_stop)
				{
					// Window number.
					*rdata_tail = (uint8_t)window;
					rdata_tail += 1;
					// Bitmap length.
					*rdata_tail = (s->windows[window]).length;
					rdata_tail += 1;
					// Copying bitmap.
					memcpy(rdata_tail,
					       (s->windows[window]).bitmap,
					       (s->windows[window]).length);
					rdata_tail += (s->windows[window]).length;
				} else {
					WARN(ZS_RDATA_OVERFLOW);
					p--; {goto st316;}
				}
			}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1468;
tr1746:
	{ window_add_bit(KNOT_RRTYPE_TLSA, s); }
	{
		s->buffer_length = 0;
	}
	{
		for (uint16_t window = 0; window <= s->last_window; window++) {
			if ((s->windows[window]).length > 0) {
				if (rdata_tail + 2 + (s->windows[window]).length <= rdata_stop)
				{
					// Window number.
					*rdata_tail = (uint8_t)window;
					rdata_tail += 1;
					// Bitmap length.
					*rdata_tail = (s->windows[window]).length;
					rdata_tail += 1;
					// Copying bitmap.
					memcpy(rdata_tail,
					       (s->windows[window]).bitmap,
					       (s->windows[window]).length);
					rdata_tail += (s->windows[window]).length;
				} else {
					WARN(ZS_RDATA_OVERFLOW);
					p--; {goto st316;}
				}
			}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1468;
tr1755:
	{ window_add_bit(KNOT_RRTYPE_TXT, s); }
	{
		s->buffer_length = 0;
	}
	{
		for (uint16_t window = 0; window <= s->last_window; window++) {
			if ((s->windows[window]).length > 0) {
				if (rdata_tail + 2 + (s->windows[window]).length <= rdata_stop)
				{
					// Window number.
					*rdata_tail = (uint8_t)window;
					rdata_tail += 1;
					// Bitmap length.
					*rdata_tail = (s->windows[window]).length;
					rdata_tail += 1;
					// Copying bitmap.
					memcpy(rdata_tail,
					       (s->windows[window]).bitmap,
					       (s->windows[window]).length);
					rdata_tail += (s->windows[window]).length;
				} else {
					WARN(ZS_RDATA_OVERFLOW);
					p--; {goto st316;}
				}
			}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1468;
tr1767:
	{
		if (s->number64 <= UINT16_MAX) {
			window_add_bit(s->number64, s);
		} else {
			WARN(ZS_NUMBER16_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		s->buffer_length = 0;
	}
	{
		for (uint16_t window = 0; window <= s->last_window; window++) {
			if ((s->windows[window]).length > 0) {
				if (rdata_tail + 2 + (s->windows[window]).length <= rdata_stop)
				{
					// Window number.
					*rdata_tail = (uint8_t)window;
					rdata_tail += 1;
					// Bitmap length.
					*rdata_tail = (s->windows[window]).length;
					rdata_tail += 1;
					// Copying bitmap.
					memcpy(rdata_tail,
					       (s->windows[window]).bitmap,
					       (s->windows[window]).length);
					rdata_tail += (s->windows[window]).length;
				} else {
					WARN(ZS_RDATA_OVERFLOW);
					p--; {goto st316;}
				}
			}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1468;
tr1777:
	{ window_add_bit(KNOT_RRTYPE_URI, s); }
	{
		s->buffer_length = 0;
	}
	{
		for (uint16_t window = 0; window <= s->last_window; window++) {
			if ((s->windows[window]).length > 0) {
				if (rdata_tail + 2 + (s->windows[window]).length <= rdata_stop)
				{
					// Window number.
					*rdata_tail = (uint8_t)window;
					rdata_tail += 1;
					// Bitmap length.
					*rdata_tail = (s->windows[window]).length;
					rdata_tail += 1;
					// Copying bitmap.
					memcpy(rdata_tail,
					       (s->windows[window]).bitmap,
					       (s->windows[window]).length);
					rdata_tail += (s->windows[window]).length;
				} else {
					WARN(ZS_RDATA_OVERFLOW);
					p--; {goto st316;}
				}
			}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1468;
tr1790:
	{ window_add_bit(KNOT_RRTYPE_WALLET, s); }
	{
		s->buffer_length = 0;
	}
	{
		for (uint16_t window = 0; window <= s->last_window; window++) {
			if ((s->windows[window]).length > 0) {
				if (rdata_tail + 2 + (s->windows[window]).length <= rdata_stop)
				{
					// Window number.
					*rdata_tail = (uint8_t)window;
					rdata_tail += 1;
					// Bitmap length.
					*rdata_tail = (s->windows[window]).length;
					rdata_tail += 1;
					// Copying bitmap.
					memcpy(rdata_tail,
					       (s->windows[window]).bitmap,
					       (s->windows[window]).length);
					rdata_tail += (s->windows[window]).length;
				} else {
					WARN(ZS_RDATA_OVERFLOW);
					p--; {goto st316;}
				}
			}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1468;
tr1803:
	{ window_add_bit(KNOT_RRTYPE_ZONEMD, s); }
	{
		s->buffer_length = 0;
	}
	{
		for (uint16_t window = 0; window <= s->last_window; window++) {
			if ((s->windows[window]).length > 0) {
				if (rdata_tail + 2 + (s->windows[window]).length <= rdata_stop)
				{
					// Window number.
					*rdata_tail = (uint8_t)window;
					rdata_tail += 1;
					// Bitmap length.
					*rdata_tail = (s->windows[window]).length;
					rdata_tail += 1;
					// Copying bitmap.
					memcpy(rdata_tail,
					       (s->windows[window]).bitmap,
					       (s->windows[window]).length);
					rdata_tail += (s->windows[window]).length;
				} else {
					WARN(ZS_RDATA_OVERFLOW);
					p--; {goto st316;}
				}
			}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1468;
tr1814:
	{ window_add_bit(KNOT_RRTYPE_AFSDB, s); }
	{
		s->buffer_length = 0;
	}
	{
		for (uint16_t window = 0; window <= s->last_window; window++) {
			if ((s->windows[window]).length > 0) {
				if (rdata_tail + 2 + (s->windows[window]).length <= rdata_stop)
				{
					// Window number.
					*rdata_tail = (uint8_t)window;
					rdata_tail += 1;
					// Bitmap length.
					*rdata_tail = (s->windows[window]).length;
					rdata_tail += 1;
					// Copying bitmap.
					memcpy(rdata_tail,
					       (s->windows[window]).bitmap,
					       (s->windows[window]).length);
					rdata_tail += (s->windows[window]).length;
				} else {
					WARN(ZS_RDATA_OVERFLOW);
					p--; {goto st316;}
				}
			}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1468;
tr1823:
	{ window_add_bit(KNOT_RRTYPE_APL, s); }
	{
		s->buffer_length = 0;
	}
	{
		for (uint16_t window = 0; window <= s->last_window; window++) {
			if ((s->windows[window]).length > 0) {
				if (rdata_tail + 2 + (s->windows[window]).length <= rdata_stop)
				{
					// Window number.
					*rdata_tail = (uint8_t)window;
					rdata_tail += 1;
					// Bitmap length.
					*rdata_tail = (s->windows[window]).length;
					rdata_tail += 1;
					// Copying bitmap.
					memcpy(rdata_tail,
					       (s->windows[window]).bitmap,
					       (s->windows[window]).length);
					rdata_tail += (s->windows[window]).length;
				} else {
					WARN(ZS_RDATA_OVERFLOW);
					p--; {goto st316;}
				}
			}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1468;
st1468:
	if ( ++p == pe )
		goto _test_eof1468;
case 1468:
	_widec = (*p);
	if ( (*p) < 10 ) {
		if ( (*p) <= 9 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) > 10 ) {
		if ( 11 <= (*p) )
 {			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	if ( _widec == 2058 )
		goto tr1294;
	if ( 1920 <= _widec && _widec <= 2175 )
		goto tr1293;
	goto tr1237;
st395:
	if ( ++p == pe )
		goto _test_eof395;
case 395:
	switch( (*p) ) {
		case 78: goto st396;
		case 83: goto st401;
		case 110: goto st396;
		case 115: goto st401;
	}
	goto tr1237;
st396:
	if ( ++p == pe )
		goto _test_eof396;
case 396:
	switch( (*p) ) {
		case 83: goto st397;
		case 115: goto st397;
	}
	goto tr1237;
st397:
	if ( ++p == pe )
		goto _test_eof397;
case 397:
	switch( (*p) ) {
		case 75: goto st398;
		case 107: goto st398;
	}
	goto tr1237;
st398:
	if ( ++p == pe )
		goto _test_eof398;
case 398:
	switch( (*p) ) {
		case 69: goto st399;
		case 101: goto st399;
	}
	goto tr1237;
st399:
	if ( ++p == pe )
		goto _test_eof399;
case 399:
	switch( (*p) ) {
		case 89: goto st400;
		case 121: goto st400;
	}
	goto tr1237;
st400:
	if ( ++p == pe )
		goto _test_eof400;
case 400:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(2688 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 !s->multiline  ) _widec += 512;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(2688 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		if (
 !s->multiline  ) _widec += 512;
	}
	switch( _widec ) {
		case 9: goto tr1315;
		case 32: goto tr1315;
		case 40: goto tr1316;
		case 41: goto tr1317;
		case 3082: goto tr1318;
		case 3131: goto tr1319;
		case 3338: goto tr1320;
		case 3387: goto tr1320;
		case 3594: goto tr1321;
		case 3643: goto tr1322;
	}
	goto tr1237;
st401:
	if ( ++p == pe )
		goto _test_eof401;
case 401:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(2688 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 !s->multiline  ) _widec += 512;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(2688 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		if (
 !s->multiline  ) _widec += 512;
	}
	switch( _widec ) {
		case 9: goto tr1323;
		case 32: goto tr1323;
		case 40: goto tr1324;
		case 41: goto tr1325;
		case 3082: goto tr1326;
		case 3131: goto tr1327;
		case 3338: goto tr1328;
		case 3387: goto tr1328;
		case 3594: goto tr1329;
		case 3643: goto tr1330;
	}
	goto tr1237;
st402:
	if ( ++p == pe )
		goto _test_eof402;
case 402:
	switch( (*p) ) {
		case 82: goto st403;
		case 114: goto st403;
	}
	goto tr1237;
st403:
	if ( ++p == pe )
		goto _test_eof403;
case 403:
	switch( (*p) ) {
		case 84: goto st404;
		case 116: goto st404;
	}
	goto tr1237;
st404:
	if ( ++p == pe )
		goto _test_eof404;
case 404:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(2688 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 !s->multiline  ) _widec += 512;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(2688 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		if (
 !s->multiline  ) _widec += 512;
	}
	switch( _widec ) {
		case 9: goto tr1333;
		case 32: goto tr1333;
		case 40: goto tr1334;
		case 41: goto tr1335;
		case 3082: goto tr1336;
		case 3131: goto tr1337;
		case 3338: goto tr1338;
		case 3387: goto tr1338;
		case 3594: goto tr1339;
		case 3643: goto tr1340;
	}
	goto tr1237;
st405:
	if ( ++p == pe )
		goto _test_eof405;
case 405:
	switch( (*p) ) {
		case 65: goto st406;
		case 97: goto st406;
	}
	goto tr1237;
st406:
	if ( ++p == pe )
		goto _test_eof406;
case 406:
	switch( (*p) ) {
		case 77: goto st407;
		case 109: goto st407;
	}
	goto tr1237;
st407:
	if ( ++p == pe )
		goto _test_eof407;
case 407:
	switch( (*p) ) {
		case 69: goto st408;
		case 101: goto st408;
	}
	goto tr1237;
st408:
	if ( ++p == pe )
		goto _test_eof408;
case 408:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(2688 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 !s->multiline  ) _widec += 512;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(2688 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		if (
 !s->multiline  ) _widec += 512;
	}
	switch( _widec ) {
		case 9: goto tr1344;
		case 32: goto tr1344;
		case 40: goto tr1345;
		case 41: goto tr1346;
		case 3082: goto tr1347;
		case 3131: goto tr1348;
		case 3338: goto tr1349;
		case 3387: goto tr1349;
		case 3594: goto tr1350;
		case 3643: goto tr1351;
	}
	goto tr1237;
st409:
	if ( ++p == pe )
		goto _test_eof409;
case 409:
	switch( (*p) ) {
		case 89: goto st410;
		case 121: goto st410;
	}
	goto tr1237;
st410:
	if ( ++p == pe )
		goto _test_eof410;
case 410:
	switch( (*p) ) {
		case 78: goto st411;
		case 110: goto st411;
	}
	goto tr1237;
st411:
	if ( ++p == pe )
		goto _test_eof411;
case 411:
	switch( (*p) ) {
		case 67: goto st412;
		case 99: goto st412;
	}
	goto tr1237;
st412:
	if ( ++p == pe )
		goto _test_eof412;
case 412:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(2688 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 !s->multiline  ) _widec += 512;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(2688 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		if (
 !s->multiline  ) _widec += 512;
	}
	switch( _widec ) {
		case 9: goto tr1355;
		case 32: goto tr1355;
		case 40: goto tr1356;
		case 41: goto tr1357;
		case 3082: goto tr1358;
		case 3131: goto tr1359;
		case 3338: goto tr1360;
		case 3387: goto tr1360;
		case 3594: goto tr1361;
		case 3643: goto tr1362;
	}
	goto tr1237;
st413:
	if ( ++p == pe )
		goto _test_eof413;
case 413:
	switch( (*p) ) {
		case 72: goto st414;
		case 78: goto st418;
		case 83: goto st426;
		case 104: goto st414;
		case 110: goto st418;
		case 115: goto st426;
	}
	goto tr1237;
st414:
	if ( ++p == pe )
		goto _test_eof414;
case 414:
	switch( (*p) ) {
		case 67: goto st415;
		case 99: goto st415;
	}
	goto tr1237;
st415:
	if ( ++p == pe )
		goto _test_eof415;
case 415:
	switch( (*p) ) {
		case 73: goto st416;
		case 105: goto st416;
	}
	goto tr1237;
st416:
	if ( ++p == pe )
		goto _test_eof416;
case 416:
	switch( (*p) ) {
		case 68: goto st417;
		case 100: goto st417;
	}
	goto tr1237;
st417:
	if ( ++p == pe )
		goto _test_eof417;
case 417:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(2688 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 !s->multiline  ) _widec += 512;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(2688 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		if (
 !s->multiline  ) _widec += 512;
	}
	switch( _widec ) {
		case 9: goto tr1369;
		case 32: goto tr1369;
		case 40: goto tr1370;
		case 41: goto tr1371;
		case 3082: goto tr1372;
		case 3131: goto tr1373;
		case 3338: goto tr1374;
		case 3387: goto tr1374;
		case 3594: goto tr1375;
		case 3643: goto tr1376;
	}
	goto tr1237;
st418:
	if ( ++p == pe )
		goto _test_eof418;
case 418:
	switch( (*p) ) {
		case 65: goto st419;
		case 83: goto st422;
		case 97: goto st419;
		case 115: goto st422;
	}
	goto tr1237;
st419:
	if ( ++p == pe )
		goto _test_eof419;
case 419:
	switch( (*p) ) {
		case 77: goto st420;
		case 109: goto st420;
	}
	goto tr1237;
st420:
	if ( ++p == pe )
		goto _test_eof420;
case 420:
	switch( (*p) ) {
		case 69: goto st421;
		case 101: goto st421;
	}
	goto tr1237;
st421:
	if ( ++p == pe )
		goto _test_eof421;
case 421:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(2688 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 !s->multiline  ) _widec += 512;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(2688 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		if (
 !s->multiline  ) _widec += 512;
	}
	switch( _widec ) {
		case 9: goto tr1381;
		case 32: goto tr1381;
		case 40: goto tr1382;
		case 41: goto tr1383;
		case 3082: goto tr1384;
		case 3131: goto tr1385;
		case 3338: goto tr1386;
		case 3387: goto tr1386;
		case 3594: goto tr1387;
		case 3643: goto tr1388;
	}
	goto tr1237;
st422:
	if ( ++p == pe )
		goto _test_eof422;
case 422:
	switch( (*p) ) {
		case 75: goto st423;
		case 107: goto st423;
	}
	goto tr1237;
st423:
	if ( ++p == pe )
		goto _test_eof423;
case 423:
	switch( (*p) ) {
		case 69: goto st424;
		case 101: goto st424;
	}
	goto tr1237;
st424:
	if ( ++p == pe )
		goto _test_eof424;
case 424:
	switch( (*p) ) {
		case 89: goto st425;
		case 121: goto st425;
	}
	goto tr1237;
st425:
	if ( ++p == pe )
		goto _test_eof425;
case 425:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(2688 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 !s->multiline  ) _widec += 512;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(2688 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		if (
 !s->multiline  ) _widec += 512;
	}
	switch( _widec ) {
		case 9: goto tr1392;
		case 32: goto tr1392;
		case 40: goto tr1393;
		case 41: goto tr1394;
		case 3082: goto tr1395;
		case 3131: goto tr1396;
		case 3338: goto tr1397;
		case 3387: goto tr1397;
		case 3594: goto tr1398;
		case 3643: goto tr1399;
	}
	goto tr1237;
st426:
	if ( ++p == pe )
		goto _test_eof426;
case 426:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(2688 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 !s->multiline  ) _widec += 512;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(2688 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		if (
 !s->multiline  ) _widec += 512;
	}
	switch( _widec ) {
		case 9: goto tr1400;
		case 32: goto tr1400;
		case 40: goto tr1401;
		case 41: goto tr1402;
		case 3082: goto tr1403;
		case 3131: goto tr1404;
		case 3338: goto tr1405;
		case 3387: goto tr1405;
		case 3594: goto tr1406;
		case 3643: goto tr1407;
	}
	goto tr1237;
st427:
	if ( ++p == pe )
		goto _test_eof427;
case 427:
	switch( (*p) ) {
		case 85: goto st428;
		case 117: goto st428;
	}
	goto tr1237;
st428:
	if ( ++p == pe )
		goto _test_eof428;
case 428:
	switch( (*p) ) {
		case 73: goto st429;
		case 105: goto st429;
	}
	goto tr1237;
st429:
	if ( ++p == pe )
		goto _test_eof429;
case 429:
	switch( (*p) ) {
		case 52: goto st430;
		case 54: goto st432;
	}
	goto tr1237;
st430:
	if ( ++p == pe )
		goto _test_eof430;
case 430:
	if ( (*p) == 56 )
		goto st431;
	goto tr1237;
st431:
	if ( ++p == pe )
		goto _test_eof431;
case 431:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(2688 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 !s->multiline  ) _widec += 512;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(2688 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		if (
 !s->multiline  ) _widec += 512;
	}
	switch( _widec ) {
		case 9: goto tr1413;
		case 32: goto tr1413;
		case 40: goto tr1414;
		case 41: goto tr1415;
		case 3082: goto tr1416;
		case 3131: goto tr1417;
		case 3338: goto tr1418;
		case 3387: goto tr1418;
		case 3594: goto tr1419;
		case 3643: goto tr1420;
	}
	goto tr1237;
st432:
	if ( ++p == pe )
		goto _test_eof432;
case 432:
	if ( (*p) == 52 )
		goto st433;
	goto tr1237;
st433:
	if ( ++p == pe )
		goto _test_eof433;
case 433:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(2688 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 !s->multiline  ) _widec += 512;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(2688 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		if (
 !s->multiline  ) _widec += 512;
	}
	switch( _widec ) {
		case 9: goto tr1422;
		case 32: goto tr1422;
		case 40: goto tr1423;
		case 41: goto tr1424;
		case 3082: goto tr1425;
		case 3131: goto tr1426;
		case 3338: goto tr1427;
		case 3387: goto tr1427;
		case 3594: goto tr1428;
		case 3643: goto tr1429;
	}
	goto tr1237;
st434:
	if ( ++p == pe )
		goto _test_eof434;
case 434:
	switch( (*p) ) {
		case 73: goto st435;
		case 84: goto st439;
		case 105: goto st435;
		case 116: goto st439;
	}
	goto tr1237;
st435:
	if ( ++p == pe )
		goto _test_eof435;
case 435:
	switch( (*p) ) {
		case 78: goto st436;
		case 110: goto st436;
	}
	goto tr1237;
st436:
	if ( ++p == pe )
		goto _test_eof436;
case 436:
	switch( (*p) ) {
		case 70: goto st437;
		case 102: goto st437;
	}
	goto tr1237;
st437:
	if ( ++p == pe )
		goto _test_eof437;
case 437:
	switch( (*p) ) {
		case 79: goto st438;
		case 111: goto st438;
	}
	goto tr1237;
st438:
	if ( ++p == pe )
		goto _test_eof438;
case 438:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(2688 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 !s->multiline  ) _widec += 512;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(2688 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		if (
 !s->multiline  ) _widec += 512;
	}
	switch( _widec ) {
		case 9: goto tr1435;
		case 32: goto tr1435;
		case 40: goto tr1436;
		case 41: goto tr1437;
		case 3082: goto tr1438;
		case 3131: goto tr1439;
		case 3338: goto tr1440;
		case 3387: goto tr1440;
		case 3594: goto tr1441;
		case 3643: goto tr1442;
	}
	goto tr1237;
st439:
	if ( ++p == pe )
		goto _test_eof439;
case 439:
	switch( (*p) ) {
		case 84: goto st440;
		case 116: goto st440;
	}
	goto tr1237;
st440:
	if ( ++p == pe )
		goto _test_eof440;
case 440:
	switch( (*p) ) {
		case 80: goto st441;
		case 112: goto st441;
	}
	goto tr1237;
st441:
	if ( ++p == pe )
		goto _test_eof441;
case 441:
	switch( (*p) ) {
		case 83: goto st442;
		case 115: goto st442;
	}
	goto tr1237;
st442:
	if ( ++p == pe )
		goto _test_eof442;
case 442:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(2688 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 !s->multiline  ) _widec += 512;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(2688 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		if (
 !s->multiline  ) _widec += 512;
	}
	switch( _widec ) {
		case 9: goto tr1446;
		case 32: goto tr1446;
		case 40: goto tr1447;
		case 41: goto tr1448;
		case 3082: goto tr1449;
		case 3131: goto tr1450;
		case 3338: goto tr1451;
		case 3387: goto tr1451;
		case 3594: goto tr1452;
		case 3643: goto tr1453;
	}
	goto tr1237;
st443:
	if ( ++p == pe )
		goto _test_eof443;
case 443:
	switch( (*p) ) {
		case 80: goto st444;
		case 112: goto st444;
	}
	goto tr1237;
st444:
	if ( ++p == pe )
		goto _test_eof444;
case 444:
	switch( (*p) ) {
		case 83: goto st445;
		case 115: goto st445;
	}
	goto tr1237;
st445:
	if ( ++p == pe )
		goto _test_eof445;
case 445:
	switch( (*p) ) {
		case 69: goto st446;
		case 101: goto st446;
	}
	goto tr1237;
st446:
	if ( ++p == pe )
		goto _test_eof446;
case 446:
	switch( (*p) ) {
		case 67: goto st447;
		case 99: goto st447;
	}
	goto tr1237;
st447:
	if ( ++p == pe )
		goto _test_eof447;
case 447:
	switch( (*p) ) {
		case 75: goto st448;
		case 107: goto st448;
	}
	goto tr1237;
st448:
	if ( ++p == pe )
		goto _test_eof448;
case 448:
	switch( (*p) ) {
		case 69: goto st449;
		case 101: goto st449;
	}
	goto tr1237;
st449:
	if ( ++p == pe )
		goto _test_eof449;
case 449:
	switch( (*p) ) {
		case 89: goto st450;
		case 121: goto st450;
	}
	goto tr1237;
st450:
	if ( ++p == pe )
		goto _test_eof450;
case 450:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(2688 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 !s->multiline  ) _widec += 512;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(2688 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		if (
 !s->multiline  ) _widec += 512;
	}
	switch( _widec ) {
		case 9: goto tr1461;
		case 32: goto tr1461;
		case 40: goto tr1462;
		case 41: goto tr1463;
		case 3082: goto tr1464;
		case 3131: goto tr1465;
		case 3338: goto tr1466;
		case 3387: goto tr1466;
		case 3594: goto tr1467;
		case 3643: goto tr1468;
	}
	goto tr1237;
st451:
	if ( ++p == pe )
		goto _test_eof451;
case 451:
	switch( (*p) ) {
		case 69: goto st452;
		case 88: goto st454;
		case 101: goto st452;
		case 120: goto st454;
	}
	goto tr1237;
st452:
	if ( ++p == pe )
		goto _test_eof452;
case 452:
	switch( (*p) ) {
		case 89: goto st453;
		case 121: goto st453;
	}
	goto tr1237;
st453:
	if ( ++p == pe )
		goto _test_eof453;
case 453:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(2688 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 !s->multiline  ) _widec += 512;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(2688 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		if (
 !s->multiline  ) _widec += 512;
	}
	switch( _widec ) {
		case 9: goto tr1472;
		case 32: goto tr1472;
		case 40: goto tr1473;
		case 41: goto tr1474;
		case 3082: goto tr1475;
		case 3131: goto tr1476;
		case 3338: goto tr1477;
		case 3387: goto tr1477;
		case 3594: goto tr1478;
		case 3643: goto tr1479;
	}
	goto tr1237;
st454:
	if ( ++p == pe )
		goto _test_eof454;
case 454:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(2688 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 !s->multiline  ) _widec += 512;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(2688 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		if (
 !s->multiline  ) _widec += 512;
	}
	switch( _widec ) {
		case 9: goto tr1480;
		case 32: goto tr1480;
		case 40: goto tr1481;
		case 41: goto tr1482;
		case 3082: goto tr1483;
		case 3131: goto tr1484;
		case 3338: goto tr1485;
		case 3387: goto tr1485;
		case 3594: goto tr1486;
		case 3643: goto tr1487;
	}
	goto tr1237;
st455:
	if ( ++p == pe )
		goto _test_eof455;
case 455:
	switch( (*p) ) {
		case 51: goto st456;
		case 54: goto st458;
		case 79: goto st460;
		case 80: goto st462;
		case 111: goto st460;
		case 112: goto st462;
	}
	goto tr1237;
st456:
	if ( ++p == pe )
		goto _test_eof456;
case 456:
	if ( (*p) == 50 )
		goto st457;
	goto tr1237;
st457:
	if ( ++p == pe )
		goto _test_eof457;
case 457:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(2688 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 !s->multiline  ) _widec += 512;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(2688 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		if (
 !s->multiline  ) _widec += 512;
	}
	switch( _widec ) {
		case 9: goto tr1493;
		case 32: goto tr1493;
		case 40: goto tr1494;
		case 41: goto tr1495;
		case 3082: goto tr1496;
		case 3131: goto tr1497;
		case 3338: goto tr1498;
		case 3387: goto tr1498;
		case 3594: goto tr1499;
		case 3643: goto tr1500;
	}
	goto tr1237;
st458:
	if ( ++p == pe )
		goto _test_eof458;
case 458:
	if ( (*p) == 52 )
		goto st459;
	goto tr1237;
st459:
	if ( ++p == pe )
		goto _test_eof459;
case 459:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(2688 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 !s->multiline  ) _widec += 512;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(2688 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		if (
 !s->multiline  ) _widec += 512;
	}
	switch( _widec ) {
		case 9: goto tr1502;
		case 32: goto tr1502;
		case 40: goto tr1503;
		case 41: goto tr1504;
		case 3082: goto tr1505;
		case 3131: goto tr1506;
		case 3338: goto tr1507;
		case 3387: goto tr1507;
		case 3594: goto tr1508;
		case 3643: goto tr1509;
	}
	goto tr1237;
st460:
	if ( ++p == pe )
		goto _test_eof460;
case 460:
	switch( (*p) ) {
		case 67: goto st461;
		case 99: goto st461;
	}
	goto tr1237;
st461:
	if ( ++p == pe )
		goto _test_eof461;
case 461:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(2688 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 !s->multiline  ) _widec += 512;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(2688 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		if (
 !s->multiline  ) _widec += 512;
	}
	switch( _widec ) {
		case 9: goto tr1511;
		case 32: goto tr1511;
		case 40: goto tr1512;
		case 41: goto tr1513;
		case 3082: goto tr1514;
		case 3131: goto tr1515;
		case 3338: goto tr1516;
		case 3387: goto tr1516;
		case 3594: goto tr1517;
		case 3643: goto tr1518;
	}
	goto tr1237;
st462:
	if ( ++p == pe )
		goto _test_eof462;
case 462:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(2688 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 !s->multiline  ) _widec += 512;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(2688 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		if (
 !s->multiline  ) _widec += 512;
	}
	switch( _widec ) {
		case 9: goto tr1519;
		case 32: goto tr1519;
		case 40: goto tr1520;
		case 41: goto tr1521;
		case 3082: goto tr1522;
		case 3131: goto tr1523;
		case 3338: goto tr1524;
		case 3387: goto tr1524;
		case 3594: goto tr1525;
		case 3643: goto tr1526;
	}
	goto tr1237;
st463:
	if ( ++p == pe )
		goto _test_eof463;
case 463:
	switch( (*p) ) {
		case 73: goto st464;
		case 88: goto st468;
		case 105: goto st464;
		case 120: goto st468;
	}
	goto tr1237;
st464:
	if ( ++p == pe )
		goto _test_eof464;
case 464:
	switch( (*p) ) {
		case 78: goto st465;
		case 110: goto st465;
	}
	goto tr1237;
st465:
	if ( ++p == pe )
		goto _test_eof465;
case 465:
	switch( (*p) ) {
		case 70: goto st466;
		case 102: goto st466;
	}
	goto tr1237;
st466:
	if ( ++p == pe )
		goto _test_eof466;
case 466:
	switch( (*p) ) {
		case 79: goto st467;
		case 111: goto st467;
	}
	goto tr1237;
st467:
	if ( ++p == pe )
		goto _test_eof467;
case 467:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(2688 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 !s->multiline  ) _widec += 512;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(2688 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		if (
 !s->multiline  ) _widec += 512;
	}
	switch( _widec ) {
		case 9: goto tr1532;
		case 32: goto tr1532;
		case 40: goto tr1533;
		case 41: goto tr1534;
		case 3082: goto tr1535;
		case 3131: goto tr1536;
		case 3338: goto tr1537;
		case 3387: goto tr1537;
		case 3594: goto tr1538;
		case 3643: goto tr1539;
	}
	goto tr1237;
st468:
	if ( ++p == pe )
		goto _test_eof468;
case 468:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(2688 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 !s->multiline  ) _widec += 512;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(2688 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		if (
 !s->multiline  ) _widec += 512;
	}
	switch( _widec ) {
		case 9: goto tr1540;
		case 32: goto tr1540;
		case 40: goto tr1541;
		case 41: goto tr1542;
		case 3082: goto tr1543;
		case 3131: goto tr1544;
		case 3338: goto tr1545;
		case 3387: goto tr1545;
		case 3594: goto tr1546;
		case 3643: goto tr1547;
	}
	goto tr1237;
st469:
	if ( ++p == pe )
		goto _test_eof469;
case 469:
	switch( (*p) ) {
		case 65: goto st470;
		case 73: goto st474;
		case 83: goto st476;
		case 97: goto st470;
		case 105: goto st474;
		case 115: goto st476;
	}
	goto tr1237;
st470:
	if ( ++p == pe )
		goto _test_eof470;
case 470:
	switch( (*p) ) {
		case 80: goto st471;
		case 112: goto st471;
	}
	goto tr1237;
st471:
	if ( ++p == pe )
		goto _test_eof471;
case 471:
	switch( (*p) ) {
		case 84: goto st472;
		case 116: goto st472;
	}
	goto tr1237;
st472:
	if ( ++p == pe )
		goto _test_eof472;
case 472:
	switch( (*p) ) {
		case 82: goto st473;
		case 114: goto st473;
	}
	goto tr1237;
st473:
	if ( ++p == pe )
		goto _test_eof473;
case 473:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(2688 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 !s->multiline  ) _widec += 512;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(2688 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		if (
 !s->multiline  ) _widec += 512;
	}
	switch( _widec ) {
		case 9: goto tr1554;
		case 32: goto tr1554;
		case 40: goto tr1555;
		case 41: goto tr1556;
		case 3082: goto tr1557;
		case 3131: goto tr1558;
		case 3338: goto tr1559;
		case 3387: goto tr1559;
		case 3594: goto tr1560;
		case 3643: goto tr1561;
	}
	goto tr1237;
st474:
	if ( ++p == pe )
		goto _test_eof474;
case 474:
	switch( (*p) ) {
		case 68: goto st475;
		case 100: goto st475;
	}
	goto tr1237;
st475:
	if ( ++p == pe )
		goto _test_eof475;
case 475:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(2688 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 !s->multiline  ) _widec += 512;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(2688 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		if (
 !s->multiline  ) _widec += 512;
	}
	switch( _widec ) {
		case 9: goto tr1563;
		case 32: goto tr1563;
		case 40: goto tr1564;
		case 41: goto tr1565;
		case 3082: goto tr1566;
		case 3131: goto tr1567;
		case 3338: goto tr1568;
		case 3387: goto tr1568;
		case 3594: goto tr1569;
		case 3643: goto tr1570;
	}
	goto tr1237;
st476:
	if ( ++p == pe )
		goto _test_eof476;
case 476:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(2688 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 !s->multiline  ) _widec += 512;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(2688 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		if (
 !s->multiline  ) _widec += 512;
	}
	switch( _widec ) {
		case 9: goto tr1571;
		case 32: goto tr1571;
		case 40: goto tr1572;
		case 41: goto tr1573;
		case 69: goto st477;
		case 101: goto st477;
		case 3082: goto tr1575;
		case 3131: goto tr1576;
		case 3338: goto tr1577;
		case 3387: goto tr1577;
		case 3594: goto tr1578;
		case 3643: goto tr1579;
	}
	goto tr1237;
st477:
	if ( ++p == pe )
		goto _test_eof477;
case 477:
	switch( (*p) ) {
		case 67: goto st478;
		case 99: goto st478;
	}
	goto tr1237;
st478:
	if ( ++p == pe )
		goto _test_eof478;
case 478:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(2688 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 !s->multiline  ) _widec += 512;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(2688 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		if (
 !s->multiline  ) _widec += 512;
	}
	switch( _widec ) {
		case 9: goto tr1581;
		case 32: goto tr1581;
		case 40: goto tr1582;
		case 41: goto tr1583;
		case 51: goto st479;
		case 3082: goto tr1585;
		case 3131: goto tr1586;
		case 3338: goto tr1587;
		case 3387: goto tr1587;
		case 3594: goto tr1588;
		case 3643: goto tr1589;
	}
	goto tr1237;
st479:
	if ( ++p == pe )
		goto _test_eof479;
case 479:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(2688 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 !s->multiline  ) _widec += 512;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(2688 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		if (
 !s->multiline  ) _widec += 512;
	}
	switch( _widec ) {
		case 9: goto tr1590;
		case 32: goto tr1590;
		case 40: goto tr1591;
		case 41: goto tr1592;
		case 80: goto st480;
		case 112: goto st480;
		case 3082: goto tr1594;
		case 3131: goto tr1595;
		case 3338: goto tr1596;
		case 3387: goto tr1596;
		case 3594: goto tr1597;
		case 3643: goto tr1598;
	}
	goto tr1237;
st480:
	if ( ++p == pe )
		goto _test_eof480;
case 480:
	switch( (*p) ) {
		case 65: goto st481;
		case 97: goto st481;
	}
	goto tr1237;
st481:
	if ( ++p == pe )
		goto _test_eof481;
case 481:
	switch( (*p) ) {
		case 82: goto st482;
		case 114: goto st482;
	}
	goto tr1237;
st482:
	if ( ++p == pe )
		goto _test_eof482;
case 482:
	switch( (*p) ) {
		case 65: goto st483;
		case 97: goto st483;
	}
	goto tr1237;
st483:
	if ( ++p == pe )
		goto _test_eof483;
case 483:
	switch( (*p) ) {
		case 77: goto st484;
		case 109: goto st484;
	}
	goto tr1237;
st484:
	if ( ++p == pe )
		goto _test_eof484;
case 484:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(2688 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 !s->multiline  ) _widec += 512;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(2688 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		if (
 !s->multiline  ) _widec += 512;
	}
	switch( _widec ) {
		case 9: goto tr1603;
		case 32: goto tr1603;
		case 40: goto tr1604;
		case 41: goto tr1605;
		case 3082: goto tr1606;
		case 3131: goto tr1607;
		case 3338: goto tr1608;
		case 3387: goto tr1608;
		case 3594: goto tr1609;
		case 3643: goto tr1610;
	}
	goto tr1237;
st485:
	if ( ++p == pe )
		goto _test_eof485;
case 485:
	switch( (*p) ) {
		case 80: goto st486;
		case 112: goto st486;
	}
	goto tr1237;
st486:
	if ( ++p == pe )
		goto _test_eof486;
case 486:
	switch( (*p) ) {
		case 69: goto st487;
		case 101: goto st487;
	}
	goto tr1237;
st487:
	if ( ++p == pe )
		goto _test_eof487;
case 487:
	switch( (*p) ) {
		case 78: goto st488;
		case 110: goto st488;
	}
	goto tr1237;
st488:
	if ( ++p == pe )
		goto _test_eof488;
case 488:
	switch( (*p) ) {
		case 80: goto st489;
		case 112: goto st489;
	}
	goto tr1237;
st489:
	if ( ++p == pe )
		goto _test_eof489;
case 489:
	switch( (*p) ) {
		case 71: goto st490;
		case 103: goto st490;
	}
	goto tr1237;
st490:
	if ( ++p == pe )
		goto _test_eof490;
case 490:
	switch( (*p) ) {
		case 80: goto st491;
		case 112: goto st491;
	}
	goto tr1237;
st491:
	if ( ++p == pe )
		goto _test_eof491;
case 491:
	switch( (*p) ) {
		case 75: goto st492;
		case 107: goto st492;
	}
	goto tr1237;
st492:
	if ( ++p == pe )
		goto _test_eof492;
case 492:
	switch( (*p) ) {
		case 69: goto st493;
		case 101: goto st493;
	}
	goto tr1237;
st493:
	if ( ++p == pe )
		goto _test_eof493;
case 493:
	switch( (*p) ) {
		case 89: goto st494;
		case 121: goto st494;
	}
	goto tr1237;
st494:
	if ( ++p == pe )
		goto _test_eof494;
case 494:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(2688 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 !s->multiline  ) _widec += 512;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(2688 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		if (
 !s->multiline  ) _widec += 512;
	}
	switch( _widec ) {
		case 9: goto tr1620;
		case 32: goto tr1620;
		case 40: goto tr1621;
		case 41: goto tr1622;
		case 3082: goto tr1623;
		case 3131: goto tr1624;
		case 3338: goto tr1625;
		case 3387: goto tr1625;
		case 3594: goto tr1626;
		case 3643: goto tr1627;
	}
	goto tr1237;
st495:
	if ( ++p == pe )
		goto _test_eof495;
case 495:
	switch( (*p) ) {
		case 84: goto st496;
		case 116: goto st496;
	}
	goto tr1237;
st496:
	if ( ++p == pe )
		goto _test_eof496;
case 496:
	switch( (*p) ) {
		case 82: goto st497;
		case 114: goto st497;
	}
	goto tr1237;
st497:
	if ( ++p == pe )
		goto _test_eof497;
case 497:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(2688 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 !s->multiline  ) _widec += 512;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(2688 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		if (
 !s->multiline  ) _widec += 512;
	}
	switch( _widec ) {
		case 9: goto tr1630;
		case 32: goto tr1630;
		case 40: goto tr1631;
		case 41: goto tr1632;
		case 3082: goto tr1633;
		case 3131: goto tr1634;
		case 3338: goto tr1635;
		case 3387: goto tr1635;
		case 3594: goto tr1636;
		case 3643: goto tr1637;
	}
	goto tr1237;
st498:
	if ( ++p == pe )
		goto _test_eof498;
case 498:
	switch( (*p) ) {
		case 80: goto st499;
		case 82: goto st500;
		case 84: goto st504;
		case 112: goto st499;
		case 114: goto st500;
		case 116: goto st504;
	}
	goto tr1237;
st499:
	if ( ++p == pe )
		goto _test_eof499;
case 499:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(2688 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 !s->multiline  ) _widec += 512;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(2688 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		if (
 !s->multiline  ) _widec += 512;
	}
	switch( _widec ) {
		case 9: goto tr1641;
		case 32: goto tr1641;
		case 40: goto tr1642;
		case 41: goto tr1643;
		case 3082: goto tr1644;
		case 3131: goto tr1645;
		case 3338: goto tr1646;
		case 3387: goto tr1646;
		case 3594: goto tr1647;
		case 3643: goto tr1648;
	}
	goto tr1237;
st500:
	if ( ++p == pe )
		goto _test_eof500;
case 500:
	switch( (*p) ) {
		case 83: goto st501;
		case 115: goto st501;
	}
	goto tr1237;
st501:
	if ( ++p == pe )
		goto _test_eof501;
case 501:
	switch( (*p) ) {
		case 73: goto st502;
		case 105: goto st502;
	}
	goto tr1237;
st502:
	if ( ++p == pe )
		goto _test_eof502;
case 502:
	switch( (*p) ) {
		case 71: goto st503;
		case 103: goto st503;
	}
	goto tr1237;
st503:
	if ( ++p == pe )
		goto _test_eof503;
case 503:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(2688 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 !s->multiline  ) _widec += 512;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(2688 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		if (
 !s->multiline  ) _widec += 512;
	}
	switch( _widec ) {
		case 9: goto tr1652;
		case 32: goto tr1652;
		case 40: goto tr1653;
		case 41: goto tr1654;
		case 3082: goto tr1655;
		case 3131: goto tr1656;
		case 3338: goto tr1657;
		case 3387: goto tr1657;
		case 3594: goto tr1658;
		case 3643: goto tr1659;
	}
	goto tr1237;
st504:
	if ( ++p == pe )
		goto _test_eof504;
case 504:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(2688 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 !s->multiline  ) _widec += 512;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(2688 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		if (
 !s->multiline  ) _widec += 512;
	}
	switch( _widec ) {
		case 9: goto tr1660;
		case 32: goto tr1660;
		case 40: goto tr1661;
		case 41: goto tr1662;
		case 3082: goto tr1663;
		case 3131: goto tr1664;
		case 3338: goto tr1665;
		case 3387: goto tr1665;
		case 3594: goto tr1666;
		case 3643: goto tr1667;
	}
	goto tr1237;
st505:
	if ( ++p == pe )
		goto _test_eof505;
case 505:
	switch( (*p) ) {
		case 77: goto st506;
		case 79: goto st511;
		case 80: goto st513;
		case 82: goto st515;
		case 83: goto st517;
		case 86: goto st521;
		case 109: goto st506;
		case 111: goto st511;
		case 112: goto st513;
		case 114: goto st515;
		case 115: goto st517;
		case 118: goto st521;
	}
	goto tr1237;
st506:
	if ( ++p == pe )
		goto _test_eof506;
case 506:
	switch( (*p) ) {
		case 73: goto st507;
		case 105: goto st507;
	}
	goto tr1237;
st507:
	if ( ++p == pe )
		goto _test_eof507;
case 507:
	switch( (*p) ) {
		case 77: goto st508;
		case 109: goto st508;
	}
	goto tr1237;
st508:
	if ( ++p == pe )
		goto _test_eof508;
case 508:
	switch( (*p) ) {
		case 69: goto st509;
		case 101: goto st509;
	}
	goto tr1237;
st509:
	if ( ++p == pe )
		goto _test_eof509;
case 509:
	switch( (*p) ) {
		case 65: goto st510;
		case 97: goto st510;
	}
	goto tr1237;
st510:
	if ( ++p == pe )
		goto _test_eof510;
case 510:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(2688 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 !s->multiline  ) _widec += 512;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(2688 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		if (
 !s->multiline  ) _widec += 512;
	}
	switch( _widec ) {
		case 9: goto tr1678;
		case 32: goto tr1678;
		case 40: goto tr1679;
		case 41: goto tr1680;
		case 3082: goto tr1681;
		case 3131: goto tr1682;
		case 3338: goto tr1683;
		case 3387: goto tr1683;
		case 3594: goto tr1684;
		case 3643: goto tr1685;
	}
	goto tr1237;
st511:
	if ( ++p == pe )
		goto _test_eof511;
case 511:
	switch( (*p) ) {
		case 65: goto st512;
		case 97: goto st512;
	}
	goto tr1237;
st512:
	if ( ++p == pe )
		goto _test_eof512;
case 512:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(2688 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 !s->multiline  ) _widec += 512;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(2688 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		if (
 !s->multiline  ) _widec += 512;
	}
	switch( _widec ) {
		case 9: goto tr1687;
		case 32: goto tr1687;
		case 40: goto tr1688;
		case 41: goto tr1689;
		case 3082: goto tr1690;
		case 3131: goto tr1691;
		case 3338: goto tr1692;
		case 3387: goto tr1692;
		case 3594: goto tr1693;
		case 3643: goto tr1694;
	}
	goto tr1237;
st513:
	if ( ++p == pe )
		goto _test_eof513;
case 513:
	switch( (*p) ) {
		case 70: goto st514;
		case 102: goto st514;
	}
	goto tr1237;
st514:
	if ( ++p == pe )
		goto _test_eof514;
case 514:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(2688 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 !s->multiline  ) _widec += 512;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(2688 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		if (
 !s->multiline  ) _widec += 512;
	}
	switch( _widec ) {
		case 9: goto tr1696;
		case 32: goto tr1696;
		case 40: goto tr1697;
		case 41: goto tr1698;
		case 3082: goto tr1699;
		case 3131: goto tr1700;
		case 3338: goto tr1701;
		case 3387: goto tr1701;
		case 3594: goto tr1702;
		case 3643: goto tr1703;
	}
	goto tr1237;
st515:
	if ( ++p == pe )
		goto _test_eof515;
case 515:
	switch( (*p) ) {
		case 86: goto st516;
		case 118: goto st516;
	}
	goto tr1237;
st516:
	if ( ++p == pe )
		goto _test_eof516;
case 516:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(2688 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 !s->multiline  ) _widec += 512;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(2688 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		if (
 !s->multiline  ) _widec += 512;
	}
	switch( _widec ) {
		case 9: goto tr1705;
		case 32: goto tr1705;
		case 40: goto tr1706;
		case 41: goto tr1707;
		case 3082: goto tr1708;
		case 3131: goto tr1709;
		case 3338: goto tr1710;
		case 3387: goto tr1710;
		case 3594: goto tr1711;
		case 3643: goto tr1712;
	}
	goto tr1237;
st517:
	if ( ++p == pe )
		goto _test_eof517;
case 517:
	switch( (*p) ) {
		case 72: goto st518;
		case 104: goto st518;
	}
	goto tr1237;
st518:
	if ( ++p == pe )
		goto _test_eof518;
case 518:
	switch( (*p) ) {
		case 70: goto st519;
		case 102: goto st519;
	}
	goto tr1237;
st519:
	if ( ++p == pe )
		goto _test_eof519;
case 519:
	switch( (*p) ) {
		case 80: goto st520;
		case 112: goto st520;
	}
	goto tr1237;
st520:
	if ( ++p == pe )
		goto _test_eof520;
case 520:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(2688 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 !s->multiline  ) _widec += 512;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(2688 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		if (
 !s->multiline  ) _widec += 512;
	}
	switch( _widec ) {
		case 9: goto tr1716;
		case 32: goto tr1716;
		case 40: goto tr1717;
		case 41: goto tr1718;
		case 3082: goto tr1719;
		case 3131: goto tr1720;
		case 3338: goto tr1721;
		case 3387: goto tr1721;
		case 3594: goto tr1722;
		case 3643: goto tr1723;
	}
	goto tr1237;
st521:
	if ( ++p == pe )
		goto _test_eof521;
case 521:
	switch( (*p) ) {
		case 67: goto st522;
		case 99: goto st522;
	}
	goto tr1237;
st522:
	if ( ++p == pe )
		goto _test_eof522;
case 522:
	switch( (*p) ) {
		case 66: goto st523;
		case 98: goto st523;
	}
	goto tr1237;
st523:
	if ( ++p == pe )
		goto _test_eof523;
case 523:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(2688 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 !s->multiline  ) _widec += 512;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(2688 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		if (
 !s->multiline  ) _widec += 512;
	}
	switch( _widec ) {
		case 9: goto tr1726;
		case 32: goto tr1726;
		case 40: goto tr1727;
		case 41: goto tr1728;
		case 3082: goto tr1729;
		case 3131: goto tr1730;
		case 3338: goto tr1731;
		case 3387: goto tr1731;
		case 3594: goto tr1732;
		case 3643: goto tr1733;
	}
	goto tr1237;
st524:
	if ( ++p == pe )
		goto _test_eof524;
case 524:
	switch( (*p) ) {
		case 76: goto st525;
		case 88: goto st528;
		case 89: goto st530;
		case 108: goto st525;
		case 120: goto st528;
		case 121: goto st530;
	}
	goto tr1237;
st525:
	if ( ++p == pe )
		goto _test_eof525;
case 525:
	switch( (*p) ) {
		case 83: goto st526;
		case 115: goto st526;
	}
	goto tr1237;
st526:
	if ( ++p == pe )
		goto _test_eof526;
case 526:
	switch( (*p) ) {
		case 65: goto st527;
		case 97: goto st527;
	}
	goto tr1237;
st527:
	if ( ++p == pe )
		goto _test_eof527;
case 527:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(2688 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 !s->multiline  ) _widec += 512;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(2688 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		if (
 !s->multiline  ) _widec += 512;
	}
	switch( _widec ) {
		case 9: goto tr1739;
		case 32: goto tr1739;
		case 40: goto tr1740;
		case 41: goto tr1741;
		case 3082: goto tr1742;
		case 3131: goto tr1743;
		case 3338: goto tr1744;
		case 3387: goto tr1744;
		case 3594: goto tr1745;
		case 3643: goto tr1746;
	}
	goto tr1237;
st528:
	if ( ++p == pe )
		goto _test_eof528;
case 528:
	switch( (*p) ) {
		case 84: goto st529;
		case 116: goto st529;
	}
	goto tr1237;
st529:
	if ( ++p == pe )
		goto _test_eof529;
case 529:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(2688 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 !s->multiline  ) _widec += 512;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(2688 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		if (
 !s->multiline  ) _widec += 512;
	}
	switch( _widec ) {
		case 9: goto tr1748;
		case 32: goto tr1748;
		case 40: goto tr1749;
		case 41: goto tr1750;
		case 3082: goto tr1751;
		case 3131: goto tr1752;
		case 3338: goto tr1753;
		case 3387: goto tr1753;
		case 3594: goto tr1754;
		case 3643: goto tr1755;
	}
	goto tr1237;
st530:
	if ( ++p == pe )
		goto _test_eof530;
case 530:
	switch( (*p) ) {
		case 80: goto st531;
		case 112: goto st531;
	}
	goto tr1237;
st531:
	if ( ++p == pe )
		goto _test_eof531;
case 531:
	switch( (*p) ) {
		case 69: goto st532;
		case 101: goto st532;
	}
	goto tr1237;
st532:
	if ( ++p == pe )
		goto _test_eof532;
case 532:
	if ( 48 <= (*p) && (*p) <= 57 )
		goto tr1758;
	goto tr1237;
tr1758:
	{
		s->number64 = 0;
	}
	{
		// Overflow check: 10*(s->number64) + fc - '0' <= UINT64_MAX
		if ((s->number64 < (UINT64_MAX / 10)) ||   // Dominant fast check.
			((s->number64 == (UINT64_MAX / 10)) && // Marginal case.
			 ((uint8_t)(*p) <= (UINT64_MAX % 10) + '0')
			)
		   ) {
			s->number64 *= 10;
			s->number64 += digit_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_NUMBER64_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st533;
tr1762:
	{
		// Overflow check: 10*(s->number64) + fc - '0' <= UINT64_MAX
		if ((s->number64 < (UINT64_MAX / 10)) ||   // Dominant fast check.
			((s->number64 == (UINT64_MAX / 10)) && // Marginal case.
			 ((uint8_t)(*p) <= (UINT64_MAX % 10) + '0')
			)
		   ) {
			s->number64 *= 10;
			s->number64 += digit_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_NUMBER64_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st533;
st533:
	if ( ++p == pe )
		goto _test_eof533;
case 533:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(2688 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 !s->multiline  ) _widec += 512;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(2688 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		if (
 !s->multiline  ) _widec += 512;
	}
	switch( _widec ) {
		case 9: goto tr1759;
		case 32: goto tr1759;
		case 40: goto tr1760;
		case 41: goto tr1761;
		case 3082: goto tr1763;
		case 3131: goto tr1764;
		case 3338: goto tr1765;
		case 3387: goto tr1765;
		case 3594: goto tr1766;
		case 3643: goto tr1767;
	}
	if ( 48 <= _widec && _widec <= 57 )
		goto tr1762;
	goto tr1237;
st534:
	if ( ++p == pe )
		goto _test_eof534;
case 534:
	switch( (*p) ) {
		case 82: goto st535;
		case 114: goto st535;
	}
	goto tr1237;
st535:
	if ( ++p == pe )
		goto _test_eof535;
case 535:
	switch( (*p) ) {
		case 73: goto st536;
		case 105: goto st536;
	}
	goto tr1237;
st536:
	if ( ++p == pe )
		goto _test_eof536;
case 536:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(2688 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 !s->multiline  ) _widec += 512;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(2688 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		if (
 !s->multiline  ) _widec += 512;
	}
	switch( _widec ) {
		case 9: goto tr1770;
		case 32: goto tr1770;
		case 40: goto tr1771;
		case 41: goto tr1772;
		case 3082: goto tr1773;
		case 3131: goto tr1774;
		case 3338: goto tr1775;
		case 3387: goto tr1775;
		case 3594: goto tr1776;
		case 3643: goto tr1777;
	}
	goto tr1237;
st537:
	if ( ++p == pe )
		goto _test_eof537;
case 537:
	switch( (*p) ) {
		case 65: goto st538;
		case 97: goto st538;
	}
	goto tr1237;
st538:
	if ( ++p == pe )
		goto _test_eof538;
case 538:
	switch( (*p) ) {
		case 76: goto st539;
		case 108: goto st539;
	}
	goto tr1237;
st539:
	if ( ++p == pe )
		goto _test_eof539;
case 539:
	switch( (*p) ) {
		case 76: goto st540;
		case 108: goto st540;
	}
	goto tr1237;
st540:
	if ( ++p == pe )
		goto _test_eof540;
case 540:
	switch( (*p) ) {
		case 69: goto st541;
		case 101: goto st541;
	}
	goto tr1237;
st541:
	if ( ++p == pe )
		goto _test_eof541;
case 541:
	switch( (*p) ) {
		case 84: goto st542;
		case 116: goto st542;
	}
	goto tr1237;
st542:
	if ( ++p == pe )
		goto _test_eof542;
case 542:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(2688 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 !s->multiline  ) _widec += 512;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(2688 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		if (
 !s->multiline  ) _widec += 512;
	}
	switch( _widec ) {
		case 9: goto tr1783;
		case 32: goto tr1783;
		case 40: goto tr1784;
		case 41: goto tr1785;
		case 3082: goto tr1786;
		case 3131: goto tr1787;
		case 3338: goto tr1788;
		case 3387: goto tr1788;
		case 3594: goto tr1789;
		case 3643: goto tr1790;
	}
	goto tr1237;
st543:
	if ( ++p == pe )
		goto _test_eof543;
case 543:
	switch( (*p) ) {
		case 79: goto st544;
		case 111: goto st544;
	}
	goto tr1237;
st544:
	if ( ++p == pe )
		goto _test_eof544;
case 544:
	switch( (*p) ) {
		case 78: goto st545;
		case 110: goto st545;
	}
	goto tr1237;
st545:
	if ( ++p == pe )
		goto _test_eof545;
case 545:
	switch( (*p) ) {
		case 69: goto st546;
		case 101: goto st546;
	}
	goto tr1237;
st546:
	if ( ++p == pe )
		goto _test_eof546;
case 546:
	switch( (*p) ) {
		case 77: goto st547;
		case 109: goto st547;
	}
	goto tr1237;
st547:
	if ( ++p == pe )
		goto _test_eof547;
case 547:
	switch( (*p) ) {
		case 68: goto st548;
		case 100: goto st548;
	}
	goto tr1237;
st548:
	if ( ++p == pe )
		goto _test_eof548;
case 548:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(2688 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 !s->multiline  ) _widec += 512;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(2688 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		if (
 !s->multiline  ) _widec += 512;
	}
	switch( _widec ) {
		case 9: goto tr1796;
		case 32: goto tr1796;
		case 40: goto tr1797;
		case 41: goto tr1798;
		case 3082: goto tr1799;
		case 3131: goto tr1800;
		case 3338: goto tr1801;
		case 3387: goto tr1801;
		case 3594: goto tr1802;
		case 3643: goto tr1803;
	}
	goto tr1237;
st549:
	if ( ++p == pe )
		goto _test_eof549;
case 549:
	switch( (*p) ) {
		case 83: goto st550;
		case 115: goto st550;
	}
	goto tr1237;
st550:
	if ( ++p == pe )
		goto _test_eof550;
case 550:
	switch( (*p) ) {
		case 68: goto st551;
		case 100: goto st551;
	}
	goto tr1237;
st551:
	if ( ++p == pe )
		goto _test_eof551;
case 551:
	switch( (*p) ) {
		case 66: goto st552;
		case 98: goto st552;
	}
	goto tr1237;
st552:
	if ( ++p == pe )
		goto _test_eof552;
case 552:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(2688 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 !s->multiline  ) _widec += 512;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(2688 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		if (
 !s->multiline  ) _widec += 512;
	}
	switch( _widec ) {
		case 9: goto tr1807;
		case 32: goto tr1807;
		case 40: goto tr1808;
		case 41: goto tr1809;
		case 3082: goto tr1810;
		case 3131: goto tr1811;
		case 3338: goto tr1812;
		case 3387: goto tr1812;
		case 3594: goto tr1813;
		case 3643: goto tr1814;
	}
	goto tr1237;
st553:
	if ( ++p == pe )
		goto _test_eof553;
case 553:
	switch( (*p) ) {
		case 76: goto st554;
		case 108: goto st554;
	}
	goto tr1237;
st554:
	if ( ++p == pe )
		goto _test_eof554;
case 554:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(2688 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 !s->multiline  ) _widec += 512;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(2688 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		if (
 !s->multiline  ) _widec += 512;
	}
	switch( _widec ) {
		case 9: goto tr1816;
		case 32: goto tr1816;
		case 40: goto tr1817;
		case 41: goto tr1818;
		case 3082: goto tr1819;
		case 3131: goto tr1820;
		case 3338: goto tr1821;
		case 3387: goto tr1821;
		case 3594: goto tr1822;
		case 3643: goto tr1823;
	}
	goto tr1237;
st555:
	if ( ++p == pe )
		goto _test_eof555;
case 555:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto st556;
		case 32: goto st556;
		case 40: goto tr1826;
		case 41: goto tr1827;
		case 2058: goto tr1828;
		case 2107: goto tr1829;
	}
	goto tr1824;
tr1826:
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st556;
tr1827:
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st556;
tr1828:
	{
		s->line_counter++;
	}
	goto st556;
tr1859:
	{
		s->buffer[s->buffer_length++] = 0;

		// Execute the comment callback.
		if (s->process.automatic && s->process.comment != NULL) {
			s->process.comment(s);

			// Stop if required from the callback.
			if (s->state == ZS_STATE_STOP) {
				{p++; cs = 556; goto _out;}
			}
		}
	}
	{
		s->line_counter++;
	}
	goto st556;
st556:
	if ( ++p == pe )
		goto _test_eof556;
case 556:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto st556;
		case 32: goto st556;
		case 40: goto tr1826;
		case 41: goto tr1827;
		case 2058: goto tr1828;
		case 2107: goto tr1829;
	}
	if ( 48 <= _widec && _widec <= 57 )
		goto tr1831;
	goto tr1830;
tr1831:
	{
		s->number64 = 0;
	}
	{
		// Overflow check: 10*(s->number64) + fc - '0' <= UINT64_MAX
		if ((s->number64 < (UINT64_MAX / 10)) ||   // Dominant fast check.
			((s->number64 == (UINT64_MAX / 10)) && // Marginal case.
			 ((uint8_t)(*p) <= (UINT64_MAX % 10) + '0')
			)
		   ) {
			s->number64 *= 10;
			s->number64 += digit_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_NUMBER64_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st557;
tr1835:
	{
		// Overflow check: 10*(s->number64) + fc - '0' <= UINT64_MAX
		if ((s->number64 < (UINT64_MAX / 10)) ||   // Dominant fast check.
			((s->number64 == (UINT64_MAX / 10)) && // Marginal case.
			 ((uint8_t)(*p) <= (UINT64_MAX % 10) + '0')
			)
		   ) {
			s->number64 *= 10;
			s->number64 += digit_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_NUMBER64_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st557;
st557:
	if ( ++p == pe )
		goto _test_eof557;
case 557:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr1832;
		case 32: goto tr1832;
		case 40: goto tr1833;
		case 41: goto tr1834;
		case 2058: goto tr1836;
		case 2107: goto tr1837;
	}
	if ( 48 <= _widec && _widec <= 57 )
		goto tr1835;
	goto tr1830;
tr1840:
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st558;
tr1841:
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st558;
tr1843:
	{
		s->line_counter++;
	}
	goto st558;
tr1857:
	{
		s->buffer[s->buffer_length++] = 0;

		// Execute the comment callback.
		if (s->process.automatic && s->process.comment != NULL) {
			s->process.comment(s);

			// Stop if required from the callback.
			if (s->state == ZS_STATE_STOP) {
				{p++; cs = 558; goto _out;}
			}
		}
	}
	{
		s->line_counter++;
	}
	goto st558;
tr1832:
	{
		if (s->number64 <= UINT16_MAX) {
			s->r_data_length = (uint16_t)(s->number64);
		} else {
			WARN(ZS_NUMBER16_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st558;
tr1833:
	{
		if (s->number64 <= UINT16_MAX) {
			s->r_data_length = (uint16_t)(s->number64);
		} else {
			WARN(ZS_NUMBER16_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st558;
tr1834:
	{
		if (s->number64 <= UINT16_MAX) {
			s->r_data_length = (uint16_t)(s->number64);
		} else {
			WARN(ZS_NUMBER16_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st558;
tr1836:
	{
		if (s->number64 <= UINT16_MAX) {
			s->r_data_length = (uint16_t)(s->number64);
		} else {
			WARN(ZS_NUMBER16_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		s->line_counter++;
	}
	goto st558;
st558:
	if ( ++p == pe )
		goto _test_eof558;
case 558:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto st558;
		case 32: goto st558;
		case 40: goto tr1840;
		case 41: goto tr1841;
		case 2058: goto tr1843;
		case 2107: goto tr1844;
	}
	if ( _widec < 65 ) {
		if ( 48 <= _widec && _widec <= 57 )
			goto tr1842;
	} else if ( _widec > 70 ) {
		if ( 97 <= _widec && _widec <= 102 )
			goto tr1842;
	} else
		goto tr1842;
	goto tr1838;
tr1842:
	{
		if (rdata_tail <= rdata_stop) {
			*rdata_tail = first_hex_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st559;
st559:
	if ( ++p == pe )
		goto _test_eof559;
case 559:
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr1845;
	} else if ( (*p) > 70 ) {
		if ( 97 <= (*p) && (*p) <= 102 )
			goto tr1845;
	} else
		goto tr1845;
	goto tr1838;
tr1847:
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st560;
tr1848:
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st560;
tr1849:
	{
		s->line_counter++;
	}
	goto st560;
tr1855:
	{
		s->buffer[s->buffer_length++] = 0;

		// Execute the comment callback.
		if (s->process.automatic && s->process.comment != NULL) {
			s->process.comment(s);

			// Stop if required from the callback.
			if (s->state == ZS_STATE_STOP) {
				{p++; cs = 560; goto _out;}
			}
		}
	}
	{
		s->line_counter++;
	}
	goto st560;
tr1845:
	{
		*rdata_tail += second_hex_to_num[(uint8_t)(*p)];
		rdata_tail++;
	}
	goto st560;
st560:
	if ( ++p == pe )
		goto _test_eof560;
case 560:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(2688 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 !s->multiline  ) _widec += 512;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(2688 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		if (
 !s->multiline  ) _widec += 512;
	}
	switch( _widec ) {
		case 9: goto st560;
		case 32: goto st560;
		case 40: goto tr1847;
		case 41: goto tr1848;
		case 3082: goto tr1849;
		case 3131: goto tr1850;
		case 3338: goto tr1851;
		case 3387: goto tr1851;
		case 3594: goto tr1852;
		case 3643: goto tr1853;
	}
	if ( _widec < 65 ) {
		if ( 48 <= _widec && _widec <= 57 )
			goto tr1842;
	} else if ( _widec > 70 ) {
		if ( 97 <= _widec && _widec <= 102 )
			goto tr1842;
	} else
		goto tr1842;
	goto tr1838;
tr1850:
	{
		s->buffer_length = 0;
	}
	goto st561;
tr1854:
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		}
	}
	goto st561;
st561:
	if ( ++p == pe )
		goto _test_eof561;
case 561:
	_widec = (*p);
	if ( (*p) < 10 ) {
		if ( (*p) <= 9 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) > 10 ) {
		if ( 11 <= (*p) )
 {			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	if ( _widec == 2058 )
		goto tr1855;
	if ( 1920 <= _widec && _widec <= 2175 )
		goto tr1854;
	goto tr1838;
tr1851:
	{
		if ((rdata_tail - s->r_data) != s->r_data_length) {
			WARN(ZS_BAD_RDATA_LENGTH);
			p--; {goto st316;}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1469;
st1469:
	if ( ++p == pe )
		goto _test_eof1469;
case 1469:
	goto st0;
tr1852:
	{
		s->line_counter++;
	}
	{
		if ((rdata_tail - s->r_data) != s->r_data_length) {
			WARN(ZS_BAD_RDATA_LENGTH);
			p--; {goto st316;}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1470;
st1470:
	if ( ++p == pe )
		goto _test_eof1470;
case 1470:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(2688 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 !s->multiline  ) _widec += 512;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(2688 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		if (
 !s->multiline  ) _widec += 512;
	}
	switch( _widec ) {
		case 9: goto st560;
		case 32: goto st560;
		case 40: goto tr1847;
		case 41: goto tr1848;
		case 3082: goto tr1849;
		case 3131: goto tr1850;
		case 3338: goto tr1851;
		case 3387: goto tr1851;
		case 3594: goto tr1852;
		case 3643: goto tr1853;
	}
	if ( _widec < 65 ) {
		if ( 48 <= _widec && _widec <= 57 )
			goto tr1842;
	} else if ( _widec > 70 ) {
		if ( 97 <= _widec && _widec <= 102 )
			goto tr1842;
	} else
		goto tr1842;
	goto tr1838;
tr1853:
	{
		s->buffer_length = 0;
	}
	{
		if ((rdata_tail - s->r_data) != s->r_data_length) {
			WARN(ZS_BAD_RDATA_LENGTH);
			p--; {goto st316;}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1471;
st1471:
	if ( ++p == pe )
		goto _test_eof1471;
case 1471:
	_widec = (*p);
	if ( (*p) < 10 ) {
		if ( (*p) <= 9 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) > 10 ) {
		if ( 11 <= (*p) )
 {			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	if ( _widec == 2058 )
		goto tr1855;
	if ( 1920 <= _widec && _widec <= 2175 )
		goto tr1854;
	goto tr1838;
tr1844:
	{
		s->buffer_length = 0;
	}
	goto st562;
tr1856:
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		}
	}
	goto st562;
tr1837:
	{
		if (s->number64 <= UINT16_MAX) {
			s->r_data_length = (uint16_t)(s->number64);
		} else {
			WARN(ZS_NUMBER16_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		s->buffer_length = 0;
	}
	goto st562;
st562:
	if ( ++p == pe )
		goto _test_eof562;
case 562:
	_widec = (*p);
	if ( (*p) < 10 ) {
		if ( (*p) <= 9 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) > 10 ) {
		if ( 11 <= (*p) )
 {			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	if ( _widec == 2058 )
		goto tr1857;
	if ( 1920 <= _widec && _widec <= 2175 )
		goto tr1856;
	goto tr1824;
tr1829:
	{
		s->buffer_length = 0;
	}
	goto st563;
tr1858:
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		}
	}
	goto st563;
st563:
	if ( ++p == pe )
		goto _test_eof563;
case 563:
	_widec = (*p);
	if ( (*p) < 10 ) {
		if ( (*p) <= 9 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) > 10 ) {
		if ( 11 <= (*p) )
 {			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	if ( _widec == 2058 )
		goto tr1859;
	if ( 1920 <= _widec && _widec <= 2175 )
		goto tr1858;
	goto tr1824;
st564:
	if ( ++p == pe )
		goto _test_eof564;
case 564:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto st565;
		case 32: goto st565;
		case 40: goto tr1861;
		case 41: goto tr1862;
		case 2058: goto tr1863;
		case 2107: goto tr1864;
	}
	goto tr1824;
tr1861:
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st565;
tr1862:
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st565;
tr1863:
	{
		s->line_counter++;
	}
	goto st565;
tr1899:
	{
		s->buffer[s->buffer_length++] = 0;

		// Execute the comment callback.
		if (s->process.automatic && s->process.comment != NULL) {
			s->process.comment(s);

			// Stop if required from the callback.
			if (s->state == ZS_STATE_STOP) {
				{p++; cs = 565; goto _out;}
			}
		}
	}
	{
		s->line_counter++;
	}
	goto st565;
st565:
	if ( ++p == pe )
		goto _test_eof565;
case 565:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto st565;
		case 32: goto st565;
		case 40: goto tr1861;
		case 41: goto tr1862;
		case 48: goto tr1865;
		case 2058: goto tr1863;
		case 2107: goto tr1864;
	}
	if ( 49 <= _widec && _widec <= 57 )
		goto tr1866;
	goto tr1830;
tr1865:
	{
		s->number64 = 0;
	}
	{
		// Overflow check: 10*(s->number64) + fc - '0' <= UINT64_MAX
		if ((s->number64 < (UINT64_MAX / 10)) ||   // Dominant fast check.
			((s->number64 == (UINT64_MAX / 10)) && // Marginal case.
			 ((uint8_t)(*p) <= (UINT64_MAX % 10) + '0')
			)
		   ) {
			s->number64 *= 10;
			s->number64 += digit_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_NUMBER64_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st566;
st566:
	if ( ++p == pe )
		goto _test_eof566;
case 566:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr1867;
		case 32: goto tr1867;
		case 40: goto tr1868;
		case 41: goto tr1869;
		case 1802: goto tr1871;
		case 1851: goto tr1871;
		case 2058: goto tr1872;
		case 2107: goto tr1873;
	}
	if ( 48 <= _widec && _widec <= 57 )
		goto tr1870;
	goto tr1830;
tr1867:
	{
		p--; {cs = stack[--top];goto _again;}
	}
	{
		if (s->number64 <= UINT16_MAX) {
			s->r_data_length = (uint16_t)(s->number64);
		} else {
			WARN(ZS_NUMBER16_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st1472;
tr1868:
	{
		p--; {cs = stack[--top];goto _again;}
	}
	{
		if (s->number64 <= UINT16_MAX) {
			s->r_data_length = (uint16_t)(s->number64);
		} else {
			WARN(ZS_NUMBER16_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st1472;
tr1869:
	{
		p--; {cs = stack[--top];goto _again;}
	}
	{
		if (s->number64 <= UINT16_MAX) {
			s->r_data_length = (uint16_t)(s->number64);
		} else {
			WARN(ZS_NUMBER16_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st1472;
tr1872:
	{
		p--; {cs = stack[--top];goto _again;}
	}
	{
		if (s->number64 <= UINT16_MAX) {
			s->r_data_length = (uint16_t)(s->number64);
		} else {
			WARN(ZS_NUMBER16_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		s->line_counter++;
	}
	goto st1472;
st1472:
	if ( ++p == pe )
		goto _test_eof1472;
case 1472:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto st567;
		case 32: goto st567;
		case 40: goto tr1875;
		case 41: goto tr1876;
		case 2058: goto tr1878;
		case 2107: goto tr1879;
	}
	if ( _widec < 65 ) {
		if ( 48 <= _widec && _widec <= 57 )
			goto tr1877;
	} else if ( _widec > 70 ) {
		if ( 97 <= _widec && _widec <= 102 )
			goto tr1877;
	} else
		goto tr1877;
	goto tr1838;
tr1875:
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st567;
tr1876:
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st567;
tr1878:
	{
		s->line_counter++;
	}
	goto st567;
tr1892:
	{
		s->buffer[s->buffer_length++] = 0;

		// Execute the comment callback.
		if (s->process.automatic && s->process.comment != NULL) {
			s->process.comment(s);

			// Stop if required from the callback.
			if (s->state == ZS_STATE_STOP) {
				{p++; cs = 567; goto _out;}
			}
		}
	}
	{
		s->line_counter++;
	}
	goto st567;
tr1893:
	{
		if (s->number64 <= UINT16_MAX) {
			s->r_data_length = (uint16_t)(s->number64);
		} else {
			WARN(ZS_NUMBER16_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st567;
tr1894:
	{
		if (s->number64 <= UINT16_MAX) {
			s->r_data_length = (uint16_t)(s->number64);
		} else {
			WARN(ZS_NUMBER16_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st567;
tr1895:
	{
		if (s->number64 <= UINT16_MAX) {
			s->r_data_length = (uint16_t)(s->number64);
		} else {
			WARN(ZS_NUMBER16_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st567;
tr1896:
	{
		if (s->number64 <= UINT16_MAX) {
			s->r_data_length = (uint16_t)(s->number64);
		} else {
			WARN(ZS_NUMBER16_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		s->line_counter++;
	}
	goto st567;
st567:
	if ( ++p == pe )
		goto _test_eof567;
case 567:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto st567;
		case 32: goto st567;
		case 40: goto tr1875;
		case 41: goto tr1876;
		case 2058: goto tr1878;
		case 2107: goto tr1879;
	}
	if ( _widec < 65 ) {
		if ( 48 <= _widec && _widec <= 57 )
			goto tr1877;
	} else if ( _widec > 70 ) {
		if ( 97 <= _widec && _widec <= 102 )
			goto tr1877;
	} else
		goto tr1877;
	goto tr1838;
tr1877:
	{
		if (rdata_tail <= rdata_stop) {
			*rdata_tail = first_hex_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st568;
st568:
	if ( ++p == pe )
		goto _test_eof568;
case 568:
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr1880;
	} else if ( (*p) > 70 ) {
		if ( 97 <= (*p) && (*p) <= 102 )
			goto tr1880;
	} else
		goto tr1880;
	goto tr1838;
tr1882:
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st569;
tr1883:
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st569;
tr1884:
	{
		s->line_counter++;
	}
	goto st569;
tr1890:
	{
		s->buffer[s->buffer_length++] = 0;

		// Execute the comment callback.
		if (s->process.automatic && s->process.comment != NULL) {
			s->process.comment(s);

			// Stop if required from the callback.
			if (s->state == ZS_STATE_STOP) {
				{p++; cs = 569; goto _out;}
			}
		}
	}
	{
		s->line_counter++;
	}
	goto st569;
tr1880:
	{
		*rdata_tail += second_hex_to_num[(uint8_t)(*p)];
		rdata_tail++;
	}
	goto st569;
st569:
	if ( ++p == pe )
		goto _test_eof569;
case 569:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(2688 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 !s->multiline  ) _widec += 512;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(2688 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		if (
 !s->multiline  ) _widec += 512;
	}
	switch( _widec ) {
		case 9: goto st569;
		case 32: goto st569;
		case 40: goto tr1882;
		case 41: goto tr1883;
		case 3082: goto tr1884;
		case 3131: goto tr1885;
		case 3338: goto tr1886;
		case 3387: goto tr1886;
		case 3594: goto tr1887;
		case 3643: goto tr1888;
	}
	if ( _widec < 65 ) {
		if ( 48 <= _widec && _widec <= 57 )
			goto tr1877;
	} else if ( _widec > 70 ) {
		if ( 97 <= _widec && _widec <= 102 )
			goto tr1877;
	} else
		goto tr1877;
	goto tr1838;
tr1885:
	{
		s->buffer_length = 0;
	}
	goto st570;
tr1889:
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		}
	}
	goto st570;
st570:
	if ( ++p == pe )
		goto _test_eof570;
case 570:
	_widec = (*p);
	if ( (*p) < 10 ) {
		if ( (*p) <= 9 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) > 10 ) {
		if ( 11 <= (*p) )
 {			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	if ( _widec == 2058 )
		goto tr1890;
	if ( 1920 <= _widec && _widec <= 2175 )
		goto tr1889;
	goto tr1838;
tr1871:
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1473;
tr1886:
	{
		if ((rdata_tail - s->r_data) != s->r_data_length) {
			WARN(ZS_BAD_RDATA_LENGTH);
			p--; {goto st316;}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1473;
st1473:
	if ( ++p == pe )
		goto _test_eof1473;
case 1473:
	goto tr1824;
tr1887:
	{
		s->line_counter++;
	}
	{
		if ((rdata_tail - s->r_data) != s->r_data_length) {
			WARN(ZS_BAD_RDATA_LENGTH);
			p--; {goto st316;}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1474;
st1474:
	if ( ++p == pe )
		goto _test_eof1474;
case 1474:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(2688 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 !s->multiline  ) _widec += 512;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(2688 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		if (
 !s->multiline  ) _widec += 512;
	}
	switch( _widec ) {
		case 9: goto st569;
		case 32: goto st569;
		case 40: goto tr1882;
		case 41: goto tr1883;
		case 3082: goto tr1884;
		case 3131: goto tr1885;
		case 3338: goto tr1886;
		case 3387: goto tr1886;
		case 3594: goto tr1887;
		case 3643: goto tr1888;
	}
	if ( _widec < 65 ) {
		if ( 48 <= _widec && _widec <= 57 )
			goto tr1877;
	} else if ( _widec > 70 ) {
		if ( 97 <= _widec && _widec <= 102 )
			goto tr1877;
	} else
		goto tr1877;
	goto tr1838;
tr1888:
	{
		s->buffer_length = 0;
	}
	{
		if ((rdata_tail - s->r_data) != s->r_data_length) {
			WARN(ZS_BAD_RDATA_LENGTH);
			p--; {goto st316;}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1475;
st1475:
	if ( ++p == pe )
		goto _test_eof1475;
case 1475:
	_widec = (*p);
	if ( (*p) < 10 ) {
		if ( (*p) <= 9 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) > 10 ) {
		if ( 11 <= (*p) )
 {			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	if ( _widec == 2058 )
		goto tr1890;
	if ( 1920 <= _widec && _widec <= 2175 )
		goto tr1889;
	goto tr1838;
tr1879:
	{
		s->buffer_length = 0;
	}
	goto st571;
tr1891:
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		}
	}
	goto st571;
tr1897:
	{
		if (s->number64 <= UINT16_MAX) {
			s->r_data_length = (uint16_t)(s->number64);
		} else {
			WARN(ZS_NUMBER16_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		s->buffer_length = 0;
	}
	goto st571;
st571:
	if ( ++p == pe )
		goto _test_eof571;
case 571:
	_widec = (*p);
	if ( (*p) < 10 ) {
		if ( (*p) <= 9 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) > 10 ) {
		if ( 11 <= (*p) )
 {			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	if ( _widec == 2058 )
		goto tr1892;
	if ( 1920 <= _widec && _widec <= 2175 )
		goto tr1891;
	goto tr1824;
tr1866:
	{
		s->number64 = 0;
	}
	{
		// Overflow check: 10*(s->number64) + fc - '0' <= UINT64_MAX
		if ((s->number64 < (UINT64_MAX / 10)) ||   // Dominant fast check.
			((s->number64 == (UINT64_MAX / 10)) && // Marginal case.
			 ((uint8_t)(*p) <= (UINT64_MAX % 10) + '0')
			)
		   ) {
			s->number64 *= 10;
			s->number64 += digit_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_NUMBER64_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st572;
tr1870:
	{
		// Overflow check: 10*(s->number64) + fc - '0' <= UINT64_MAX
		if ((s->number64 < (UINT64_MAX / 10)) ||   // Dominant fast check.
			((s->number64 == (UINT64_MAX / 10)) && // Marginal case.
			 ((uint8_t)(*p) <= (UINT64_MAX % 10) + '0')
			)
		   ) {
			s->number64 *= 10;
			s->number64 += digit_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_NUMBER64_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st572;
st572:
	if ( ++p == pe )
		goto _test_eof572;
case 572:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr1893;
		case 32: goto tr1893;
		case 40: goto tr1894;
		case 41: goto tr1895;
		case 2058: goto tr1896;
		case 2107: goto tr1897;
	}
	if ( 48 <= _widec && _widec <= 57 )
		goto tr1870;
	goto tr1830;
tr1873:
	{
		p--; {cs = stack[--top];goto _again;}
	}
	{
		if (s->number64 <= UINT16_MAX) {
			s->r_data_length = (uint16_t)(s->number64);
		} else {
			WARN(ZS_NUMBER16_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		s->buffer_length = 0;
	}
	goto st1476;
st1476:
	if ( ++p == pe )
		goto _test_eof1476;
case 1476:
	_widec = (*p);
	if ( (*p) < 10 ) {
		if ( (*p) <= 9 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) > 10 ) {
		if ( 11 <= (*p) )
 {			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	if ( _widec == 2058 )
		goto tr1892;
	if ( 1920 <= _widec && _widec <= 2175 )
		goto tr1891;
	goto tr1824;
tr1864:
	{
		s->buffer_length = 0;
	}
	goto st573;
tr1898:
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		}
	}
	goto st573;
st573:
	if ( ++p == pe )
		goto _test_eof573;
case 573:
	_widec = (*p);
	if ( (*p) < 10 ) {
		if ( (*p) <= 9 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) > 10 ) {
		if ( 11 <= (*p) )
 {			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	if ( _widec == 2058 )
		goto tr1899;
	if ( 1920 <= _widec && _widec <= 2175 )
		goto tr1898;
	goto tr1824;
st574:
	if ( ++p == pe )
		goto _test_eof574;
case 574:
	switch( (*p) ) {
		case 97: goto tr1901;
		case 100: goto tr1902;
		case 101: goto tr1903;
		case 105: goto tr1904;
		case 107: goto tr1905;
		case 110: goto tr1906;
		case 111: goto tr1907;
		case 112: goto tr1908;
	}
	goto tr1900;
tr1901:
	{
		if (rdata_tail + 2 > rdata_stop + 1) {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st575;
st575:
	if ( ++p == pe )
		goto _test_eof575;
case 575:
	if ( (*p) == 108 )
		goto st576;
	goto tr1900;
st576:
	if ( ++p == pe )
		goto _test_eof576;
case 576:
	if ( (*p) == 112 )
		goto st577;
	goto tr1900;
st577:
	if ( ++p == pe )
		goto _test_eof577;
case 577:
	if ( (*p) == 110 )
		goto st578;
	goto tr1900;
st578:
	if ( ++p == pe )
		goto _test_eof578;
case 578:
	switch( (*p) ) {
		case 32: goto tr1912;
		case 34: goto tr1912;
		case 44: goto tr1912;
		case 59: goto tr1912;
	}
	if ( (*p) > 10 ) {
		if ( 40 <= (*p) && (*p) <= 41 )
			goto tr1912;
	} else if ( (*p) >= 9 )
		goto tr1912;
	goto tr1900;
tr1912:
	{
		uint16_t val = htons(1);
		memcpy(rdata_tail, &val, 2);
		rdata_tail += 2;
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1477;
tr1919:
	{
		uint16_t val = htons(7);
		memcpy(rdata_tail, &val, 2);
		rdata_tail += 2;
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1477;
tr1922:
	{
		uint16_t val = htons(5);
		memcpy(rdata_tail, &val, 2);
		rdata_tail += 2;
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1477;
tr1931:
	{
		uint16_t val = htons(4);
		memcpy(rdata_tail, &val, 2);
		rdata_tail += 2;
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1477;
tr1936:
	{
		uint16_t val = htons(6);
		memcpy(rdata_tail, &val, 2);
		rdata_tail += 2;
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1477;
tr1941:
	{
		if (s->number64 <= UINT16_MAX) {
			uint16_t num16 = htons((uint16_t)s->number64);
			memcpy(rdata_tail, &num16, 2);
			rdata_tail += 2;
		} else {
			WARN(ZS_NUMBER16_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1477;
tr1957:
	{
		uint16_t val = htons(2);
		memcpy(rdata_tail, &val, 2);
		rdata_tail += 2;
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1477;
tr1962:
	{
		uint16_t val = htons(8);
		memcpy(rdata_tail, &val, 2);
		rdata_tail += 2;
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1477;
tr1966:
	{
		uint16_t val = htons(3);
		memcpy(rdata_tail, &val, 2);
		rdata_tail += 2;
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1477;
st1477:
	if ( ++p == pe )
		goto _test_eof1477;
case 1477:
	goto st0;
tr1902:
	{
		if (rdata_tail + 2 > rdata_stop + 1) {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st579;
st579:
	if ( ++p == pe )
		goto _test_eof579;
case 579:
	if ( (*p) == 111 )
		goto st580;
	goto tr1900;
st580:
	if ( ++p == pe )
		goto _test_eof580;
case 580:
	if ( (*p) == 104 )
		goto st581;
	goto tr1900;
st581:
	if ( ++p == pe )
		goto _test_eof581;
case 581:
	if ( (*p) == 112 )
		goto st582;
	goto tr1900;
st582:
	if ( ++p == pe )
		goto _test_eof582;
case 582:
	if ( (*p) == 97 )
		goto st583;
	goto tr1900;
st583:
	if ( ++p == pe )
		goto _test_eof583;
case 583:
	if ( (*p) == 116 )
		goto st584;
	goto tr1900;
st584:
	if ( ++p == pe )
		goto _test_eof584;
case 584:
	if ( (*p) == 104 )
		goto st585;
	goto tr1900;
st585:
	if ( ++p == pe )
		goto _test_eof585;
case 585:
	switch( (*p) ) {
		case 32: goto tr1919;
		case 34: goto tr1919;
		case 44: goto tr1919;
		case 59: goto tr1919;
	}
	if ( (*p) > 10 ) {
		if ( 40 <= (*p) && (*p) <= 41 )
			goto tr1919;
	} else if ( (*p) >= 9 )
		goto tr1919;
	goto tr1900;
tr1903:
	{
		if (rdata_tail + 2 > rdata_stop + 1) {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st586;
st586:
	if ( ++p == pe )
		goto _test_eof586;
case 586:
	if ( (*p) == 99 )
		goto st587;
	goto tr1900;
st587:
	if ( ++p == pe )
		goto _test_eof587;
case 587:
	if ( (*p) == 104 )
		goto st588;
	goto tr1900;
st588:
	if ( ++p == pe )
		goto _test_eof588;
case 588:
	switch( (*p) ) {
		case 32: goto tr1922;
		case 34: goto tr1922;
		case 44: goto tr1922;
		case 59: goto tr1922;
	}
	if ( (*p) > 10 ) {
		if ( 40 <= (*p) && (*p) <= 41 )
			goto tr1922;
	} else if ( (*p) >= 9 )
		goto tr1922;
	goto tr1900;
tr1904:
	{
		if (rdata_tail + 2 > rdata_stop + 1) {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st589;
st589:
	if ( ++p == pe )
		goto _test_eof589;
case 589:
	if ( (*p) == 112 )
		goto st590;
	goto tr1900;
st590:
	if ( ++p == pe )
		goto _test_eof590;
case 590:
	if ( (*p) == 118 )
		goto st591;
	goto tr1900;
st591:
	if ( ++p == pe )
		goto _test_eof591;
case 591:
	switch( (*p) ) {
		case 52: goto st592;
		case 54: goto st597;
	}
	goto tr1900;
st592:
	if ( ++p == pe )
		goto _test_eof592;
case 592:
	if ( (*p) == 104 )
		goto st593;
	goto tr1900;
st593:
	if ( ++p == pe )
		goto _test_eof593;
case 593:
	if ( (*p) == 105 )
		goto st594;
	goto tr1900;
st594:
	if ( ++p == pe )
		goto _test_eof594;
case 594:
	if ( (*p) == 110 )
		goto st595;
	goto tr1900;
st595:
	if ( ++p == pe )
		goto _test_eof595;
case 595:
	if ( (*p) == 116 )
		goto st596;
	goto tr1900;
st596:
	if ( ++p == pe )
		goto _test_eof596;
case 596:
	switch( (*p) ) {
		case 32: goto tr1931;
		case 34: goto tr1931;
		case 44: goto tr1931;
		case 59: goto tr1931;
	}
	if ( (*p) > 10 ) {
		if ( 40 <= (*p) && (*p) <= 41 )
			goto tr1931;
	} else if ( (*p) >= 9 )
		goto tr1931;
	goto tr1900;
st597:
	if ( ++p == pe )
		goto _test_eof597;
case 597:
	if ( (*p) == 104 )
		goto st598;
	goto tr1900;
st598:
	if ( ++p == pe )
		goto _test_eof598;
case 598:
	if ( (*p) == 105 )
		goto st599;
	goto tr1900;
st599:
	if ( ++p == pe )
		goto _test_eof599;
case 599:
	if ( (*p) == 110 )
		goto st600;
	goto tr1900;
st600:
	if ( ++p == pe )
		goto _test_eof600;
case 600:
	if ( (*p) == 116 )
		goto st601;
	goto tr1900;
st601:
	if ( ++p == pe )
		goto _test_eof601;
case 601:
	switch( (*p) ) {
		case 32: goto tr1936;
		case 34: goto tr1936;
		case 44: goto tr1936;
		case 59: goto tr1936;
	}
	if ( (*p) > 10 ) {
		if ( 40 <= (*p) && (*p) <= 41 )
			goto tr1936;
	} else if ( (*p) >= 9 )
		goto tr1936;
	goto tr1900;
tr1905:
	{
		if (rdata_tail + 2 > rdata_stop + 1) {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st602;
st602:
	if ( ++p == pe )
		goto _test_eof602;
case 602:
	if ( (*p) == 101 )
		goto st603;
	goto tr1900;
st603:
	if ( ++p == pe )
		goto _test_eof603;
case 603:
	if ( (*p) == 121 )
		goto st604;
	goto tr1900;
st604:
	if ( ++p == pe )
		goto _test_eof604;
case 604:
	if ( 48 <= (*p) && (*p) <= 57 )
		goto tr1940;
	goto tr1939;
tr1940:
	{
		s->number64 = 0;
	}
	{
		// Overflow check: 10*(s->number64) + fc - '0' <= UINT64_MAX
		if ((s->number64 < (UINT64_MAX / 10)) ||   // Dominant fast check.
			((s->number64 == (UINT64_MAX / 10)) && // Marginal case.
			 ((uint8_t)(*p) <= (UINT64_MAX % 10) + '0')
			)
		   ) {
			s->number64 *= 10;
			s->number64 += digit_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_NUMBER64_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st605;
tr1942:
	{
		// Overflow check: 10*(s->number64) + fc - '0' <= UINT64_MAX
		if ((s->number64 < (UINT64_MAX / 10)) ||   // Dominant fast check.
			((s->number64 == (UINT64_MAX / 10)) && // Marginal case.
			 ((uint8_t)(*p) <= (UINT64_MAX % 10) + '0')
			)
		   ) {
			s->number64 *= 10;
			s->number64 += digit_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_NUMBER64_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st605;
st605:
	if ( ++p == pe )
		goto _test_eof605;
case 605:
	switch( (*p) ) {
		case 32: goto tr1941;
		case 34: goto tr1941;
		case 44: goto tr1941;
		case 59: goto tr1941;
	}
	if ( (*p) < 40 ) {
		if ( 9 <= (*p) && (*p) <= 10 )
			goto tr1941;
	} else if ( (*p) > 41 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr1942;
	} else
		goto tr1941;
	goto tr1939;
tr1906:
	{
		if (rdata_tail + 2 > rdata_stop + 1) {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st606;
st606:
	if ( ++p == pe )
		goto _test_eof606;
case 606:
	if ( (*p) == 111 )
		goto st607;
	goto tr1900;
st607:
	if ( ++p == pe )
		goto _test_eof607;
case 607:
	if ( (*p) == 45 )
		goto st608;
	goto tr1900;
st608:
	if ( ++p == pe )
		goto _test_eof608;
case 608:
	if ( (*p) == 100 )
		goto st609;
	goto tr1900;
st609:
	if ( ++p == pe )
		goto _test_eof609;
case 609:
	if ( (*p) == 101 )
		goto st610;
	goto tr1900;
st610:
	if ( ++p == pe )
		goto _test_eof610;
case 610:
	if ( (*p) == 102 )
		goto st611;
	goto tr1900;
st611:
	if ( ++p == pe )
		goto _test_eof611;
case 611:
	if ( (*p) == 97 )
		goto st612;
	goto tr1900;
st612:
	if ( ++p == pe )
		goto _test_eof612;
case 612:
	if ( (*p) == 117 )
		goto st613;
	goto tr1900;
st613:
	if ( ++p == pe )
		goto _test_eof613;
case 613:
	if ( (*p) == 108 )
		goto st614;
	goto tr1900;
st614:
	if ( ++p == pe )
		goto _test_eof614;
case 614:
	if ( (*p) == 116 )
		goto st615;
	goto tr1900;
st615:
	if ( ++p == pe )
		goto _test_eof615;
case 615:
	if ( (*p) == 45 )
		goto st616;
	goto tr1900;
st616:
	if ( ++p == pe )
		goto _test_eof616;
case 616:
	if ( (*p) == 97 )
		goto st617;
	goto tr1900;
st617:
	if ( ++p == pe )
		goto _test_eof617;
case 617:
	if ( (*p) == 108 )
		goto st618;
	goto tr1900;
st618:
	if ( ++p == pe )
		goto _test_eof618;
case 618:
	if ( (*p) == 112 )
		goto st619;
	goto tr1900;
st619:
	if ( ++p == pe )
		goto _test_eof619;
case 619:
	if ( (*p) == 110 )
		goto st620;
	goto tr1900;
st620:
	if ( ++p == pe )
		goto _test_eof620;
case 620:
	switch( (*p) ) {
		case 32: goto tr1957;
		case 34: goto tr1957;
		case 44: goto tr1957;
		case 59: goto tr1957;
	}
	if ( (*p) > 10 ) {
		if ( 40 <= (*p) && (*p) <= 41 )
			goto tr1957;
	} else if ( (*p) >= 9 )
		goto tr1957;
	goto tr1900;
tr1907:
	{
		if (rdata_tail + 2 > rdata_stop + 1) {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st621;
st621:
	if ( ++p == pe )
		goto _test_eof621;
case 621:
	if ( (*p) == 104 )
		goto st622;
	goto tr1900;
st622:
	if ( ++p == pe )
		goto _test_eof622;
case 622:
	if ( (*p) == 116 )
		goto st623;
	goto tr1900;
st623:
	if ( ++p == pe )
		goto _test_eof623;
case 623:
	if ( (*p) == 116 )
		goto st624;
	goto tr1900;
st624:
	if ( ++p == pe )
		goto _test_eof624;
case 624:
	if ( (*p) == 112 )
		goto st625;
	goto tr1900;
st625:
	if ( ++p == pe )
		goto _test_eof625;
case 625:
	switch( (*p) ) {
		case 32: goto tr1962;
		case 34: goto tr1962;
		case 44: goto tr1962;
		case 59: goto tr1962;
	}
	if ( (*p) > 10 ) {
		if ( 40 <= (*p) && (*p) <= 41 )
			goto tr1962;
	} else if ( (*p) >= 9 )
		goto tr1962;
	goto tr1900;
tr1908:
	{
		if (rdata_tail + 2 > rdata_stop + 1) {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st626;
st626:
	if ( ++p == pe )
		goto _test_eof626;
case 626:
	if ( (*p) == 111 )
		goto st627;
	goto tr1900;
st627:
	if ( ++p == pe )
		goto _test_eof627;
case 627:
	if ( (*p) == 114 )
		goto st628;
	goto tr1900;
st628:
	if ( ++p == pe )
		goto _test_eof628;
case 628:
	if ( (*p) == 116 )
		goto st629;
	goto tr1900;
st629:
	if ( ++p == pe )
		goto _test_eof629;
case 629:
	switch( (*p) ) {
		case 32: goto tr1966;
		case 34: goto tr1966;
		case 44: goto tr1966;
		case 59: goto tr1966;
	}
	if ( (*p) > 10 ) {
		if ( 40 <= (*p) && (*p) <= 41 )
			goto tr1966;
	} else if ( (*p) >= 9 )
		goto tr1966;
	goto tr1900;
st630:
	if ( ++p == pe )
		goto _test_eof630;
case 630:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(2688 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 !s->multiline  ) _widec += 512;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(2688 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		if (
 !s->multiline  ) _widec += 512;
	}
	switch( _widec ) {
		case 9: goto tr1968;
		case 32: goto tr1968;
		case 40: goto tr1969;
		case 41: goto tr1970;
		case 3082: goto tr1971;
		case 3131: goto tr1972;
		case 3338: goto tr1973;
		case 3387: goto tr1973;
		case 3594: goto tr1974;
		case 3643: goto tr1975;
	}
	goto tr1967;
tr1977:
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st631;
tr1978:
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st631;
tr1988:
	{
		s->line_counter++;
	}
	goto st631;
tr2008:
	{
		s->buffer[s->buffer_length++] = 0;

		// Execute the comment callback.
		if (s->process.automatic && s->process.comment != NULL) {
			s->process.comment(s);

			// Stop if required from the callback.
			if (s->state == ZS_STATE_STOP) {
				{p++; cs = 631; goto _out;}
			}
		}
	}
	{
		s->line_counter++;
	}
	goto st631;
tr1968:
	{
		s->svcb.params_position = rdata_tail;
		s->svcb.last_key = -1;
	}
	goto st631;
tr1969:
	{
		s->svcb.params_position = rdata_tail;
		s->svcb.last_key = -1;
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st631;
tr1970:
	{
		s->svcb.params_position = rdata_tail;
		s->svcb.last_key = -1;
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st631;
tr1971:
	{
		s->svcb.params_position = rdata_tail;
		s->svcb.last_key = -1;
	}
	{
		s->line_counter++;
	}
	goto st631;
tr1999:
	{
		s->item_length = rdata_tail - s->item_length_location - 1;
		if (s->comma_list && s->item_length == 0) {
			WARN(ZS_EMPTY_LIST_ITEM);
			p--; {goto st316;}
		}
		if (s->item_length <= MAX_ITEM_LENGTH) {
			*(s->item_length_location) = (uint8_t)(s->item_length);
		} else {
			WARN(ZS_ITEM_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		s->comma_list = false;
		if (s->pending_backslash) {
			WARN(ZS_BAD_ALPN_BACKSLASH);
			p--; {goto st316;}
		}
	}
	{
		s->item_length = rdata_tail - s->item_length2_location - 2;

		if (s->item_length <= MAX_ITEM_LENGTH2) {
			uint16_t val = htons((uint16_t)(s->item_length));
			memcpy(s->item_length2_location, &val, 2);
		} else {
			WARN(ZS_ITEM_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		int ret = svcb_sort(s, rdata_tail);
		if (ret != ZS_OK) {
			WARN(ret);
			p--; {goto st316;}
		}
	}
	goto st631;
tr2000:
	{
		s->item_length = rdata_tail - s->item_length_location - 1;
		if (s->comma_list && s->item_length == 0) {
			WARN(ZS_EMPTY_LIST_ITEM);
			p--; {goto st316;}
		}
		if (s->item_length <= MAX_ITEM_LENGTH) {
			*(s->item_length_location) = (uint8_t)(s->item_length);
		} else {
			WARN(ZS_ITEM_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		s->comma_list = false;
		if (s->pending_backslash) {
			WARN(ZS_BAD_ALPN_BACKSLASH);
			p--; {goto st316;}
		}
	}
	{
		s->item_length = rdata_tail - s->item_length2_location - 2;

		if (s->item_length <= MAX_ITEM_LENGTH2) {
			uint16_t val = htons((uint16_t)(s->item_length));
			memcpy(s->item_length2_location, &val, 2);
		} else {
			WARN(ZS_ITEM_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		int ret = svcb_sort(s, rdata_tail);
		if (ret != ZS_OK) {
			WARN(ret);
			p--; {goto st316;}
		}
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st631;
tr2001:
	{
		s->item_length = rdata_tail - s->item_length_location - 1;
		if (s->comma_list && s->item_length == 0) {
			WARN(ZS_EMPTY_LIST_ITEM);
			p--; {goto st316;}
		}
		if (s->item_length <= MAX_ITEM_LENGTH) {
			*(s->item_length_location) = (uint8_t)(s->item_length);
		} else {
			WARN(ZS_ITEM_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		s->comma_list = false;
		if (s->pending_backslash) {
			WARN(ZS_BAD_ALPN_BACKSLASH);
			p--; {goto st316;}
		}
	}
	{
		s->item_length = rdata_tail - s->item_length2_location - 2;

		if (s->item_length <= MAX_ITEM_LENGTH2) {
			uint16_t val = htons((uint16_t)(s->item_length));
			memcpy(s->item_length2_location, &val, 2);
		} else {
			WARN(ZS_ITEM_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		int ret = svcb_sort(s, rdata_tail);
		if (ret != ZS_OK) {
			WARN(ret);
			p--; {goto st316;}
		}
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st631;
tr2002:
	{
		s->item_length = rdata_tail - s->item_length_location - 1;
		if (s->comma_list && s->item_length == 0) {
			WARN(ZS_EMPTY_LIST_ITEM);
			p--; {goto st316;}
		}
		if (s->item_length <= MAX_ITEM_LENGTH) {
			*(s->item_length_location) = (uint8_t)(s->item_length);
		} else {
			WARN(ZS_ITEM_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		s->comma_list = false;
		if (s->pending_backslash) {
			WARN(ZS_BAD_ALPN_BACKSLASH);
			p--; {goto st316;}
		}
	}
	{
		s->item_length = rdata_tail - s->item_length2_location - 2;

		if (s->item_length <= MAX_ITEM_LENGTH2) {
			uint16_t val = htons((uint16_t)(s->item_length));
			memcpy(s->item_length2_location, &val, 2);
		} else {
			WARN(ZS_ITEM_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		int ret = svcb_sort(s, rdata_tail);
		if (ret != ZS_OK) {
			WARN(ret);
			p--; {goto st316;}
		}
	}
	{
		s->line_counter++;
	}
	goto st631;
tr2018:
	{
		s->item_length = rdata_tail - s->item_length2_location - 2;

		if (s->item_length <= MAX_ITEM_LENGTH2) {
			uint16_t val = htons((uint16_t)(s->item_length));
			memcpy(s->item_length2_location, &val, 2);
		} else {
			WARN(ZS_ITEM_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		int ret = svcb_sort(s, rdata_tail);
		if (ret != ZS_OK) {
			WARN(ret);
			p--; {goto st316;}
		}
	}
	goto st631;
tr2019:
	{
		s->item_length = rdata_tail - s->item_length2_location - 2;

		if (s->item_length <= MAX_ITEM_LENGTH2) {
			uint16_t val = htons((uint16_t)(s->item_length));
			memcpy(s->item_length2_location, &val, 2);
		} else {
			WARN(ZS_ITEM_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		int ret = svcb_sort(s, rdata_tail);
		if (ret != ZS_OK) {
			WARN(ret);
			p--; {goto st316;}
		}
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st631;
tr2020:
	{
		s->item_length = rdata_tail - s->item_length2_location - 2;

		if (s->item_length <= MAX_ITEM_LENGTH2) {
			uint16_t val = htons((uint16_t)(s->item_length));
			memcpy(s->item_length2_location, &val, 2);
		} else {
			WARN(ZS_ITEM_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		int ret = svcb_sort(s, rdata_tail);
		if (ret != ZS_OK) {
			WARN(ret);
			p--; {goto st316;}
		}
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st631;
tr2021:
	{
		s->item_length = rdata_tail - s->item_length2_location - 2;

		if (s->item_length <= MAX_ITEM_LENGTH2) {
			uint16_t val = htons((uint16_t)(s->item_length));
			memcpy(s->item_length2_location, &val, 2);
		} else {
			WARN(ZS_ITEM_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		int ret = svcb_sort(s, rdata_tail);
		if (ret != ZS_OK) {
			WARN(ret);
			p--; {goto st316;}
		}
	}
	{
		s->line_counter++;
	}
	goto st631;
tr2028:
	{
		int ret = svcb_sort(s, rdata_tail);
		if (ret != ZS_OK) {
			WARN(ret);
			p--; {goto st316;}
		}
	}
	goto st631;
tr2029:
	{
		int ret = svcb_sort(s, rdata_tail);
		if (ret != ZS_OK) {
			WARN(ret);
			p--; {goto st316;}
		}
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st631;
tr2030:
	{
		int ret = svcb_sort(s, rdata_tail);
		if (ret != ZS_OK) {
			WARN(ret);
			p--; {goto st316;}
		}
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st631;
tr2031:
	{
		int ret = svcb_sort(s, rdata_tail);
		if (ret != ZS_OK) {
			WARN(ret);
			p--; {goto st316;}
		}
	}
	{
		s->line_counter++;
	}
	goto st631;
tr2071:
	{
		s->buffer[s->buffer_length] = 0;

		if (inet_pton(AF_INET, (char *)s->buffer, s->addr) <= 0) {
			WARN(ZS_BAD_IPV4);
			p--; {goto st316;}
		}
	}
	{
		if (rdata_tail + ZS_INET4_ADDR_LENGTH > rdata_stop + 1) {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
		memcpy(rdata_tail, s->addr, ZS_INET4_ADDR_LENGTH);
		rdata_tail += ZS_INET4_ADDR_LENGTH;
	}
	{
		s->item_length = rdata_tail - s->item_length2_location - 2;

		if (s->item_length <= MAX_ITEM_LENGTH2) {
			uint16_t val = htons((uint16_t)(s->item_length));
			memcpy(s->item_length2_location, &val, 2);
		} else {
			WARN(ZS_ITEM_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		int ret = svcb_sort(s, rdata_tail);
		if (ret != ZS_OK) {
			WARN(ret);
			p--; {goto st316;}
		}
	}
	goto st631;
tr2072:
	{
		s->buffer[s->buffer_length] = 0;

		if (inet_pton(AF_INET, (char *)s->buffer, s->addr) <= 0) {
			WARN(ZS_BAD_IPV4);
			p--; {goto st316;}
		}
	}
	{
		if (rdata_tail + ZS_INET4_ADDR_LENGTH > rdata_stop + 1) {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
		memcpy(rdata_tail, s->addr, ZS_INET4_ADDR_LENGTH);
		rdata_tail += ZS_INET4_ADDR_LENGTH;
	}
	{
		s->item_length = rdata_tail - s->item_length2_location - 2;

		if (s->item_length <= MAX_ITEM_LENGTH2) {
			uint16_t val = htons((uint16_t)(s->item_length));
			memcpy(s->item_length2_location, &val, 2);
		} else {
			WARN(ZS_ITEM_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		int ret = svcb_sort(s, rdata_tail);
		if (ret != ZS_OK) {
			WARN(ret);
			p--; {goto st316;}
		}
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st631;
tr2073:
	{
		s->buffer[s->buffer_length] = 0;

		if (inet_pton(AF_INET, (char *)s->buffer, s->addr) <= 0) {
			WARN(ZS_BAD_IPV4);
			p--; {goto st316;}
		}
	}
	{
		if (rdata_tail + ZS_INET4_ADDR_LENGTH > rdata_stop + 1) {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
		memcpy(rdata_tail, s->addr, ZS_INET4_ADDR_LENGTH);
		rdata_tail += ZS_INET4_ADDR_LENGTH;
	}
	{
		s->item_length = rdata_tail - s->item_length2_location - 2;

		if (s->item_length <= MAX_ITEM_LENGTH2) {
			uint16_t val = htons((uint16_t)(s->item_length));
			memcpy(s->item_length2_location, &val, 2);
		} else {
			WARN(ZS_ITEM_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		int ret = svcb_sort(s, rdata_tail);
		if (ret != ZS_OK) {
			WARN(ret);
			p--; {goto st316;}
		}
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st631;
tr2076:
	{
		s->buffer[s->buffer_length] = 0;

		if (inet_pton(AF_INET, (char *)s->buffer, s->addr) <= 0) {
			WARN(ZS_BAD_IPV4);
			p--; {goto st316;}
		}
	}
	{
		if (rdata_tail + ZS_INET4_ADDR_LENGTH > rdata_stop + 1) {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
		memcpy(rdata_tail, s->addr, ZS_INET4_ADDR_LENGTH);
		rdata_tail += ZS_INET4_ADDR_LENGTH;
	}
	{
		s->item_length = rdata_tail - s->item_length2_location - 2;

		if (s->item_length <= MAX_ITEM_LENGTH2) {
			uint16_t val = htons((uint16_t)(s->item_length));
			memcpy(s->item_length2_location, &val, 2);
		} else {
			WARN(ZS_ITEM_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		int ret = svcb_sort(s, rdata_tail);
		if (ret != ZS_OK) {
			WARN(ret);
			p--; {goto st316;}
		}
	}
	{
		s->line_counter++;
	}
	goto st631;
tr2094:
	{
		s->buffer[s->buffer_length] = 0;

		if (inet_pton(AF_INET6, (char *)s->buffer, s->addr) <= 0) {
			WARN(ZS_BAD_IPV6);
			p--; {goto st316;}
		}
	}
	{
		if (rdata_tail + ZS_INET6_ADDR_LENGTH > rdata_stop + 1) {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
		memcpy(rdata_tail, s->addr, ZS_INET6_ADDR_LENGTH);
		rdata_tail += ZS_INET6_ADDR_LENGTH;
	}
	{
		s->item_length = rdata_tail - s->item_length2_location - 2;

		if (s->item_length <= MAX_ITEM_LENGTH2) {
			uint16_t val = htons((uint16_t)(s->item_length));
			memcpy(s->item_length2_location, &val, 2);
		} else {
			WARN(ZS_ITEM_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		int ret = svcb_sort(s, rdata_tail);
		if (ret != ZS_OK) {
			WARN(ret);
			p--; {goto st316;}
		}
	}
	goto st631;
tr2095:
	{
		s->buffer[s->buffer_length] = 0;

		if (inet_pton(AF_INET6, (char *)s->buffer, s->addr) <= 0) {
			WARN(ZS_BAD_IPV6);
			p--; {goto st316;}
		}
	}
	{
		if (rdata_tail + ZS_INET6_ADDR_LENGTH > rdata_stop + 1) {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
		memcpy(rdata_tail, s->addr, ZS_INET6_ADDR_LENGTH);
		rdata_tail += ZS_INET6_ADDR_LENGTH;
	}
	{
		s->item_length = rdata_tail - s->item_length2_location - 2;

		if (s->item_length <= MAX_ITEM_LENGTH2) {
			uint16_t val = htons((uint16_t)(s->item_length));
			memcpy(s->item_length2_location, &val, 2);
		} else {
			WARN(ZS_ITEM_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		int ret = svcb_sort(s, rdata_tail);
		if (ret != ZS_OK) {
			WARN(ret);
			p--; {goto st316;}
		}
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st631;
tr2096:
	{
		s->buffer[s->buffer_length] = 0;

		if (inet_pton(AF_INET6, (char *)s->buffer, s->addr) <= 0) {
			WARN(ZS_BAD_IPV6);
			p--; {goto st316;}
		}
	}
	{
		if (rdata_tail + ZS_INET6_ADDR_LENGTH > rdata_stop + 1) {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
		memcpy(rdata_tail, s->addr, ZS_INET6_ADDR_LENGTH);
		rdata_tail += ZS_INET6_ADDR_LENGTH;
	}
	{
		s->item_length = rdata_tail - s->item_length2_location - 2;

		if (s->item_length <= MAX_ITEM_LENGTH2) {
			uint16_t val = htons((uint16_t)(s->item_length));
			memcpy(s->item_length2_location, &val, 2);
		} else {
			WARN(ZS_ITEM_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		int ret = svcb_sort(s, rdata_tail);
		if (ret != ZS_OK) {
			WARN(ret);
			p--; {goto st316;}
		}
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st631;
tr2099:
	{
		s->buffer[s->buffer_length] = 0;

		if (inet_pton(AF_INET6, (char *)s->buffer, s->addr) <= 0) {
			WARN(ZS_BAD_IPV6);
			p--; {goto st316;}
		}
	}
	{
		if (rdata_tail + ZS_INET6_ADDR_LENGTH > rdata_stop + 1) {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
		memcpy(rdata_tail, s->addr, ZS_INET6_ADDR_LENGTH);
		rdata_tail += ZS_INET6_ADDR_LENGTH;
	}
	{
		s->item_length = rdata_tail - s->item_length2_location - 2;

		if (s->item_length <= MAX_ITEM_LENGTH2) {
			uint16_t val = htons((uint16_t)(s->item_length));
			memcpy(s->item_length2_location, &val, 2);
		} else {
			WARN(ZS_ITEM_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		int ret = svcb_sort(s, rdata_tail);
		if (ret != ZS_OK) {
			WARN(ret);
			p--; {goto st316;}
		}
	}
	{
		s->line_counter++;
	}
	goto st631;
tr2109:
	{
		if (s->number64 <= UINT16_MAX) {
			uint16_t num16 = htons((uint16_t)s->number64);
			memcpy(rdata_tail, &num16, 2);
			rdata_tail += 2;
		} else {
			WARN(ZS_NUMBER16_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		uint16_t val = htons(0);
		memcpy(rdata_tail, &val, 2);
		rdata_tail += 2;
	}
	{
		int ret = svcb_sort(s, rdata_tail);
		if (ret != ZS_OK) {
			WARN(ret);
			p--; {goto st316;}
		}
	}
	goto st631;
tr2110:
	{
		if (s->number64 <= UINT16_MAX) {
			uint16_t num16 = htons((uint16_t)s->number64);
			memcpy(rdata_tail, &num16, 2);
			rdata_tail += 2;
		} else {
			WARN(ZS_NUMBER16_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		uint16_t val = htons(0);
		memcpy(rdata_tail, &val, 2);
		rdata_tail += 2;
	}
	{
		int ret = svcb_sort(s, rdata_tail);
		if (ret != ZS_OK) {
			WARN(ret);
			p--; {goto st316;}
		}
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st631;
tr2111:
	{
		if (s->number64 <= UINT16_MAX) {
			uint16_t num16 = htons((uint16_t)s->number64);
			memcpy(rdata_tail, &num16, 2);
			rdata_tail += 2;
		} else {
			WARN(ZS_NUMBER16_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		uint16_t val = htons(0);
		memcpy(rdata_tail, &val, 2);
		rdata_tail += 2;
	}
	{
		int ret = svcb_sort(s, rdata_tail);
		if (ret != ZS_OK) {
			WARN(ret);
			p--; {goto st316;}
		}
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st631;
tr2114:
	{
		if (s->number64 <= UINT16_MAX) {
			uint16_t num16 = htons((uint16_t)s->number64);
			memcpy(rdata_tail, &num16, 2);
			rdata_tail += 2;
		} else {
			WARN(ZS_NUMBER16_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		uint16_t val = htons(0);
		memcpy(rdata_tail, &val, 2);
		rdata_tail += 2;
	}
	{
		int ret = svcb_sort(s, rdata_tail);
		if (ret != ZS_OK) {
			WARN(ret);
			p--; {goto st316;}
		}
	}
	{
		s->line_counter++;
	}
	goto st631;
tr2134:
	{
		s->item_length = rdata_tail - s->item_length2_location - 2;

		if (s->item_length <= MAX_ITEM_LENGTH2) {
			uint16_t val = htons((uint16_t)(s->item_length));
			memcpy(s->item_length2_location, &val, 2);
		} else {
			WARN(ZS_ITEM_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		svcb_mandatory_sort(s->svcb.mandatory_position, rdata_tail);
	}
	{
		int ret = svcb_sort(s, rdata_tail);
		if (ret != ZS_OK) {
			WARN(ret);
			p--; {goto st316;}
		}
	}
	goto st631;
tr2135:
	{
		s->item_length = rdata_tail - s->item_length2_location - 2;

		if (s->item_length <= MAX_ITEM_LENGTH2) {
			uint16_t val = htons((uint16_t)(s->item_length));
			memcpy(s->item_length2_location, &val, 2);
		} else {
			WARN(ZS_ITEM_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		svcb_mandatory_sort(s->svcb.mandatory_position, rdata_tail);
	}
	{
		int ret = svcb_sort(s, rdata_tail);
		if (ret != ZS_OK) {
			WARN(ret);
			p--; {goto st316;}
		}
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st631;
tr2136:
	{
		s->item_length = rdata_tail - s->item_length2_location - 2;

		if (s->item_length <= MAX_ITEM_LENGTH2) {
			uint16_t val = htons((uint16_t)(s->item_length));
			memcpy(s->item_length2_location, &val, 2);
		} else {
			WARN(ZS_ITEM_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		svcb_mandatory_sort(s->svcb.mandatory_position, rdata_tail);
	}
	{
		int ret = svcb_sort(s, rdata_tail);
		if (ret != ZS_OK) {
			WARN(ret);
			p--; {goto st316;}
		}
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st631;
tr2138:
	{
		s->item_length = rdata_tail - s->item_length2_location - 2;

		if (s->item_length <= MAX_ITEM_LENGTH2) {
			uint16_t val = htons((uint16_t)(s->item_length));
			memcpy(s->item_length2_location, &val, 2);
		} else {
			WARN(ZS_ITEM_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		svcb_mandatory_sort(s->svcb.mandatory_position, rdata_tail);
	}
	{
		int ret = svcb_sort(s, rdata_tail);
		if (ret != ZS_OK) {
			WARN(ret);
			p--; {goto st316;}
		}
	}
	{
		s->line_counter++;
	}
	goto st631;
tr2158:
	{
		uint16_t val = htons(2);
		memcpy(rdata_tail, &val, 2);
		rdata_tail += 2;
	}
	{
		uint16_t val = htons(0);
		memcpy(rdata_tail, &val, 2);
		rdata_tail += 2;
	}
	{
		int ret = svcb_sort(s, rdata_tail);
		if (ret != ZS_OK) {
			WARN(ret);
			p--; {goto st316;}
		}
	}
	goto st631;
tr2159:
	{
		uint16_t val = htons(2);
		memcpy(rdata_tail, &val, 2);
		rdata_tail += 2;
	}
	{
		uint16_t val = htons(0);
		memcpy(rdata_tail, &val, 2);
		rdata_tail += 2;
	}
	{
		int ret = svcb_sort(s, rdata_tail);
		if (ret != ZS_OK) {
			WARN(ret);
			p--; {goto st316;}
		}
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st631;
tr2160:
	{
		uint16_t val = htons(2);
		memcpy(rdata_tail, &val, 2);
		rdata_tail += 2;
	}
	{
		uint16_t val = htons(0);
		memcpy(rdata_tail, &val, 2);
		rdata_tail += 2;
	}
	{
		int ret = svcb_sort(s, rdata_tail);
		if (ret != ZS_OK) {
			WARN(ret);
			p--; {goto st316;}
		}
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st631;
tr2161:
	{
		uint16_t val = htons(2);
		memcpy(rdata_tail, &val, 2);
		rdata_tail += 2;
	}
	{
		uint16_t val = htons(0);
		memcpy(rdata_tail, &val, 2);
		rdata_tail += 2;
	}
	{
		int ret = svcb_sort(s, rdata_tail);
		if (ret != ZS_OK) {
			WARN(ret);
			p--; {goto st316;}
		}
	}
	{
		s->line_counter++;
	}
	goto st631;
tr2170:
	{
		uint16_t val = htons(8);
		memcpy(rdata_tail, &val, 2);
		rdata_tail += 2;
	}
	{
		uint16_t val = htons(0);
		memcpy(rdata_tail, &val, 2);
		rdata_tail += 2;
	}
	{
		int ret = svcb_sort(s, rdata_tail);
		if (ret != ZS_OK) {
			WARN(ret);
			p--; {goto st316;}
		}
	}
	goto st631;
tr2171:
	{
		uint16_t val = htons(8);
		memcpy(rdata_tail, &val, 2);
		rdata_tail += 2;
	}
	{
		uint16_t val = htons(0);
		memcpy(rdata_tail, &val, 2);
		rdata_tail += 2;
	}
	{
		int ret = svcb_sort(s, rdata_tail);
		if (ret != ZS_OK) {
			WARN(ret);
			p--; {goto st316;}
		}
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st631;
tr2172:
	{
		uint16_t val = htons(8);
		memcpy(rdata_tail, &val, 2);
		rdata_tail += 2;
	}
	{
		uint16_t val = htons(0);
		memcpy(rdata_tail, &val, 2);
		rdata_tail += 2;
	}
	{
		int ret = svcb_sort(s, rdata_tail);
		if (ret != ZS_OK) {
			WARN(ret);
			p--; {goto st316;}
		}
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st631;
tr2173:
	{
		uint16_t val = htons(8);
		memcpy(rdata_tail, &val, 2);
		rdata_tail += 2;
	}
	{
		uint16_t val = htons(0);
		memcpy(rdata_tail, &val, 2);
		rdata_tail += 2;
	}
	{
		int ret = svcb_sort(s, rdata_tail);
		if (ret != ZS_OK) {
			WARN(ret);
			p--; {goto st316;}
		}
	}
	{
		s->line_counter++;
	}
	goto st631;
tr2187:
	{
		if (s->number64 <= UINT16_MAX) {
			uint16_t num16 = htons((uint16_t)s->number64);
			memcpy(rdata_tail, &num16, 2);
			rdata_tail += 2;
		} else {
			WARN(ZS_NUMBER16_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		int ret = svcb_sort(s, rdata_tail);
		if (ret != ZS_OK) {
			WARN(ret);
			p--; {goto st316;}
		}
	}
	goto st631;
tr2188:
	{
		if (s->number64 <= UINT16_MAX) {
			uint16_t num16 = htons((uint16_t)s->number64);
			memcpy(rdata_tail, &num16, 2);
			rdata_tail += 2;
		} else {
			WARN(ZS_NUMBER16_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		int ret = svcb_sort(s, rdata_tail);
		if (ret != ZS_OK) {
			WARN(ret);
			p--; {goto st316;}
		}
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st631;
tr2189:
	{
		if (s->number64 <= UINT16_MAX) {
			uint16_t num16 = htons((uint16_t)s->number64);
			memcpy(rdata_tail, &num16, 2);
			rdata_tail += 2;
		} else {
			WARN(ZS_NUMBER16_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		int ret = svcb_sort(s, rdata_tail);
		if (ret != ZS_OK) {
			WARN(ret);
			p--; {goto st316;}
		}
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st631;
tr2191:
	{
		if (s->number64 <= UINT16_MAX) {
			uint16_t num16 = htons((uint16_t)s->number64);
			memcpy(rdata_tail, &num16, 2);
			rdata_tail += 2;
		} else {
			WARN(ZS_NUMBER16_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		int ret = svcb_sort(s, rdata_tail);
		if (ret != ZS_OK) {
			WARN(ret);
			p--; {goto st316;}
		}
	}
	{
		s->line_counter++;
	}
	goto st631;
st631:
	if ( ++p == pe )
		goto _test_eof631;
case 631:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(2688 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 !s->multiline  ) _widec += 512;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(2688 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		if (
 !s->multiline  ) _widec += 512;
	}
	switch( _widec ) {
		case 9: goto st631;
		case 32: goto st631;
		case 40: goto tr1977;
		case 41: goto tr1978;
		case 97: goto tr1979;
		case 100: goto tr1980;
		case 101: goto tr1981;
		case 105: goto tr1982;
		case 107: goto tr1983;
		case 109: goto tr1984;
		case 110: goto tr1985;
		case 111: goto tr1986;
		case 112: goto tr1987;
		case 3082: goto tr1988;
		case 3131: goto tr1989;
		case 3338: goto tr1990;
		case 3387: goto tr1990;
		case 3594: goto tr1991;
		case 3643: goto tr1992;
	}
	goto tr1967;
tr1979:
	{
		if (rdata_tail + 4 > rdata_stop + 1) { // key_len + val_len
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
		s->svcb.param_position = rdata_tail;
	}
	goto st632;
st632:
	if ( ++p == pe )
		goto _test_eof632;
case 632:
	if ( (*p) == 108 )
		goto st633;
	goto tr1967;
st633:
	if ( ++p == pe )
		goto _test_eof633;
case 633:
	if ( (*p) == 112 )
		goto st634;
	goto tr1967;
st634:
	if ( ++p == pe )
		goto _test_eof634;
case 634:
	if ( (*p) == 110 )
		goto st635;
	goto tr1967;
st635:
	if ( ++p == pe )
		goto _test_eof635;
case 635:
	if ( (*p) == 61 )
		goto tr1996;
	goto tr1967;
tr1996:
	{
		uint16_t val = htons(1);
		memcpy(rdata_tail, &val, 2);
		rdata_tail += 2;
	}
	goto st636;
st636:
	if ( ++p == pe )
		goto _test_eof636;
case 636:
	switch( (*p) ) {
		case 32: goto tr1967;
		case 34: goto tr1998;
		case 59: goto tr1967;
	}
	if ( (*p) > 10 ) {
		if ( 40 <= (*p) && (*p) <= 41 )
			goto tr1967;
	} else if ( (*p) >= 9 )
		goto tr1967;
	goto tr1997;
tr1997:
	{
		s->comma_list = true;
		s->pending_backslash = false;
	}
	{
		if (rdata_tail < rdata_stop) {
			s->item_length2_location = rdata_tail;
			rdata_tail += 2;
		} else {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (rdata_tail <= rdata_stop) {
			s->item_length_location = rdata_tail++;
		} else {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{ p--; {stack[top++] = 637;goto st327;} }
	goto st637;
st637:
	if ( ++p == pe )
		goto _test_eof637;
case 637:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(2688 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 !s->multiline  ) _widec += 512;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(2688 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		if (
 !s->multiline  ) _widec += 512;
	}
	switch( _widec ) {
		case 9: goto tr1999;
		case 32: goto tr1999;
		case 40: goto tr2000;
		case 41: goto tr2001;
		case 3082: goto tr2002;
		case 3131: goto tr2003;
		case 3338: goto tr2004;
		case 3387: goto tr2004;
		case 3594: goto tr2005;
		case 3643: goto tr2006;
	}
	goto tr1967;
tr1989:
	{
		s->buffer_length = 0;
	}
	goto st638;
tr2007:
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		}
	}
	goto st638;
tr1972:
	{
		s->svcb.params_position = rdata_tail;
		s->svcb.last_key = -1;
	}
	{
		s->buffer_length = 0;
	}
	goto st638;
tr2003:
	{
		s->item_length = rdata_tail - s->item_length_location - 1;
		if (s->comma_list && s->item_length == 0) {
			WARN(ZS_EMPTY_LIST_ITEM);
			p--; {goto st316;}
		}
		if (s->item_length <= MAX_ITEM_LENGTH) {
			*(s->item_length_location) = (uint8_t)(s->item_length);
		} else {
			WARN(ZS_ITEM_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		s->comma_list = false;
		if (s->pending_backslash) {
			WARN(ZS_BAD_ALPN_BACKSLASH);
			p--; {goto st316;}
		}
	}
	{
		s->item_length = rdata_tail - s->item_length2_location - 2;

		if (s->item_length <= MAX_ITEM_LENGTH2) {
			uint16_t val = htons((uint16_t)(s->item_length));
			memcpy(s->item_length2_location, &val, 2);
		} else {
			WARN(ZS_ITEM_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		int ret = svcb_sort(s, rdata_tail);
		if (ret != ZS_OK) {
			WARN(ret);
			p--; {goto st316;}
		}
	}
	{
		s->buffer_length = 0;
	}
	goto st638;
tr2022:
	{
		s->item_length = rdata_tail - s->item_length2_location - 2;

		if (s->item_length <= MAX_ITEM_LENGTH2) {
			uint16_t val = htons((uint16_t)(s->item_length));
			memcpy(s->item_length2_location, &val, 2);
		} else {
			WARN(ZS_ITEM_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		int ret = svcb_sort(s, rdata_tail);
		if (ret != ZS_OK) {
			WARN(ret);
			p--; {goto st316;}
		}
	}
	{
		s->buffer_length = 0;
	}
	goto st638;
tr2032:
	{
		int ret = svcb_sort(s, rdata_tail);
		if (ret != ZS_OK) {
			WARN(ret);
			p--; {goto st316;}
		}
	}
	{
		s->buffer_length = 0;
	}
	goto st638;
tr2077:
	{
		s->buffer[s->buffer_length] = 0;

		if (inet_pton(AF_INET, (char *)s->buffer, s->addr) <= 0) {
			WARN(ZS_BAD_IPV4);
			p--; {goto st316;}
		}
	}
	{
		if (rdata_tail + ZS_INET4_ADDR_LENGTH > rdata_stop + 1) {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
		memcpy(rdata_tail, s->addr, ZS_INET4_ADDR_LENGTH);
		rdata_tail += ZS_INET4_ADDR_LENGTH;
	}
	{
		s->item_length = rdata_tail - s->item_length2_location - 2;

		if (s->item_length <= MAX_ITEM_LENGTH2) {
			uint16_t val = htons((uint16_t)(s->item_length));
			memcpy(s->item_length2_location, &val, 2);
		} else {
			WARN(ZS_ITEM_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		int ret = svcb_sort(s, rdata_tail);
		if (ret != ZS_OK) {
			WARN(ret);
			p--; {goto st316;}
		}
	}
	{
		s->buffer_length = 0;
	}
	goto st638;
tr2100:
	{
		s->buffer[s->buffer_length] = 0;

		if (inet_pton(AF_INET6, (char *)s->buffer, s->addr) <= 0) {
			WARN(ZS_BAD_IPV6);
			p--; {goto st316;}
		}
	}
	{
		if (rdata_tail + ZS_INET6_ADDR_LENGTH > rdata_stop + 1) {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
		memcpy(rdata_tail, s->addr, ZS_INET6_ADDR_LENGTH);
		rdata_tail += ZS_INET6_ADDR_LENGTH;
	}
	{
		s->item_length = rdata_tail - s->item_length2_location - 2;

		if (s->item_length <= MAX_ITEM_LENGTH2) {
			uint16_t val = htons((uint16_t)(s->item_length));
			memcpy(s->item_length2_location, &val, 2);
		} else {
			WARN(ZS_ITEM_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		int ret = svcb_sort(s, rdata_tail);
		if (ret != ZS_OK) {
			WARN(ret);
			p--; {goto st316;}
		}
	}
	{
		s->buffer_length = 0;
	}
	goto st638;
tr2115:
	{
		if (s->number64 <= UINT16_MAX) {
			uint16_t num16 = htons((uint16_t)s->number64);
			memcpy(rdata_tail, &num16, 2);
			rdata_tail += 2;
		} else {
			WARN(ZS_NUMBER16_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		uint16_t val = htons(0);
		memcpy(rdata_tail, &val, 2);
		rdata_tail += 2;
	}
	{
		int ret = svcb_sort(s, rdata_tail);
		if (ret != ZS_OK) {
			WARN(ret);
			p--; {goto st316;}
		}
	}
	{
		s->buffer_length = 0;
	}
	goto st638;
tr2139:
	{
		s->item_length = rdata_tail - s->item_length2_location - 2;

		if (s->item_length <= MAX_ITEM_LENGTH2) {
			uint16_t val = htons((uint16_t)(s->item_length));
			memcpy(s->item_length2_location, &val, 2);
		} else {
			WARN(ZS_ITEM_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		svcb_mandatory_sort(s->svcb.mandatory_position, rdata_tail);
	}
	{
		int ret = svcb_sort(s, rdata_tail);
		if (ret != ZS_OK) {
			WARN(ret);
			p--; {goto st316;}
		}
	}
	{
		s->buffer_length = 0;
	}
	goto st638;
tr2162:
	{
		uint16_t val = htons(2);
		memcpy(rdata_tail, &val, 2);
		rdata_tail += 2;
	}
	{
		uint16_t val = htons(0);
		memcpy(rdata_tail, &val, 2);
		rdata_tail += 2;
	}
	{
		int ret = svcb_sort(s, rdata_tail);
		if (ret != ZS_OK) {
			WARN(ret);
			p--; {goto st316;}
		}
	}
	{
		s->buffer_length = 0;
	}
	goto st638;
tr2174:
	{
		uint16_t val = htons(8);
		memcpy(rdata_tail, &val, 2);
		rdata_tail += 2;
	}
	{
		uint16_t val = htons(0);
		memcpy(rdata_tail, &val, 2);
		rdata_tail += 2;
	}
	{
		int ret = svcb_sort(s, rdata_tail);
		if (ret != ZS_OK) {
			WARN(ret);
			p--; {goto st316;}
		}
	}
	{
		s->buffer_length = 0;
	}
	goto st638;
tr2192:
	{
		if (s->number64 <= UINT16_MAX) {
			uint16_t num16 = htons((uint16_t)s->number64);
			memcpy(rdata_tail, &num16, 2);
			rdata_tail += 2;
		} else {
			WARN(ZS_NUMBER16_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		int ret = svcb_sort(s, rdata_tail);
		if (ret != ZS_OK) {
			WARN(ret);
			p--; {goto st316;}
		}
	}
	{
		s->buffer_length = 0;
	}
	goto st638;
st638:
	if ( ++p == pe )
		goto _test_eof638;
case 638:
	_widec = (*p);
	if ( (*p) < 10 ) {
		if ( (*p) <= 9 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) > 10 ) {
		if ( 11 <= (*p) )
 {			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	if ( _widec == 2058 )
		goto tr2008;
	if ( 1920 <= _widec && _widec <= 2175 )
		goto tr2007;
	goto tr1967;
tr1973:
	{
		s->svcb.params_position = rdata_tail;
		s->svcb.last_key = -1;
	}
	{
		int ret = svcb_check(s, rdata_tail);
		if (ret != ZS_OK) {
			WARN(ret);
			p--; {goto st316;}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1478;
tr1990:
	{
		int ret = svcb_check(s, rdata_tail);
		if (ret != ZS_OK) {
			WARN(ret);
			p--; {goto st316;}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1478;
tr2004:
	{
		s->item_length = rdata_tail - s->item_length_location - 1;
		if (s->comma_list && s->item_length == 0) {
			WARN(ZS_EMPTY_LIST_ITEM);
			p--; {goto st316;}
		}
		if (s->item_length <= MAX_ITEM_LENGTH) {
			*(s->item_length_location) = (uint8_t)(s->item_length);
		} else {
			WARN(ZS_ITEM_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		s->comma_list = false;
		if (s->pending_backslash) {
			WARN(ZS_BAD_ALPN_BACKSLASH);
			p--; {goto st316;}
		}
	}
	{
		s->item_length = rdata_tail - s->item_length2_location - 2;

		if (s->item_length <= MAX_ITEM_LENGTH2) {
			uint16_t val = htons((uint16_t)(s->item_length));
			memcpy(s->item_length2_location, &val, 2);
		} else {
			WARN(ZS_ITEM_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		int ret = svcb_sort(s, rdata_tail);
		if (ret != ZS_OK) {
			WARN(ret);
			p--; {goto st316;}
		}
	}
	{
		int ret = svcb_check(s, rdata_tail);
		if (ret != ZS_OK) {
			WARN(ret);
			p--; {goto st316;}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1478;
tr2023:
	{
		s->item_length = rdata_tail - s->item_length2_location - 2;

		if (s->item_length <= MAX_ITEM_LENGTH2) {
			uint16_t val = htons((uint16_t)(s->item_length));
			memcpy(s->item_length2_location, &val, 2);
		} else {
			WARN(ZS_ITEM_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		int ret = svcb_sort(s, rdata_tail);
		if (ret != ZS_OK) {
			WARN(ret);
			p--; {goto st316;}
		}
	}
	{
		int ret = svcb_check(s, rdata_tail);
		if (ret != ZS_OK) {
			WARN(ret);
			p--; {goto st316;}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1478;
tr2033:
	{
		int ret = svcb_sort(s, rdata_tail);
		if (ret != ZS_OK) {
			WARN(ret);
			p--; {goto st316;}
		}
	}
	{
		int ret = svcb_check(s, rdata_tail);
		if (ret != ZS_OK) {
			WARN(ret);
			p--; {goto st316;}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1478;
tr2078:
	{
		s->buffer[s->buffer_length] = 0;

		if (inet_pton(AF_INET, (char *)s->buffer, s->addr) <= 0) {
			WARN(ZS_BAD_IPV4);
			p--; {goto st316;}
		}
	}
	{
		if (rdata_tail + ZS_INET4_ADDR_LENGTH > rdata_stop + 1) {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
		memcpy(rdata_tail, s->addr, ZS_INET4_ADDR_LENGTH);
		rdata_tail += ZS_INET4_ADDR_LENGTH;
	}
	{
		s->item_length = rdata_tail - s->item_length2_location - 2;

		if (s->item_length <= MAX_ITEM_LENGTH2) {
			uint16_t val = htons((uint16_t)(s->item_length));
			memcpy(s->item_length2_location, &val, 2);
		} else {
			WARN(ZS_ITEM_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		int ret = svcb_sort(s, rdata_tail);
		if (ret != ZS_OK) {
			WARN(ret);
			p--; {goto st316;}
		}
	}
	{
		int ret = svcb_check(s, rdata_tail);
		if (ret != ZS_OK) {
			WARN(ret);
			p--; {goto st316;}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1478;
tr2101:
	{
		s->buffer[s->buffer_length] = 0;

		if (inet_pton(AF_INET6, (char *)s->buffer, s->addr) <= 0) {
			WARN(ZS_BAD_IPV6);
			p--; {goto st316;}
		}
	}
	{
		if (rdata_tail + ZS_INET6_ADDR_LENGTH > rdata_stop + 1) {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
		memcpy(rdata_tail, s->addr, ZS_INET6_ADDR_LENGTH);
		rdata_tail += ZS_INET6_ADDR_LENGTH;
	}
	{
		s->item_length = rdata_tail - s->item_length2_location - 2;

		if (s->item_length <= MAX_ITEM_LENGTH2) {
			uint16_t val = htons((uint16_t)(s->item_length));
			memcpy(s->item_length2_location, &val, 2);
		} else {
			WARN(ZS_ITEM_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		int ret = svcb_sort(s, rdata_tail);
		if (ret != ZS_OK) {
			WARN(ret);
			p--; {goto st316;}
		}
	}
	{
		int ret = svcb_check(s, rdata_tail);
		if (ret != ZS_OK) {
			WARN(ret);
			p--; {goto st316;}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1478;
tr2116:
	{
		if (s->number64 <= UINT16_MAX) {
			uint16_t num16 = htons((uint16_t)s->number64);
			memcpy(rdata_tail, &num16, 2);
			rdata_tail += 2;
		} else {
			WARN(ZS_NUMBER16_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		uint16_t val = htons(0);
		memcpy(rdata_tail, &val, 2);
		rdata_tail += 2;
	}
	{
		int ret = svcb_sort(s, rdata_tail);
		if (ret != ZS_OK) {
			WARN(ret);
			p--; {goto st316;}
		}
	}
	{
		int ret = svcb_check(s, rdata_tail);
		if (ret != ZS_OK) {
			WARN(ret);
			p--; {goto st316;}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1478;
tr2140:
	{
		s->item_length = rdata_tail - s->item_length2_location - 2;

		if (s->item_length <= MAX_ITEM_LENGTH2) {
			uint16_t val = htons((uint16_t)(s->item_length));
			memcpy(s->item_length2_location, &val, 2);
		} else {
			WARN(ZS_ITEM_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		svcb_mandatory_sort(s->svcb.mandatory_position, rdata_tail);
	}
	{
		int ret = svcb_sort(s, rdata_tail);
		if (ret != ZS_OK) {
			WARN(ret);
			p--; {goto st316;}
		}
	}
	{
		int ret = svcb_check(s, rdata_tail);
		if (ret != ZS_OK) {
			WARN(ret);
			p--; {goto st316;}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1478;
tr2163:
	{
		uint16_t val = htons(2);
		memcpy(rdata_tail, &val, 2);
		rdata_tail += 2;
	}
	{
		uint16_t val = htons(0);
		memcpy(rdata_tail, &val, 2);
		rdata_tail += 2;
	}
	{
		int ret = svcb_sort(s, rdata_tail);
		if (ret != ZS_OK) {
			WARN(ret);
			p--; {goto st316;}
		}
	}
	{
		int ret = svcb_check(s, rdata_tail);
		if (ret != ZS_OK) {
			WARN(ret);
			p--; {goto st316;}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1478;
tr2175:
	{
		uint16_t val = htons(8);
		memcpy(rdata_tail, &val, 2);
		rdata_tail += 2;
	}
	{
		uint16_t val = htons(0);
		memcpy(rdata_tail, &val, 2);
		rdata_tail += 2;
	}
	{
		int ret = svcb_sort(s, rdata_tail);
		if (ret != ZS_OK) {
			WARN(ret);
			p--; {goto st316;}
		}
	}
	{
		int ret = svcb_check(s, rdata_tail);
		if (ret != ZS_OK) {
			WARN(ret);
			p--; {goto st316;}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1478;
tr2193:
	{
		if (s->number64 <= UINT16_MAX) {
			uint16_t num16 = htons((uint16_t)s->number64);
			memcpy(rdata_tail, &num16, 2);
			rdata_tail += 2;
		} else {
			WARN(ZS_NUMBER16_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		int ret = svcb_sort(s, rdata_tail);
		if (ret != ZS_OK) {
			WARN(ret);
			p--; {goto st316;}
		}
	}
	{
		int ret = svcb_check(s, rdata_tail);
		if (ret != ZS_OK) {
			WARN(ret);
			p--; {goto st316;}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1478;
st1478:
	if ( ++p == pe )
		goto _test_eof1478;
case 1478:
	goto st0;
tr1974:
	{
		s->svcb.params_position = rdata_tail;
		s->svcb.last_key = -1;
	}
	{
		s->line_counter++;
	}
	{
		int ret = svcb_check(s, rdata_tail);
		if (ret != ZS_OK) {
			WARN(ret);
			p--; {goto st316;}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1479;
tr1991:
	{
		s->line_counter++;
	}
	{
		int ret = svcb_check(s, rdata_tail);
		if (ret != ZS_OK) {
			WARN(ret);
			p--; {goto st316;}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1479;
tr2005:
	{
		s->item_length = rdata_tail - s->item_length_location - 1;
		if (s->comma_list && s->item_length == 0) {
			WARN(ZS_EMPTY_LIST_ITEM);
			p--; {goto st316;}
		}
		if (s->item_length <= MAX_ITEM_LENGTH) {
			*(s->item_length_location) = (uint8_t)(s->item_length);
		} else {
			WARN(ZS_ITEM_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		s->comma_list = false;
		if (s->pending_backslash) {
			WARN(ZS_BAD_ALPN_BACKSLASH);
			p--; {goto st316;}
		}
	}
	{
		s->item_length = rdata_tail - s->item_length2_location - 2;

		if (s->item_length <= MAX_ITEM_LENGTH2) {
			uint16_t val = htons((uint16_t)(s->item_length));
			memcpy(s->item_length2_location, &val, 2);
		} else {
			WARN(ZS_ITEM_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		int ret = svcb_sort(s, rdata_tail);
		if (ret != ZS_OK) {
			WARN(ret);
			p--; {goto st316;}
		}
	}
	{
		s->line_counter++;
	}
	{
		int ret = svcb_check(s, rdata_tail);
		if (ret != ZS_OK) {
			WARN(ret);
			p--; {goto st316;}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1479;
tr2024:
	{
		s->item_length = rdata_tail - s->item_length2_location - 2;

		if (s->item_length <= MAX_ITEM_LENGTH2) {
			uint16_t val = htons((uint16_t)(s->item_length));
			memcpy(s->item_length2_location, &val, 2);
		} else {
			WARN(ZS_ITEM_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		int ret = svcb_sort(s, rdata_tail);
		if (ret != ZS_OK) {
			WARN(ret);
			p--; {goto st316;}
		}
	}
	{
		s->line_counter++;
	}
	{
		int ret = svcb_check(s, rdata_tail);
		if (ret != ZS_OK) {
			WARN(ret);
			p--; {goto st316;}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1479;
tr2034:
	{
		int ret = svcb_sort(s, rdata_tail);
		if (ret != ZS_OK) {
			WARN(ret);
			p--; {goto st316;}
		}
	}
	{
		s->line_counter++;
	}
	{
		int ret = svcb_check(s, rdata_tail);
		if (ret != ZS_OK) {
			WARN(ret);
			p--; {goto st316;}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1479;
tr2079:
	{
		s->buffer[s->buffer_length] = 0;

		if (inet_pton(AF_INET, (char *)s->buffer, s->addr) <= 0) {
			WARN(ZS_BAD_IPV4);
			p--; {goto st316;}
		}
	}
	{
		if (rdata_tail + ZS_INET4_ADDR_LENGTH > rdata_stop + 1) {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
		memcpy(rdata_tail, s->addr, ZS_INET4_ADDR_LENGTH);
		rdata_tail += ZS_INET4_ADDR_LENGTH;
	}
	{
		s->item_length = rdata_tail - s->item_length2_location - 2;

		if (s->item_length <= MAX_ITEM_LENGTH2) {
			uint16_t val = htons((uint16_t)(s->item_length));
			memcpy(s->item_length2_location, &val, 2);
		} else {
			WARN(ZS_ITEM_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		int ret = svcb_sort(s, rdata_tail);
		if (ret != ZS_OK) {
			WARN(ret);
			p--; {goto st316;}
		}
	}
	{
		s->line_counter++;
	}
	{
		int ret = svcb_check(s, rdata_tail);
		if (ret != ZS_OK) {
			WARN(ret);
			p--; {goto st316;}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1479;
tr2102:
	{
		s->buffer[s->buffer_length] = 0;

		if (inet_pton(AF_INET6, (char *)s->buffer, s->addr) <= 0) {
			WARN(ZS_BAD_IPV6);
			p--; {goto st316;}
		}
	}
	{
		if (rdata_tail + ZS_INET6_ADDR_LENGTH > rdata_stop + 1) {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
		memcpy(rdata_tail, s->addr, ZS_INET6_ADDR_LENGTH);
		rdata_tail += ZS_INET6_ADDR_LENGTH;
	}
	{
		s->item_length = rdata_tail - s->item_length2_location - 2;

		if (s->item_length <= MAX_ITEM_LENGTH2) {
			uint16_t val = htons((uint16_t)(s->item_length));
			memcpy(s->item_length2_location, &val, 2);
		} else {
			WARN(ZS_ITEM_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		int ret = svcb_sort(s, rdata_tail);
		if (ret != ZS_OK) {
			WARN(ret);
			p--; {goto st316;}
		}
	}
	{
		s->line_counter++;
	}
	{
		int ret = svcb_check(s, rdata_tail);
		if (ret != ZS_OK) {
			WARN(ret);
			p--; {goto st316;}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1479;
tr2117:
	{
		if (s->number64 <= UINT16_MAX) {
			uint16_t num16 = htons((uint16_t)s->number64);
			memcpy(rdata_tail, &num16, 2);
			rdata_tail += 2;
		} else {
			WARN(ZS_NUMBER16_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		uint16_t val = htons(0);
		memcpy(rdata_tail, &val, 2);
		rdata_tail += 2;
	}
	{
		int ret = svcb_sort(s, rdata_tail);
		if (ret != ZS_OK) {
			WARN(ret);
			p--; {goto st316;}
		}
	}
	{
		s->line_counter++;
	}
	{
		int ret = svcb_check(s, rdata_tail);
		if (ret != ZS_OK) {
			WARN(ret);
			p--; {goto st316;}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1479;
tr2141:
	{
		s->item_length = rdata_tail - s->item_length2_location - 2;

		if (s->item_length <= MAX_ITEM_LENGTH2) {
			uint16_t val = htons((uint16_t)(s->item_length));
			memcpy(s->item_length2_location, &val, 2);
		} else {
			WARN(ZS_ITEM_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		svcb_mandatory_sort(s->svcb.mandatory_position, rdata_tail);
	}
	{
		int ret = svcb_sort(s, rdata_tail);
		if (ret != ZS_OK) {
			WARN(ret);
			p--; {goto st316;}
		}
	}
	{
		s->line_counter++;
	}
	{
		int ret = svcb_check(s, rdata_tail);
		if (ret != ZS_OK) {
			WARN(ret);
			p--; {goto st316;}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1479;
tr2164:
	{
		uint16_t val = htons(2);
		memcpy(rdata_tail, &val, 2);
		rdata_tail += 2;
	}
	{
		uint16_t val = htons(0);
		memcpy(rdata_tail, &val, 2);
		rdata_tail += 2;
	}
	{
		int ret = svcb_sort(s, rdata_tail);
		if (ret != ZS_OK) {
			WARN(ret);
			p--; {goto st316;}
		}
	}
	{
		s->line_counter++;
	}
	{
		int ret = svcb_check(s, rdata_tail);
		if (ret != ZS_OK) {
			WARN(ret);
			p--; {goto st316;}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1479;
tr2176:
	{
		uint16_t val = htons(8);
		memcpy(rdata_tail, &val, 2);
		rdata_tail += 2;
	}
	{
		uint16_t val = htons(0);
		memcpy(rdata_tail, &val, 2);
		rdata_tail += 2;
	}
	{
		int ret = svcb_sort(s, rdata_tail);
		if (ret != ZS_OK) {
			WARN(ret);
			p--; {goto st316;}
		}
	}
	{
		s->line_counter++;
	}
	{
		int ret = svcb_check(s, rdata_tail);
		if (ret != ZS_OK) {
			WARN(ret);
			p--; {goto st316;}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1479;
tr2194:
	{
		if (s->number64 <= UINT16_MAX) {
			uint16_t num16 = htons((uint16_t)s->number64);
			memcpy(rdata_tail, &num16, 2);
			rdata_tail += 2;
		} else {
			WARN(ZS_NUMBER16_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		int ret = svcb_sort(s, rdata_tail);
		if (ret != ZS_OK) {
			WARN(ret);
			p--; {goto st316;}
		}
	}
	{
		s->line_counter++;
	}
	{
		int ret = svcb_check(s, rdata_tail);
		if (ret != ZS_OK) {
			WARN(ret);
			p--; {goto st316;}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1479;
st1479:
	if ( ++p == pe )
		goto _test_eof1479;
case 1479:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(2688 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 !s->multiline  ) _widec += 512;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(2688 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		if (
 !s->multiline  ) _widec += 512;
	}
	switch( _widec ) {
		case 9: goto st631;
		case 32: goto st631;
		case 40: goto tr1977;
		case 41: goto tr1978;
		case 97: goto tr1979;
		case 100: goto tr1980;
		case 101: goto tr1981;
		case 105: goto tr1982;
		case 107: goto tr1983;
		case 109: goto tr1984;
		case 110: goto tr1985;
		case 111: goto tr1986;
		case 112: goto tr1987;
		case 3082: goto tr1988;
		case 3131: goto tr1989;
		case 3338: goto tr1990;
		case 3387: goto tr1990;
		case 3594: goto tr1991;
		case 3643: goto tr1992;
	}
	goto tr1967;
tr1980:
	{
		if (rdata_tail + 4 > rdata_stop + 1) { // key_len + val_len
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
		s->svcb.param_position = rdata_tail;
	}
	goto st639;
st639:
	if ( ++p == pe )
		goto _test_eof639;
case 639:
	if ( (*p) == 111 )
		goto st640;
	goto tr1967;
st640:
	if ( ++p == pe )
		goto _test_eof640;
case 640:
	if ( (*p) == 104 )
		goto st641;
	goto tr1967;
st641:
	if ( ++p == pe )
		goto _test_eof641;
case 641:
	if ( (*p) == 112 )
		goto st642;
	goto tr1967;
st642:
	if ( ++p == pe )
		goto _test_eof642;
case 642:
	if ( (*p) == 97 )
		goto st643;
	goto tr1967;
st643:
	if ( ++p == pe )
		goto _test_eof643;
case 643:
	if ( (*p) == 116 )
		goto st644;
	goto tr1967;
st644:
	if ( ++p == pe )
		goto _test_eof644;
case 644:
	if ( (*p) == 104 )
		goto st645;
	goto tr1967;
st645:
	if ( ++p == pe )
		goto _test_eof645;
case 645:
	if ( (*p) == 61 )
		goto tr2015;
	goto tr1967;
tr2015:
	{
		uint16_t val = htons(7);
		memcpy(rdata_tail, &val, 2);
		rdata_tail += 2;
	}
	goto st646;
st646:
	if ( ++p == pe )
		goto _test_eof646;
case 646:
	switch( (*p) ) {
		case 32: goto tr1967;
		case 34: goto tr2017;
		case 59: goto tr1967;
	}
	if ( (*p) > 10 ) {
		if ( 40 <= (*p) && (*p) <= 41 )
			goto tr1967;
	} else if ( (*p) >= 9 )
		goto tr1967;
	goto tr2016;
tr2016:
	{
		if (rdata_tail < rdata_stop) {
			s->item_length2_location = rdata_tail;
			rdata_tail += 2;
		} else {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{ p--; {stack[top++] = 647;goto st327;} }
	goto st647;
st647:
	if ( ++p == pe )
		goto _test_eof647;
case 647:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(2688 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 !s->multiline  ) _widec += 512;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(2688 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		if (
 !s->multiline  ) _widec += 512;
	}
	switch( _widec ) {
		case 9: goto tr2018;
		case 32: goto tr2018;
		case 40: goto tr2019;
		case 41: goto tr2020;
		case 3082: goto tr2021;
		case 3131: goto tr2022;
		case 3338: goto tr2023;
		case 3387: goto tr2023;
		case 3594: goto tr2024;
		case 3643: goto tr2025;
	}
	goto tr1967;
tr1975:
	{
		s->svcb.params_position = rdata_tail;
		s->svcb.last_key = -1;
	}
	{
		s->buffer_length = 0;
	}
	{
		int ret = svcb_check(s, rdata_tail);
		if (ret != ZS_OK) {
			WARN(ret);
			p--; {goto st316;}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1480;
tr1992:
	{
		s->buffer_length = 0;
	}
	{
		int ret = svcb_check(s, rdata_tail);
		if (ret != ZS_OK) {
			WARN(ret);
			p--; {goto st316;}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1480;
tr2006:
	{
		s->item_length = rdata_tail - s->item_length_location - 1;
		if (s->comma_list && s->item_length == 0) {
			WARN(ZS_EMPTY_LIST_ITEM);
			p--; {goto st316;}
		}
		if (s->item_length <= MAX_ITEM_LENGTH) {
			*(s->item_length_location) = (uint8_t)(s->item_length);
		} else {
			WARN(ZS_ITEM_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		s->comma_list = false;
		if (s->pending_backslash) {
			WARN(ZS_BAD_ALPN_BACKSLASH);
			p--; {goto st316;}
		}
	}
	{
		s->item_length = rdata_tail - s->item_length2_location - 2;

		if (s->item_length <= MAX_ITEM_LENGTH2) {
			uint16_t val = htons((uint16_t)(s->item_length));
			memcpy(s->item_length2_location, &val, 2);
		} else {
			WARN(ZS_ITEM_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		int ret = svcb_sort(s, rdata_tail);
		if (ret != ZS_OK) {
			WARN(ret);
			p--; {goto st316;}
		}
	}
	{
		s->buffer_length = 0;
	}
	{
		int ret = svcb_check(s, rdata_tail);
		if (ret != ZS_OK) {
			WARN(ret);
			p--; {goto st316;}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1480;
tr2025:
	{
		s->item_length = rdata_tail - s->item_length2_location - 2;

		if (s->item_length <= MAX_ITEM_LENGTH2) {
			uint16_t val = htons((uint16_t)(s->item_length));
			memcpy(s->item_length2_location, &val, 2);
		} else {
			WARN(ZS_ITEM_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		int ret = svcb_sort(s, rdata_tail);
		if (ret != ZS_OK) {
			WARN(ret);
			p--; {goto st316;}
		}
	}
	{
		s->buffer_length = 0;
	}
	{
		int ret = svcb_check(s, rdata_tail);
		if (ret != ZS_OK) {
			WARN(ret);
			p--; {goto st316;}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1480;
tr2035:
	{
		int ret = svcb_sort(s, rdata_tail);
		if (ret != ZS_OK) {
			WARN(ret);
			p--; {goto st316;}
		}
	}
	{
		s->buffer_length = 0;
	}
	{
		int ret = svcb_check(s, rdata_tail);
		if (ret != ZS_OK) {
			WARN(ret);
			p--; {goto st316;}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1480;
tr2080:
	{
		s->buffer[s->buffer_length] = 0;

		if (inet_pton(AF_INET, (char *)s->buffer, s->addr) <= 0) {
			WARN(ZS_BAD_IPV4);
			p--; {goto st316;}
		}
	}
	{
		if (rdata_tail + ZS_INET4_ADDR_LENGTH > rdata_stop + 1) {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
		memcpy(rdata_tail, s->addr, ZS_INET4_ADDR_LENGTH);
		rdata_tail += ZS_INET4_ADDR_LENGTH;
	}
	{
		s->item_length = rdata_tail - s->item_length2_location - 2;

		if (s->item_length <= MAX_ITEM_LENGTH2) {
			uint16_t val = htons((uint16_t)(s->item_length));
			memcpy(s->item_length2_location, &val, 2);
		} else {
			WARN(ZS_ITEM_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		int ret = svcb_sort(s, rdata_tail);
		if (ret != ZS_OK) {
			WARN(ret);
			p--; {goto st316;}
		}
	}
	{
		s->buffer_length = 0;
	}
	{
		int ret = svcb_check(s, rdata_tail);
		if (ret != ZS_OK) {
			WARN(ret);
			p--; {goto st316;}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1480;
tr2103:
	{
		s->buffer[s->buffer_length] = 0;

		if (inet_pton(AF_INET6, (char *)s->buffer, s->addr) <= 0) {
			WARN(ZS_BAD_IPV6);
			p--; {goto st316;}
		}
	}
	{
		if (rdata_tail + ZS_INET6_ADDR_LENGTH > rdata_stop + 1) {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
		memcpy(rdata_tail, s->addr, ZS_INET6_ADDR_LENGTH);
		rdata_tail += ZS_INET6_ADDR_LENGTH;
	}
	{
		s->item_length = rdata_tail - s->item_length2_location - 2;

		if (s->item_length <= MAX_ITEM_LENGTH2) {
			uint16_t val = htons((uint16_t)(s->item_length));
			memcpy(s->item_length2_location, &val, 2);
		} else {
			WARN(ZS_ITEM_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		int ret = svcb_sort(s, rdata_tail);
		if (ret != ZS_OK) {
			WARN(ret);
			p--; {goto st316;}
		}
	}
	{
		s->buffer_length = 0;
	}
	{
		int ret = svcb_check(s, rdata_tail);
		if (ret != ZS_OK) {
			WARN(ret);
			p--; {goto st316;}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1480;
tr2118:
	{
		if (s->number64 <= UINT16_MAX) {
			uint16_t num16 = htons((uint16_t)s->number64);
			memcpy(rdata_tail, &num16, 2);
			rdata_tail += 2;
		} else {
			WARN(ZS_NUMBER16_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		uint16_t val = htons(0);
		memcpy(rdata_tail, &val, 2);
		rdata_tail += 2;
	}
	{
		int ret = svcb_sort(s, rdata_tail);
		if (ret != ZS_OK) {
			WARN(ret);
			p--; {goto st316;}
		}
	}
	{
		s->buffer_length = 0;
	}
	{
		int ret = svcb_check(s, rdata_tail);
		if (ret != ZS_OK) {
			WARN(ret);
			p--; {goto st316;}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1480;
tr2142:
	{
		s->item_length = rdata_tail - s->item_length2_location - 2;

		if (s->item_length <= MAX_ITEM_LENGTH2) {
			uint16_t val = htons((uint16_t)(s->item_length));
			memcpy(s->item_length2_location, &val, 2);
		} else {
			WARN(ZS_ITEM_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		svcb_mandatory_sort(s->svcb.mandatory_position, rdata_tail);
	}
	{
		int ret = svcb_sort(s, rdata_tail);
		if (ret != ZS_OK) {
			WARN(ret);
			p--; {goto st316;}
		}
	}
	{
		s->buffer_length = 0;
	}
	{
		int ret = svcb_check(s, rdata_tail);
		if (ret != ZS_OK) {
			WARN(ret);
			p--; {goto st316;}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1480;
tr2165:
	{
		uint16_t val = htons(2);
		memcpy(rdata_tail, &val, 2);
		rdata_tail += 2;
	}
	{
		uint16_t val = htons(0);
		memcpy(rdata_tail, &val, 2);
		rdata_tail += 2;
	}
	{
		int ret = svcb_sort(s, rdata_tail);
		if (ret != ZS_OK) {
			WARN(ret);
			p--; {goto st316;}
		}
	}
	{
		s->buffer_length = 0;
	}
	{
		int ret = svcb_check(s, rdata_tail);
		if (ret != ZS_OK) {
			WARN(ret);
			p--; {goto st316;}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1480;
tr2177:
	{
		uint16_t val = htons(8);
		memcpy(rdata_tail, &val, 2);
		rdata_tail += 2;
	}
	{
		uint16_t val = htons(0);
		memcpy(rdata_tail, &val, 2);
		rdata_tail += 2;
	}
	{
		int ret = svcb_sort(s, rdata_tail);
		if (ret != ZS_OK) {
			WARN(ret);
			p--; {goto st316;}
		}
	}
	{
		s->buffer_length = 0;
	}
	{
		int ret = svcb_check(s, rdata_tail);
		if (ret != ZS_OK) {
			WARN(ret);
			p--; {goto st316;}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1480;
tr2195:
	{
		if (s->number64 <= UINT16_MAX) {
			uint16_t num16 = htons((uint16_t)s->number64);
			memcpy(rdata_tail, &num16, 2);
			rdata_tail += 2;
		} else {
			WARN(ZS_NUMBER16_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		int ret = svcb_sort(s, rdata_tail);
		if (ret != ZS_OK) {
			WARN(ret);
			p--; {goto st316;}
		}
	}
	{
		s->buffer_length = 0;
	}
	{
		int ret = svcb_check(s, rdata_tail);
		if (ret != ZS_OK) {
			WARN(ret);
			p--; {goto st316;}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1480;
st1480:
	if ( ++p == pe )
		goto _test_eof1480;
case 1480:
	_widec = (*p);
	if ( (*p) < 10 ) {
		if ( (*p) <= 9 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) > 10 ) {
		if ( 11 <= (*p) )
 {			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	if ( _widec == 2058 )
		goto tr2008;
	if ( 1920 <= _widec && _widec <= 2175 )
		goto tr2007;
	goto tr1967;
tr2017:
	{
		if (rdata_tail < rdata_stop) {
			s->item_length2_location = rdata_tail;
			rdata_tail += 2;
		} else {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{ p--; {stack[top++] = 648;goto st327;} }
	goto st648;
st648:
	if ( ++p == pe )
		goto _test_eof648;
case 648:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(2688 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 !s->multiline  ) _widec += 512;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(2688 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		if (
 !s->multiline  ) _widec += 512;
	}
	switch( _widec ) {
		case 9: goto tr2018;
		case 32: goto tr2018;
		case 40: goto tr2019;
		case 41: goto tr2020;
		case 3082: goto tr2021;
		case 3131: goto tr2022;
		case 3338: goto tr2023;
		case 3387: goto tr2023;
		case 3594: goto tr2024;
		case 3643: goto tr2025;
	}
	if ( _widec < 11 ) {
		if ( _widec <= 8 )
			goto tr2026;
	} else if ( _widec > 58 ) {
		if ( 60 <= _widec )
			goto tr2026;
	} else
		goto tr2026;
	goto tr1967;
tr2026:
	{
		if (rdata_tail < rdata_stop) {
			s->item_length2_location = rdata_tail;
			rdata_tail += 2;
		} else {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{ p--; {stack[top++] = 649;goto st327;} }
	goto st649;
st649:
	if ( ++p == pe )
		goto _test_eof649;
case 649:
	if ( (*p) == 34 )
		goto tr2027;
	goto tr1967;
tr2027:
	{
		s->item_length = rdata_tail - s->item_length2_location - 2;

		if (s->item_length <= MAX_ITEM_LENGTH2) {
			uint16_t val = htons((uint16_t)(s->item_length));
			memcpy(s->item_length2_location, &val, 2);
		} else {
			WARN(ZS_ITEM_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st650;
tr2067:
	{
		s->buffer[s->buffer_length] = 0;

		if (inet_pton(AF_INET, (char *)s->buffer, s->addr) <= 0) {
			WARN(ZS_BAD_IPV4);
			p--; {goto st316;}
		}
	}
	{
		if (rdata_tail + ZS_INET4_ADDR_LENGTH > rdata_stop + 1) {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
		memcpy(rdata_tail, s->addr, ZS_INET4_ADDR_LENGTH);
		rdata_tail += ZS_INET4_ADDR_LENGTH;
	}
	{
		s->item_length = rdata_tail - s->item_length2_location - 2;

		if (s->item_length <= MAX_ITEM_LENGTH2) {
			uint16_t val = htons((uint16_t)(s->item_length));
			memcpy(s->item_length2_location, &val, 2);
		} else {
			WARN(ZS_ITEM_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st650;
tr2090:
	{
		s->buffer[s->buffer_length] = 0;

		if (inet_pton(AF_INET6, (char *)s->buffer, s->addr) <= 0) {
			WARN(ZS_BAD_IPV6);
			p--; {goto st316;}
		}
	}
	{
		if (rdata_tail + ZS_INET6_ADDR_LENGTH > rdata_stop + 1) {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
		memcpy(rdata_tail, s->addr, ZS_INET6_ADDR_LENGTH);
		rdata_tail += ZS_INET6_ADDR_LENGTH;
	}
	{
		s->item_length = rdata_tail - s->item_length2_location - 2;

		if (s->item_length <= MAX_ITEM_LENGTH2) {
			uint16_t val = htons((uint16_t)(s->item_length));
			memcpy(s->item_length2_location, &val, 2);
		} else {
			WARN(ZS_ITEM_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st650;
tr2185:
	{
		if (s->number64 <= UINT16_MAX) {
			uint16_t num16 = htons((uint16_t)s->number64);
			memcpy(rdata_tail, &num16, 2);
			rdata_tail += 2;
		} else {
			WARN(ZS_NUMBER16_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st650;
tr2131:
	{
		s->item_length = rdata_tail - s->item_length2_location - 2;

		if (s->item_length <= MAX_ITEM_LENGTH2) {
			uint16_t val = htons((uint16_t)(s->item_length));
			memcpy(s->item_length2_location, &val, 2);
		} else {
			WARN(ZS_ITEM_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		svcb_mandatory_sort(s->svcb.mandatory_position, rdata_tail);
	}
	goto st650;
tr2197:
	{
		s->item_length = rdata_tail - s->item_length_location - 1;
		if (s->comma_list && s->item_length == 0) {
			WARN(ZS_EMPTY_LIST_ITEM);
			p--; {goto st316;}
		}
		if (s->item_length <= MAX_ITEM_LENGTH) {
			*(s->item_length_location) = (uint8_t)(s->item_length);
		} else {
			WARN(ZS_ITEM_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		s->comma_list = false;
		if (s->pending_backslash) {
			WARN(ZS_BAD_ALPN_BACKSLASH);
			p--; {goto st316;}
		}
	}
	{
		s->item_length = rdata_tail - s->item_length2_location - 2;

		if (s->item_length <= MAX_ITEM_LENGTH2) {
			uint16_t val = htons((uint16_t)(s->item_length));
			memcpy(s->item_length2_location, &val, 2);
		} else {
			WARN(ZS_ITEM_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st650;
st650:
	if ( ++p == pe )
		goto _test_eof650;
case 650:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(2688 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 !s->multiline  ) _widec += 512;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(2688 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		if (
 !s->multiline  ) _widec += 512;
	}
	switch( _widec ) {
		case 9: goto tr2028;
		case 32: goto tr2028;
		case 40: goto tr2029;
		case 41: goto tr2030;
		case 3082: goto tr2031;
		case 3131: goto tr2032;
		case 3338: goto tr2033;
		case 3387: goto tr2033;
		case 3594: goto tr2034;
		case 3643: goto tr2035;
	}
	goto tr1967;
tr1981:
	{
		if (rdata_tail + 4 > rdata_stop + 1) { // key_len + val_len
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
		s->svcb.param_position = rdata_tail;
	}
	goto st651;
st651:
	if ( ++p == pe )
		goto _test_eof651;
case 651:
	if ( (*p) == 99 )
		goto st652;
	goto tr1967;
st652:
	if ( ++p == pe )
		goto _test_eof652;
case 652:
	if ( (*p) == 104 )
		goto st653;
	goto tr1967;
st653:
	if ( ++p == pe )
		goto _test_eof653;
case 653:
	if ( (*p) == 61 )
		goto tr2038;
	goto tr1967;
tr2038:
	{
		uint16_t val = htons(5);
		memcpy(rdata_tail, &val, 2);
		rdata_tail += 2;
	}
	goto st654;
st654:
	if ( ++p == pe )
		goto _test_eof654;
case 654:
	switch( (*p) ) {
		case 34: goto st655;
		case 43: goto tr2040;
	}
	if ( (*p) < 65 ) {
		if ( 47 <= (*p) && (*p) <= 57 )
			goto tr2040;
	} else if ( (*p) > 90 ) {
		if ( 97 <= (*p) && (*p) <= 122 )
			goto tr2040;
	} else
		goto tr2040;
	goto tr1967;
st655:
	if ( ++p == pe )
		goto _test_eof655;
case 655:
	if ( (*p) == 43 )
		goto tr2041;
	if ( (*p) < 65 ) {
		if ( 47 <= (*p) && (*p) <= 57 )
			goto tr2041;
	} else if ( (*p) > 90 ) {
		if ( 97 <= (*p) && (*p) <= 122 )
			goto tr2041;
	} else
		goto tr2041;
	goto tr1967;
tr2047:
	{
		if (rdata_tail <= rdata_stop) {
			*rdata_tail = first_base64_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st656;
tr2041:
	{
		if (rdata_tail < rdata_stop) {
			s->item_length2_location = rdata_tail;
			rdata_tail += 2;
		} else {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (rdata_tail <= rdata_stop) {
			*rdata_tail = first_base64_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st656;
st656:
	if ( ++p == pe )
		goto _test_eof656;
case 656:
	if ( (*p) == 43 )
		goto tr2042;
	if ( (*p) < 65 ) {
		if ( 47 <= (*p) && (*p) <= 57 )
			goto tr2042;
	} else if ( (*p) > 90 ) {
		if ( 97 <= (*p) && (*p) <= 122 )
			goto tr2042;
	} else
		goto tr2042;
	goto tr1967;
tr2042:
	{
		*(rdata_tail++) += second_left_base64_to_num[(uint8_t)(*p)];

		if (rdata_tail <= rdata_stop) {
			*rdata_tail = second_right_base64_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st657;
st657:
	if ( ++p == pe )
		goto _test_eof657;
case 657:
	switch( (*p) ) {
		case 43: goto tr2043;
		case 61: goto st660;
	}
	if ( (*p) < 65 ) {
		if ( 47 <= (*p) && (*p) <= 57 )
			goto tr2043;
	} else if ( (*p) > 90 ) {
		if ( 97 <= (*p) && (*p) <= 122 )
			goto tr2043;
	} else
		goto tr2043;
	goto tr1967;
tr2043:
	{
		*(rdata_tail++) += third_left_base64_to_num[(uint8_t)(*p)];

		if (rdata_tail <= rdata_stop) {
			*rdata_tail = third_right_base64_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st658;
st658:
	if ( ++p == pe )
		goto _test_eof658;
case 658:
	switch( (*p) ) {
		case 43: goto tr2045;
		case 61: goto st659;
	}
	if ( (*p) < 65 ) {
		if ( 47 <= (*p) && (*p) <= 57 )
			goto tr2045;
	} else if ( (*p) > 90 ) {
		if ( 97 <= (*p) && (*p) <= 122 )
			goto tr2045;
	} else
		goto tr2045;
	goto tr1967;
tr2045:
	{
		*(rdata_tail++) += fourth_base64_to_num[(uint8_t)(*p)];
	}
	goto st659;
st659:
	if ( ++p == pe )
		goto _test_eof659;
case 659:
	switch( (*p) ) {
		case 34: goto tr2027;
		case 43: goto tr2047;
	}
	if ( (*p) < 65 ) {
		if ( 47 <= (*p) && (*p) <= 57 )
			goto tr2047;
	} else if ( (*p) > 90 ) {
		if ( 97 <= (*p) && (*p) <= 122 )
			goto tr2047;
	} else
		goto tr2047;
	goto tr1967;
st660:
	if ( ++p == pe )
		goto _test_eof660;
case 660:
	if ( (*p) == 61 )
		goto st659;
	goto tr1967;
tr2053:
	{
		if (rdata_tail <= rdata_stop) {
			*rdata_tail = first_base64_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st661;
tr2040:
	{
		if (rdata_tail < rdata_stop) {
			s->item_length2_location = rdata_tail;
			rdata_tail += 2;
		} else {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (rdata_tail <= rdata_stop) {
			*rdata_tail = first_base64_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st661;
st661:
	if ( ++p == pe )
		goto _test_eof661;
case 661:
	if ( (*p) == 43 )
		goto tr2048;
	if ( (*p) < 65 ) {
		if ( 47 <= (*p) && (*p) <= 57 )
			goto tr2048;
	} else if ( (*p) > 90 ) {
		if ( 97 <= (*p) && (*p) <= 122 )
			goto tr2048;
	} else
		goto tr2048;
	goto tr1967;
tr2048:
	{
		*(rdata_tail++) += second_left_base64_to_num[(uint8_t)(*p)];

		if (rdata_tail <= rdata_stop) {
			*rdata_tail = second_right_base64_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st662;
st662:
	if ( ++p == pe )
		goto _test_eof662;
case 662:
	switch( (*p) ) {
		case 43: goto tr2049;
		case 61: goto st665;
	}
	if ( (*p) < 65 ) {
		if ( 47 <= (*p) && (*p) <= 57 )
			goto tr2049;
	} else if ( (*p) > 90 ) {
		if ( 97 <= (*p) && (*p) <= 122 )
			goto tr2049;
	} else
		goto tr2049;
	goto tr1967;
tr2049:
	{
		*(rdata_tail++) += third_left_base64_to_num[(uint8_t)(*p)];

		if (rdata_tail <= rdata_stop) {
			*rdata_tail = third_right_base64_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st663;
st663:
	if ( ++p == pe )
		goto _test_eof663;
case 663:
	switch( (*p) ) {
		case 43: goto tr2051;
		case 61: goto st664;
	}
	if ( (*p) < 65 ) {
		if ( 47 <= (*p) && (*p) <= 57 )
			goto tr2051;
	} else if ( (*p) > 90 ) {
		if ( 97 <= (*p) && (*p) <= 122 )
			goto tr2051;
	} else
		goto tr2051;
	goto tr1967;
tr2051:
	{
		*(rdata_tail++) += fourth_base64_to_num[(uint8_t)(*p)];
	}
	goto st664;
st664:
	if ( ++p == pe )
		goto _test_eof664;
case 664:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(2688 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 !s->multiline  ) _widec += 512;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(2688 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		if (
 !s->multiline  ) _widec += 512;
	}
	switch( _widec ) {
		case 9: goto tr2018;
		case 32: goto tr2018;
		case 40: goto tr2019;
		case 41: goto tr2020;
		case 43: goto tr2053;
		case 3082: goto tr2021;
		case 3131: goto tr2022;
		case 3338: goto tr2023;
		case 3387: goto tr2023;
		case 3594: goto tr2024;
		case 3643: goto tr2025;
	}
	if ( _widec < 65 ) {
		if ( 47 <= _widec && _widec <= 57 )
			goto tr2053;
	} else if ( _widec > 90 ) {
		if ( 97 <= _widec && _widec <= 122 )
			goto tr2053;
	} else
		goto tr2053;
	goto tr1967;
st665:
	if ( ++p == pe )
		goto _test_eof665;
case 665:
	if ( (*p) == 61 )
		goto st664;
	goto tr1967;
tr1982:
	{
		if (rdata_tail + 4 > rdata_stop + 1) { // key_len + val_len
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
		s->svcb.param_position = rdata_tail;
	}
	goto st666;
st666:
	if ( ++p == pe )
		goto _test_eof666;
case 666:
	if ( (*p) == 112 )
		goto st667;
	goto tr1967;
st667:
	if ( ++p == pe )
		goto _test_eof667;
case 667:
	if ( (*p) == 118 )
		goto st668;
	goto tr1967;
st668:
	if ( ++p == pe )
		goto _test_eof668;
case 668:
	switch( (*p) ) {
		case 52: goto st669;
		case 54: goto st680;
	}
	goto tr1967;
st669:
	if ( ++p == pe )
		goto _test_eof669;
case 669:
	if ( (*p) == 104 )
		goto st670;
	goto tr1967;
st670:
	if ( ++p == pe )
		goto _test_eof670;
case 670:
	if ( (*p) == 105 )
		goto st671;
	goto tr1967;
st671:
	if ( ++p == pe )
		goto _test_eof671;
case 671:
	if ( (*p) == 110 )
		goto st672;
	goto tr1967;
st672:
	if ( ++p == pe )
		goto _test_eof672;
case 672:
	if ( (*p) == 116 )
		goto st673;
	goto tr1967;
st673:
	if ( ++p == pe )
		goto _test_eof673;
case 673:
	if ( (*p) == 61 )
		goto tr2062;
	goto tr1967;
tr2062:
	{
		uint16_t val = htons(4);
		memcpy(rdata_tail, &val, 2);
		rdata_tail += 2;
	}
	goto st674;
st674:
	if ( ++p == pe )
		goto _test_eof674;
case 674:
	switch( (*p) ) {
		case 34: goto st675;
		case 46: goto tr2065;
	}
	if ( 48 <= (*p) && (*p) <= 57 )
		goto tr2065;
	goto tr2063;
st675:
	if ( ++p == pe )
		goto _test_eof675;
case 675:
	if ( (*p) == 46 )
		goto tr2066;
	if ( 48 <= (*p) && (*p) <= 57 )
		goto tr2066;
	goto tr2063;
tr2066:
	{
		if (rdata_tail < rdata_stop) {
			s->item_length2_location = rdata_tail;
			rdata_tail += 2;
		} else {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		s->buffer_length = 0;
	}
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		} else {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st676;
tr2069:
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		} else {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st676;
tr2070:
	{
		s->buffer_length = 0;
	}
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		} else {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st676;
st676:
	if ( ++p == pe )
		goto _test_eof676;
case 676:
	switch( (*p) ) {
		case 34: goto tr2067;
		case 44: goto tr2068;
		case 46: goto tr2069;
	}
	if ( 48 <= (*p) && (*p) <= 57 )
		goto tr2069;
	goto tr2063;
tr2068:
	{
		s->buffer[s->buffer_length] = 0;

		if (inet_pton(AF_INET, (char *)s->buffer, s->addr) <= 0) {
			WARN(ZS_BAD_IPV4);
			p--; {goto st316;}
		}
	}
	{
		if (rdata_tail + ZS_INET4_ADDR_LENGTH > rdata_stop + 1) {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
		memcpy(rdata_tail, s->addr, ZS_INET4_ADDR_LENGTH);
		rdata_tail += ZS_INET4_ADDR_LENGTH;
	}
	goto st677;
st677:
	if ( ++p == pe )
		goto _test_eof677;
case 677:
	if ( (*p) == 46 )
		goto tr2070;
	if ( 48 <= (*p) && (*p) <= 57 )
		goto tr2070;
	goto tr2063;
tr2065:
	{
		if (rdata_tail < rdata_stop) {
			s->item_length2_location = rdata_tail;
			rdata_tail += 2;
		} else {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		s->buffer_length = 0;
	}
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		} else {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st678;
tr2075:
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		} else {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st678;
tr2081:
	{
		s->buffer_length = 0;
	}
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		} else {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st678;
st678:
	if ( ++p == pe )
		goto _test_eof678;
case 678:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(2688 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 !s->multiline  ) _widec += 512;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(2688 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		if (
 !s->multiline  ) _widec += 512;
	}
	switch( _widec ) {
		case 9: goto tr2071;
		case 32: goto tr2071;
		case 40: goto tr2072;
		case 41: goto tr2073;
		case 44: goto tr2074;
		case 46: goto tr2075;
		case 3082: goto tr2076;
		case 3131: goto tr2077;
		case 3338: goto tr2078;
		case 3387: goto tr2078;
		case 3594: goto tr2079;
		case 3643: goto tr2080;
	}
	if ( 48 <= _widec && _widec <= 57 )
		goto tr2075;
	goto tr2063;
tr2074:
	{
		s->buffer[s->buffer_length] = 0;

		if (inet_pton(AF_INET, (char *)s->buffer, s->addr) <= 0) {
			WARN(ZS_BAD_IPV4);
			p--; {goto st316;}
		}
	}
	{
		if (rdata_tail + ZS_INET4_ADDR_LENGTH > rdata_stop + 1) {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
		memcpy(rdata_tail, s->addr, ZS_INET4_ADDR_LENGTH);
		rdata_tail += ZS_INET4_ADDR_LENGTH;
	}
	goto st679;
st679:
	if ( ++p == pe )
		goto _test_eof679;
case 679:
	if ( (*p) == 46 )
		goto tr2081;
	if ( 48 <= (*p) && (*p) <= 57 )
		goto tr2081;
	goto tr2063;
st680:
	if ( ++p == pe )
		goto _test_eof680;
case 680:
	if ( (*p) == 104 )
		goto st681;
	goto tr1967;
st681:
	if ( ++p == pe )
		goto _test_eof681;
case 681:
	if ( (*p) == 105 )
		goto st682;
	goto tr1967;
st682:
	if ( ++p == pe )
		goto _test_eof682;
case 682:
	if ( (*p) == 110 )
		goto st683;
	goto tr1967;
st683:
	if ( ++p == pe )
		goto _test_eof683;
case 683:
	if ( (*p) == 116 )
		goto st684;
	goto tr1967;
st684:
	if ( ++p == pe )
		goto _test_eof684;
case 684:
	if ( (*p) == 61 )
		goto tr2086;
	goto tr1967;
tr2086:
	{
		uint16_t val = htons(6);
		memcpy(rdata_tail, &val, 2);
		rdata_tail += 2;
	}
	goto st685;
st685:
	if ( ++p == pe )
		goto _test_eof685;
case 685:
	switch( (*p) ) {
		case 34: goto st686;
		case 46: goto tr2088;
	}
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 58 )
			goto tr2088;
	} else if ( (*p) > 70 ) {
		if ( 97 <= (*p) && (*p) <= 102 )
			goto tr2088;
	} else
		goto tr2088;
	goto tr2063;
st686:
	if ( ++p == pe )
		goto _test_eof686;
case 686:
	if ( (*p) == 46 )
		goto tr2089;
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 58 )
			goto tr2089;
	} else if ( (*p) > 70 ) {
		if ( 97 <= (*p) && (*p) <= 102 )
			goto tr2089;
	} else
		goto tr2089;
	goto tr2063;
tr2089:
	{
		if (rdata_tail < rdata_stop) {
			s->item_length2_location = rdata_tail;
			rdata_tail += 2;
		} else {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		s->buffer_length = 0;
	}
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		} else {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st687;
tr2092:
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		} else {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st687;
tr2093:
	{
		s->buffer_length = 0;
	}
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		} else {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st687;
st687:
	if ( ++p == pe )
		goto _test_eof687;
case 687:
	switch( (*p) ) {
		case 34: goto tr2090;
		case 44: goto tr2091;
		case 46: goto tr2092;
	}
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 58 )
			goto tr2092;
	} else if ( (*p) > 70 ) {
		if ( 97 <= (*p) && (*p) <= 102 )
			goto tr2092;
	} else
		goto tr2092;
	goto tr2063;
tr2091:
	{
		s->buffer[s->buffer_length] = 0;

		if (inet_pton(AF_INET6, (char *)s->buffer, s->addr) <= 0) {
			WARN(ZS_BAD_IPV6);
			p--; {goto st316;}
		}
	}
	{
		if (rdata_tail + ZS_INET6_ADDR_LENGTH > rdata_stop + 1) {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
		memcpy(rdata_tail, s->addr, ZS_INET6_ADDR_LENGTH);
		rdata_tail += ZS_INET6_ADDR_LENGTH;
	}
	goto st688;
st688:
	if ( ++p == pe )
		goto _test_eof688;
case 688:
	if ( (*p) == 46 )
		goto tr2093;
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 58 )
			goto tr2093;
	} else if ( (*p) > 70 ) {
		if ( 97 <= (*p) && (*p) <= 102 )
			goto tr2093;
	} else
		goto tr2093;
	goto tr2063;
tr2088:
	{
		if (rdata_tail < rdata_stop) {
			s->item_length2_location = rdata_tail;
			rdata_tail += 2;
		} else {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		s->buffer_length = 0;
	}
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		} else {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st689;
tr2098:
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		} else {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st689;
tr2104:
	{
		s->buffer_length = 0;
	}
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		} else {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st689;
st689:
	if ( ++p == pe )
		goto _test_eof689;
case 689:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(2688 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 !s->multiline  ) _widec += 512;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(2688 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		if (
 !s->multiline  ) _widec += 512;
	}
	switch( _widec ) {
		case 9: goto tr2094;
		case 32: goto tr2094;
		case 40: goto tr2095;
		case 41: goto tr2096;
		case 44: goto tr2097;
		case 46: goto tr2098;
		case 3082: goto tr2099;
		case 3131: goto tr2100;
		case 3338: goto tr2101;
		case 3387: goto tr2101;
		case 3594: goto tr2102;
		case 3643: goto tr2103;
	}
	if ( _widec < 65 ) {
		if ( 48 <= _widec && _widec <= 58 )
			goto tr2098;
	} else if ( _widec > 70 ) {
		if ( 97 <= _widec && _widec <= 102 )
			goto tr2098;
	} else
		goto tr2098;
	goto tr2063;
tr2097:
	{
		s->buffer[s->buffer_length] = 0;

		if (inet_pton(AF_INET6, (char *)s->buffer, s->addr) <= 0) {
			WARN(ZS_BAD_IPV6);
			p--; {goto st316;}
		}
	}
	{
		if (rdata_tail + ZS_INET6_ADDR_LENGTH > rdata_stop + 1) {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
		memcpy(rdata_tail, s->addr, ZS_INET6_ADDR_LENGTH);
		rdata_tail += ZS_INET6_ADDR_LENGTH;
	}
	goto st690;
st690:
	if ( ++p == pe )
		goto _test_eof690;
case 690:
	if ( (*p) == 46 )
		goto tr2104;
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 58 )
			goto tr2104;
	} else if ( (*p) > 70 ) {
		if ( 97 <= (*p) && (*p) <= 102 )
			goto tr2104;
	} else
		goto tr2104;
	goto tr2063;
tr1983:
	{
		if (rdata_tail + 4 > rdata_stop + 1) { // key_len + val_len
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
		s->svcb.param_position = rdata_tail;
	}
	goto st691;
st691:
	if ( ++p == pe )
		goto _test_eof691;
case 691:
	if ( (*p) == 101 )
		goto st692;
	goto tr1967;
st692:
	if ( ++p == pe )
		goto _test_eof692;
case 692:
	if ( (*p) == 121 )
		goto st693;
	goto tr1967;
st693:
	if ( ++p == pe )
		goto _test_eof693;
case 693:
	if ( 48 <= (*p) && (*p) <= 57 )
		goto tr2108;
	goto tr2107;
tr2108:
	{
		s->number64 = 0;
	}
	{
		// Overflow check: 10*(s->number64) + fc - '0' <= UINT64_MAX
		if ((s->number64 < (UINT64_MAX / 10)) ||   // Dominant fast check.
			((s->number64 == (UINT64_MAX / 10)) && // Marginal case.
			 ((uint8_t)(*p) <= (UINT64_MAX % 10) + '0')
			)
		   ) {
			s->number64 *= 10;
			s->number64 += digit_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_NUMBER64_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st694;
tr2112:
	{
		// Overflow check: 10*(s->number64) + fc - '0' <= UINT64_MAX
		if ((s->number64 < (UINT64_MAX / 10)) ||   // Dominant fast check.
			((s->number64 == (UINT64_MAX / 10)) && // Marginal case.
			 ((uint8_t)(*p) <= (UINT64_MAX % 10) + '0')
			)
		   ) {
			s->number64 *= 10;
			s->number64 += digit_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_NUMBER64_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st694;
st694:
	if ( ++p == pe )
		goto _test_eof694;
case 694:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(2688 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 !s->multiline  ) _widec += 512;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(2688 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		if (
 !s->multiline  ) _widec += 512;
	}
	switch( _widec ) {
		case 9: goto tr2109;
		case 32: goto tr2109;
		case 40: goto tr2110;
		case 41: goto tr2111;
		case 61: goto tr2113;
		case 3082: goto tr2114;
		case 3131: goto tr2115;
		case 3338: goto tr2116;
		case 3387: goto tr2116;
		case 3594: goto tr2117;
		case 3643: goto tr2118;
	}
	if ( 48 <= _widec && _widec <= 57 )
		goto tr2112;
	goto tr2107;
tr2113:
	{
		if (s->number64 <= UINT16_MAX) {
			uint16_t num16 = htons((uint16_t)s->number64);
			memcpy(rdata_tail, &num16, 2);
			rdata_tail += 2;
		} else {
			WARN(ZS_NUMBER16_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st695;
st695:
	if ( ++p == pe )
		goto _test_eof695;
case 695:
	switch( (*p) ) {
		case 32: goto tr1967;
		case 59: goto tr1967;
	}
	if ( (*p) > 10 ) {
		if ( 40 <= (*p) && (*p) <= 41 )
			goto tr1967;
	} else if ( (*p) >= 9 )
		goto tr1967;
	goto tr2016;
tr1984:
	{
		if (rdata_tail + 4 > rdata_stop + 1) { // key_len + val_len
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
		s->svcb.param_position = rdata_tail;
	}
	goto st696;
st696:
	if ( ++p == pe )
		goto _test_eof696;
case 696:
	if ( (*p) == 97 )
		goto st697;
	goto tr1967;
st697:
	if ( ++p == pe )
		goto _test_eof697;
case 697:
	if ( (*p) == 110 )
		goto st698;
	goto tr1967;
st698:
	if ( ++p == pe )
		goto _test_eof698;
case 698:
	if ( (*p) == 100 )
		goto st699;
	goto tr1967;
st699:
	if ( ++p == pe )
		goto _test_eof699;
case 699:
	if ( (*p) == 97 )
		goto st700;
	goto tr1967;
st700:
	if ( ++p == pe )
		goto _test_eof700;
case 700:
	if ( (*p) == 116 )
		goto st701;
	goto tr1967;
st701:
	if ( ++p == pe )
		goto _test_eof701;
case 701:
	if ( (*p) == 111 )
		goto st702;
	goto tr1967;
st702:
	if ( ++p == pe )
		goto _test_eof702;
case 702:
	if ( (*p) == 114 )
		goto st703;
	goto tr1967;
st703:
	if ( ++p == pe )
		goto _test_eof703;
case 703:
	if ( (*p) == 121 )
		goto st704;
	goto tr1967;
st704:
	if ( ++p == pe )
		goto _test_eof704;
case 704:
	if ( (*p) == 61 )
		goto tr2127;
	goto tr1967;
tr2127:
	{
		uint16_t val = htons(0);
		memcpy(rdata_tail, &val, 2);
		rdata_tail += 2;
	}
	goto st705;
st705:
	if ( ++p == pe )
		goto _test_eof705;
case 705:
	if ( (*p) == 34 )
		goto st706;
	if ( (*p) > 90 ) {
		if ( 97 <= (*p) && (*p) <= 122 )
			goto tr2129;
	} else if ( (*p) >= 65 )
		goto tr2129;
	goto tr1967;
st706:
	if ( ++p == pe )
		goto _test_eof706;
case 706:
	if ( (*p) > 90 ) {
		if ( 97 <= (*p) && (*p) <= 122 )
			goto tr2130;
	} else if ( (*p) >= 65 )
		goto tr2130;
	goto tr1967;
tr2130:
	{
		s->svcb.mandatory_position = rdata_tail + 2; // Skip 2-B prefix.
	}
	{
		if (rdata_tail < rdata_stop) {
			s->item_length2_location = rdata_tail;
			rdata_tail += 2;
		} else {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{ p--; {stack[top++] = 707;goto st574;} }
	goto st707;
tr2133:
	{ p--; {stack[top++] = 707;goto st574;} }
	goto st707;
st707:
	if ( ++p == pe )
		goto _test_eof707;
case 707:
	switch( (*p) ) {
		case 34: goto tr2131;
		case 44: goto st708;
	}
	goto tr1967;
st708:
	if ( ++p == pe )
		goto _test_eof708;
case 708:
	if ( (*p) > 90 ) {
		if ( 97 <= (*p) && (*p) <= 122 )
			goto tr2133;
	} else if ( (*p) >= 65 )
		goto tr2133;
	goto tr1967;
tr2129:
	{
		s->svcb.mandatory_position = rdata_tail + 2; // Skip 2-B prefix.
	}
	{
		if (rdata_tail < rdata_stop) {
			s->item_length2_location = rdata_tail;
			rdata_tail += 2;
		} else {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{ p--; {stack[top++] = 709;goto st574;} }
	goto st709;
tr2143:
	{ p--; {stack[top++] = 709;goto st574;} }
	goto st709;
st709:
	if ( ++p == pe )
		goto _test_eof709;
case 709:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(2688 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 !s->multiline  ) _widec += 512;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(2688 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		if (
 !s->multiline  ) _widec += 512;
	}
	switch( _widec ) {
		case 9: goto tr2134;
		case 32: goto tr2134;
		case 40: goto tr2135;
		case 41: goto tr2136;
		case 44: goto st710;
		case 3082: goto tr2138;
		case 3131: goto tr2139;
		case 3338: goto tr2140;
		case 3387: goto tr2140;
		case 3594: goto tr2141;
		case 3643: goto tr2142;
	}
	goto tr1967;
st710:
	if ( ++p == pe )
		goto _test_eof710;
case 710:
	if ( (*p) > 90 ) {
		if ( 97 <= (*p) && (*p) <= 122 )
			goto tr2143;
	} else if ( (*p) >= 65 )
		goto tr2143;
	goto tr1967;
tr1985:
	{
		if (rdata_tail + 4 > rdata_stop + 1) { // key_len + val_len
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
		s->svcb.param_position = rdata_tail;
	}
	goto st711;
st711:
	if ( ++p == pe )
		goto _test_eof711;
case 711:
	if ( (*p) == 111 )
		goto st712;
	goto tr1967;
st712:
	if ( ++p == pe )
		goto _test_eof712;
case 712:
	if ( (*p) == 45 )
		goto st713;
	goto tr1967;
st713:
	if ( ++p == pe )
		goto _test_eof713;
case 713:
	if ( (*p) == 100 )
		goto st714;
	goto tr1967;
st714:
	if ( ++p == pe )
		goto _test_eof714;
case 714:
	if ( (*p) == 101 )
		goto st715;
	goto tr1967;
st715:
	if ( ++p == pe )
		goto _test_eof715;
case 715:
	if ( (*p) == 102 )
		goto st716;
	goto tr1967;
st716:
	if ( ++p == pe )
		goto _test_eof716;
case 716:
	if ( (*p) == 97 )
		goto st717;
	goto tr1967;
st717:
	if ( ++p == pe )
		goto _test_eof717;
case 717:
	if ( (*p) == 117 )
		goto st718;
	goto tr1967;
st718:
	if ( ++p == pe )
		goto _test_eof718;
case 718:
	if ( (*p) == 108 )
		goto st719;
	goto tr1967;
st719:
	if ( ++p == pe )
		goto _test_eof719;
case 719:
	if ( (*p) == 116 )
		goto st720;
	goto tr1967;
st720:
	if ( ++p == pe )
		goto _test_eof720;
case 720:
	if ( (*p) == 45 )
		goto st721;
	goto tr1967;
st721:
	if ( ++p == pe )
		goto _test_eof721;
case 721:
	if ( (*p) == 97 )
		goto st722;
	goto tr1967;
st722:
	if ( ++p == pe )
		goto _test_eof722;
case 722:
	if ( (*p) == 108 )
		goto st723;
	goto tr1967;
st723:
	if ( ++p == pe )
		goto _test_eof723;
case 723:
	if ( (*p) == 112 )
		goto st724;
	goto tr1967;
st724:
	if ( ++p == pe )
		goto _test_eof724;
case 724:
	if ( (*p) == 110 )
		goto st725;
	goto tr1967;
st725:
	if ( ++p == pe )
		goto _test_eof725;
case 725:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(2688 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 !s->multiline  ) _widec += 512;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(2688 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		if (
 !s->multiline  ) _widec += 512;
	}
	switch( _widec ) {
		case 9: goto tr2158;
		case 32: goto tr2158;
		case 40: goto tr2159;
		case 41: goto tr2160;
		case 3082: goto tr2161;
		case 3131: goto tr2162;
		case 3338: goto tr2163;
		case 3387: goto tr2163;
		case 3594: goto tr2164;
		case 3643: goto tr2165;
	}
	goto tr1967;
tr1986:
	{
		if (rdata_tail + 4 > rdata_stop + 1) { // key_len + val_len
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
		s->svcb.param_position = rdata_tail;
	}
	goto st726;
st726:
	if ( ++p == pe )
		goto _test_eof726;
case 726:
	if ( (*p) == 104 )
		goto st727;
	goto tr1967;
st727:
	if ( ++p == pe )
		goto _test_eof727;
case 727:
	if ( (*p) == 116 )
		goto st728;
	goto tr1967;
st728:
	if ( ++p == pe )
		goto _test_eof728;
case 728:
	if ( (*p) == 116 )
		goto st729;
	goto tr1967;
st729:
	if ( ++p == pe )
		goto _test_eof729;
case 729:
	if ( (*p) == 112 )
		goto st730;
	goto tr1967;
st730:
	if ( ++p == pe )
		goto _test_eof730;
case 730:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(2688 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 !s->multiline  ) _widec += 512;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(2688 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		if (
 !s->multiline  ) _widec += 512;
	}
	switch( _widec ) {
		case 9: goto tr2170;
		case 32: goto tr2170;
		case 40: goto tr2171;
		case 41: goto tr2172;
		case 3082: goto tr2173;
		case 3131: goto tr2174;
		case 3338: goto tr2175;
		case 3387: goto tr2175;
		case 3594: goto tr2176;
		case 3643: goto tr2177;
	}
	goto tr1967;
tr1987:
	{
		if (rdata_tail + 4 > rdata_stop + 1) { // key_len + val_len
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
		s->svcb.param_position = rdata_tail;
	}
	goto st731;
st731:
	if ( ++p == pe )
		goto _test_eof731;
case 731:
	if ( (*p) == 111 )
		goto st732;
	goto tr1967;
st732:
	if ( ++p == pe )
		goto _test_eof732;
case 732:
	if ( (*p) == 114 )
		goto st733;
	goto tr1967;
st733:
	if ( ++p == pe )
		goto _test_eof733;
case 733:
	if ( (*p) == 116 )
		goto st734;
	goto tr1967;
st734:
	if ( ++p == pe )
		goto _test_eof734;
case 734:
	if ( (*p) == 61 )
		goto tr2181;
	goto tr1967;
tr2181:
	{
		uint16_t val = htons(3);
		memcpy(rdata_tail, &val, 2);
		rdata_tail += 2;
	}
	goto st735;
st735:
	if ( ++p == pe )
		goto _test_eof735;
case 735:
	if ( (*p) == 34 )
		goto st736;
	if ( 48 <= (*p) && (*p) <= 57 )
		goto tr2183;
	goto tr2107;
st736:
	if ( ++p == pe )
		goto _test_eof736;
case 736:
	if ( 48 <= (*p) && (*p) <= 57 )
		goto tr2184;
	goto tr2107;
tr2186:
	{
		// Overflow check: 10*(s->number64) + fc - '0' <= UINT64_MAX
		if ((s->number64 < (UINT64_MAX / 10)) ||   // Dominant fast check.
			((s->number64 == (UINT64_MAX / 10)) && // Marginal case.
			 ((uint8_t)(*p) <= (UINT64_MAX % 10) + '0')
			)
		   ) {
			s->number64 *= 10;
			s->number64 += digit_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_NUMBER64_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st737;
tr2184:
	{
		uint16_t val = htons(2);
		memcpy(rdata_tail, &val, 2);
		rdata_tail += 2;
	}
	{
		if (rdata_tail + 2 > rdata_stop + 1) {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		s->number64 = 0;
	}
	{
		// Overflow check: 10*(s->number64) + fc - '0' <= UINT64_MAX
		if ((s->number64 < (UINT64_MAX / 10)) ||   // Dominant fast check.
			((s->number64 == (UINT64_MAX / 10)) && // Marginal case.
			 ((uint8_t)(*p) <= (UINT64_MAX % 10) + '0')
			)
		   ) {
			s->number64 *= 10;
			s->number64 += digit_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_NUMBER64_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st737;
st737:
	if ( ++p == pe )
		goto _test_eof737;
case 737:
	if ( (*p) == 34 )
		goto tr2185;
	if ( 48 <= (*p) && (*p) <= 57 )
		goto tr2186;
	goto tr2107;
tr2190:
	{
		// Overflow check: 10*(s->number64) + fc - '0' <= UINT64_MAX
		if ((s->number64 < (UINT64_MAX / 10)) ||   // Dominant fast check.
			((s->number64 == (UINT64_MAX / 10)) && // Marginal case.
			 ((uint8_t)(*p) <= (UINT64_MAX % 10) + '0')
			)
		   ) {
			s->number64 *= 10;
			s->number64 += digit_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_NUMBER64_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st738;
tr2183:
	{
		uint16_t val = htons(2);
		memcpy(rdata_tail, &val, 2);
		rdata_tail += 2;
	}
	{
		if (rdata_tail + 2 > rdata_stop + 1) {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		s->number64 = 0;
	}
	{
		// Overflow check: 10*(s->number64) + fc - '0' <= UINT64_MAX
		if ((s->number64 < (UINT64_MAX / 10)) ||   // Dominant fast check.
			((s->number64 == (UINT64_MAX / 10)) && // Marginal case.
			 ((uint8_t)(*p) <= (UINT64_MAX % 10) + '0')
			)
		   ) {
			s->number64 *= 10;
			s->number64 += digit_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_NUMBER64_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st738;
st738:
	if ( ++p == pe )
		goto _test_eof738;
case 738:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(2688 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 !s->multiline  ) _widec += 512;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(2688 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		if (
 !s->multiline  ) _widec += 512;
	}
	switch( _widec ) {
		case 9: goto tr2187;
		case 32: goto tr2187;
		case 40: goto tr2188;
		case 41: goto tr2189;
		case 3082: goto tr2191;
		case 3131: goto tr2192;
		case 3338: goto tr2193;
		case 3387: goto tr2193;
		case 3594: goto tr2194;
		case 3643: goto tr2195;
	}
	if ( 48 <= _widec && _widec <= 57 )
		goto tr2190;
	goto tr2107;
tr1998:
	{
		s->comma_list = true;
		s->pending_backslash = false;
	}
	{
		if (rdata_tail < rdata_stop) {
			s->item_length2_location = rdata_tail;
			rdata_tail += 2;
		} else {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (rdata_tail <= rdata_stop) {
			s->item_length_location = rdata_tail++;
		} else {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{ p--; {stack[top++] = 739;goto st327;} }
	goto st739;
st739:
	if ( ++p == pe )
		goto _test_eof739;
case 739:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(2688 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 !s->multiline  ) _widec += 512;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(2688 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		if (
 !s->multiline  ) _widec += 512;
	}
	switch( _widec ) {
		case 9: goto tr1999;
		case 32: goto tr1999;
		case 40: goto tr2000;
		case 41: goto tr2001;
		case 3082: goto tr2002;
		case 3131: goto tr2003;
		case 3338: goto tr2004;
		case 3387: goto tr2004;
		case 3594: goto tr2005;
		case 3643: goto tr2006;
	}
	if ( _widec < 11 ) {
		if ( _widec <= 8 )
			goto tr2196;
	} else if ( _widec > 58 ) {
		if ( 60 <= _widec )
			goto tr2196;
	} else
		goto tr2196;
	goto tr1967;
tr2196:
	{
		s->comma_list = true;
		s->pending_backslash = false;
	}
	{
		if (rdata_tail < rdata_stop) {
			s->item_length2_location = rdata_tail;
			rdata_tail += 2;
		} else {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (rdata_tail <= rdata_stop) {
			s->item_length_location = rdata_tail++;
		} else {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{ p--; {stack[top++] = 740;goto st327;} }
	goto st740;
st740:
	if ( ++p == pe )
		goto _test_eof740;
case 740:
	if ( (*p) == 34 )
		goto tr2197;
	goto tr1967;
st741:
	if ( ++p == pe )
		goto _test_eof741;
case 741:
	switch( (*p) ) {
		case 68: goto st743;
		case 69: goto st758;
		case 73: goto st797;
		case 80: goto st805;
		case 82: goto st818;
		case 100: goto st743;
		case 101: goto st758;
		case 105: goto st797;
		case 112: goto st805;
		case 114: goto st818;
	}
	if ( 48 <= (*p) && (*p) <= 57 )
		goto tr2199;
	goto tr2198;
tr2199:
	{
		s->number64 = 0;
	}
	{
		// Overflow check: 10*(s->number64) + fc - '0' <= UINT64_MAX
		if ((s->number64 < (UINT64_MAX / 10)) ||   // Dominant fast check.
			((s->number64 == (UINT64_MAX / 10)) && // Marginal case.
			 ((uint8_t)(*p) <= (UINT64_MAX % 10) + '0')
			)
		   ) {
			s->number64 *= 10;
			s->number64 += digit_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_NUMBER64_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st742;
tr2206:
	{
		// Overflow check: 10*(s->number64) + fc - '0' <= UINT64_MAX
		if ((s->number64 < (UINT64_MAX / 10)) ||   // Dominant fast check.
			((s->number64 == (UINT64_MAX / 10)) && // Marginal case.
			 ((uint8_t)(*p) <= (UINT64_MAX % 10) + '0')
			)
		   ) {
			s->number64 *= 10;
			s->number64 += digit_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_NUMBER64_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st742;
st742:
	if ( ++p == pe )
		goto _test_eof742;
case 742:
	switch( (*p) ) {
		case 32: goto tr2205;
		case 59: goto tr2205;
	}
	if ( (*p) < 40 ) {
		if ( 9 <= (*p) && (*p) <= 10 )
			goto tr2205;
	} else if ( (*p) > 41 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr2206;
	} else
		goto tr2205;
	goto tr2198;
tr2205:
	{
		if (s->number64 <= UINT8_MAX) {
			*rdata_tail = (uint8_t)(s->number64);
			rdata_tail += 1;
		} else {
			WARN(ZS_NUMBER8_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1481;
tr2209:
	{
		*(rdata_tail++) = 2;
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1481;
tr2211:
	{
		*(rdata_tail++) = 3;
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1481;
tr2223:
	{
		*(rdata_tail++) = 6;
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1481;
tr2233:
	{
		*(rdata_tail++) = 12;
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1481;
tr2247:
	{
		*(rdata_tail++) = 13;
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1481;
tr2256:
	{
		*(rdata_tail++) = 14;
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1481;
tr2263:
	{
		*(rdata_tail++) = 15;
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1481;
tr2266:
	{
		*(rdata_tail++) = 16;
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1481;
tr2274:
	{
		*(rdata_tail++) = 252;
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1481;
tr2285:
	{
		*(rdata_tail++) = 253;
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1481;
tr2288:
	{
		*(rdata_tail++) = 254;
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1481;
tr2295:
	{
		*(rdata_tail++) = 1;
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1481;
tr2301:
	{
		*(rdata_tail++) = 5;
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1481;
tr2313:
	{
		*(rdata_tail++) = 7;
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1481;
tr2316:
	{
		*(rdata_tail++) = 8;
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1481;
tr2319:
	{
		*(rdata_tail++) = 10;
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1481;
st1481:
	if ( ++p == pe )
		goto _test_eof1481;
case 1481:
	goto st0;
st743:
	if ( ++p == pe )
		goto _test_eof743;
case 743:
	switch( (*p) ) {
		case 72: goto st744;
		case 83: goto st745;
		case 104: goto st744;
		case 115: goto st745;
	}
	goto tr2198;
st744:
	if ( ++p == pe )
		goto _test_eof744;
case 744:
	switch( (*p) ) {
		case 32: goto tr2209;
		case 59: goto tr2209;
	}
	if ( (*p) > 10 ) {
		if ( 40 <= (*p) && (*p) <= 41 )
			goto tr2209;
	} else if ( (*p) >= 9 )
		goto tr2209;
	goto tr2198;
st745:
	if ( ++p == pe )
		goto _test_eof745;
case 745:
	switch( (*p) ) {
		case 65: goto st746;
		case 97: goto st746;
	}
	goto tr2198;
st746:
	if ( ++p == pe )
		goto _test_eof746;
case 746:
	switch( (*p) ) {
		case 32: goto tr2211;
		case 45: goto st747;
		case 59: goto tr2211;
	}
	if ( (*p) > 10 ) {
		if ( 40 <= (*p) && (*p) <= 41 )
			goto tr2211;
	} else if ( (*p) >= 9 )
		goto tr2211;
	goto tr2198;
st747:
	if ( ++p == pe )
		goto _test_eof747;
case 747:
	switch( (*p) ) {
		case 78: goto st748;
		case 110: goto st748;
	}
	goto tr2198;
st748:
	if ( ++p == pe )
		goto _test_eof748;
case 748:
	switch( (*p) ) {
		case 83: goto st749;
		case 115: goto st749;
	}
	goto tr2198;
st749:
	if ( ++p == pe )
		goto _test_eof749;
case 749:
	switch( (*p) ) {
		case 69: goto st750;
		case 101: goto st750;
	}
	goto tr2198;
st750:
	if ( ++p == pe )
		goto _test_eof750;
case 750:
	switch( (*p) ) {
		case 67: goto st751;
		case 99: goto st751;
	}
	goto tr2198;
st751:
	if ( ++p == pe )
		goto _test_eof751;
case 751:
	if ( (*p) == 51 )
		goto st752;
	goto tr2198;
st752:
	if ( ++p == pe )
		goto _test_eof752;
case 752:
	if ( (*p) == 45 )
		goto st753;
	goto tr2198;
st753:
	if ( ++p == pe )
		goto _test_eof753;
case 753:
	switch( (*p) ) {
		case 83: goto st754;
		case 115: goto st754;
	}
	goto tr2198;
st754:
	if ( ++p == pe )
		goto _test_eof754;
case 754:
	switch( (*p) ) {
		case 72: goto st755;
		case 104: goto st755;
	}
	goto tr2198;
st755:
	if ( ++p == pe )
		goto _test_eof755;
case 755:
	switch( (*p) ) {
		case 65: goto st756;
		case 97: goto st756;
	}
	goto tr2198;
st756:
	if ( ++p == pe )
		goto _test_eof756;
case 756:
	if ( (*p) == 49 )
		goto st757;
	goto tr2198;
st757:
	if ( ++p == pe )
		goto _test_eof757;
case 757:
	switch( (*p) ) {
		case 32: goto tr2223;
		case 59: goto tr2223;
	}
	if ( (*p) > 10 ) {
		if ( 40 <= (*p) && (*p) <= 41 )
			goto tr2223;
	} else if ( (*p) >= 9 )
		goto tr2223;
	goto tr2198;
st758:
	if ( ++p == pe )
		goto _test_eof758;
case 758:
	switch( (*p) ) {
		case 67: goto st759;
		case 68: goto st788;
		case 99: goto st759;
		case 100: goto st788;
	}
	goto tr2198;
st759:
	if ( ++p == pe )
		goto _test_eof759;
case 759:
	switch( (*p) ) {
		case 67: goto st760;
		case 68: goto st766;
		case 99: goto st760;
		case 100: goto st766;
	}
	goto tr2198;
st760:
	if ( ++p == pe )
		goto _test_eof760;
case 760:
	if ( (*p) == 45 )
		goto st761;
	goto tr2198;
st761:
	if ( ++p == pe )
		goto _test_eof761;
case 761:
	switch( (*p) ) {
		case 71: goto st762;
		case 103: goto st762;
	}
	goto tr2198;
st762:
	if ( ++p == pe )
		goto _test_eof762;
case 762:
	switch( (*p) ) {
		case 79: goto st763;
		case 111: goto st763;
	}
	goto tr2198;
st763:
	if ( ++p == pe )
		goto _test_eof763;
case 763:
	switch( (*p) ) {
		case 83: goto st764;
		case 115: goto st764;
	}
	goto tr2198;
st764:
	if ( ++p == pe )
		goto _test_eof764;
case 764:
	switch( (*p) ) {
		case 84: goto st765;
		case 116: goto st765;
	}
	goto tr2198;
st765:
	if ( ++p == pe )
		goto _test_eof765;
case 765:
	switch( (*p) ) {
		case 32: goto tr2233;
		case 59: goto tr2233;
	}
	if ( (*p) > 10 ) {
		if ( 40 <= (*p) && (*p) <= 41 )
			goto tr2233;
	} else if ( (*p) >= 9 )
		goto tr2233;
	goto tr2198;
st766:
	if ( ++p == pe )
		goto _test_eof766;
case 766:
	switch( (*p) ) {
		case 83: goto st767;
		case 115: goto st767;
	}
	goto tr2198;
st767:
	if ( ++p == pe )
		goto _test_eof767;
case 767:
	switch( (*p) ) {
		case 65: goto st768;
		case 97: goto st768;
	}
	goto tr2198;
st768:
	if ( ++p == pe )
		goto _test_eof768;
case 768:
	switch( (*p) ) {
		case 80: goto st769;
		case 112: goto st769;
	}
	goto tr2198;
st769:
	if ( ++p == pe )
		goto _test_eof769;
case 769:
	switch( (*p) ) {
		case 50: goto st770;
		case 51: goto st779;
	}
	goto tr2198;
st770:
	if ( ++p == pe )
		goto _test_eof770;
case 770:
	if ( (*p) == 53 )
		goto st771;
	goto tr2198;
st771:
	if ( ++p == pe )
		goto _test_eof771;
case 771:
	if ( (*p) == 54 )
		goto st772;
	goto tr2198;
st772:
	if ( ++p == pe )
		goto _test_eof772;
case 772:
	switch( (*p) ) {
		case 83: goto st773;
		case 115: goto st773;
	}
	goto tr2198;
st773:
	if ( ++p == pe )
		goto _test_eof773;
case 773:
	switch( (*p) ) {
		case 72: goto st774;
		case 104: goto st774;
	}
	goto tr2198;
st774:
	if ( ++p == pe )
		goto _test_eof774;
case 774:
	switch( (*p) ) {
		case 65: goto st775;
		case 97: goto st775;
	}
	goto tr2198;
st775:
	if ( ++p == pe )
		goto _test_eof775;
case 775:
	if ( (*p) == 50 )
		goto st776;
	goto tr2198;
st776:
	if ( ++p == pe )
		goto _test_eof776;
case 776:
	if ( (*p) == 53 )
		goto st777;
	goto tr2198;
st777:
	if ( ++p == pe )
		goto _test_eof777;
case 777:
	if ( (*p) == 54 )
		goto st778;
	goto tr2198;
st778:
	if ( ++p == pe )
		goto _test_eof778;
case 778:
	switch( (*p) ) {
		case 32: goto tr2247;
		case 59: goto tr2247;
	}
	if ( (*p) > 10 ) {
		if ( 40 <= (*p) && (*p) <= 41 )
			goto tr2247;
	} else if ( (*p) >= 9 )
		goto tr2247;
	goto tr2198;
st779:
	if ( ++p == pe )
		goto _test_eof779;
case 779:
	if ( (*p) == 56 )
		goto st780;
	goto tr2198;
st780:
	if ( ++p == pe )
		goto _test_eof780;
case 780:
	if ( (*p) == 52 )
		goto st781;
	goto tr2198;
st781:
	if ( ++p == pe )
		goto _test_eof781;
case 781:
	switch( (*p) ) {
		case 83: goto st782;
		case 115: goto st782;
	}
	goto tr2198;
st782:
	if ( ++p == pe )
		goto _test_eof782;
case 782:
	switch( (*p) ) {
		case 72: goto st783;
		case 104: goto st783;
	}
	goto tr2198;
st783:
	if ( ++p == pe )
		goto _test_eof783;
case 783:
	switch( (*p) ) {
		case 65: goto st784;
		case 97: goto st784;
	}
	goto tr2198;
st784:
	if ( ++p == pe )
		goto _test_eof784;
case 784:
	if ( (*p) == 51 )
		goto st785;
	goto tr2198;
st785:
	if ( ++p == pe )
		goto _test_eof785;
case 785:
	if ( (*p) == 56 )
		goto st786;
	goto tr2198;
st786:
	if ( ++p == pe )
		goto _test_eof786;
case 786:
	if ( (*p) == 52 )
		goto st787;
	goto tr2198;
st787:
	if ( ++p == pe )
		goto _test_eof787;
case 787:
	switch( (*p) ) {
		case 32: goto tr2256;
		case 59: goto tr2256;
	}
	if ( (*p) > 10 ) {
		if ( 40 <= (*p) && (*p) <= 41 )
			goto tr2256;
	} else if ( (*p) >= 9 )
		goto tr2256;
	goto tr2198;
st788:
	if ( ++p == pe )
		goto _test_eof788;
case 788:
	switch( (*p) ) {
		case 50: goto st789;
		case 52: goto st794;
	}
	goto tr2198;
st789:
	if ( ++p == pe )
		goto _test_eof789;
case 789:
	if ( (*p) == 53 )
		goto st790;
	goto tr2198;
st790:
	if ( ++p == pe )
		goto _test_eof790;
case 790:
	if ( (*p) == 53 )
		goto st791;
	goto tr2198;
st791:
	if ( ++p == pe )
		goto _test_eof791;
case 791:
	if ( (*p) == 49 )
		goto st792;
	goto tr2198;
st792:
	if ( ++p == pe )
		goto _test_eof792;
case 792:
	if ( (*p) == 57 )
		goto st793;
	goto tr2198;
st793:
	if ( ++p == pe )
		goto _test_eof793;
case 793:
	switch( (*p) ) {
		case 32: goto tr2263;
		case 59: goto tr2263;
	}
	if ( (*p) > 10 ) {
		if ( 40 <= (*p) && (*p) <= 41 )
			goto tr2263;
	} else if ( (*p) >= 9 )
		goto tr2263;
	goto tr2198;
st794:
	if ( ++p == pe )
		goto _test_eof794;
case 794:
	if ( (*p) == 52 )
		goto st795;
	goto tr2198;
st795:
	if ( ++p == pe )
		goto _test_eof795;
case 795:
	if ( (*p) == 56 )
		goto st796;
	goto tr2198;
st796:
	if ( ++p == pe )
		goto _test_eof796;
case 796:
	switch( (*p) ) {
		case 32: goto tr2266;
		case 59: goto tr2266;
	}
	if ( (*p) > 10 ) {
		if ( 40 <= (*p) && (*p) <= 41 )
			goto tr2266;
	} else if ( (*p) >= 9 )
		goto tr2266;
	goto tr2198;
st797:
	if ( ++p == pe )
		goto _test_eof797;
case 797:
	switch( (*p) ) {
		case 78: goto st798;
		case 110: goto st798;
	}
	goto tr2198;
st798:
	if ( ++p == pe )
		goto _test_eof798;
case 798:
	switch( (*p) ) {
		case 68: goto st799;
		case 100: goto st799;
	}
	goto tr2198;
st799:
	if ( ++p == pe )
		goto _test_eof799;
case 799:
	switch( (*p) ) {
		case 73: goto st800;
		case 105: goto st800;
	}
	goto tr2198;
st800:
	if ( ++p == pe )
		goto _test_eof800;
case 800:
	switch( (*p) ) {
		case 82: goto st801;
		case 114: goto st801;
	}
	goto tr2198;
st801:
	if ( ++p == pe )
		goto _test_eof801;
case 801:
	switch( (*p) ) {
		case 69: goto st802;
		case 101: goto st802;
	}
	goto tr2198;
st802:
	if ( ++p == pe )
		goto _test_eof802;
case 802:
	switch( (*p) ) {
		case 67: goto st803;
		case 99: goto st803;
	}
	goto tr2198;
st803:
	if ( ++p == pe )
		goto _test_eof803;
case 803:
	switch( (*p) ) {
		case 84: goto st804;
		case 116: goto st804;
	}
	goto tr2198;
st804:
	if ( ++p == pe )
		goto _test_eof804;
case 804:
	switch( (*p) ) {
		case 32: goto tr2274;
		case 59: goto tr2274;
	}
	if ( (*p) > 10 ) {
		if ( 40 <= (*p) && (*p) <= 41 )
			goto tr2274;
	} else if ( (*p) >= 9 )
		goto tr2274;
	goto tr2198;
st805:
	if ( ++p == pe )
		goto _test_eof805;
case 805:
	switch( (*p) ) {
		case 82: goto st806;
		case 114: goto st806;
	}
	goto tr2198;
st806:
	if ( ++p == pe )
		goto _test_eof806;
case 806:
	switch( (*p) ) {
		case 73: goto st807;
		case 105: goto st807;
	}
	goto tr2198;
st807:
	if ( ++p == pe )
		goto _test_eof807;
case 807:
	switch( (*p) ) {
		case 86: goto st808;
		case 118: goto st808;
	}
	goto tr2198;
st808:
	if ( ++p == pe )
		goto _test_eof808;
case 808:
	switch( (*p) ) {
		case 65: goto st809;
		case 97: goto st809;
	}
	goto tr2198;
st809:
	if ( ++p == pe )
		goto _test_eof809;
case 809:
	switch( (*p) ) {
		case 84: goto st810;
		case 116: goto st810;
	}
	goto tr2198;
st810:
	if ( ++p == pe )
		goto _test_eof810;
case 810:
	switch( (*p) ) {
		case 69: goto st811;
		case 101: goto st811;
	}
	goto tr2198;
st811:
	if ( ++p == pe )
		goto _test_eof811;
case 811:
	switch( (*p) ) {
		case 68: goto st812;
		case 79: goto st815;
		case 100: goto st812;
		case 111: goto st815;
	}
	goto tr2198;
st812:
	if ( ++p == pe )
		goto _test_eof812;
case 812:
	switch( (*p) ) {
		case 78: goto st813;
		case 110: goto st813;
	}
	goto tr2198;
st813:
	if ( ++p == pe )
		goto _test_eof813;
case 813:
	switch( (*p) ) {
		case 83: goto st814;
		case 115: goto st814;
	}
	goto tr2198;
st814:
	if ( ++p == pe )
		goto _test_eof814;
case 814:
	switch( (*p) ) {
		case 32: goto tr2285;
		case 59: goto tr2285;
	}
	if ( (*p) > 10 ) {
		if ( 40 <= (*p) && (*p) <= 41 )
			goto tr2285;
	} else if ( (*p) >= 9 )
		goto tr2285;
	goto tr2198;
st815:
	if ( ++p == pe )
		goto _test_eof815;
case 815:
	switch( (*p) ) {
		case 73: goto st816;
		case 105: goto st816;
	}
	goto tr2198;
st816:
	if ( ++p == pe )
		goto _test_eof816;
case 816:
	switch( (*p) ) {
		case 68: goto st817;
		case 100: goto st817;
	}
	goto tr2198;
st817:
	if ( ++p == pe )
		goto _test_eof817;
case 817:
	switch( (*p) ) {
		case 32: goto tr2288;
		case 59: goto tr2288;
	}
	if ( (*p) > 10 ) {
		if ( 40 <= (*p) && (*p) <= 41 )
			goto tr2288;
	} else if ( (*p) >= 9 )
		goto tr2288;
	goto tr2198;
st818:
	if ( ++p == pe )
		goto _test_eof818;
case 818:
	switch( (*p) ) {
		case 83: goto st819;
		case 115: goto st819;
	}
	goto tr2198;
st819:
	if ( ++p == pe )
		goto _test_eof819;
case 819:
	switch( (*p) ) {
		case 65: goto st820;
		case 97: goto st820;
	}
	goto tr2198;
st820:
	if ( ++p == pe )
		goto _test_eof820;
case 820:
	switch( (*p) ) {
		case 77: goto st821;
		case 83: goto st824;
		case 109: goto st821;
		case 115: goto st824;
	}
	goto tr2198;
st821:
	if ( ++p == pe )
		goto _test_eof821;
case 821:
	switch( (*p) ) {
		case 68: goto st822;
		case 100: goto st822;
	}
	goto tr2198;
st822:
	if ( ++p == pe )
		goto _test_eof822;
case 822:
	if ( (*p) == 53 )
		goto st823;
	goto tr2198;
st823:
	if ( ++p == pe )
		goto _test_eof823;
case 823:
	switch( (*p) ) {
		case 32: goto tr2295;
		case 59: goto tr2295;
	}
	if ( (*p) > 10 ) {
		if ( 40 <= (*p) && (*p) <= 41 )
			goto tr2295;
	} else if ( (*p) >= 9 )
		goto tr2295;
	goto tr2198;
st824:
	if ( ++p == pe )
		goto _test_eof824;
case 824:
	switch( (*p) ) {
		case 72: goto st825;
		case 104: goto st825;
	}
	goto tr2198;
st825:
	if ( ++p == pe )
		goto _test_eof825;
case 825:
	switch( (*p) ) {
		case 65: goto st826;
		case 97: goto st826;
	}
	goto tr2198;
st826:
	if ( ++p == pe )
		goto _test_eof826;
case 826:
	switch( (*p) ) {
		case 49: goto st827;
		case 50: goto st839;
		case 53: goto st842;
	}
	goto tr2198;
st827:
	if ( ++p == pe )
		goto _test_eof827;
case 827:
	switch( (*p) ) {
		case 32: goto tr2301;
		case 45: goto st828;
		case 59: goto tr2301;
	}
	if ( (*p) > 10 ) {
		if ( 40 <= (*p) && (*p) <= 41 )
			goto tr2301;
	} else if ( (*p) >= 9 )
		goto tr2301;
	goto tr2198;
st828:
	if ( ++p == pe )
		goto _test_eof828;
case 828:
	switch( (*p) ) {
		case 78: goto st829;
		case 110: goto st829;
	}
	goto tr2198;
st829:
	if ( ++p == pe )
		goto _test_eof829;
case 829:
	switch( (*p) ) {
		case 83: goto st830;
		case 115: goto st830;
	}
	goto tr2198;
st830:
	if ( ++p == pe )
		goto _test_eof830;
case 830:
	switch( (*p) ) {
		case 69: goto st831;
		case 101: goto st831;
	}
	goto tr2198;
st831:
	if ( ++p == pe )
		goto _test_eof831;
case 831:
	switch( (*p) ) {
		case 67: goto st832;
		case 99: goto st832;
	}
	goto tr2198;
st832:
	if ( ++p == pe )
		goto _test_eof832;
case 832:
	if ( (*p) == 51 )
		goto st833;
	goto tr2198;
st833:
	if ( ++p == pe )
		goto _test_eof833;
case 833:
	if ( (*p) == 45 )
		goto st834;
	goto tr2198;
st834:
	if ( ++p == pe )
		goto _test_eof834;
case 834:
	switch( (*p) ) {
		case 83: goto st835;
		case 115: goto st835;
	}
	goto tr2198;
st835:
	if ( ++p == pe )
		goto _test_eof835;
case 835:
	switch( (*p) ) {
		case 72: goto st836;
		case 104: goto st836;
	}
	goto tr2198;
st836:
	if ( ++p == pe )
		goto _test_eof836;
case 836:
	switch( (*p) ) {
		case 65: goto st837;
		case 97: goto st837;
	}
	goto tr2198;
st837:
	if ( ++p == pe )
		goto _test_eof837;
case 837:
	if ( (*p) == 49 )
		goto st838;
	goto tr2198;
st838:
	if ( ++p == pe )
		goto _test_eof838;
case 838:
	switch( (*p) ) {
		case 32: goto tr2313;
		case 59: goto tr2313;
	}
	if ( (*p) > 10 ) {
		if ( 40 <= (*p) && (*p) <= 41 )
			goto tr2313;
	} else if ( (*p) >= 9 )
		goto tr2313;
	goto tr2198;
st839:
	if ( ++p == pe )
		goto _test_eof839;
case 839:
	if ( (*p) == 53 )
		goto st840;
	goto tr2198;
st840:
	if ( ++p == pe )
		goto _test_eof840;
case 840:
	if ( (*p) == 54 )
		goto st841;
	goto tr2198;
st841:
	if ( ++p == pe )
		goto _test_eof841;
case 841:
	switch( (*p) ) {
		case 32: goto tr2316;
		case 59: goto tr2316;
	}
	if ( (*p) > 10 ) {
		if ( 40 <= (*p) && (*p) <= 41 )
			goto tr2316;
	} else if ( (*p) >= 9 )
		goto tr2316;
	goto tr2198;
st842:
	if ( ++p == pe )
		goto _test_eof842;
case 842:
	if ( (*p) == 49 )
		goto st843;
	goto tr2198;
st843:
	if ( ++p == pe )
		goto _test_eof843;
case 843:
	if ( (*p) == 50 )
		goto st844;
	goto tr2198;
st844:
	if ( ++p == pe )
		goto _test_eof844;
case 844:
	switch( (*p) ) {
		case 32: goto tr2319;
		case 59: goto tr2319;
	}
	if ( (*p) > 10 ) {
		if ( 40 <= (*p) && (*p) <= 41 )
			goto tr2319;
	} else if ( (*p) >= 9 )
		goto tr2319;
	goto tr2198;
st845:
	if ( ++p == pe )
		goto _test_eof845;
case 845:
	switch( (*p) ) {
		case 65: goto st847;
		case 73: goto st853;
		case 79: goto st870;
		case 80: goto st873;
		case 83: goto st879;
		case 85: goto st883;
		case 97: goto st847;
		case 105: goto st853;
		case 111: goto st870;
		case 112: goto st873;
		case 115: goto st879;
		case 117: goto st883;
	}
	if ( 48 <= (*p) && (*p) <= 57 )
		goto tr2321;
	goto tr2320;
tr2321:
	{
		s->number64 = 0;
	}
	{
		// Overflow check: 10*(s->number64) + fc - '0' <= UINT64_MAX
		if ((s->number64 < (UINT64_MAX / 10)) ||   // Dominant fast check.
			((s->number64 == (UINT64_MAX / 10)) && // Marginal case.
			 ((uint8_t)(*p) <= (UINT64_MAX % 10) + '0')
			)
		   ) {
			s->number64 *= 10;
			s->number64 += digit_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_NUMBER64_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st846;
tr2329:
	{
		// Overflow check: 10*(s->number64) + fc - '0' <= UINT64_MAX
		if ((s->number64 < (UINT64_MAX / 10)) ||   // Dominant fast check.
			((s->number64 == (UINT64_MAX / 10)) && // Marginal case.
			 ((uint8_t)(*p) <= (UINT64_MAX % 10) + '0')
			)
		   ) {
			s->number64 *= 10;
			s->number64 += digit_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_NUMBER64_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st846;
st846:
	if ( ++p == pe )
		goto _test_eof846;
case 846:
	switch( (*p) ) {
		case 32: goto tr2328;
		case 59: goto tr2328;
	}
	if ( (*p) < 40 ) {
		if ( 9 <= (*p) && (*p) <= 10 )
			goto tr2328;
	} else if ( (*p) > 41 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr2329;
	} else
		goto tr2328;
	goto tr2320;
tr2365:
	{
		uint16_t val = htons(1);
		memcpy(rdata_tail, &val, 2);
		rdata_tail += 2;
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1482;
tr2335:
	{
		uint16_t val = htons(7);
		memcpy(rdata_tail, &val, 2);
		rdata_tail += 2;
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1482;
tr2355:
	{
		uint16_t val = htons(5);
		memcpy(rdata_tail, &val, 2);
		rdata_tail += 2;
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1482;
tr2351:
	{
		uint16_t val = htons(4);
		memcpy(rdata_tail, &val, 2);
		rdata_tail += 2;
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1482;
tr2348:
	{
		uint16_t val = htons(6);
		memcpy(rdata_tail, &val, 2);
		rdata_tail += 2;
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1482;
tr2328:
	{
		if (s->number64 <= UINT16_MAX) {
			uint16_t num16 = htons((uint16_t)s->number64);
			memcpy(rdata_tail, &num16, 2);
			rdata_tail += 2;
		} else {
			WARN(ZS_NUMBER16_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1482;
tr2369:
	{
		uint16_t val = htons(2);
		memcpy(rdata_tail, &val, 2);
		rdata_tail += 2;
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1482;
tr2344:
	{
		uint16_t val = htons(8);
		memcpy(rdata_tail, &val, 2);
		rdata_tail += 2;
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1482;
tr2362:
	{
		uint16_t val = htons(3);
		memcpy(rdata_tail, &val, 2);
		rdata_tail += 2;
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1482;
tr2358:
	{
		uint16_t val = htons(254);
		memcpy(rdata_tail, &val, 2);
		rdata_tail += 2;
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1482;
tr2372:
	{
		uint16_t val = htons(253);
		memcpy(rdata_tail, &val, 2);
		rdata_tail += 2;
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1482;
st1482:
	if ( ++p == pe )
		goto _test_eof1482;
case 1482:
	goto st0;
st847:
	if ( ++p == pe )
		goto _test_eof847;
case 847:
	switch( (*p) ) {
		case 67: goto st848;
		case 99: goto st848;
	}
	goto tr2320;
st848:
	if ( ++p == pe )
		goto _test_eof848;
case 848:
	switch( (*p) ) {
		case 80: goto st849;
		case 112: goto st849;
	}
	goto tr2320;
st849:
	if ( ++p == pe )
		goto _test_eof849;
case 849:
	switch( (*p) ) {
		case 75: goto st850;
		case 107: goto st850;
	}
	goto tr2320;
st850:
	if ( ++p == pe )
		goto _test_eof850;
case 850:
	switch( (*p) ) {
		case 73: goto st851;
		case 105: goto st851;
	}
	goto tr2320;
st851:
	if ( ++p == pe )
		goto _test_eof851;
case 851:
	switch( (*p) ) {
		case 88: goto st852;
		case 120: goto st852;
	}
	goto tr2320;
st852:
	if ( ++p == pe )
		goto _test_eof852;
case 852:
	switch( (*p) ) {
		case 32: goto tr2335;
		case 59: goto tr2335;
	}
	if ( (*p) > 10 ) {
		if ( 40 <= (*p) && (*p) <= 41 )
			goto tr2335;
	} else if ( (*p) >= 9 )
		goto tr2335;
	goto tr2320;
st853:
	if ( ++p == pe )
		goto _test_eof853;
case 853:
	switch( (*p) ) {
		case 65: goto st854;
		case 80: goto st860;
		case 83: goto st866;
		case 97: goto st854;
		case 112: goto st860;
		case 115: goto st866;
	}
	goto tr2320;
st854:
	if ( ++p == pe )
		goto _test_eof854;
case 854:
	switch( (*p) ) {
		case 67: goto st855;
		case 99: goto st855;
	}
	goto tr2320;
st855:
	if ( ++p == pe )
		goto _test_eof855;
case 855:
	switch( (*p) ) {
		case 80: goto st856;
		case 112: goto st856;
	}
	goto tr2320;
st856:
	if ( ++p == pe )
		goto _test_eof856;
case 856:
	switch( (*p) ) {
		case 75: goto st857;
		case 107: goto st857;
	}
	goto tr2320;
st857:
	if ( ++p == pe )
		goto _test_eof857;
case 857:
	switch( (*p) ) {
		case 73: goto st858;
		case 105: goto st858;
	}
	goto tr2320;
st858:
	if ( ++p == pe )
		goto _test_eof858;
case 858:
	switch( (*p) ) {
		case 88: goto st859;
		case 120: goto st859;
	}
	goto tr2320;
st859:
	if ( ++p == pe )
		goto _test_eof859;
case 859:
	switch( (*p) ) {
		case 32: goto tr2344;
		case 59: goto tr2344;
	}
	if ( (*p) > 10 ) {
		if ( 40 <= (*p) && (*p) <= 41 )
			goto tr2344;
	} else if ( (*p) >= 9 )
		goto tr2344;
	goto tr2320;
st860:
	if ( ++p == pe )
		goto _test_eof860;
case 860:
	switch( (*p) ) {
		case 71: goto st861;
		case 75: goto st863;
		case 103: goto st861;
		case 107: goto st863;
	}
	goto tr2320;
st861:
	if ( ++p == pe )
		goto _test_eof861;
case 861:
	switch( (*p) ) {
		case 80: goto st862;
		case 112: goto st862;
	}
	goto tr2320;
st862:
	if ( ++p == pe )
		goto _test_eof862;
case 862:
	switch( (*p) ) {
		case 32: goto tr2348;
		case 59: goto tr2348;
	}
	if ( (*p) > 10 ) {
		if ( 40 <= (*p) && (*p) <= 41 )
			goto tr2348;
	} else if ( (*p) >= 9 )
		goto tr2348;
	goto tr2320;
st863:
	if ( ++p == pe )
		goto _test_eof863;
case 863:
	switch( (*p) ) {
		case 73: goto st864;
		case 105: goto st864;
	}
	goto tr2320;
st864:
	if ( ++p == pe )
		goto _test_eof864;
case 864:
	switch( (*p) ) {
		case 88: goto st865;
		case 120: goto st865;
	}
	goto tr2320;
st865:
	if ( ++p == pe )
		goto _test_eof865;
case 865:
	switch( (*p) ) {
		case 32: goto tr2351;
		case 59: goto tr2351;
	}
	if ( (*p) > 10 ) {
		if ( 40 <= (*p) && (*p) <= 41 )
			goto tr2351;
	} else if ( (*p) >= 9 )
		goto tr2351;
	goto tr2320;
st866:
	if ( ++p == pe )
		goto _test_eof866;
case 866:
	switch( (*p) ) {
		case 80: goto st867;
		case 112: goto st867;
	}
	goto tr2320;
st867:
	if ( ++p == pe )
		goto _test_eof867;
case 867:
	switch( (*p) ) {
		case 75: goto st868;
		case 107: goto st868;
	}
	goto tr2320;
st868:
	if ( ++p == pe )
		goto _test_eof868;
case 868:
	switch( (*p) ) {
		case 73: goto st869;
		case 105: goto st869;
	}
	goto tr2320;
st869:
	if ( ++p == pe )
		goto _test_eof869;
case 869:
	switch( (*p) ) {
		case 32: goto tr2355;
		case 59: goto tr2355;
	}
	if ( (*p) > 10 ) {
		if ( 40 <= (*p) && (*p) <= 41 )
			goto tr2355;
	} else if ( (*p) >= 9 )
		goto tr2355;
	goto tr2320;
st870:
	if ( ++p == pe )
		goto _test_eof870;
case 870:
	switch( (*p) ) {
		case 73: goto st871;
		case 105: goto st871;
	}
	goto tr2320;
st871:
	if ( ++p == pe )
		goto _test_eof871;
case 871:
	switch( (*p) ) {
		case 68: goto st872;
		case 100: goto st872;
	}
	goto tr2320;
st872:
	if ( ++p == pe )
		goto _test_eof872;
case 872:
	switch( (*p) ) {
		case 32: goto tr2358;
		case 59: goto tr2358;
	}
	if ( (*p) > 10 ) {
		if ( 40 <= (*p) && (*p) <= 41 )
			goto tr2358;
	} else if ( (*p) >= 9 )
		goto tr2358;
	goto tr2320;
st873:
	if ( ++p == pe )
		goto _test_eof873;
case 873:
	switch( (*p) ) {
		case 71: goto st874;
		case 75: goto st876;
		case 103: goto st874;
		case 107: goto st876;
	}
	goto tr2320;
st874:
	if ( ++p == pe )
		goto _test_eof874;
case 874:
	switch( (*p) ) {
		case 80: goto st875;
		case 112: goto st875;
	}
	goto tr2320;
st875:
	if ( ++p == pe )
		goto _test_eof875;
case 875:
	switch( (*p) ) {
		case 32: goto tr2362;
		case 59: goto tr2362;
	}
	if ( (*p) > 10 ) {
		if ( 40 <= (*p) && (*p) <= 41 )
			goto tr2362;
	} else if ( (*p) >= 9 )
		goto tr2362;
	goto tr2320;
st876:
	if ( ++p == pe )
		goto _test_eof876;
case 876:
	switch( (*p) ) {
		case 73: goto st877;
		case 105: goto st877;
	}
	goto tr2320;
st877:
	if ( ++p == pe )
		goto _test_eof877;
case 877:
	switch( (*p) ) {
		case 88: goto st878;
		case 120: goto st878;
	}
	goto tr2320;
st878:
	if ( ++p == pe )
		goto _test_eof878;
case 878:
	switch( (*p) ) {
		case 32: goto tr2365;
		case 59: goto tr2365;
	}
	if ( (*p) > 10 ) {
		if ( 40 <= (*p) && (*p) <= 41 )
			goto tr2365;
	} else if ( (*p) >= 9 )
		goto tr2365;
	goto tr2320;
st879:
	if ( ++p == pe )
		goto _test_eof879;
case 879:
	switch( (*p) ) {
		case 80: goto st880;
		case 112: goto st880;
	}
	goto tr2320;
st880:
	if ( ++p == pe )
		goto _test_eof880;
case 880:
	switch( (*p) ) {
		case 75: goto st881;
		case 107: goto st881;
	}
	goto tr2320;
st881:
	if ( ++p == pe )
		goto _test_eof881;
case 881:
	switch( (*p) ) {
		case 73: goto st882;
		case 105: goto st882;
	}
	goto tr2320;
st882:
	if ( ++p == pe )
		goto _test_eof882;
case 882:
	switch( (*p) ) {
		case 32: goto tr2369;
		case 59: goto tr2369;
	}
	if ( (*p) > 10 ) {
		if ( 40 <= (*p) && (*p) <= 41 )
			goto tr2369;
	} else if ( (*p) >= 9 )
		goto tr2369;
	goto tr2320;
st883:
	if ( ++p == pe )
		goto _test_eof883;
case 883:
	switch( (*p) ) {
		case 82: goto st884;
		case 114: goto st884;
	}
	goto tr2320;
st884:
	if ( ++p == pe )
		goto _test_eof884;
case 884:
	switch( (*p) ) {
		case 73: goto st885;
		case 105: goto st885;
	}
	goto tr2320;
st885:
	if ( ++p == pe )
		goto _test_eof885;
case 885:
	switch( (*p) ) {
		case 32: goto tr2372;
		case 59: goto tr2372;
	}
	if ( (*p) > 10 ) {
		if ( 40 <= (*p) && (*p) <= 41 )
			goto tr2372;
	} else if ( (*p) >= 9 )
		goto tr2372;
	goto tr2320;
st886:
	if ( ++p == pe )
		goto _test_eof886;
case 886:
	if ( (*p) == 46 )
		goto tr2374;
	if ( 48 <= (*p) && (*p) <= 57 )
		goto tr2374;
	goto tr2373;
tr2376:
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		} else {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st887;
tr2374:
	{
		s->buffer_length = 0;
	}
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		} else {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st887;
st887:
	if ( ++p == pe )
		goto _test_eof887;
case 887:
	switch( (*p) ) {
		case 32: goto tr2375;
		case 46: goto tr2376;
		case 59: goto tr2375;
	}
	if ( (*p) < 40 ) {
		if ( 9 <= (*p) && (*p) <= 10 )
			goto tr2375;
	} else if ( (*p) > 41 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr2376;
	} else
		goto tr2375;
	goto tr2373;
tr2375:
	{
		s->buffer[s->buffer_length] = 0;

		if (inet_pton(AF_INET, (char *)s->buffer, s->addr) <= 0) {
			WARN(ZS_BAD_IPV4);
			p--; {goto st316;}
		}
	}
	{
		if (rdata_tail + ZS_INET4_ADDR_LENGTH > rdata_stop + 1) {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
		memcpy(rdata_tail, s->addr, ZS_INET4_ADDR_LENGTH);
		rdata_tail += ZS_INET4_ADDR_LENGTH;
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1483;
st1483:
	if ( ++p == pe )
		goto _test_eof1483;
case 1483:
	goto st0;
st888:
	if ( ++p == pe )
		goto _test_eof888;
case 888:
	switch( (*p) ) {
		case 42: goto tr2377;
		case 92: goto tr2377;
		case 95: goto tr2377;
	}
	if ( (*p) < 64 ) {
		if ( 45 <= (*p) && (*p) <= 57 )
			goto tr2377;
	} else if ( (*p) > 90 ) {
		if ( 97 <= (*p) && (*p) <= 122 )
			goto tr2377;
	} else
		goto tr2377;
	goto tr77;
tr2377:
	{
		s->dname = rdata_tail;
	}
	{ p--; {stack[top++] = 889;goto st318;} }
	goto st889;
st889:
	if ( ++p == pe )
		goto _test_eof889;
case 889:
	switch( (*p) ) {
		case 32: goto tr2378;
		case 59: goto tr2378;
	}
	if ( (*p) > 10 ) {
		if ( 40 <= (*p) && (*p) <= 41 )
			goto tr2378;
	} else if ( (*p) >= 9 )
		goto tr2378;
	goto tr77;
tr2378:
	{
		rdata_tail += s->dname_tmp_length;
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1484;
st1484:
	if ( ++p == pe )
		goto _test_eof1484;
case 1484:
	goto st0;
st890:
	if ( ++p == pe )
		goto _test_eof890;
case 890:
	switch( (*p) ) {
		case 42: goto tr2379;
		case 92: goto tr2379;
		case 95: goto tr2379;
	}
	if ( (*p) < 64 ) {
		if ( 45 <= (*p) && (*p) <= 57 )
			goto tr2379;
	} else if ( (*p) > 90 ) {
		if ( 97 <= (*p) && (*p) <= 122 )
			goto tr2379;
	} else
		goto tr2379;
	goto tr77;
tr2379:
	{
		s->dname = rdata_tail;
	}
	{ p--; {stack[top++] = 891;goto st318;} }
	goto st891;
st891:
	if ( ++p == pe )
		goto _test_eof891;
case 891:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr2380;
		case 32: goto tr2380;
		case 40: goto tr2381;
		case 41: goto tr2382;
		case 2058: goto tr2383;
		case 2107: goto tr2384;
	}
	goto tr77;
tr2386:
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st892;
tr2387:
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st892;
tr2389:
	{
		s->line_counter++;
	}
	goto st892;
tr2533:
	{
		s->buffer[s->buffer_length++] = 0;

		// Execute the comment callback.
		if (s->process.automatic && s->process.comment != NULL) {
			s->process.comment(s);

			// Stop if required from the callback.
			if (s->state == ZS_STATE_STOP) {
				{p++; cs = 892; goto _out;}
			}
		}
	}
	{
		s->line_counter++;
	}
	goto st892;
tr2380:
	{
		rdata_tail += s->dname_tmp_length;
	}
	goto st892;
tr2381:
	{
		rdata_tail += s->dname_tmp_length;
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st892;
tr2382:
	{
		rdata_tail += s->dname_tmp_length;
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st892;
tr2383:
	{
		rdata_tail += s->dname_tmp_length;
	}
	{
		s->line_counter++;
	}
	goto st892;
st892:
	if ( ++p == pe )
		goto _test_eof892;
case 892:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto st892;
		case 32: goto st892;
		case 40: goto tr2386;
		case 41: goto tr2387;
		case 42: goto tr2388;
		case 92: goto tr2388;
		case 95: goto tr2388;
		case 2058: goto tr2389;
		case 2107: goto tr2390;
	}
	if ( _widec < 64 ) {
		if ( 45 <= _widec && _widec <= 57 )
			goto tr2388;
	} else if ( _widec > 90 ) {
		if ( 97 <= _widec && _widec <= 122 )
			goto tr2388;
	} else
		goto tr2388;
	goto tr77;
tr2388:
	{
		s->dname = rdata_tail;
	}
	{ p--; {stack[top++] = 893;goto st318;} }
	goto st893;
st893:
	if ( ++p == pe )
		goto _test_eof893;
case 893:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr2391;
		case 32: goto tr2391;
		case 40: goto tr2392;
		case 41: goto tr2393;
		case 2058: goto tr2394;
		case 2107: goto tr2395;
	}
	goto tr77;
tr2398:
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st894;
tr2399:
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st894;
tr2401:
	{
		s->line_counter++;
	}
	goto st894;
tr2531:
	{
		s->buffer[s->buffer_length++] = 0;

		// Execute the comment callback.
		if (s->process.automatic && s->process.comment != NULL) {
			s->process.comment(s);

			// Stop if required from the callback.
			if (s->state == ZS_STATE_STOP) {
				{p++; cs = 894; goto _out;}
			}
		}
	}
	{
		s->line_counter++;
	}
	goto st894;
tr2391:
	{
		rdata_tail += s->dname_tmp_length;
	}
	goto st894;
tr2392:
	{
		rdata_tail += s->dname_tmp_length;
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st894;
tr2393:
	{
		rdata_tail += s->dname_tmp_length;
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st894;
tr2394:
	{
		rdata_tail += s->dname_tmp_length;
	}
	{
		s->line_counter++;
	}
	goto st894;
st894:
	if ( ++p == pe )
		goto _test_eof894;
case 894:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto st894;
		case 32: goto st894;
		case 40: goto tr2398;
		case 41: goto tr2399;
		case 2058: goto tr2401;
		case 2107: goto tr2402;
	}
	if ( 48 <= _widec && _widec <= 57 )
		goto tr2400;
	goto tr2396;
tr2400:
	{
		s->number64 = 0;
	}
	{
		// Overflow check: 10*(s->number64) + fc - '0' <= UINT64_MAX
		if ((s->number64 < (UINT64_MAX / 10)) ||   // Dominant fast check.
			((s->number64 == (UINT64_MAX / 10)) && // Marginal case.
			 ((uint8_t)(*p) <= (UINT64_MAX % 10) + '0')
			)
		   ) {
			s->number64 *= 10;
			s->number64 += digit_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_NUMBER64_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st895;
tr2406:
	{
		// Overflow check: 10*(s->number64) + fc - '0' <= UINT64_MAX
		if ((s->number64 < (UINT64_MAX / 10)) ||   // Dominant fast check.
			((s->number64 == (UINT64_MAX / 10)) && // Marginal case.
			 ((uint8_t)(*p) <= (UINT64_MAX % 10) + '0')
			)
		   ) {
			s->number64 *= 10;
			s->number64 += digit_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_NUMBER64_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st895;
st895:
	if ( ++p == pe )
		goto _test_eof895;
case 895:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr2403;
		case 32: goto tr2403;
		case 40: goto tr2404;
		case 41: goto tr2405;
		case 2058: goto tr2407;
		case 2107: goto tr2408;
	}
	if ( 48 <= _widec && _widec <= 57 )
		goto tr2406;
	goto tr2396;
tr2410:
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st896;
tr2411:
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st896;
tr2413:
	{
		s->line_counter++;
	}
	goto st896;
tr2529:
	{
		s->buffer[s->buffer_length++] = 0;

		// Execute the comment callback.
		if (s->process.automatic && s->process.comment != NULL) {
			s->process.comment(s);

			// Stop if required from the callback.
			if (s->state == ZS_STATE_STOP) {
				{p++; cs = 896; goto _out;}
			}
		}
	}
	{
		s->line_counter++;
	}
	goto st896;
tr2403:
	{
		if (s->number64 <= UINT32_MAX) {
			uint32_t num32 = htonl((uint32_t)s->number64);
			memcpy(rdata_tail, &num32, 4);
			rdata_tail += 4;
		} else {
			WARN(ZS_NUMBER32_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st896;
tr2404:
	{
		if (s->number64 <= UINT32_MAX) {
			uint32_t num32 = htonl((uint32_t)s->number64);
			memcpy(rdata_tail, &num32, 4);
			rdata_tail += 4;
		} else {
			WARN(ZS_NUMBER32_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st896;
tr2405:
	{
		if (s->number64 <= UINT32_MAX) {
			uint32_t num32 = htonl((uint32_t)s->number64);
			memcpy(rdata_tail, &num32, 4);
			rdata_tail += 4;
		} else {
			WARN(ZS_NUMBER32_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st896;
tr2407:
	{
		if (s->number64 <= UINT32_MAX) {
			uint32_t num32 = htonl((uint32_t)s->number64);
			memcpy(rdata_tail, &num32, 4);
			rdata_tail += 4;
		} else {
			WARN(ZS_NUMBER32_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		s->line_counter++;
	}
	goto st896;
st896:
	if ( ++p == pe )
		goto _test_eof896;
case 896:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto st896;
		case 32: goto st896;
		case 40: goto tr2410;
		case 41: goto tr2411;
		case 2058: goto tr2413;
		case 2107: goto tr2414;
	}
	if ( 48 <= _widec && _widec <= 57 )
		goto tr2412;
	goto tr2396;
tr2412:
	{
		s->number64 = 0;
	}
	{
		// Overflow check: 10*(s->number64) + fc - '0' <= UINT64_MAX
		if ((s->number64 < (UINT64_MAX / 10)) ||   // Dominant fast check.
			((s->number64 == (UINT64_MAX / 10)) && // Marginal case.
			 ((uint8_t)(*p) <= (UINT64_MAX % 10) + '0')
			)
		   ) {
			s->number64 *= 10;
			s->number64 += digit_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_NUMBER64_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st897;
tr2419:
	{
		// Overflow check: 10*(s->number64) + fc - '0' <= UINT64_MAX
		if ((s->number64 < (UINT64_MAX / 10)) ||   // Dominant fast check.
			((s->number64 == (UINT64_MAX / 10)) && // Marginal case.
			 ((uint8_t)(*p) <= (UINT64_MAX % 10) + '0')
			)
		   ) {
			s->number64 *= 10;
			s->number64 += digit_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_NUMBER64_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st897;
st897:
	if ( ++p == pe )
		goto _test_eof897;
case 897:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr2416;
		case 32: goto tr2416;
		case 40: goto tr2417;
		case 41: goto tr2418;
		case 68: goto tr2420;
		case 72: goto tr2421;
		case 77: goto tr2422;
		case 83: goto st916;
		case 87: goto tr2424;
		case 100: goto tr2420;
		case 104: goto tr2421;
		case 109: goto tr2422;
		case 115: goto st916;
		case 119: goto tr2424;
		case 2058: goto tr2425;
		case 2107: goto tr2426;
	}
	if ( 48 <= _widec && _widec <= 57 )
		goto tr2419;
	goto tr2415;
tr2428:
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st898;
tr2429:
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st898;
tr2431:
	{
		s->line_counter++;
	}
	goto st898;
tr2514:
	{
		s->buffer[s->buffer_length++] = 0;

		// Execute the comment callback.
		if (s->process.automatic && s->process.comment != NULL) {
			s->process.comment(s);

			// Stop if required from the callback.
			if (s->state == ZS_STATE_STOP) {
				{p++; cs = 898; goto _out;}
			}
		}
	}
	{
		s->line_counter++;
	}
	goto st898;
tr2416:
	{
		if (s->number64 <= UINT32_MAX) {
			uint32_t num32 = htonl((uint32_t)s->number64);
			memcpy(rdata_tail, &num32, 4);
			rdata_tail += 4;
		} else {
			WARN(ZS_NUMBER32_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st898;
tr2417:
	{
		if (s->number64 <= UINT32_MAX) {
			uint32_t num32 = htonl((uint32_t)s->number64);
			memcpy(rdata_tail, &num32, 4);
			rdata_tail += 4;
		} else {
			WARN(ZS_NUMBER32_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st898;
tr2418:
	{
		if (s->number64 <= UINT32_MAX) {
			uint32_t num32 = htonl((uint32_t)s->number64);
			memcpy(rdata_tail, &num32, 4);
			rdata_tail += 4;
		} else {
			WARN(ZS_NUMBER32_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st898;
tr2425:
	{
		if (s->number64 <= UINT32_MAX) {
			uint32_t num32 = htonl((uint32_t)s->number64);
			memcpy(rdata_tail, &num32, 4);
			rdata_tail += 4;
		} else {
			WARN(ZS_NUMBER32_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		s->line_counter++;
	}
	goto st898;
tr2522:
	{
		if (s->number64 + s->number64_tmp < UINT32_MAX) {
			s->number64 += s->number64_tmp;
		} else {
			WARN(ZS_NUMBER32_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->number64 <= UINT32_MAX) {
			uint32_t num32 = htonl((uint32_t)s->number64);
			memcpy(rdata_tail, &num32, 4);
			rdata_tail += 4;
		} else {
			WARN(ZS_NUMBER32_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st898;
tr2523:
	{
		if (s->number64 + s->number64_tmp < UINT32_MAX) {
			s->number64 += s->number64_tmp;
		} else {
			WARN(ZS_NUMBER32_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->number64 <= UINT32_MAX) {
			uint32_t num32 = htonl((uint32_t)s->number64);
			memcpy(rdata_tail, &num32, 4);
			rdata_tail += 4;
		} else {
			WARN(ZS_NUMBER32_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st898;
tr2524:
	{
		if (s->number64 + s->number64_tmp < UINT32_MAX) {
			s->number64 += s->number64_tmp;
		} else {
			WARN(ZS_NUMBER32_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->number64 <= UINT32_MAX) {
			uint32_t num32 = htonl((uint32_t)s->number64);
			memcpy(rdata_tail, &num32, 4);
			rdata_tail += 4;
		} else {
			WARN(ZS_NUMBER32_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st898;
tr2526:
	{
		if (s->number64 + s->number64_tmp < UINT32_MAX) {
			s->number64 += s->number64_tmp;
		} else {
			WARN(ZS_NUMBER32_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->number64 <= UINT32_MAX) {
			uint32_t num32 = htonl((uint32_t)s->number64);
			memcpy(rdata_tail, &num32, 4);
			rdata_tail += 4;
		} else {
			WARN(ZS_NUMBER32_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		s->line_counter++;
	}
	goto st898;
st898:
	if ( ++p == pe )
		goto _test_eof898;
case 898:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto st898;
		case 32: goto st898;
		case 40: goto tr2428;
		case 41: goto tr2429;
		case 2058: goto tr2431;
		case 2107: goto tr2432;
	}
	if ( 48 <= _widec && _widec <= 57 )
		goto tr2430;
	goto tr2396;
tr2430:
	{
		s->number64 = 0;
	}
	{
		// Overflow check: 10*(s->number64) + fc - '0' <= UINT64_MAX
		if ((s->number64 < (UINT64_MAX / 10)) ||   // Dominant fast check.
			((s->number64 == (UINT64_MAX / 10)) && // Marginal case.
			 ((uint8_t)(*p) <= (UINT64_MAX % 10) + '0')
			)
		   ) {
			s->number64 *= 10;
			s->number64 += digit_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_NUMBER64_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st899;
tr2436:
	{
		// Overflow check: 10*(s->number64) + fc - '0' <= UINT64_MAX
		if ((s->number64 < (UINT64_MAX / 10)) ||   // Dominant fast check.
			((s->number64 == (UINT64_MAX / 10)) && // Marginal case.
			 ((uint8_t)(*p) <= (UINT64_MAX % 10) + '0')
			)
		   ) {
			s->number64 *= 10;
			s->number64 += digit_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_NUMBER64_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st899;
st899:
	if ( ++p == pe )
		goto _test_eof899;
case 899:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr2433;
		case 32: goto tr2433;
		case 40: goto tr2434;
		case 41: goto tr2435;
		case 68: goto tr2437;
		case 72: goto tr2438;
		case 77: goto tr2439;
		case 83: goto st912;
		case 87: goto tr2441;
		case 100: goto tr2437;
		case 104: goto tr2438;
		case 109: goto tr2439;
		case 115: goto st912;
		case 119: goto tr2441;
		case 2058: goto tr2442;
		case 2107: goto tr2443;
	}
	if ( 48 <= _widec && _widec <= 57 )
		goto tr2436;
	goto tr2415;
tr2445:
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st900;
tr2446:
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st900;
tr2448:
	{
		s->line_counter++;
	}
	goto st900;
tr2499:
	{
		s->buffer[s->buffer_length++] = 0;

		// Execute the comment callback.
		if (s->process.automatic && s->process.comment != NULL) {
			s->process.comment(s);

			// Stop if required from the callback.
			if (s->state == ZS_STATE_STOP) {
				{p++; cs = 900; goto _out;}
			}
		}
	}
	{
		s->line_counter++;
	}
	goto st900;
tr2433:
	{
		if (s->number64 <= UINT32_MAX) {
			uint32_t num32 = htonl((uint32_t)s->number64);
			memcpy(rdata_tail, &num32, 4);
			rdata_tail += 4;
		} else {
			WARN(ZS_NUMBER32_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st900;
tr2434:
	{
		if (s->number64 <= UINT32_MAX) {
			uint32_t num32 = htonl((uint32_t)s->number64);
			memcpy(rdata_tail, &num32, 4);
			rdata_tail += 4;
		} else {
			WARN(ZS_NUMBER32_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st900;
tr2435:
	{
		if (s->number64 <= UINT32_MAX) {
			uint32_t num32 = htonl((uint32_t)s->number64);
			memcpy(rdata_tail, &num32, 4);
			rdata_tail += 4;
		} else {
			WARN(ZS_NUMBER32_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st900;
tr2442:
	{
		if (s->number64 <= UINT32_MAX) {
			uint32_t num32 = htonl((uint32_t)s->number64);
			memcpy(rdata_tail, &num32, 4);
			rdata_tail += 4;
		} else {
			WARN(ZS_NUMBER32_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		s->line_counter++;
	}
	goto st900;
tr2507:
	{
		if (s->number64 + s->number64_tmp < UINT32_MAX) {
			s->number64 += s->number64_tmp;
		} else {
			WARN(ZS_NUMBER32_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->number64 <= UINT32_MAX) {
			uint32_t num32 = htonl((uint32_t)s->number64);
			memcpy(rdata_tail, &num32, 4);
			rdata_tail += 4;
		} else {
			WARN(ZS_NUMBER32_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st900;
tr2508:
	{
		if (s->number64 + s->number64_tmp < UINT32_MAX) {
			s->number64 += s->number64_tmp;
		} else {
			WARN(ZS_NUMBER32_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->number64 <= UINT32_MAX) {
			uint32_t num32 = htonl((uint32_t)s->number64);
			memcpy(rdata_tail, &num32, 4);
			rdata_tail += 4;
		} else {
			WARN(ZS_NUMBER32_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st900;
tr2509:
	{
		if (s->number64 + s->number64_tmp < UINT32_MAX) {
			s->number64 += s->number64_tmp;
		} else {
			WARN(ZS_NUMBER32_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->number64 <= UINT32_MAX) {
			uint32_t num32 = htonl((uint32_t)s->number64);
			memcpy(rdata_tail, &num32, 4);
			rdata_tail += 4;
		} else {
			WARN(ZS_NUMBER32_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st900;
tr2511:
	{
		if (s->number64 + s->number64_tmp < UINT32_MAX) {
			s->number64 += s->number64_tmp;
		} else {
			WARN(ZS_NUMBER32_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->number64 <= UINT32_MAX) {
			uint32_t num32 = htonl((uint32_t)s->number64);
			memcpy(rdata_tail, &num32, 4);
			rdata_tail += 4;
		} else {
			WARN(ZS_NUMBER32_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		s->line_counter++;
	}
	goto st900;
st900:
	if ( ++p == pe )
		goto _test_eof900;
case 900:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto st900;
		case 32: goto st900;
		case 40: goto tr2445;
		case 41: goto tr2446;
		case 2058: goto tr2448;
		case 2107: goto tr2449;
	}
	if ( 48 <= _widec && _widec <= 57 )
		goto tr2447;
	goto tr2396;
tr2447:
	{
		s->number64 = 0;
	}
	{
		// Overflow check: 10*(s->number64) + fc - '0' <= UINT64_MAX
		if ((s->number64 < (UINT64_MAX / 10)) ||   // Dominant fast check.
			((s->number64 == (UINT64_MAX / 10)) && // Marginal case.
			 ((uint8_t)(*p) <= (UINT64_MAX % 10) + '0')
			)
		   ) {
			s->number64 *= 10;
			s->number64 += digit_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_NUMBER64_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st901;
tr2453:
	{
		// Overflow check: 10*(s->number64) + fc - '0' <= UINT64_MAX
		if ((s->number64 < (UINT64_MAX / 10)) ||   // Dominant fast check.
			((s->number64 == (UINT64_MAX / 10)) && // Marginal case.
			 ((uint8_t)(*p) <= (UINT64_MAX % 10) + '0')
			)
		   ) {
			s->number64 *= 10;
			s->number64 += digit_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_NUMBER64_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st901;
st901:
	if ( ++p == pe )
		goto _test_eof901;
case 901:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr2450;
		case 32: goto tr2450;
		case 40: goto tr2451;
		case 41: goto tr2452;
		case 68: goto tr2454;
		case 72: goto tr2455;
		case 77: goto tr2456;
		case 83: goto st908;
		case 87: goto tr2458;
		case 100: goto tr2454;
		case 104: goto tr2455;
		case 109: goto tr2456;
		case 115: goto st908;
		case 119: goto tr2458;
		case 2058: goto tr2459;
		case 2107: goto tr2460;
	}
	if ( 48 <= _widec && _widec <= 57 )
		goto tr2453;
	goto tr2415;
tr2462:
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st902;
tr2463:
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st902;
tr2465:
	{
		s->line_counter++;
	}
	goto st902;
tr2484:
	{
		s->buffer[s->buffer_length++] = 0;

		// Execute the comment callback.
		if (s->process.automatic && s->process.comment != NULL) {
			s->process.comment(s);

			// Stop if required from the callback.
			if (s->state == ZS_STATE_STOP) {
				{p++; cs = 902; goto _out;}
			}
		}
	}
	{
		s->line_counter++;
	}
	goto st902;
tr2450:
	{
		if (s->number64 <= UINT32_MAX) {
			uint32_t num32 = htonl((uint32_t)s->number64);
			memcpy(rdata_tail, &num32, 4);
			rdata_tail += 4;
		} else {
			WARN(ZS_NUMBER32_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st902;
tr2451:
	{
		if (s->number64 <= UINT32_MAX) {
			uint32_t num32 = htonl((uint32_t)s->number64);
			memcpy(rdata_tail, &num32, 4);
			rdata_tail += 4;
		} else {
			WARN(ZS_NUMBER32_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st902;
tr2452:
	{
		if (s->number64 <= UINT32_MAX) {
			uint32_t num32 = htonl((uint32_t)s->number64);
			memcpy(rdata_tail, &num32, 4);
			rdata_tail += 4;
		} else {
			WARN(ZS_NUMBER32_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st902;
tr2459:
	{
		if (s->number64 <= UINT32_MAX) {
			uint32_t num32 = htonl((uint32_t)s->number64);
			memcpy(rdata_tail, &num32, 4);
			rdata_tail += 4;
		} else {
			WARN(ZS_NUMBER32_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		s->line_counter++;
	}
	goto st902;
tr2492:
	{
		if (s->number64 + s->number64_tmp < UINT32_MAX) {
			s->number64 += s->number64_tmp;
		} else {
			WARN(ZS_NUMBER32_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->number64 <= UINT32_MAX) {
			uint32_t num32 = htonl((uint32_t)s->number64);
			memcpy(rdata_tail, &num32, 4);
			rdata_tail += 4;
		} else {
			WARN(ZS_NUMBER32_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st902;
tr2493:
	{
		if (s->number64 + s->number64_tmp < UINT32_MAX) {
			s->number64 += s->number64_tmp;
		} else {
			WARN(ZS_NUMBER32_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->number64 <= UINT32_MAX) {
			uint32_t num32 = htonl((uint32_t)s->number64);
			memcpy(rdata_tail, &num32, 4);
			rdata_tail += 4;
		} else {
			WARN(ZS_NUMBER32_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st902;
tr2494:
	{
		if (s->number64 + s->number64_tmp < UINT32_MAX) {
			s->number64 += s->number64_tmp;
		} else {
			WARN(ZS_NUMBER32_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->number64 <= UINT32_MAX) {
			uint32_t num32 = htonl((uint32_t)s->number64);
			memcpy(rdata_tail, &num32, 4);
			rdata_tail += 4;
		} else {
			WARN(ZS_NUMBER32_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st902;
tr2496:
	{
		if (s->number64 + s->number64_tmp < UINT32_MAX) {
			s->number64 += s->number64_tmp;
		} else {
			WARN(ZS_NUMBER32_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->number64 <= UINT32_MAX) {
			uint32_t num32 = htonl((uint32_t)s->number64);
			memcpy(rdata_tail, &num32, 4);
			rdata_tail += 4;
		} else {
			WARN(ZS_NUMBER32_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		s->line_counter++;
	}
	goto st902;
st902:
	if ( ++p == pe )
		goto _test_eof902;
case 902:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto st902;
		case 32: goto st902;
		case 40: goto tr2462;
		case 41: goto tr2463;
		case 2058: goto tr2465;
		case 2107: goto tr2466;
	}
	if ( 48 <= _widec && _widec <= 57 )
		goto tr2464;
	goto tr2396;
tr2464:
	{
		s->number64 = 0;
	}
	{
		// Overflow check: 10*(s->number64) + fc - '0' <= UINT64_MAX
		if ((s->number64 < (UINT64_MAX / 10)) ||   // Dominant fast check.
			((s->number64 == (UINT64_MAX / 10)) && // Marginal case.
			 ((uint8_t)(*p) <= (UINT64_MAX % 10) + '0')
			)
		   ) {
			s->number64 *= 10;
			s->number64 += digit_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_NUMBER64_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st903;
tr2468:
	{
		// Overflow check: 10*(s->number64) + fc - '0' <= UINT64_MAX
		if ((s->number64 < (UINT64_MAX / 10)) ||   // Dominant fast check.
			((s->number64 == (UINT64_MAX / 10)) && // Marginal case.
			 ((uint8_t)(*p) <= (UINT64_MAX % 10) + '0')
			)
		   ) {
			s->number64 *= 10;
			s->number64 += digit_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_NUMBER64_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st903;
st903:
	if ( ++p == pe )
		goto _test_eof903;
case 903:
	switch( (*p) ) {
		case 32: goto tr2467;
		case 59: goto tr2467;
		case 68: goto tr2469;
		case 72: goto tr2470;
		case 77: goto tr2471;
		case 83: goto st904;
		case 87: goto tr2473;
		case 100: goto tr2469;
		case 104: goto tr2470;
		case 109: goto tr2471;
		case 115: goto st904;
		case 119: goto tr2473;
	}
	if ( (*p) < 40 ) {
		if ( 9 <= (*p) && (*p) <= 10 )
			goto tr2467;
	} else if ( (*p) > 41 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr2468;
	} else
		goto tr2467;
	goto tr2415;
tr2467:
	{
		if (s->number64 <= UINT32_MAX) {
			uint32_t num32 = htonl((uint32_t)s->number64);
			memcpy(rdata_tail, &num32, 4);
			rdata_tail += 4;
		} else {
			WARN(ZS_NUMBER32_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1485;
tr2481:
	{
		if (s->number64 + s->number64_tmp < UINT32_MAX) {
			s->number64 += s->number64_tmp;
		} else {
			WARN(ZS_NUMBER32_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->number64 <= UINT32_MAX) {
			uint32_t num32 = htonl((uint32_t)s->number64);
			memcpy(rdata_tail, &num32, 4);
			rdata_tail += 4;
		} else {
			WARN(ZS_NUMBER32_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1485;
st1485:
	if ( ++p == pe )
		goto _test_eof1485;
case 1485:
	goto st0;
tr2469:
	{ if (s->number64 <= (UINT32_MAX / 86400)) {
	                  s->number64 *= 86400;
	              } else {
	                  WARN(ZS_NUMBER32_OVERFLOW);
	                  p--; {goto st316;}
	              }
	            }
	goto st904;
tr2470:
	{ if (s->number64 <= (UINT32_MAX / 3600)) {
	                  s->number64 *= 3600;
	              } else {
	                  WARN(ZS_NUMBER32_OVERFLOW);
	                  p--; {goto st316;}
	              }
	            }
	goto st904;
tr2471:
	{ if (s->number64 <= (UINT32_MAX / 60)) {
	                  s->number64 *= 60;
	              } else {
	                  WARN(ZS_NUMBER32_OVERFLOW);
	                  p--; {goto st316;}
	              }
	            }
	goto st904;
tr2473:
	{ if (s->number64 <= (UINT32_MAX / 604800)) {
	                  s->number64 *= 604800;
	              } else {
	                  WARN(ZS_NUMBER32_OVERFLOW);
	                  p--; {goto st316;}
	              }
	            }
	goto st904;
st904:
	if ( ++p == pe )
		goto _test_eof904;
case 904:
	switch( (*p) ) {
		case 32: goto tr2467;
		case 59: goto tr2467;
	}
	if ( (*p) < 40 ) {
		if ( 9 <= (*p) && (*p) <= 10 )
			goto tr2467;
	} else if ( (*p) > 41 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr2474;
	} else
		goto tr2467;
	goto tr2415;
tr2475:
	{
		// Overflow check: 10*(s->number64) + fc - '0' <= UINT64_MAX
		if ((s->number64 < (UINT64_MAX / 10)) ||   // Dominant fast check.
			((s->number64 == (UINT64_MAX / 10)) && // Marginal case.
			 ((uint8_t)(*p) <= (UINT64_MAX % 10) + '0')
			)
		   ) {
			s->number64 *= 10;
			s->number64 += digit_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_NUMBER64_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st905;
tr2474:
	{
		s->number64_tmp = s->number64;
	}
	{
		s->number64 = 0;
	}
	{
		// Overflow check: 10*(s->number64) + fc - '0' <= UINT64_MAX
		if ((s->number64 < (UINT64_MAX / 10)) ||   // Dominant fast check.
			((s->number64 == (UINT64_MAX / 10)) && // Marginal case.
			 ((uint8_t)(*p) <= (UINT64_MAX % 10) + '0')
			)
		   ) {
			s->number64 *= 10;
			s->number64 += digit_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_NUMBER64_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st905;
tr2482:
	{
		if (s->number64 + s->number64_tmp < UINT32_MAX) {
			s->number64 += s->number64_tmp;
		} else {
			WARN(ZS_NUMBER32_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		s->number64_tmp = s->number64;
	}
	{
		s->number64 = 0;
	}
	{
		// Overflow check: 10*(s->number64) + fc - '0' <= UINT64_MAX
		if ((s->number64 < (UINT64_MAX / 10)) ||   // Dominant fast check.
			((s->number64 == (UINT64_MAX / 10)) && // Marginal case.
			 ((uint8_t)(*p) <= (UINT64_MAX % 10) + '0')
			)
		   ) {
			s->number64 *= 10;
			s->number64 += digit_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_NUMBER64_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st905;
st905:
	if ( ++p == pe )
		goto _test_eof905;
case 905:
	switch( (*p) ) {
		case 68: goto tr2476;
		case 72: goto tr2477;
		case 77: goto tr2478;
		case 83: goto st906;
		case 87: goto tr2480;
		case 100: goto tr2476;
		case 104: goto tr2477;
		case 109: goto tr2478;
		case 115: goto st906;
		case 119: goto tr2480;
	}
	if ( 48 <= (*p) && (*p) <= 57 )
		goto tr2475;
	goto tr2415;
tr2476:
	{ if (s->number64 <= (UINT32_MAX / 86400)) {
	                  s->number64 *= 86400;
	              } else {
	                  WARN(ZS_NUMBER32_OVERFLOW);
	                  p--; {goto st316;}
	              }
	            }
	goto st906;
tr2477:
	{ if (s->number64 <= (UINT32_MAX / 3600)) {
	                  s->number64 *= 3600;
	              } else {
	                  WARN(ZS_NUMBER32_OVERFLOW);
	                  p--; {goto st316;}
	              }
	            }
	goto st906;
tr2478:
	{ if (s->number64 <= (UINT32_MAX / 60)) {
	                  s->number64 *= 60;
	              } else {
	                  WARN(ZS_NUMBER32_OVERFLOW);
	                  p--; {goto st316;}
	              }
	            }
	goto st906;
tr2480:
	{ if (s->number64 <= (UINT32_MAX / 604800)) {
	                  s->number64 *= 604800;
	              } else {
	                  WARN(ZS_NUMBER32_OVERFLOW);
	                  p--; {goto st316;}
	              }
	            }
	goto st906;
st906:
	if ( ++p == pe )
		goto _test_eof906;
case 906:
	switch( (*p) ) {
		case 32: goto tr2481;
		case 59: goto tr2481;
	}
	if ( (*p) < 40 ) {
		if ( 9 <= (*p) && (*p) <= 10 )
			goto tr2481;
	} else if ( (*p) > 41 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr2482;
	} else
		goto tr2481;
	goto tr2415;
tr2466:
	{
		s->buffer_length = 0;
	}
	goto st907;
tr2483:
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		}
	}
	goto st907;
tr2460:
	{
		if (s->number64 <= UINT32_MAX) {
			uint32_t num32 = htonl((uint32_t)s->number64);
			memcpy(rdata_tail, &num32, 4);
			rdata_tail += 4;
		} else {
			WARN(ZS_NUMBER32_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		s->buffer_length = 0;
	}
	goto st907;
tr2497:
	{
		if (s->number64 + s->number64_tmp < UINT32_MAX) {
			s->number64 += s->number64_tmp;
		} else {
			WARN(ZS_NUMBER32_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->number64 <= UINT32_MAX) {
			uint32_t num32 = htonl((uint32_t)s->number64);
			memcpy(rdata_tail, &num32, 4);
			rdata_tail += 4;
		} else {
			WARN(ZS_NUMBER32_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		s->buffer_length = 0;
	}
	goto st907;
st907:
	if ( ++p == pe )
		goto _test_eof907;
case 907:
	_widec = (*p);
	if ( (*p) < 10 ) {
		if ( (*p) <= 9 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) > 10 ) {
		if ( 11 <= (*p) )
 {			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	if ( _widec == 2058 )
		goto tr2484;
	if ( 1920 <= _widec && _widec <= 2175 )
		goto tr2483;
	goto tr77;
tr2454:
	{ if (s->number64 <= (UINT32_MAX / 86400)) {
	                  s->number64 *= 86400;
	              } else {
	                  WARN(ZS_NUMBER32_OVERFLOW);
	                  p--; {goto st316;}
	              }
	            }
	goto st908;
tr2455:
	{ if (s->number64 <= (UINT32_MAX / 3600)) {
	                  s->number64 *= 3600;
	              } else {
	                  WARN(ZS_NUMBER32_OVERFLOW);
	                  p--; {goto st316;}
	              }
	            }
	goto st908;
tr2456:
	{ if (s->number64 <= (UINT32_MAX / 60)) {
	                  s->number64 *= 60;
	              } else {
	                  WARN(ZS_NUMBER32_OVERFLOW);
	                  p--; {goto st316;}
	              }
	            }
	goto st908;
tr2458:
	{ if (s->number64 <= (UINT32_MAX / 604800)) {
	                  s->number64 *= 604800;
	              } else {
	                  WARN(ZS_NUMBER32_OVERFLOW);
	                  p--; {goto st316;}
	              }
	            }
	goto st908;
st908:
	if ( ++p == pe )
		goto _test_eof908;
case 908:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr2450;
		case 32: goto tr2450;
		case 40: goto tr2451;
		case 41: goto tr2452;
		case 2058: goto tr2459;
		case 2107: goto tr2460;
	}
	if ( 48 <= _widec && _widec <= 57 )
		goto tr2485;
	goto tr2415;
tr2486:
	{
		// Overflow check: 10*(s->number64) + fc - '0' <= UINT64_MAX
		if ((s->number64 < (UINT64_MAX / 10)) ||   // Dominant fast check.
			((s->number64 == (UINT64_MAX / 10)) && // Marginal case.
			 ((uint8_t)(*p) <= (UINT64_MAX % 10) + '0')
			)
		   ) {
			s->number64 *= 10;
			s->number64 += digit_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_NUMBER64_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st909;
tr2485:
	{
		s->number64_tmp = s->number64;
	}
	{
		s->number64 = 0;
	}
	{
		// Overflow check: 10*(s->number64) + fc - '0' <= UINT64_MAX
		if ((s->number64 < (UINT64_MAX / 10)) ||   // Dominant fast check.
			((s->number64 == (UINT64_MAX / 10)) && // Marginal case.
			 ((uint8_t)(*p) <= (UINT64_MAX % 10) + '0')
			)
		   ) {
			s->number64 *= 10;
			s->number64 += digit_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_NUMBER64_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st909;
tr2495:
	{
		if (s->number64 + s->number64_tmp < UINT32_MAX) {
			s->number64 += s->number64_tmp;
		} else {
			WARN(ZS_NUMBER32_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		s->number64_tmp = s->number64;
	}
	{
		s->number64 = 0;
	}
	{
		// Overflow check: 10*(s->number64) + fc - '0' <= UINT64_MAX
		if ((s->number64 < (UINT64_MAX / 10)) ||   // Dominant fast check.
			((s->number64 == (UINT64_MAX / 10)) && // Marginal case.
			 ((uint8_t)(*p) <= (UINT64_MAX % 10) + '0')
			)
		   ) {
			s->number64 *= 10;
			s->number64 += digit_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_NUMBER64_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st909;
st909:
	if ( ++p == pe )
		goto _test_eof909;
case 909:
	switch( (*p) ) {
		case 68: goto tr2487;
		case 72: goto tr2488;
		case 77: goto tr2489;
		case 83: goto st910;
		case 87: goto tr2491;
		case 100: goto tr2487;
		case 104: goto tr2488;
		case 109: goto tr2489;
		case 115: goto st910;
		case 119: goto tr2491;
	}
	if ( 48 <= (*p) && (*p) <= 57 )
		goto tr2486;
	goto tr2415;
tr2487:
	{ if (s->number64 <= (UINT32_MAX / 86400)) {
	                  s->number64 *= 86400;
	              } else {
	                  WARN(ZS_NUMBER32_OVERFLOW);
	                  p--; {goto st316;}
	              }
	            }
	goto st910;
tr2488:
	{ if (s->number64 <= (UINT32_MAX / 3600)) {
	                  s->number64 *= 3600;
	              } else {
	                  WARN(ZS_NUMBER32_OVERFLOW);
	                  p--; {goto st316;}
	              }
	            }
	goto st910;
tr2489:
	{ if (s->number64 <= (UINT32_MAX / 60)) {
	                  s->number64 *= 60;
	              } else {
	                  WARN(ZS_NUMBER32_OVERFLOW);
	                  p--; {goto st316;}
	              }
	            }
	goto st910;
tr2491:
	{ if (s->number64 <= (UINT32_MAX / 604800)) {
	                  s->number64 *= 604800;
	              } else {
	                  WARN(ZS_NUMBER32_OVERFLOW);
	                  p--; {goto st316;}
	              }
	            }
	goto st910;
st910:
	if ( ++p == pe )
		goto _test_eof910;
case 910:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr2492;
		case 32: goto tr2492;
		case 40: goto tr2493;
		case 41: goto tr2494;
		case 2058: goto tr2496;
		case 2107: goto tr2497;
	}
	if ( 48 <= _widec && _widec <= 57 )
		goto tr2495;
	goto tr2415;
tr2449:
	{
		s->buffer_length = 0;
	}
	goto st911;
tr2498:
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		}
	}
	goto st911;
tr2443:
	{
		if (s->number64 <= UINT32_MAX) {
			uint32_t num32 = htonl((uint32_t)s->number64);
			memcpy(rdata_tail, &num32, 4);
			rdata_tail += 4;
		} else {
			WARN(ZS_NUMBER32_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		s->buffer_length = 0;
	}
	goto st911;
tr2512:
	{
		if (s->number64 + s->number64_tmp < UINT32_MAX) {
			s->number64 += s->number64_tmp;
		} else {
			WARN(ZS_NUMBER32_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->number64 <= UINT32_MAX) {
			uint32_t num32 = htonl((uint32_t)s->number64);
			memcpy(rdata_tail, &num32, 4);
			rdata_tail += 4;
		} else {
			WARN(ZS_NUMBER32_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		s->buffer_length = 0;
	}
	goto st911;
st911:
	if ( ++p == pe )
		goto _test_eof911;
case 911:
	_widec = (*p);
	if ( (*p) < 10 ) {
		if ( (*p) <= 9 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) > 10 ) {
		if ( 11 <= (*p) )
 {			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	if ( _widec == 2058 )
		goto tr2499;
	if ( 1920 <= _widec && _widec <= 2175 )
		goto tr2498;
	goto tr77;
tr2437:
	{ if (s->number64 <= (UINT32_MAX / 86400)) {
	                  s->number64 *= 86400;
	              } else {
	                  WARN(ZS_NUMBER32_OVERFLOW);
	                  p--; {goto st316;}
	              }
	            }
	goto st912;
tr2438:
	{ if (s->number64 <= (UINT32_MAX / 3600)) {
	                  s->number64 *= 3600;
	              } else {
	                  WARN(ZS_NUMBER32_OVERFLOW);
	                  p--; {goto st316;}
	              }
	            }
	goto st912;
tr2439:
	{ if (s->number64 <= (UINT32_MAX / 60)) {
	                  s->number64 *= 60;
	              } else {
	                  WARN(ZS_NUMBER32_OVERFLOW);
	                  p--; {goto st316;}
	              }
	            }
	goto st912;
tr2441:
	{ if (s->number64 <= (UINT32_MAX / 604800)) {
	                  s->number64 *= 604800;
	              } else {
	                  WARN(ZS_NUMBER32_OVERFLOW);
	                  p--; {goto st316;}
	              }
	            }
	goto st912;
st912:
	if ( ++p == pe )
		goto _test_eof912;
case 912:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr2433;
		case 32: goto tr2433;
		case 40: goto tr2434;
		case 41: goto tr2435;
		case 2058: goto tr2442;
		case 2107: goto tr2443;
	}
	if ( 48 <= _widec && _widec <= 57 )
		goto tr2500;
	goto tr2415;
tr2501:
	{
		// Overflow check: 10*(s->number64) + fc - '0' <= UINT64_MAX
		if ((s->number64 < (UINT64_MAX / 10)) ||   // Dominant fast check.
			((s->number64 == (UINT64_MAX / 10)) && // Marginal case.
			 ((uint8_t)(*p) <= (UINT64_MAX % 10) + '0')
			)
		   ) {
			s->number64 *= 10;
			s->number64 += digit_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_NUMBER64_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st913;
tr2500:
	{
		s->number64_tmp = s->number64;
	}
	{
		s->number64 = 0;
	}
	{
		// Overflow check: 10*(s->number64) + fc - '0' <= UINT64_MAX
		if ((s->number64 < (UINT64_MAX / 10)) ||   // Dominant fast check.
			((s->number64 == (UINT64_MAX / 10)) && // Marginal case.
			 ((uint8_t)(*p) <= (UINT64_MAX % 10) + '0')
			)
		   ) {
			s->number64 *= 10;
			s->number64 += digit_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_NUMBER64_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st913;
tr2510:
	{
		if (s->number64 + s->number64_tmp < UINT32_MAX) {
			s->number64 += s->number64_tmp;
		} else {
			WARN(ZS_NUMBER32_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		s->number64_tmp = s->number64;
	}
	{
		s->number64 = 0;
	}
	{
		// Overflow check: 10*(s->number64) + fc - '0' <= UINT64_MAX
		if ((s->number64 < (UINT64_MAX / 10)) ||   // Dominant fast check.
			((s->number64 == (UINT64_MAX / 10)) && // Marginal case.
			 ((uint8_t)(*p) <= (UINT64_MAX % 10) + '0')
			)
		   ) {
			s->number64 *= 10;
			s->number64 += digit_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_NUMBER64_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st913;
st913:
	if ( ++p == pe )
		goto _test_eof913;
case 913:
	switch( (*p) ) {
		case 68: goto tr2502;
		case 72: goto tr2503;
		case 77: goto tr2504;
		case 83: goto st914;
		case 87: goto tr2506;
		case 100: goto tr2502;
		case 104: goto tr2503;
		case 109: goto tr2504;
		case 115: goto st914;
		case 119: goto tr2506;
	}
	if ( 48 <= (*p) && (*p) <= 57 )
		goto tr2501;
	goto tr2415;
tr2502:
	{ if (s->number64 <= (UINT32_MAX / 86400)) {
	                  s->number64 *= 86400;
	              } else {
	                  WARN(ZS_NUMBER32_OVERFLOW);
	                  p--; {goto st316;}
	              }
	            }
	goto st914;
tr2503:
	{ if (s->number64 <= (UINT32_MAX / 3600)) {
	                  s->number64 *= 3600;
	              } else {
	                  WARN(ZS_NUMBER32_OVERFLOW);
	                  p--; {goto st316;}
	              }
	            }
	goto st914;
tr2504:
	{ if (s->number64 <= (UINT32_MAX / 60)) {
	                  s->number64 *= 60;
	              } else {
	                  WARN(ZS_NUMBER32_OVERFLOW);
	                  p--; {goto st316;}
	              }
	            }
	goto st914;
tr2506:
	{ if (s->number64 <= (UINT32_MAX / 604800)) {
	                  s->number64 *= 604800;
	              } else {
	                  WARN(ZS_NUMBER32_OVERFLOW);
	                  p--; {goto st316;}
	              }
	            }
	goto st914;
st914:
	if ( ++p == pe )
		goto _test_eof914;
case 914:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr2507;
		case 32: goto tr2507;
		case 40: goto tr2508;
		case 41: goto tr2509;
		case 2058: goto tr2511;
		case 2107: goto tr2512;
	}
	if ( 48 <= _widec && _widec <= 57 )
		goto tr2510;
	goto tr2415;
tr2432:
	{
		s->buffer_length = 0;
	}
	goto st915;
tr2513:
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		}
	}
	goto st915;
tr2426:
	{
		if (s->number64 <= UINT32_MAX) {
			uint32_t num32 = htonl((uint32_t)s->number64);
			memcpy(rdata_tail, &num32, 4);
			rdata_tail += 4;
		} else {
			WARN(ZS_NUMBER32_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		s->buffer_length = 0;
	}
	goto st915;
tr2527:
	{
		if (s->number64 + s->number64_tmp < UINT32_MAX) {
			s->number64 += s->number64_tmp;
		} else {
			WARN(ZS_NUMBER32_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->number64 <= UINT32_MAX) {
			uint32_t num32 = htonl((uint32_t)s->number64);
			memcpy(rdata_tail, &num32, 4);
			rdata_tail += 4;
		} else {
			WARN(ZS_NUMBER32_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		s->buffer_length = 0;
	}
	goto st915;
st915:
	if ( ++p == pe )
		goto _test_eof915;
case 915:
	_widec = (*p);
	if ( (*p) < 10 ) {
		if ( (*p) <= 9 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) > 10 ) {
		if ( 11 <= (*p) )
 {			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	if ( _widec == 2058 )
		goto tr2514;
	if ( 1920 <= _widec && _widec <= 2175 )
		goto tr2513;
	goto tr77;
tr2420:
	{ if (s->number64 <= (UINT32_MAX / 86400)) {
	                  s->number64 *= 86400;
	              } else {
	                  WARN(ZS_NUMBER32_OVERFLOW);
	                  p--; {goto st316;}
	              }
	            }
	goto st916;
tr2421:
	{ if (s->number64 <= (UINT32_MAX / 3600)) {
	                  s->number64 *= 3600;
	              } else {
	                  WARN(ZS_NUMBER32_OVERFLOW);
	                  p--; {goto st316;}
	              }
	            }
	goto st916;
tr2422:
	{ if (s->number64 <= (UINT32_MAX / 60)) {
	                  s->number64 *= 60;
	              } else {
	                  WARN(ZS_NUMBER32_OVERFLOW);
	                  p--; {goto st316;}
	              }
	            }
	goto st916;
tr2424:
	{ if (s->number64 <= (UINT32_MAX / 604800)) {
	                  s->number64 *= 604800;
	              } else {
	                  WARN(ZS_NUMBER32_OVERFLOW);
	                  p--; {goto st316;}
	              }
	            }
	goto st916;
st916:
	if ( ++p == pe )
		goto _test_eof916;
case 916:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr2416;
		case 32: goto tr2416;
		case 40: goto tr2417;
		case 41: goto tr2418;
		case 2058: goto tr2425;
		case 2107: goto tr2426;
	}
	if ( 48 <= _widec && _widec <= 57 )
		goto tr2515;
	goto tr2415;
tr2516:
	{
		// Overflow check: 10*(s->number64) + fc - '0' <= UINT64_MAX
		if ((s->number64 < (UINT64_MAX / 10)) ||   // Dominant fast check.
			((s->number64 == (UINT64_MAX / 10)) && // Marginal case.
			 ((uint8_t)(*p) <= (UINT64_MAX % 10) + '0')
			)
		   ) {
			s->number64 *= 10;
			s->number64 += digit_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_NUMBER64_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st917;
tr2515:
	{
		s->number64_tmp = s->number64;
	}
	{
		s->number64 = 0;
	}
	{
		// Overflow check: 10*(s->number64) + fc - '0' <= UINT64_MAX
		if ((s->number64 < (UINT64_MAX / 10)) ||   // Dominant fast check.
			((s->number64 == (UINT64_MAX / 10)) && // Marginal case.
			 ((uint8_t)(*p) <= (UINT64_MAX % 10) + '0')
			)
		   ) {
			s->number64 *= 10;
			s->number64 += digit_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_NUMBER64_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st917;
tr2525:
	{
		if (s->number64 + s->number64_tmp < UINT32_MAX) {
			s->number64 += s->number64_tmp;
		} else {
			WARN(ZS_NUMBER32_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		s->number64_tmp = s->number64;
	}
	{
		s->number64 = 0;
	}
	{
		// Overflow check: 10*(s->number64) + fc - '0' <= UINT64_MAX
		if ((s->number64 < (UINT64_MAX / 10)) ||   // Dominant fast check.
			((s->number64 == (UINT64_MAX / 10)) && // Marginal case.
			 ((uint8_t)(*p) <= (UINT64_MAX % 10) + '0')
			)
		   ) {
			s->number64 *= 10;
			s->number64 += digit_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_NUMBER64_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st917;
st917:
	if ( ++p == pe )
		goto _test_eof917;
case 917:
	switch( (*p) ) {
		case 68: goto tr2517;
		case 72: goto tr2518;
		case 77: goto tr2519;
		case 83: goto st918;
		case 87: goto tr2521;
		case 100: goto tr2517;
		case 104: goto tr2518;
		case 109: goto tr2519;
		case 115: goto st918;
		case 119: goto tr2521;
	}
	if ( 48 <= (*p) && (*p) <= 57 )
		goto tr2516;
	goto tr2415;
tr2517:
	{ if (s->number64 <= (UINT32_MAX / 86400)) {
	                  s->number64 *= 86400;
	              } else {
	                  WARN(ZS_NUMBER32_OVERFLOW);
	                  p--; {goto st316;}
	              }
	            }
	goto st918;
tr2518:
	{ if (s->number64 <= (UINT32_MAX / 3600)) {
	                  s->number64 *= 3600;
	              } else {
	                  WARN(ZS_NUMBER32_OVERFLOW);
	                  p--; {goto st316;}
	              }
	            }
	goto st918;
tr2519:
	{ if (s->number64 <= (UINT32_MAX / 60)) {
	                  s->number64 *= 60;
	              } else {
	                  WARN(ZS_NUMBER32_OVERFLOW);
	                  p--; {goto st316;}
	              }
	            }
	goto st918;
tr2521:
	{ if (s->number64 <= (UINT32_MAX / 604800)) {
	                  s->number64 *= 604800;
	              } else {
	                  WARN(ZS_NUMBER32_OVERFLOW);
	                  p--; {goto st316;}
	              }
	            }
	goto st918;
st918:
	if ( ++p == pe )
		goto _test_eof918;
case 918:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr2522;
		case 32: goto tr2522;
		case 40: goto tr2523;
		case 41: goto tr2524;
		case 2058: goto tr2526;
		case 2107: goto tr2527;
	}
	if ( 48 <= _widec && _widec <= 57 )
		goto tr2525;
	goto tr2415;
tr2414:
	{
		s->buffer_length = 0;
	}
	goto st919;
tr2528:
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		}
	}
	goto st919;
tr2408:
	{
		if (s->number64 <= UINT32_MAX) {
			uint32_t num32 = htonl((uint32_t)s->number64);
			memcpy(rdata_tail, &num32, 4);
			rdata_tail += 4;
		} else {
			WARN(ZS_NUMBER32_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		s->buffer_length = 0;
	}
	goto st919;
st919:
	if ( ++p == pe )
		goto _test_eof919;
case 919:
	_widec = (*p);
	if ( (*p) < 10 ) {
		if ( (*p) <= 9 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) > 10 ) {
		if ( 11 <= (*p) )
 {			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	if ( _widec == 2058 )
		goto tr2529;
	if ( 1920 <= _widec && _widec <= 2175 )
		goto tr2528;
	goto tr77;
tr2402:
	{
		s->buffer_length = 0;
	}
	goto st920;
tr2530:
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		}
	}
	goto st920;
tr2395:
	{
		rdata_tail += s->dname_tmp_length;
	}
	{
		s->buffer_length = 0;
	}
	goto st920;
st920:
	if ( ++p == pe )
		goto _test_eof920;
case 920:
	_widec = (*p);
	if ( (*p) < 10 ) {
		if ( (*p) <= 9 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) > 10 ) {
		if ( 11 <= (*p) )
 {			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	if ( _widec == 2058 )
		goto tr2531;
	if ( 1920 <= _widec && _widec <= 2175 )
		goto tr2530;
	goto tr77;
tr2390:
	{
		s->buffer_length = 0;
	}
	goto st921;
tr2532:
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		}
	}
	goto st921;
tr2384:
	{
		rdata_tail += s->dname_tmp_length;
	}
	{
		s->buffer_length = 0;
	}
	goto st921;
st921:
	if ( ++p == pe )
		goto _test_eof921;
case 921:
	_widec = (*p);
	if ( (*p) < 10 ) {
		if ( (*p) <= 9 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) > 10 ) {
		if ( 11 <= (*p) )
 {			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	if ( _widec == 2058 )
		goto tr2533;
	if ( 1920 <= _widec && _widec <= 2175 )
		goto tr2532;
	goto tr77;
st922:
	if ( ++p == pe )
		goto _test_eof922;
case 922:
	switch( (*p) ) {
		case 32: goto tr77;
		case 59: goto tr77;
	}
	if ( (*p) > 10 ) {
		if ( 40 <= (*p) && (*p) <= 41 )
			goto tr77;
	} else if ( (*p) >= 9 )
		goto tr77;
	goto tr2534;
tr2534:
	{
		if (rdata_tail <= rdata_stop) {
			s->item_length_location = rdata_tail++;
		} else {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{ p--; {stack[top++] = 923;goto st327;} }
	goto st923;
st923:
	if ( ++p == pe )
		goto _test_eof923;
case 923:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr2535;
		case 32: goto tr2535;
		case 40: goto tr2536;
		case 41: goto tr2537;
		case 2058: goto tr2538;
		case 2107: goto tr2539;
	}
	goto tr77;
tr2542:
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st924;
tr2543:
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st924;
tr2544:
	{
		s->line_counter++;
	}
	goto st924;
tr2548:
	{
		s->buffer[s->buffer_length++] = 0;

		// Execute the comment callback.
		if (s->process.automatic && s->process.comment != NULL) {
			s->process.comment(s);

			// Stop if required from the callback.
			if (s->state == ZS_STATE_STOP) {
				{p++; cs = 924; goto _out;}
			}
		}
	}
	{
		s->line_counter++;
	}
	goto st924;
tr2535:
	{
		s->item_length = rdata_tail - s->item_length_location - 1;
		if (s->comma_list && s->item_length == 0) {
			WARN(ZS_EMPTY_LIST_ITEM);
			p--; {goto st316;}
		}
		if (s->item_length <= MAX_ITEM_LENGTH) {
			*(s->item_length_location) = (uint8_t)(s->item_length);
		} else {
			WARN(ZS_ITEM_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st924;
tr2536:
	{
		s->item_length = rdata_tail - s->item_length_location - 1;
		if (s->comma_list && s->item_length == 0) {
			WARN(ZS_EMPTY_LIST_ITEM);
			p--; {goto st316;}
		}
		if (s->item_length <= MAX_ITEM_LENGTH) {
			*(s->item_length_location) = (uint8_t)(s->item_length);
		} else {
			WARN(ZS_ITEM_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st924;
tr2537:
	{
		s->item_length = rdata_tail - s->item_length_location - 1;
		if (s->comma_list && s->item_length == 0) {
			WARN(ZS_EMPTY_LIST_ITEM);
			p--; {goto st316;}
		}
		if (s->item_length <= MAX_ITEM_LENGTH) {
			*(s->item_length_location) = (uint8_t)(s->item_length);
		} else {
			WARN(ZS_ITEM_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st924;
tr2538:
	{
		s->item_length = rdata_tail - s->item_length_location - 1;
		if (s->comma_list && s->item_length == 0) {
			WARN(ZS_EMPTY_LIST_ITEM);
			p--; {goto st316;}
		}
		if (s->item_length <= MAX_ITEM_LENGTH) {
			*(s->item_length_location) = (uint8_t)(s->item_length);
		} else {
			WARN(ZS_ITEM_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		s->line_counter++;
	}
	goto st924;
st924:
	if ( ++p == pe )
		goto _test_eof924;
case 924:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto st924;
		case 32: goto st924;
		case 40: goto tr2542;
		case 41: goto tr2543;
		case 2058: goto tr2544;
		case 2107: goto tr2545;
	}
	if ( _widec < 11 ) {
		if ( _widec <= 8 )
			goto tr2540;
	} else if ( _widec > 58 ) {
		if ( 60 <= _widec )
			goto tr2540;
	} else
		goto tr2540;
	goto tr77;
tr2540:
	{
		if (rdata_tail <= rdata_stop) {
			s->item_length_location = rdata_tail++;
		} else {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{ p--; {stack[top++] = 925;goto st327;} }
	goto st925;
st925:
	if ( ++p == pe )
		goto _test_eof925;
case 925:
	switch( (*p) ) {
		case 32: goto tr2546;
		case 59: goto tr2546;
	}
	if ( (*p) > 10 ) {
		if ( 40 <= (*p) && (*p) <= 41 )
			goto tr2546;
	} else if ( (*p) >= 9 )
		goto tr2546;
	goto tr77;
tr2546:
	{
		s->item_length = rdata_tail - s->item_length_location - 1;
		if (s->comma_list && s->item_length == 0) {
			WARN(ZS_EMPTY_LIST_ITEM);
			p--; {goto st316;}
		}
		if (s->item_length <= MAX_ITEM_LENGTH) {
			*(s->item_length_location) = (uint8_t)(s->item_length);
		} else {
			WARN(ZS_ITEM_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1486;
st1486:
	if ( ++p == pe )
		goto _test_eof1486;
case 1486:
	goto st0;
tr2545:
	{
		s->buffer_length = 0;
	}
	goto st926;
tr2547:
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		}
	}
	goto st926;
tr2539:
	{
		s->item_length = rdata_tail - s->item_length_location - 1;
		if (s->comma_list && s->item_length == 0) {
			WARN(ZS_EMPTY_LIST_ITEM);
			p--; {goto st316;}
		}
		if (s->item_length <= MAX_ITEM_LENGTH) {
			*(s->item_length_location) = (uint8_t)(s->item_length);
		} else {
			WARN(ZS_ITEM_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		s->buffer_length = 0;
	}
	goto st926;
st926:
	if ( ++p == pe )
		goto _test_eof926;
case 926:
	_widec = (*p);
	if ( (*p) < 10 ) {
		if ( (*p) <= 9 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) > 10 ) {
		if ( 11 <= (*p) )
 {			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	if ( _widec == 2058 )
		goto tr2548;
	if ( 1920 <= _widec && _widec <= 2175 )
		goto tr2547;
	goto tr77;
st927:
	if ( ++p == pe )
		goto _test_eof927;
case 927:
	switch( (*p) ) {
		case 42: goto tr2549;
		case 92: goto tr2549;
		case 95: goto tr2549;
	}
	if ( (*p) < 64 ) {
		if ( 45 <= (*p) && (*p) <= 57 )
			goto tr2549;
	} else if ( (*p) > 90 ) {
		if ( 97 <= (*p) && (*p) <= 122 )
			goto tr2549;
	} else
		goto tr2549;
	goto tr77;
tr2549:
	{
		s->dname = rdata_tail;
	}
	{ p--; {stack[top++] = 928;goto st318;} }
	goto st928;
st928:
	if ( ++p == pe )
		goto _test_eof928;
case 928:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr2550;
		case 32: goto tr2550;
		case 40: goto tr2551;
		case 41: goto tr2552;
		case 2058: goto tr2553;
		case 2107: goto tr2554;
	}
	goto tr77;
tr2556:
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st929;
tr2557:
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st929;
tr2559:
	{
		s->line_counter++;
	}
	goto st929;
tr2563:
	{
		s->buffer[s->buffer_length++] = 0;

		// Execute the comment callback.
		if (s->process.automatic && s->process.comment != NULL) {
			s->process.comment(s);

			// Stop if required from the callback.
			if (s->state == ZS_STATE_STOP) {
				{p++; cs = 929; goto _out;}
			}
		}
	}
	{
		s->line_counter++;
	}
	goto st929;
tr2550:
	{
		rdata_tail += s->dname_tmp_length;
	}
	goto st929;
tr2551:
	{
		rdata_tail += s->dname_tmp_length;
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st929;
tr2552:
	{
		rdata_tail += s->dname_tmp_length;
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st929;
tr2553:
	{
		rdata_tail += s->dname_tmp_length;
	}
	{
		s->line_counter++;
	}
	goto st929;
st929:
	if ( ++p == pe )
		goto _test_eof929;
case 929:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto st929;
		case 32: goto st929;
		case 40: goto tr2556;
		case 41: goto tr2557;
		case 42: goto tr2558;
		case 92: goto tr2558;
		case 95: goto tr2558;
		case 2058: goto tr2559;
		case 2107: goto tr2560;
	}
	if ( _widec < 64 ) {
		if ( 45 <= _widec && _widec <= 57 )
			goto tr2558;
	} else if ( _widec > 90 ) {
		if ( 97 <= _widec && _widec <= 122 )
			goto tr2558;
	} else
		goto tr2558;
	goto tr77;
tr2558:
	{
		s->dname = rdata_tail;
	}
	{ p--; {stack[top++] = 930;goto st318;} }
	goto st930;
st930:
	if ( ++p == pe )
		goto _test_eof930;
case 930:
	switch( (*p) ) {
		case 32: goto tr2561;
		case 59: goto tr2561;
	}
	if ( (*p) > 10 ) {
		if ( 40 <= (*p) && (*p) <= 41 )
			goto tr2561;
	} else if ( (*p) >= 9 )
		goto tr2561;
	goto tr77;
tr2561:
	{
		rdata_tail += s->dname_tmp_length;
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1487;
st1487:
	if ( ++p == pe )
		goto _test_eof1487;
case 1487:
	goto st0;
tr2560:
	{
		s->buffer_length = 0;
	}
	goto st931;
tr2562:
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		}
	}
	goto st931;
tr2554:
	{
		rdata_tail += s->dname_tmp_length;
	}
	{
		s->buffer_length = 0;
	}
	goto st931;
st931:
	if ( ++p == pe )
		goto _test_eof931;
case 931:
	_widec = (*p);
	if ( (*p) < 10 ) {
		if ( (*p) <= 9 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) > 10 ) {
		if ( 11 <= (*p) )
 {			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	if ( _widec == 2058 )
		goto tr2563;
	if ( 1920 <= _widec && _widec <= 2175 )
		goto tr2562;
	goto tr77;
st932:
	if ( ++p == pe )
		goto _test_eof932;
case 932:
	if ( 48 <= (*p) && (*p) <= 57 )
		goto tr2564;
	goto tr2396;
tr2564:
	{
		s->number64 = 0;
	}
	{
		// Overflow check: 10*(s->number64) + fc - '0' <= UINT64_MAX
		if ((s->number64 < (UINT64_MAX / 10)) ||   // Dominant fast check.
			((s->number64 == (UINT64_MAX / 10)) && // Marginal case.
			 ((uint8_t)(*p) <= (UINT64_MAX % 10) + '0')
			)
		   ) {
			s->number64 *= 10;
			s->number64 += digit_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_NUMBER64_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st933;
tr2568:
	{
		// Overflow check: 10*(s->number64) + fc - '0' <= UINT64_MAX
		if ((s->number64 < (UINT64_MAX / 10)) ||   // Dominant fast check.
			((s->number64 == (UINT64_MAX / 10)) && // Marginal case.
			 ((uint8_t)(*p) <= (UINT64_MAX % 10) + '0')
			)
		   ) {
			s->number64 *= 10;
			s->number64 += digit_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_NUMBER64_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st933;
st933:
	if ( ++p == pe )
		goto _test_eof933;
case 933:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr2565;
		case 32: goto tr2565;
		case 40: goto tr2566;
		case 41: goto tr2567;
		case 2058: goto tr2569;
		case 2107: goto tr2570;
	}
	if ( 48 <= _widec && _widec <= 57 )
		goto tr2568;
	goto tr2396;
tr2572:
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st934;
tr2573:
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st934;
tr2575:
	{
		s->line_counter++;
	}
	goto st934;
tr2579:
	{
		s->buffer[s->buffer_length++] = 0;

		// Execute the comment callback.
		if (s->process.automatic && s->process.comment != NULL) {
			s->process.comment(s);

			// Stop if required from the callback.
			if (s->state == ZS_STATE_STOP) {
				{p++; cs = 934; goto _out;}
			}
		}
	}
	{
		s->line_counter++;
	}
	goto st934;
tr2565:
	{
		if (s->number64 <= UINT16_MAX) {
			uint16_t num16 = htons((uint16_t)s->number64);
			memcpy(rdata_tail, &num16, 2);
			rdata_tail += 2;
		} else {
			WARN(ZS_NUMBER16_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st934;
tr2566:
	{
		if (s->number64 <= UINT16_MAX) {
			uint16_t num16 = htons((uint16_t)s->number64);
			memcpy(rdata_tail, &num16, 2);
			rdata_tail += 2;
		} else {
			WARN(ZS_NUMBER16_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st934;
tr2567:
	{
		if (s->number64 <= UINT16_MAX) {
			uint16_t num16 = htons((uint16_t)s->number64);
			memcpy(rdata_tail, &num16, 2);
			rdata_tail += 2;
		} else {
			WARN(ZS_NUMBER16_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st934;
tr2569:
	{
		if (s->number64 <= UINT16_MAX) {
			uint16_t num16 = htons((uint16_t)s->number64);
			memcpy(rdata_tail, &num16, 2);
			rdata_tail += 2;
		} else {
			WARN(ZS_NUMBER16_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		s->line_counter++;
	}
	goto st934;
st934:
	if ( ++p == pe )
		goto _test_eof934;
case 934:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto st934;
		case 32: goto st934;
		case 40: goto tr2572;
		case 41: goto tr2573;
		case 42: goto tr2574;
		case 92: goto tr2574;
		case 95: goto tr2574;
		case 2058: goto tr2575;
		case 2107: goto tr2576;
	}
	if ( _widec < 64 ) {
		if ( 45 <= _widec && _widec <= 57 )
			goto tr2574;
	} else if ( _widec > 90 ) {
		if ( 97 <= _widec && _widec <= 122 )
			goto tr2574;
	} else
		goto tr2574;
	goto tr77;
tr2574:
	{
		s->dname = rdata_tail;
	}
	{ p--; {stack[top++] = 935;goto st318;} }
	goto st935;
st935:
	if ( ++p == pe )
		goto _test_eof935;
case 935:
	switch( (*p) ) {
		case 32: goto tr2577;
		case 59: goto tr2577;
	}
	if ( (*p) > 10 ) {
		if ( 40 <= (*p) && (*p) <= 41 )
			goto tr2577;
	} else if ( (*p) >= 9 )
		goto tr2577;
	goto tr77;
tr2577:
	{
		rdata_tail += s->dname_tmp_length;
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1488;
st1488:
	if ( ++p == pe )
		goto _test_eof1488;
case 1488:
	goto st0;
tr2576:
	{
		s->buffer_length = 0;
	}
	goto st936;
tr2578:
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		}
	}
	goto st936;
tr2570:
	{
		if (s->number64 <= UINT16_MAX) {
			uint16_t num16 = htons((uint16_t)s->number64);
			memcpy(rdata_tail, &num16, 2);
			rdata_tail += 2;
		} else {
			WARN(ZS_NUMBER16_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		s->buffer_length = 0;
	}
	goto st936;
st936:
	if ( ++p == pe )
		goto _test_eof936;
case 936:
	_widec = (*p);
	if ( (*p) < 10 ) {
		if ( (*p) <= 9 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) > 10 ) {
		if ( 11 <= (*p) )
 {			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	if ( _widec == 2058 )
		goto tr2579;
	if ( 1920 <= _widec && _widec <= 2175 )
		goto tr2578;
	goto tr77;
st937:
	if ( ++p == pe )
		goto _test_eof937;
case 937:
	switch( (*p) ) {
		case 32: goto tr2581;
		case 59: goto tr2581;
	}
	if ( (*p) > 10 ) {
		if ( 40 <= (*p) && (*p) <= 41 )
			goto tr2581;
	} else if ( (*p) >= 9 )
		goto tr2581;
	goto tr2580;
tr2590:
	{
		if (rdata_tail <= rdata_stop) {
			s->item_length_location = rdata_tail++;
		} else {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{ p--; {stack[top++] = 938;goto st327;} }
	goto st938;
tr2580:
	{
		s->long_string = true;
	}
	{
		if (rdata_tail <= rdata_stop) {
			s->item_length_location = rdata_tail++;
		} else {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{ p--; {stack[top++] = 938;goto st327;} }
	goto st938;
st938:
	if ( ++p == pe )
		goto _test_eof938;
case 938:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(2688 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 !s->multiline  ) _widec += 512;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(2688 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		if (
 !s->multiline  ) _widec += 512;
	}
	switch( _widec ) {
		case 9: goto tr2582;
		case 32: goto tr2582;
		case 40: goto tr2583;
		case 41: goto tr2584;
		case 3082: goto tr2585;
		case 3131: goto tr2586;
		case 3338: goto tr2587;
		case 3387: goto tr2587;
		case 3594: goto tr2588;
		case 3643: goto tr2589;
	}
	goto tr2581;
tr2592:
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st939;
tr2593:
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st939;
tr2594:
	{
		s->line_counter++;
	}
	goto st939;
tr2600:
	{
		s->buffer[s->buffer_length++] = 0;

		// Execute the comment callback.
		if (s->process.automatic && s->process.comment != NULL) {
			s->process.comment(s);

			// Stop if required from the callback.
			if (s->state == ZS_STATE_STOP) {
				{p++; cs = 939; goto _out;}
			}
		}
	}
	{
		s->line_counter++;
	}
	goto st939;
tr2582:
	{
		s->item_length = rdata_tail - s->item_length_location - 1;
		if (s->comma_list && s->item_length == 0) {
			WARN(ZS_EMPTY_LIST_ITEM);
			p--; {goto st316;}
		}
		if (s->item_length <= MAX_ITEM_LENGTH) {
			*(s->item_length_location) = (uint8_t)(s->item_length);
		} else {
			WARN(ZS_ITEM_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st939;
tr2583:
	{
		s->item_length = rdata_tail - s->item_length_location - 1;
		if (s->comma_list && s->item_length == 0) {
			WARN(ZS_EMPTY_LIST_ITEM);
			p--; {goto st316;}
		}
		if (s->item_length <= MAX_ITEM_LENGTH) {
			*(s->item_length_location) = (uint8_t)(s->item_length);
		} else {
			WARN(ZS_ITEM_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st939;
tr2584:
	{
		s->item_length = rdata_tail - s->item_length_location - 1;
		if (s->comma_list && s->item_length == 0) {
			WARN(ZS_EMPTY_LIST_ITEM);
			p--; {goto st316;}
		}
		if (s->item_length <= MAX_ITEM_LENGTH) {
			*(s->item_length_location) = (uint8_t)(s->item_length);
		} else {
			WARN(ZS_ITEM_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st939;
tr2585:
	{
		s->item_length = rdata_tail - s->item_length_location - 1;
		if (s->comma_list && s->item_length == 0) {
			WARN(ZS_EMPTY_LIST_ITEM);
			p--; {goto st316;}
		}
		if (s->item_length <= MAX_ITEM_LENGTH) {
			*(s->item_length_location) = (uint8_t)(s->item_length);
		} else {
			WARN(ZS_ITEM_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		s->line_counter++;
	}
	goto st939;
st939:
	if ( ++p == pe )
		goto _test_eof939;
case 939:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(2688 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 !s->multiline  ) _widec += 512;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(2688 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		if (
 !s->multiline  ) _widec += 512;
	}
	switch( _widec ) {
		case 9: goto st939;
		case 32: goto st939;
		case 40: goto tr2592;
		case 41: goto tr2593;
		case 3082: goto tr2594;
		case 3131: goto tr2595;
		case 3338: goto tr2596;
		case 3387: goto tr2596;
		case 3594: goto tr2597;
		case 3643: goto tr2598;
	}
	if ( _widec < 11 ) {
		if ( _widec <= 8 )
			goto tr2590;
	} else if ( _widec > 58 ) {
		if ( 60 <= _widec )
			goto tr2590;
	} else
		goto tr2590;
	goto tr2581;
tr2595:
	{
		s->buffer_length = 0;
	}
	goto st940;
tr2599:
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		}
	}
	goto st940;
tr2586:
	{
		s->item_length = rdata_tail - s->item_length_location - 1;
		if (s->comma_list && s->item_length == 0) {
			WARN(ZS_EMPTY_LIST_ITEM);
			p--; {goto st316;}
		}
		if (s->item_length <= MAX_ITEM_LENGTH) {
			*(s->item_length_location) = (uint8_t)(s->item_length);
		} else {
			WARN(ZS_ITEM_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		s->buffer_length = 0;
	}
	goto st940;
st940:
	if ( ++p == pe )
		goto _test_eof940;
case 940:
	_widec = (*p);
	if ( (*p) < 10 ) {
		if ( (*p) <= 9 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) > 10 ) {
		if ( 11 <= (*p) )
 {			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	if ( _widec == 2058 )
		goto tr2600;
	if ( 1920 <= _widec && _widec <= 2175 )
		goto tr2599;
	goto tr2581;
tr2587:
	{
		s->item_length = rdata_tail - s->item_length_location - 1;
		if (s->comma_list && s->item_length == 0) {
			WARN(ZS_EMPTY_LIST_ITEM);
			p--; {goto st316;}
		}
		if (s->item_length <= MAX_ITEM_LENGTH) {
			*(s->item_length_location) = (uint8_t)(s->item_length);
		} else {
			WARN(ZS_ITEM_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		s->long_string = false;
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1489;
tr2596:
	{
		s->long_string = false;
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1489;
st1489:
	if ( ++p == pe )
		goto _test_eof1489;
case 1489:
	goto st0;
tr2588:
	{
		s->item_length = rdata_tail - s->item_length_location - 1;
		if (s->comma_list && s->item_length == 0) {
			WARN(ZS_EMPTY_LIST_ITEM);
			p--; {goto st316;}
		}
		if (s->item_length <= MAX_ITEM_LENGTH) {
			*(s->item_length_location) = (uint8_t)(s->item_length);
		} else {
			WARN(ZS_ITEM_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		s->line_counter++;
	}
	{
		s->long_string = false;
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1490;
tr2597:
	{
		s->line_counter++;
	}
	{
		s->long_string = false;
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1490;
st1490:
	if ( ++p == pe )
		goto _test_eof1490;
case 1490:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(2688 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 !s->multiline  ) _widec += 512;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(2688 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		if (
 !s->multiline  ) _widec += 512;
	}
	switch( _widec ) {
		case 9: goto st939;
		case 32: goto st939;
		case 40: goto tr2592;
		case 41: goto tr2593;
		case 3082: goto tr2594;
		case 3131: goto tr2595;
		case 3338: goto tr2596;
		case 3387: goto tr2596;
		case 3594: goto tr2597;
		case 3643: goto tr2598;
	}
	if ( _widec < 11 ) {
		if ( _widec <= 8 )
			goto tr2590;
	} else if ( _widec > 58 ) {
		if ( 60 <= _widec )
			goto tr2590;
	} else
		goto tr2590;
	goto tr2581;
tr2589:
	{
		s->item_length = rdata_tail - s->item_length_location - 1;
		if (s->comma_list && s->item_length == 0) {
			WARN(ZS_EMPTY_LIST_ITEM);
			p--; {goto st316;}
		}
		if (s->item_length <= MAX_ITEM_LENGTH) {
			*(s->item_length_location) = (uint8_t)(s->item_length);
		} else {
			WARN(ZS_ITEM_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		s->buffer_length = 0;
	}
	{
		s->long_string = false;
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1491;
tr2598:
	{
		s->buffer_length = 0;
	}
	{
		s->long_string = false;
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1491;
st1491:
	if ( ++p == pe )
		goto _test_eof1491;
case 1491:
	_widec = (*p);
	if ( (*p) < 10 ) {
		if ( (*p) <= 9 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) > 10 ) {
		if ( 11 <= (*p) )
 {			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	if ( _widec == 2058 )
		goto tr2600;
	if ( 1920 <= _widec && _widec <= 2175 )
		goto tr2599;
	goto tr2581;
st941:
	if ( ++p == pe )
		goto _test_eof941;
case 941:
	if ( (*p) == 46 )
		goto tr2601;
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 58 )
			goto tr2601;
	} else if ( (*p) > 70 ) {
		if ( 97 <= (*p) && (*p) <= 102 )
			goto tr2601;
	} else
		goto tr2601;
	goto tr2373;
tr2603:
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		} else {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st942;
tr2601:
	{
		s->buffer_length = 0;
	}
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		} else {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st942;
st942:
	if ( ++p == pe )
		goto _test_eof942;
case 942:
	switch( (*p) ) {
		case 32: goto tr2602;
		case 46: goto tr2603;
		case 59: goto tr2602;
	}
	if ( (*p) < 48 ) {
		if ( (*p) > 10 ) {
			if ( 40 <= (*p) && (*p) <= 41 )
				goto tr2602;
		} else if ( (*p) >= 9 )
			goto tr2602;
	} else if ( (*p) > 58 ) {
		if ( (*p) > 70 ) {
			if ( 97 <= (*p) && (*p) <= 102 )
				goto tr2603;
		} else if ( (*p) >= 65 )
			goto tr2603;
	} else
		goto tr2603;
	goto tr2373;
tr2602:
	{
		s->buffer[s->buffer_length] = 0;

		if (inet_pton(AF_INET6, (char *)s->buffer, s->addr) <= 0) {
			WARN(ZS_BAD_IPV6);
			p--; {goto st316;}
		}
	}
	{
		if (rdata_tail + ZS_INET6_ADDR_LENGTH > rdata_stop + 1) {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
		memcpy(rdata_tail, s->addr, ZS_INET6_ADDR_LENGTH);
		rdata_tail += ZS_INET6_ADDR_LENGTH;
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1492;
st1492:
	if ( ++p == pe )
		goto _test_eof1492;
case 1492:
	goto st0;
st943:
	if ( ++p == pe )
		goto _test_eof943;
case 943:
	if ( 48 <= (*p) && (*p) <= 57 )
		goto tr2605;
	goto tr2604;
tr2609:
	{
		// Overflow check: 10*(s->number64) + fc - '0' <= UINT64_MAX
		if ((s->number64 < (UINT64_MAX / 10)) ||   // Dominant fast check.
			((s->number64 == (UINT64_MAX / 10)) && // Marginal case.
			 ((uint8_t)(*p) <= (UINT64_MAX % 10) + '0')
			)
		   ) {
			s->number64 *= 10;
			s->number64 += digit_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_NUMBER64_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st944;
tr2605:
	{
		memset(&(s->loc), 0, sizeof(s->loc));
		// Defaults.
		s->loc.siz = 100;
		s->loc.vp  = 1000;
		s->loc.hp  = 1000000;
		s->loc.lat_sign  = 1;
		s->loc.long_sign = 1;
		s->loc.alt_sign  = 1;
	}
	{
		s->number64 = 0;
	}
	{
		// Overflow check: 10*(s->number64) + fc - '0' <= UINT64_MAX
		if ((s->number64 < (UINT64_MAX / 10)) ||   // Dominant fast check.
			((s->number64 == (UINT64_MAX / 10)) && // Marginal case.
			 ((uint8_t)(*p) <= (UINT64_MAX % 10) + '0')
			)
		   ) {
			s->number64 *= 10;
			s->number64 += digit_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_NUMBER64_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st944;
st944:
	if ( ++p == pe )
		goto _test_eof944;
case 944:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr2606;
		case 32: goto tr2606;
		case 40: goto tr2607;
		case 41: goto tr2608;
		case 2058: goto tr2610;
		case 2107: goto tr2611;
	}
	if ( 48 <= _widec && _widec <= 57 )
		goto tr2609;
	goto tr2604;
tr2613:
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st945;
tr2614:
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st945;
tr2618:
	{
		s->line_counter++;
	}
	goto st945;
tr2861:
	{
		s->buffer[s->buffer_length++] = 0;

		// Execute the comment callback.
		if (s->process.automatic && s->process.comment != NULL) {
			s->process.comment(s);

			// Stop if required from the callback.
			if (s->state == ZS_STATE_STOP) {
				{p++; cs = 945; goto _out;}
			}
		}
	}
	{
		s->line_counter++;
	}
	goto st945;
tr2606:
	{
		if (s->number64 <= 90) {
			s->loc.d1 = (uint32_t)(s->number64);
		} else {
			WARN(ZS_BAD_NUMBER);
			p--; {goto st316;}
		}
	}
	goto st945;
tr2607:
	{
		if (s->number64 <= 90) {
			s->loc.d1 = (uint32_t)(s->number64);
		} else {
			WARN(ZS_BAD_NUMBER);
			p--; {goto st316;}
		}
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st945;
tr2608:
	{
		if (s->number64 <= 90) {
			s->loc.d1 = (uint32_t)(s->number64);
		} else {
			WARN(ZS_BAD_NUMBER);
			p--; {goto st316;}
		}
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st945;
tr2610:
	{
		if (s->number64 <= 90) {
			s->loc.d1 = (uint32_t)(s->number64);
		} else {
			WARN(ZS_BAD_NUMBER);
			p--; {goto st316;}
		}
	}
	{
		s->line_counter++;
	}
	goto st945;
st945:
	if ( ++p == pe )
		goto _test_eof945;
case 945:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto st945;
		case 32: goto st945;
		case 40: goto tr2613;
		case 41: goto tr2614;
		case 78: goto st950;
		case 83: goto st992;
		case 2058: goto tr2618;
		case 2107: goto tr2619;
	}
	if ( 48 <= _widec && _widec <= 57 )
		goto tr2615;
	goto tr2604;
tr2615:
	{
		s->number64 = 0;
	}
	{
		// Overflow check: 10*(s->number64) + fc - '0' <= UINT64_MAX
		if ((s->number64 < (UINT64_MAX / 10)) ||   // Dominant fast check.
			((s->number64 == (UINT64_MAX / 10)) && // Marginal case.
			 ((uint8_t)(*p) <= (UINT64_MAX % 10) + '0')
			)
		   ) {
			s->number64 *= 10;
			s->number64 += digit_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_NUMBER64_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st946;
tr2623:
	{
		// Overflow check: 10*(s->number64) + fc - '0' <= UINT64_MAX
		if ((s->number64 < (UINT64_MAX / 10)) ||   // Dominant fast check.
			((s->number64 == (UINT64_MAX / 10)) && // Marginal case.
			 ((uint8_t)(*p) <= (UINT64_MAX % 10) + '0')
			)
		   ) {
			s->number64 *= 10;
			s->number64 += digit_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_NUMBER64_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st946;
st946:
	if ( ++p == pe )
		goto _test_eof946;
case 946:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr2620;
		case 32: goto tr2620;
		case 40: goto tr2621;
		case 41: goto tr2622;
		case 2058: goto tr2624;
		case 2107: goto tr2625;
	}
	if ( 48 <= _widec && _widec <= 57 )
		goto tr2623;
	goto tr2604;
tr2627:
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st947;
tr2628:
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st947;
tr2630:
	{
		s->line_counter++;
	}
	goto st947;
tr2859:
	{
		s->buffer[s->buffer_length++] = 0;

		// Execute the comment callback.
		if (s->process.automatic && s->process.comment != NULL) {
			s->process.comment(s);

			// Stop if required from the callback.
			if (s->state == ZS_STATE_STOP) {
				{p++; cs = 947; goto _out;}
			}
		}
	}
	{
		s->line_counter++;
	}
	goto st947;
tr2620:
	{
		if (s->number64 <= 59) {
			s->loc.m1 = (uint32_t)(s->number64);
		} else {
			WARN(ZS_BAD_NUMBER);
			p--; {goto st316;}
		}
	}
	goto st947;
tr2621:
	{
		if (s->number64 <= 59) {
			s->loc.m1 = (uint32_t)(s->number64);
		} else {
			WARN(ZS_BAD_NUMBER);
			p--; {goto st316;}
		}
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st947;
tr2622:
	{
		if (s->number64 <= 59) {
			s->loc.m1 = (uint32_t)(s->number64);
		} else {
			WARN(ZS_BAD_NUMBER);
			p--; {goto st316;}
		}
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st947;
tr2624:
	{
		if (s->number64 <= 59) {
			s->loc.m1 = (uint32_t)(s->number64);
		} else {
			WARN(ZS_BAD_NUMBER);
			p--; {goto st316;}
		}
	}
	{
		s->line_counter++;
	}
	goto st947;
st947:
	if ( ++p == pe )
		goto _test_eof947;
case 947:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto st947;
		case 32: goto st947;
		case 40: goto tr2627;
		case 41: goto tr2628;
		case 78: goto st950;
		case 83: goto st992;
		case 2058: goto tr2630;
		case 2107: goto tr2631;
	}
	if ( 48 <= _widec && _widec <= 57 )
		goto tr2629;
	goto tr2604;
tr2636:
	{
		// Overflow check: 10*(s->number64) + fc - '0' <= UINT64_MAX
		if ((s->number64 < (UINT64_MAX / 10)) ||   // Dominant fast check.
			((s->number64 == (UINT64_MAX / 10)) && // Marginal case.
			 ((uint8_t)(*p) <= (UINT64_MAX % 10) + '0')
			)
		   ) {
			s->number64 *= 10;
			s->number64 += digit_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_NUMBER64_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st948;
tr2629:
	{
		s->decimals = 3;
	}
	{
		s->decimal_counter = 0;
	}
	{
		s->number64 = 0;
	}
	{
		// Overflow check: 10*(s->number64) + fc - '0' <= UINT64_MAX
		if ((s->number64 < (UINT64_MAX / 10)) ||   // Dominant fast check.
			((s->number64 == (UINT64_MAX / 10)) && // Marginal case.
			 ((uint8_t)(*p) <= (UINT64_MAX % 10) + '0')
			)
		   ) {
			s->number64 *= 10;
			s->number64 += digit_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_NUMBER64_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st948;
st948:
	if ( ++p == pe )
		goto _test_eof948;
case 948:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr2632;
		case 32: goto tr2632;
		case 40: goto tr2633;
		case 41: goto tr2634;
		case 46: goto st994;
		case 2058: goto tr2637;
		case 2107: goto tr2638;
	}
	if ( 48 <= _widec && _widec <= 57 )
		goto tr2636;
	goto tr2604;
tr2640:
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st949;
tr2641:
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st949;
tr2642:
	{
		s->line_counter++;
	}
	goto st949;
tr2850:
	{
		s->buffer[s->buffer_length++] = 0;

		// Execute the comment callback.
		if (s->process.automatic && s->process.comment != NULL) {
			s->process.comment(s);

			// Stop if required from the callback.
			if (s->state == ZS_STATE_STOP) {
				{p++; cs = 949; goto _out;}
			}
		}
	}
	{
		s->line_counter++;
	}
	goto st949;
tr2632:
	{
		if (s->decimal_counter == 0 && s->number64 < UINT32_MAX) {
			s->number64 *= pow(10, s->decimals);
		} else if (s->decimal_counter <= s->decimals &&
				 s->number64_tmp < UINT32_MAX) {
			s->number64 *= pow(10, s->decimals - s->decimal_counter);
			s->number64 += s->number64_tmp * pow(10, s->decimals);
		} else {
			WARN(ZS_FLOAT_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->number64 <= 59999) {
			s->loc.s1 = (uint32_t)(s->number64);
		} else {
			WARN(ZS_BAD_NUMBER);
			p--; {goto st316;}
		}
	}
	goto st949;
tr2633:
	{
		if (s->decimal_counter == 0 && s->number64 < UINT32_MAX) {
			s->number64 *= pow(10, s->decimals);
		} else if (s->decimal_counter <= s->decimals &&
				 s->number64_tmp < UINT32_MAX) {
			s->number64 *= pow(10, s->decimals - s->decimal_counter);
			s->number64 += s->number64_tmp * pow(10, s->decimals);
		} else {
			WARN(ZS_FLOAT_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->number64 <= 59999) {
			s->loc.s1 = (uint32_t)(s->number64);
		} else {
			WARN(ZS_BAD_NUMBER);
			p--; {goto st316;}
		}
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st949;
tr2634:
	{
		if (s->decimal_counter == 0 && s->number64 < UINT32_MAX) {
			s->number64 *= pow(10, s->decimals);
		} else if (s->decimal_counter <= s->decimals &&
				 s->number64_tmp < UINT32_MAX) {
			s->number64 *= pow(10, s->decimals - s->decimal_counter);
			s->number64 += s->number64_tmp * pow(10, s->decimals);
		} else {
			WARN(ZS_FLOAT_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->number64 <= 59999) {
			s->loc.s1 = (uint32_t)(s->number64);
		} else {
			WARN(ZS_BAD_NUMBER);
			p--; {goto st316;}
		}
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st949;
tr2637:
	{
		if (s->decimal_counter == 0 && s->number64 < UINT32_MAX) {
			s->number64 *= pow(10, s->decimals);
		} else if (s->decimal_counter <= s->decimals &&
				 s->number64_tmp < UINT32_MAX) {
			s->number64 *= pow(10, s->decimals - s->decimal_counter);
			s->number64 += s->number64_tmp * pow(10, s->decimals);
		} else {
			WARN(ZS_FLOAT_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->number64 <= 59999) {
			s->loc.s1 = (uint32_t)(s->number64);
		} else {
			WARN(ZS_BAD_NUMBER);
			p--; {goto st316;}
		}
	}
	{
		s->line_counter++;
	}
	goto st949;
tr2851:
	{
		s->number64_tmp = s->number64;
	}
	{
		if (s->decimal_counter == 0 && s->number64 < UINT32_MAX) {
			s->number64 *= pow(10, s->decimals);
		} else if (s->decimal_counter <= s->decimals &&
				 s->number64_tmp < UINT32_MAX) {
			s->number64 *= pow(10, s->decimals - s->decimal_counter);
			s->number64 += s->number64_tmp * pow(10, s->decimals);
		} else {
			WARN(ZS_FLOAT_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->number64 <= 59999) {
			s->loc.s1 = (uint32_t)(s->number64);
		} else {
			WARN(ZS_BAD_NUMBER);
			p--; {goto st316;}
		}
	}
	goto st949;
tr2852:
	{
		s->number64_tmp = s->number64;
	}
	{
		if (s->decimal_counter == 0 && s->number64 < UINT32_MAX) {
			s->number64 *= pow(10, s->decimals);
		} else if (s->decimal_counter <= s->decimals &&
				 s->number64_tmp < UINT32_MAX) {
			s->number64 *= pow(10, s->decimals - s->decimal_counter);
			s->number64 += s->number64_tmp * pow(10, s->decimals);
		} else {
			WARN(ZS_FLOAT_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->number64 <= 59999) {
			s->loc.s1 = (uint32_t)(s->number64);
		} else {
			WARN(ZS_BAD_NUMBER);
			p--; {goto st316;}
		}
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st949;
tr2853:
	{
		s->number64_tmp = s->number64;
	}
	{
		if (s->decimal_counter == 0 && s->number64 < UINT32_MAX) {
			s->number64 *= pow(10, s->decimals);
		} else if (s->decimal_counter <= s->decimals &&
				 s->number64_tmp < UINT32_MAX) {
			s->number64 *= pow(10, s->decimals - s->decimal_counter);
			s->number64 += s->number64_tmp * pow(10, s->decimals);
		} else {
			WARN(ZS_FLOAT_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->number64 <= 59999) {
			s->loc.s1 = (uint32_t)(s->number64);
		} else {
			WARN(ZS_BAD_NUMBER);
			p--; {goto st316;}
		}
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st949;
tr2855:
	{
		s->number64_tmp = s->number64;
	}
	{
		if (s->decimal_counter == 0 && s->number64 < UINT32_MAX) {
			s->number64 *= pow(10, s->decimals);
		} else if (s->decimal_counter <= s->decimals &&
				 s->number64_tmp < UINT32_MAX) {
			s->number64 *= pow(10, s->decimals - s->decimal_counter);
			s->number64 += s->number64_tmp * pow(10, s->decimals);
		} else {
			WARN(ZS_FLOAT_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->number64 <= 59999) {
			s->loc.s1 = (uint32_t)(s->number64);
		} else {
			WARN(ZS_BAD_NUMBER);
			p--; {goto st316;}
		}
	}
	{
		s->line_counter++;
	}
	goto st949;
st949:
	if ( ++p == pe )
		goto _test_eof949;
case 949:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto st949;
		case 32: goto st949;
		case 40: goto tr2640;
		case 41: goto tr2641;
		case 78: goto st950;
		case 83: goto st992;
		case 2058: goto tr2642;
		case 2107: goto tr2643;
	}
	goto tr2604;
st950:
	if ( ++p == pe )
		goto _test_eof950;
case 950:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto st951;
		case 32: goto st951;
		case 40: goto tr2645;
		case 41: goto tr2646;
		case 2058: goto tr2647;
		case 2107: goto tr2648;
	}
	goto tr2604;
tr2645:
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st951;
tr2646:
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st951;
tr2647:
	{
		s->line_counter++;
	}
	goto st951;
tr2843:
	{
		s->buffer[s->buffer_length++] = 0;

		// Execute the comment callback.
		if (s->process.automatic && s->process.comment != NULL) {
			s->process.comment(s);

			// Stop if required from the callback.
			if (s->state == ZS_STATE_STOP) {
				{p++; cs = 951; goto _out;}
			}
		}
	}
	{
		s->line_counter++;
	}
	goto st951;
tr2844:
	{
		s->loc.lat_sign = -1;
	}
	goto st951;
tr2845:
	{
		s->loc.lat_sign = -1;
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st951;
tr2846:
	{
		s->loc.lat_sign = -1;
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st951;
tr2847:
	{
		s->loc.lat_sign = -1;
	}
	{
		s->line_counter++;
	}
	goto st951;
st951:
	if ( ++p == pe )
		goto _test_eof951;
case 951:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto st951;
		case 32: goto st951;
		case 40: goto tr2645;
		case 41: goto tr2646;
		case 2058: goto tr2647;
		case 2107: goto tr2648;
	}
	if ( 48 <= _widec && _widec <= 57 )
		goto tr2649;
	goto tr2604;
tr2649:
	{
		s->number64 = 0;
	}
	{
		// Overflow check: 10*(s->number64) + fc - '0' <= UINT64_MAX
		if ((s->number64 < (UINT64_MAX / 10)) ||   // Dominant fast check.
			((s->number64 == (UINT64_MAX / 10)) && // Marginal case.
			 ((uint8_t)(*p) <= (UINT64_MAX % 10) + '0')
			)
		   ) {
			s->number64 *= 10;
			s->number64 += digit_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_NUMBER64_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st952;
tr2653:
	{
		// Overflow check: 10*(s->number64) + fc - '0' <= UINT64_MAX
		if ((s->number64 < (UINT64_MAX / 10)) ||   // Dominant fast check.
			((s->number64 == (UINT64_MAX / 10)) && // Marginal case.
			 ((uint8_t)(*p) <= (UINT64_MAX % 10) + '0')
			)
		   ) {
			s->number64 *= 10;
			s->number64 += digit_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_NUMBER64_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st952;
st952:
	if ( ++p == pe )
		goto _test_eof952;
case 952:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr2650;
		case 32: goto tr2650;
		case 40: goto tr2651;
		case 41: goto tr2652;
		case 2058: goto tr2654;
		case 2107: goto tr2655;
	}
	if ( 48 <= _widec && _widec <= 57 )
		goto tr2653;
	goto tr2604;
tr2657:
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st953;
tr2658:
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st953;
tr2662:
	{
		s->line_counter++;
	}
	goto st953;
tr2841:
	{
		s->buffer[s->buffer_length++] = 0;

		// Execute the comment callback.
		if (s->process.automatic && s->process.comment != NULL) {
			s->process.comment(s);

			// Stop if required from the callback.
			if (s->state == ZS_STATE_STOP) {
				{p++; cs = 953; goto _out;}
			}
		}
	}
	{
		s->line_counter++;
	}
	goto st953;
tr2650:
	{
		if (s->number64 <= 180) {
			s->loc.d2 = (uint32_t)(s->number64);
		} else {
			WARN(ZS_BAD_NUMBER);
			p--; {goto st316;}
		}
	}
	goto st953;
tr2651:
	{
		if (s->number64 <= 180) {
			s->loc.d2 = (uint32_t)(s->number64);
		} else {
			WARN(ZS_BAD_NUMBER);
			p--; {goto st316;}
		}
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st953;
tr2652:
	{
		if (s->number64 <= 180) {
			s->loc.d2 = (uint32_t)(s->number64);
		} else {
			WARN(ZS_BAD_NUMBER);
			p--; {goto st316;}
		}
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st953;
tr2654:
	{
		if (s->number64 <= 180) {
			s->loc.d2 = (uint32_t)(s->number64);
		} else {
			WARN(ZS_BAD_NUMBER);
			p--; {goto st316;}
		}
	}
	{
		s->line_counter++;
	}
	goto st953;
st953:
	if ( ++p == pe )
		goto _test_eof953;
case 953:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto st953;
		case 32: goto st953;
		case 40: goto tr2657;
		case 41: goto tr2658;
		case 69: goto st958;
		case 87: goto st985;
		case 2058: goto tr2662;
		case 2107: goto tr2663;
	}
	if ( 48 <= _widec && _widec <= 57 )
		goto tr2659;
	goto tr2604;
tr2659:
	{
		s->number64 = 0;
	}
	{
		// Overflow check: 10*(s->number64) + fc - '0' <= UINT64_MAX
		if ((s->number64 < (UINT64_MAX / 10)) ||   // Dominant fast check.
			((s->number64 == (UINT64_MAX / 10)) && // Marginal case.
			 ((uint8_t)(*p) <= (UINT64_MAX % 10) + '0')
			)
		   ) {
			s->number64 *= 10;
			s->number64 += digit_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_NUMBER64_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st954;
tr2667:
	{
		// Overflow check: 10*(s->number64) + fc - '0' <= UINT64_MAX
		if ((s->number64 < (UINT64_MAX / 10)) ||   // Dominant fast check.
			((s->number64 == (UINT64_MAX / 10)) && // Marginal case.
			 ((uint8_t)(*p) <= (UINT64_MAX % 10) + '0')
			)
		   ) {
			s->number64 *= 10;
			s->number64 += digit_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_NUMBER64_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st954;
st954:
	if ( ++p == pe )
		goto _test_eof954;
case 954:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr2664;
		case 32: goto tr2664;
		case 40: goto tr2665;
		case 41: goto tr2666;
		case 2058: goto tr2668;
		case 2107: goto tr2669;
	}
	if ( 48 <= _widec && _widec <= 57 )
		goto tr2667;
	goto tr2604;
tr2671:
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st955;
tr2672:
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st955;
tr2674:
	{
		s->line_counter++;
	}
	goto st955;
tr2839:
	{
		s->buffer[s->buffer_length++] = 0;

		// Execute the comment callback.
		if (s->process.automatic && s->process.comment != NULL) {
			s->process.comment(s);

			// Stop if required from the callback.
			if (s->state == ZS_STATE_STOP) {
				{p++; cs = 955; goto _out;}
			}
		}
	}
	{
		s->line_counter++;
	}
	goto st955;
tr2664:
	{
		if (s->number64 <= 59) {
			s->loc.m2 = (uint32_t)(s->number64);
		} else {
			WARN(ZS_BAD_NUMBER);
			p--; {goto st316;}
		}
	}
	goto st955;
tr2665:
	{
		if (s->number64 <= 59) {
			s->loc.m2 = (uint32_t)(s->number64);
		} else {
			WARN(ZS_BAD_NUMBER);
			p--; {goto st316;}
		}
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st955;
tr2666:
	{
		if (s->number64 <= 59) {
			s->loc.m2 = (uint32_t)(s->number64);
		} else {
			WARN(ZS_BAD_NUMBER);
			p--; {goto st316;}
		}
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st955;
tr2668:
	{
		if (s->number64 <= 59) {
			s->loc.m2 = (uint32_t)(s->number64);
		} else {
			WARN(ZS_BAD_NUMBER);
			p--; {goto st316;}
		}
	}
	{
		s->line_counter++;
	}
	goto st955;
st955:
	if ( ++p == pe )
		goto _test_eof955;
case 955:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto st955;
		case 32: goto st955;
		case 40: goto tr2671;
		case 41: goto tr2672;
		case 69: goto st958;
		case 87: goto st985;
		case 2058: goto tr2674;
		case 2107: goto tr2675;
	}
	if ( 48 <= _widec && _widec <= 57 )
		goto tr2673;
	goto tr2604;
tr2680:
	{
		// Overflow check: 10*(s->number64) + fc - '0' <= UINT64_MAX
		if ((s->number64 < (UINT64_MAX / 10)) ||   // Dominant fast check.
			((s->number64 == (UINT64_MAX / 10)) && // Marginal case.
			 ((uint8_t)(*p) <= (UINT64_MAX % 10) + '0')
			)
		   ) {
			s->number64 *= 10;
			s->number64 += digit_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_NUMBER64_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st956;
tr2673:
	{
		s->decimals = 3;
	}
	{
		s->decimal_counter = 0;
	}
	{
		s->number64 = 0;
	}
	{
		// Overflow check: 10*(s->number64) + fc - '0' <= UINT64_MAX
		if ((s->number64 < (UINT64_MAX / 10)) ||   // Dominant fast check.
			((s->number64 == (UINT64_MAX / 10)) && // Marginal case.
			 ((uint8_t)(*p) <= (UINT64_MAX % 10) + '0')
			)
		   ) {
			s->number64 *= 10;
			s->number64 += digit_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_NUMBER64_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st956;
st956:
	if ( ++p == pe )
		goto _test_eof956;
case 956:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr2676;
		case 32: goto tr2676;
		case 40: goto tr2677;
		case 41: goto tr2678;
		case 46: goto st987;
		case 2058: goto tr2681;
		case 2107: goto tr2682;
	}
	if ( 48 <= _widec && _widec <= 57 )
		goto tr2680;
	goto tr2604;
tr2684:
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st957;
tr2685:
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st957;
tr2686:
	{
		s->line_counter++;
	}
	goto st957;
tr2830:
	{
		s->buffer[s->buffer_length++] = 0;

		// Execute the comment callback.
		if (s->process.automatic && s->process.comment != NULL) {
			s->process.comment(s);

			// Stop if required from the callback.
			if (s->state == ZS_STATE_STOP) {
				{p++; cs = 957; goto _out;}
			}
		}
	}
	{
		s->line_counter++;
	}
	goto st957;
tr2676:
	{
		if (s->decimal_counter == 0 && s->number64 < UINT32_MAX) {
			s->number64 *= pow(10, s->decimals);
		} else if (s->decimal_counter <= s->decimals &&
				 s->number64_tmp < UINT32_MAX) {
			s->number64 *= pow(10, s->decimals - s->decimal_counter);
			s->number64 += s->number64_tmp * pow(10, s->decimals);
		} else {
			WARN(ZS_FLOAT_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->number64 <= 59999) {
			s->loc.s2 = (uint32_t)(s->number64);
		} else {
			WARN(ZS_BAD_NUMBER);
			p--; {goto st316;}
		}
	}
	goto st957;
tr2677:
	{
		if (s->decimal_counter == 0 && s->number64 < UINT32_MAX) {
			s->number64 *= pow(10, s->decimals);
		} else if (s->decimal_counter <= s->decimals &&
				 s->number64_tmp < UINT32_MAX) {
			s->number64 *= pow(10, s->decimals - s->decimal_counter);
			s->number64 += s->number64_tmp * pow(10, s->decimals);
		} else {
			WARN(ZS_FLOAT_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->number64 <= 59999) {
			s->loc.s2 = (uint32_t)(s->number64);
		} else {
			WARN(ZS_BAD_NUMBER);
			p--; {goto st316;}
		}
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st957;
tr2678:
	{
		if (s->decimal_counter == 0 && s->number64 < UINT32_MAX) {
			s->number64 *= pow(10, s->decimals);
		} else if (s->decimal_counter <= s->decimals &&
				 s->number64_tmp < UINT32_MAX) {
			s->number64 *= pow(10, s->decimals - s->decimal_counter);
			s->number64 += s->number64_tmp * pow(10, s->decimals);
		} else {
			WARN(ZS_FLOAT_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->number64 <= 59999) {
			s->loc.s2 = (uint32_t)(s->number64);
		} else {
			WARN(ZS_BAD_NUMBER);
			p--; {goto st316;}
		}
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st957;
tr2681:
	{
		if (s->decimal_counter == 0 && s->number64 < UINT32_MAX) {
			s->number64 *= pow(10, s->decimals);
		} else if (s->decimal_counter <= s->decimals &&
				 s->number64_tmp < UINT32_MAX) {
			s->number64 *= pow(10, s->decimals - s->decimal_counter);
			s->number64 += s->number64_tmp * pow(10, s->decimals);
		} else {
			WARN(ZS_FLOAT_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->number64 <= 59999) {
			s->loc.s2 = (uint32_t)(s->number64);
		} else {
			WARN(ZS_BAD_NUMBER);
			p--; {goto st316;}
		}
	}
	{
		s->line_counter++;
	}
	goto st957;
tr2831:
	{
		s->number64_tmp = s->number64;
	}
	{
		if (s->decimal_counter == 0 && s->number64 < UINT32_MAX) {
			s->number64 *= pow(10, s->decimals);
		} else if (s->decimal_counter <= s->decimals &&
				 s->number64_tmp < UINT32_MAX) {
			s->number64 *= pow(10, s->decimals - s->decimal_counter);
			s->number64 += s->number64_tmp * pow(10, s->decimals);
		} else {
			WARN(ZS_FLOAT_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->number64 <= 59999) {
			s->loc.s2 = (uint32_t)(s->number64);
		} else {
			WARN(ZS_BAD_NUMBER);
			p--; {goto st316;}
		}
	}
	goto st957;
tr2832:
	{
		s->number64_tmp = s->number64;
	}
	{
		if (s->decimal_counter == 0 && s->number64 < UINT32_MAX) {
			s->number64 *= pow(10, s->decimals);
		} else if (s->decimal_counter <= s->decimals &&
				 s->number64_tmp < UINT32_MAX) {
			s->number64 *= pow(10, s->decimals - s->decimal_counter);
			s->number64 += s->number64_tmp * pow(10, s->decimals);
		} else {
			WARN(ZS_FLOAT_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->number64 <= 59999) {
			s->loc.s2 = (uint32_t)(s->number64);
		} else {
			WARN(ZS_BAD_NUMBER);
			p--; {goto st316;}
		}
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st957;
tr2833:
	{
		s->number64_tmp = s->number64;
	}
	{
		if (s->decimal_counter == 0 && s->number64 < UINT32_MAX) {
			s->number64 *= pow(10, s->decimals);
		} else if (s->decimal_counter <= s->decimals &&
				 s->number64_tmp < UINT32_MAX) {
			s->number64 *= pow(10, s->decimals - s->decimal_counter);
			s->number64 += s->number64_tmp * pow(10, s->decimals);
		} else {
			WARN(ZS_FLOAT_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->number64 <= 59999) {
			s->loc.s2 = (uint32_t)(s->number64);
		} else {
			WARN(ZS_BAD_NUMBER);
			p--; {goto st316;}
		}
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st957;
tr2835:
	{
		s->number64_tmp = s->number64;
	}
	{
		if (s->decimal_counter == 0 && s->number64 < UINT32_MAX) {
			s->number64 *= pow(10, s->decimals);
		} else if (s->decimal_counter <= s->decimals &&
				 s->number64_tmp < UINT32_MAX) {
			s->number64 *= pow(10, s->decimals - s->decimal_counter);
			s->number64 += s->number64_tmp * pow(10, s->decimals);
		} else {
			WARN(ZS_FLOAT_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->number64 <= 59999) {
			s->loc.s2 = (uint32_t)(s->number64);
		} else {
			WARN(ZS_BAD_NUMBER);
			p--; {goto st316;}
		}
	}
	{
		s->line_counter++;
	}
	goto st957;
st957:
	if ( ++p == pe )
		goto _test_eof957;
case 957:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto st957;
		case 32: goto st957;
		case 40: goto tr2684;
		case 41: goto tr2685;
		case 69: goto st958;
		case 87: goto st985;
		case 2058: goto tr2686;
		case 2107: goto tr2687;
	}
	goto tr2604;
st958:
	if ( ++p == pe )
		goto _test_eof958;
case 958:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto st959;
		case 32: goto st959;
		case 40: goto tr2689;
		case 41: goto tr2690;
		case 2058: goto tr2691;
		case 2107: goto tr2692;
	}
	goto tr2604;
tr2689:
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st959;
tr2690:
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st959;
tr2691:
	{
		s->line_counter++;
	}
	goto st959;
tr2823:
	{
		s->buffer[s->buffer_length++] = 0;

		// Execute the comment callback.
		if (s->process.automatic && s->process.comment != NULL) {
			s->process.comment(s);

			// Stop if required from the callback.
			if (s->state == ZS_STATE_STOP) {
				{p++; cs = 959; goto _out;}
			}
		}
	}
	{
		s->line_counter++;
	}
	goto st959;
tr2824:
	{
		s->loc.long_sign = -1;
	}
	goto st959;
tr2825:
	{
		s->loc.long_sign = -1;
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st959;
tr2826:
	{
		s->loc.long_sign = -1;
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st959;
tr2827:
	{
		s->loc.long_sign = -1;
	}
	{
		s->line_counter++;
	}
	goto st959;
st959:
	if ( ++p == pe )
		goto _test_eof959;
case 959:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto st959;
		case 32: goto st959;
		case 40: goto tr2689;
		case 41: goto tr2690;
		case 45: goto st960;
		case 2058: goto tr2691;
		case 2107: goto tr2692;
	}
	if ( 48 <= _widec && _widec <= 57 )
		goto tr2694;
	goto tr2604;
st960:
	if ( ++p == pe )
		goto _test_eof960;
case 960:
	if ( 48 <= (*p) && (*p) <= 57 )
		goto tr2695;
	goto tr2604;
tr2700:
	{
		// Overflow check: 10*(s->number64) + fc - '0' <= UINT64_MAX
		if ((s->number64 < (UINT64_MAX / 10)) ||   // Dominant fast check.
			((s->number64 == (UINT64_MAX / 10)) && // Marginal case.
			 ((uint8_t)(*p) <= (UINT64_MAX % 10) + '0')
			)
		   ) {
			s->number64 *= 10;
			s->number64 += digit_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_NUMBER64_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st961;
tr2694:
	{
		s->decimals = 2;
	}
	{
		s->decimal_counter = 0;
	}
	{
		s->number64 = 0;
	}
	{
		// Overflow check: 10*(s->number64) + fc - '0' <= UINT64_MAX
		if ((s->number64 < (UINT64_MAX / 10)) ||   // Dominant fast check.
			((s->number64 == (UINT64_MAX / 10)) && // Marginal case.
			 ((uint8_t)(*p) <= (UINT64_MAX % 10) + '0')
			)
		   ) {
			s->number64 *= 10;
			s->number64 += digit_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_NUMBER64_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st961;
tr2695:
	{
		s->loc.alt_sign = -1;
	}
	{
		s->decimals = 2;
	}
	{
		s->decimal_counter = 0;
	}
	{
		s->number64 = 0;
	}
	{
		// Overflow check: 10*(s->number64) + fc - '0' <= UINT64_MAX
		if ((s->number64 < (UINT64_MAX / 10)) ||   // Dominant fast check.
			((s->number64 == (UINT64_MAX / 10)) && // Marginal case.
			 ((uint8_t)(*p) <= (UINT64_MAX % 10) + '0')
			)
		   ) {
			s->number64 *= 10;
			s->number64 += digit_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_NUMBER64_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st961;
st961:
	if ( ++p == pe )
		goto _test_eof961;
case 961:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(2688 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 !s->multiline  ) _widec += 512;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(2688 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		if (
 !s->multiline  ) _widec += 512;
	}
	switch( _widec ) {
		case 9: goto tr2696;
		case 32: goto tr2696;
		case 40: goto tr2697;
		case 41: goto tr2698;
		case 46: goto st981;
		case 109: goto tr2701;
		case 3082: goto tr2702;
		case 3131: goto tr2703;
		case 3338: goto tr2704;
		case 3387: goto tr2704;
		case 3594: goto tr2705;
		case 3643: goto tr2706;
	}
	if ( 48 <= _widec && _widec <= 57 )
		goto tr2700;
	goto tr2604;
tr2708:
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st962;
tr2709:
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st962;
tr2711:
	{
		s->line_counter++;
	}
	goto st962;
tr2810:
	{
		s->buffer[s->buffer_length++] = 0;

		// Execute the comment callback.
		if (s->process.automatic && s->process.comment != NULL) {
			s->process.comment(s);

			// Stop if required from the callback.
			if (s->state == ZS_STATE_STOP) {
				{p++; cs = 962; goto _out;}
			}
		}
	}
	{
		s->line_counter++;
	}
	goto st962;
tr2696:
	{
		if (s->decimal_counter == 0 && s->number64 < UINT32_MAX) {
			s->number64 *= pow(10, s->decimals);
		} else if (s->decimal_counter <= s->decimals &&
				 s->number64_tmp < UINT32_MAX) {
			s->number64 *= pow(10, s->decimals - s->decimal_counter);
			s->number64 += s->number64_tmp * pow(10, s->decimals);
		} else {
			WARN(ZS_FLOAT_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if ((s->loc.alt_sign ==  1 && s->number64 <= 4284967295) ||
		    (s->loc.alt_sign == -1 && s->number64 <=   10000000))
		{
			s->loc.alt = (uint32_t)(s->number64);
		} else {
			WARN(ZS_BAD_NUMBER);
			p--; {goto st316;}
		}
	}
	goto st962;
tr2697:
	{
		if (s->decimal_counter == 0 && s->number64 < UINT32_MAX) {
			s->number64 *= pow(10, s->decimals);
		} else if (s->decimal_counter <= s->decimals &&
				 s->number64_tmp < UINT32_MAX) {
			s->number64 *= pow(10, s->decimals - s->decimal_counter);
			s->number64 += s->number64_tmp * pow(10, s->decimals);
		} else {
			WARN(ZS_FLOAT_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if ((s->loc.alt_sign ==  1 && s->number64 <= 4284967295) ||
		    (s->loc.alt_sign == -1 && s->number64 <=   10000000))
		{
			s->loc.alt = (uint32_t)(s->number64);
		} else {
			WARN(ZS_BAD_NUMBER);
			p--; {goto st316;}
		}
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st962;
tr2698:
	{
		if (s->decimal_counter == 0 && s->number64 < UINT32_MAX) {
			s->number64 *= pow(10, s->decimals);
		} else if (s->decimal_counter <= s->decimals &&
				 s->number64_tmp < UINT32_MAX) {
			s->number64 *= pow(10, s->decimals - s->decimal_counter);
			s->number64 += s->number64_tmp * pow(10, s->decimals);
		} else {
			WARN(ZS_FLOAT_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if ((s->loc.alt_sign ==  1 && s->number64 <= 4284967295) ||
		    (s->loc.alt_sign == -1 && s->number64 <=   10000000))
		{
			s->loc.alt = (uint32_t)(s->number64);
		} else {
			WARN(ZS_BAD_NUMBER);
			p--; {goto st316;}
		}
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st962;
tr2702:
	{
		if (s->decimal_counter == 0 && s->number64 < UINT32_MAX) {
			s->number64 *= pow(10, s->decimals);
		} else if (s->decimal_counter <= s->decimals &&
				 s->number64_tmp < UINT32_MAX) {
			s->number64 *= pow(10, s->decimals - s->decimal_counter);
			s->number64 += s->number64_tmp * pow(10, s->decimals);
		} else {
			WARN(ZS_FLOAT_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if ((s->loc.alt_sign ==  1 && s->number64 <= 4284967295) ||
		    (s->loc.alt_sign == -1 && s->number64 <=   10000000))
		{
			s->loc.alt = (uint32_t)(s->number64);
		} else {
			WARN(ZS_BAD_NUMBER);
			p--; {goto st316;}
		}
	}
	{
		s->line_counter++;
	}
	goto st962;
tr2811:
	{
		s->number64_tmp = s->number64;
	}
	{
		if (s->decimal_counter == 0 && s->number64 < UINT32_MAX) {
			s->number64 *= pow(10, s->decimals);
		} else if (s->decimal_counter <= s->decimals &&
				 s->number64_tmp < UINT32_MAX) {
			s->number64 *= pow(10, s->decimals - s->decimal_counter);
			s->number64 += s->number64_tmp * pow(10, s->decimals);
		} else {
			WARN(ZS_FLOAT_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if ((s->loc.alt_sign ==  1 && s->number64 <= 4284967295) ||
		    (s->loc.alt_sign == -1 && s->number64 <=   10000000))
		{
			s->loc.alt = (uint32_t)(s->number64);
		} else {
			WARN(ZS_BAD_NUMBER);
			p--; {goto st316;}
		}
	}
	goto st962;
tr2812:
	{
		s->number64_tmp = s->number64;
	}
	{
		if (s->decimal_counter == 0 && s->number64 < UINT32_MAX) {
			s->number64 *= pow(10, s->decimals);
		} else if (s->decimal_counter <= s->decimals &&
				 s->number64_tmp < UINT32_MAX) {
			s->number64 *= pow(10, s->decimals - s->decimal_counter);
			s->number64 += s->number64_tmp * pow(10, s->decimals);
		} else {
			WARN(ZS_FLOAT_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if ((s->loc.alt_sign ==  1 && s->number64 <= 4284967295) ||
		    (s->loc.alt_sign == -1 && s->number64 <=   10000000))
		{
			s->loc.alt = (uint32_t)(s->number64);
		} else {
			WARN(ZS_BAD_NUMBER);
			p--; {goto st316;}
		}
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st962;
tr2813:
	{
		s->number64_tmp = s->number64;
	}
	{
		if (s->decimal_counter == 0 && s->number64 < UINT32_MAX) {
			s->number64 *= pow(10, s->decimals);
		} else if (s->decimal_counter <= s->decimals &&
				 s->number64_tmp < UINT32_MAX) {
			s->number64 *= pow(10, s->decimals - s->decimal_counter);
			s->number64 += s->number64_tmp * pow(10, s->decimals);
		} else {
			WARN(ZS_FLOAT_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if ((s->loc.alt_sign ==  1 && s->number64 <= 4284967295) ||
		    (s->loc.alt_sign == -1 && s->number64 <=   10000000))
		{
			s->loc.alt = (uint32_t)(s->number64);
		} else {
			WARN(ZS_BAD_NUMBER);
			p--; {goto st316;}
		}
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st962;
tr2816:
	{
		s->number64_tmp = s->number64;
	}
	{
		if (s->decimal_counter == 0 && s->number64 < UINT32_MAX) {
			s->number64 *= pow(10, s->decimals);
		} else if (s->decimal_counter <= s->decimals &&
				 s->number64_tmp < UINT32_MAX) {
			s->number64 *= pow(10, s->decimals - s->decimal_counter);
			s->number64 += s->number64_tmp * pow(10, s->decimals);
		} else {
			WARN(ZS_FLOAT_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if ((s->loc.alt_sign ==  1 && s->number64 <= 4284967295) ||
		    (s->loc.alt_sign == -1 && s->number64 <=   10000000))
		{
			s->loc.alt = (uint32_t)(s->number64);
		} else {
			WARN(ZS_BAD_NUMBER);
			p--; {goto st316;}
		}
	}
	{
		s->line_counter++;
	}
	goto st962;
st962:
	if ( ++p == pe )
		goto _test_eof962;
case 962:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(2688 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 !s->multiline  ) _widec += 512;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(2688 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		if (
 !s->multiline  ) _widec += 512;
	}
	switch( _widec ) {
		case 9: goto st962;
		case 32: goto st962;
		case 40: goto tr2708;
		case 41: goto tr2709;
		case 3082: goto tr2711;
		case 3131: goto tr2712;
		case 3338: goto tr2713;
		case 3387: goto tr2713;
		case 3594: goto tr2714;
		case 3643: goto tr2715;
	}
	if ( 48 <= _widec && _widec <= 57 )
		goto tr2710;
	goto tr2604;
tr2720:
	{
		// Overflow check: 10*(s->number64) + fc - '0' <= UINT64_MAX
		if ((s->number64 < (UINT64_MAX / 10)) ||   // Dominant fast check.
			((s->number64 == (UINT64_MAX / 10)) && // Marginal case.
			 ((uint8_t)(*p) <= (UINT64_MAX % 10) + '0')
			)
		   ) {
			s->number64 *= 10;
			s->number64 += digit_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_NUMBER64_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st963;
tr2710:
	{
		s->decimals = 2;
	}
	{
		s->decimal_counter = 0;
	}
	{
		s->number64 = 0;
	}
	{
		// Overflow check: 10*(s->number64) + fc - '0' <= UINT64_MAX
		if ((s->number64 < (UINT64_MAX / 10)) ||   // Dominant fast check.
			((s->number64 == (UINT64_MAX / 10)) && // Marginal case.
			 ((uint8_t)(*p) <= (UINT64_MAX % 10) + '0')
			)
		   ) {
			s->number64 *= 10;
			s->number64 += digit_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_NUMBER64_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st963;
st963:
	if ( ++p == pe )
		goto _test_eof963;
case 963:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(2688 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 !s->multiline  ) _widec += 512;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(2688 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		if (
 !s->multiline  ) _widec += 512;
	}
	switch( _widec ) {
		case 9: goto tr2716;
		case 32: goto tr2716;
		case 40: goto tr2717;
		case 41: goto tr2718;
		case 46: goto st977;
		case 109: goto tr2721;
		case 3082: goto tr2722;
		case 3131: goto tr2723;
		case 3338: goto tr2724;
		case 3387: goto tr2724;
		case 3594: goto tr2725;
		case 3643: goto tr2726;
	}
	if ( 48 <= _widec && _widec <= 57 )
		goto tr2720;
	goto tr2604;
tr2728:
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st964;
tr2729:
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st964;
tr2731:
	{
		s->line_counter++;
	}
	goto st964;
tr2797:
	{
		s->buffer[s->buffer_length++] = 0;

		// Execute the comment callback.
		if (s->process.automatic && s->process.comment != NULL) {
			s->process.comment(s);

			// Stop if required from the callback.
			if (s->state == ZS_STATE_STOP) {
				{p++; cs = 964; goto _out;}
			}
		}
	}
	{
		s->line_counter++;
	}
	goto st964;
tr2716:
	{
		if (s->decimal_counter == 0 && s->number64 < UINT32_MAX) {
			s->number64 *= pow(10, s->decimals);
		} else if (s->decimal_counter <= s->decimals &&
				 s->number64_tmp < UINT32_MAX) {
			s->number64 *= pow(10, s->decimals - s->decimal_counter);
			s->number64 += s->number64_tmp * pow(10, s->decimals);
		} else {
			WARN(ZS_FLOAT_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->number64 <= 9000000000ULL) {
			s->loc.siz = s->number64;
		} else {
			WARN(ZS_BAD_NUMBER);
			p--; {goto st316;}
		}
	}
	goto st964;
tr2717:
	{
		if (s->decimal_counter == 0 && s->number64 < UINT32_MAX) {
			s->number64 *= pow(10, s->decimals);
		} else if (s->decimal_counter <= s->decimals &&
				 s->number64_tmp < UINT32_MAX) {
			s->number64 *= pow(10, s->decimals - s->decimal_counter);
			s->number64 += s->number64_tmp * pow(10, s->decimals);
		} else {
			WARN(ZS_FLOAT_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->number64 <= 9000000000ULL) {
			s->loc.siz = s->number64;
		} else {
			WARN(ZS_BAD_NUMBER);
			p--; {goto st316;}
		}
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st964;
tr2718:
	{
		if (s->decimal_counter == 0 && s->number64 < UINT32_MAX) {
			s->number64 *= pow(10, s->decimals);
		} else if (s->decimal_counter <= s->decimals &&
				 s->number64_tmp < UINT32_MAX) {
			s->number64 *= pow(10, s->decimals - s->decimal_counter);
			s->number64 += s->number64_tmp * pow(10, s->decimals);
		} else {
			WARN(ZS_FLOAT_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->number64 <= 9000000000ULL) {
			s->loc.siz = s->number64;
		} else {
			WARN(ZS_BAD_NUMBER);
			p--; {goto st316;}
		}
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st964;
tr2722:
	{
		if (s->decimal_counter == 0 && s->number64 < UINT32_MAX) {
			s->number64 *= pow(10, s->decimals);
		} else if (s->decimal_counter <= s->decimals &&
				 s->number64_tmp < UINT32_MAX) {
			s->number64 *= pow(10, s->decimals - s->decimal_counter);
			s->number64 += s->number64_tmp * pow(10, s->decimals);
		} else {
			WARN(ZS_FLOAT_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->number64 <= 9000000000ULL) {
			s->loc.siz = s->number64;
		} else {
			WARN(ZS_BAD_NUMBER);
			p--; {goto st316;}
		}
	}
	{
		s->line_counter++;
	}
	goto st964;
tr2798:
	{
		s->number64_tmp = s->number64;
	}
	{
		if (s->decimal_counter == 0 && s->number64 < UINT32_MAX) {
			s->number64 *= pow(10, s->decimals);
		} else if (s->decimal_counter <= s->decimals &&
				 s->number64_tmp < UINT32_MAX) {
			s->number64 *= pow(10, s->decimals - s->decimal_counter);
			s->number64 += s->number64_tmp * pow(10, s->decimals);
		} else {
			WARN(ZS_FLOAT_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->number64 <= 9000000000ULL) {
			s->loc.siz = s->number64;
		} else {
			WARN(ZS_BAD_NUMBER);
			p--; {goto st316;}
		}
	}
	goto st964;
tr2799:
	{
		s->number64_tmp = s->number64;
	}
	{
		if (s->decimal_counter == 0 && s->number64 < UINT32_MAX) {
			s->number64 *= pow(10, s->decimals);
		} else if (s->decimal_counter <= s->decimals &&
				 s->number64_tmp < UINT32_MAX) {
			s->number64 *= pow(10, s->decimals - s->decimal_counter);
			s->number64 += s->number64_tmp * pow(10, s->decimals);
		} else {
			WARN(ZS_FLOAT_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->number64 <= 9000000000ULL) {
			s->loc.siz = s->number64;
		} else {
			WARN(ZS_BAD_NUMBER);
			p--; {goto st316;}
		}
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st964;
tr2800:
	{
		s->number64_tmp = s->number64;
	}
	{
		if (s->decimal_counter == 0 && s->number64 < UINT32_MAX) {
			s->number64 *= pow(10, s->decimals);
		} else if (s->decimal_counter <= s->decimals &&
				 s->number64_tmp < UINT32_MAX) {
			s->number64 *= pow(10, s->decimals - s->decimal_counter);
			s->number64 += s->number64_tmp * pow(10, s->decimals);
		} else {
			WARN(ZS_FLOAT_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->number64 <= 9000000000ULL) {
			s->loc.siz = s->number64;
		} else {
			WARN(ZS_BAD_NUMBER);
			p--; {goto st316;}
		}
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st964;
tr2803:
	{
		s->number64_tmp = s->number64;
	}
	{
		if (s->decimal_counter == 0 && s->number64 < UINT32_MAX) {
			s->number64 *= pow(10, s->decimals);
		} else if (s->decimal_counter <= s->decimals &&
				 s->number64_tmp < UINT32_MAX) {
			s->number64 *= pow(10, s->decimals - s->decimal_counter);
			s->number64 += s->number64_tmp * pow(10, s->decimals);
		} else {
			WARN(ZS_FLOAT_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->number64 <= 9000000000ULL) {
			s->loc.siz = s->number64;
		} else {
			WARN(ZS_BAD_NUMBER);
			p--; {goto st316;}
		}
	}
	{
		s->line_counter++;
	}
	goto st964;
st964:
	if ( ++p == pe )
		goto _test_eof964;
case 964:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(2688 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 !s->multiline  ) _widec += 512;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(2688 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		if (
 !s->multiline  ) _widec += 512;
	}
	switch( _widec ) {
		case 9: goto st964;
		case 32: goto st964;
		case 40: goto tr2728;
		case 41: goto tr2729;
		case 3082: goto tr2731;
		case 3131: goto tr2732;
		case 3338: goto tr2713;
		case 3387: goto tr2713;
		case 3594: goto tr2733;
		case 3643: goto tr2734;
	}
	if ( 48 <= _widec && _widec <= 57 )
		goto tr2730;
	goto tr2604;
tr2739:
	{
		// Overflow check: 10*(s->number64) + fc - '0' <= UINT64_MAX
		if ((s->number64 < (UINT64_MAX / 10)) ||   // Dominant fast check.
			((s->number64 == (UINT64_MAX / 10)) && // Marginal case.
			 ((uint8_t)(*p) <= (UINT64_MAX % 10) + '0')
			)
		   ) {
			s->number64 *= 10;
			s->number64 += digit_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_NUMBER64_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st965;
tr2730:
	{
		s->decimals = 2;
	}
	{
		s->decimal_counter = 0;
	}
	{
		s->number64 = 0;
	}
	{
		// Overflow check: 10*(s->number64) + fc - '0' <= UINT64_MAX
		if ((s->number64 < (UINT64_MAX / 10)) ||   // Dominant fast check.
			((s->number64 == (UINT64_MAX / 10)) && // Marginal case.
			 ((uint8_t)(*p) <= (UINT64_MAX % 10) + '0')
			)
		   ) {
			s->number64 *= 10;
			s->number64 += digit_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_NUMBER64_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st965;
st965:
	if ( ++p == pe )
		goto _test_eof965;
case 965:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(2688 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 !s->multiline  ) _widec += 512;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(2688 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		if (
 !s->multiline  ) _widec += 512;
	}
	switch( _widec ) {
		case 9: goto tr2735;
		case 32: goto tr2735;
		case 40: goto tr2736;
		case 41: goto tr2737;
		case 46: goto st973;
		case 109: goto tr2740;
		case 3082: goto tr2741;
		case 3131: goto tr2742;
		case 3338: goto tr2743;
		case 3387: goto tr2743;
		case 3594: goto tr2744;
		case 3643: goto tr2745;
	}
	if ( 48 <= _widec && _widec <= 57 )
		goto tr2739;
	goto tr2604;
tr2747:
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st966;
tr2748:
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st966;
tr2750:
	{
		s->line_counter++;
	}
	goto st966;
tr2784:
	{
		s->buffer[s->buffer_length++] = 0;

		// Execute the comment callback.
		if (s->process.automatic && s->process.comment != NULL) {
			s->process.comment(s);

			// Stop if required from the callback.
			if (s->state == ZS_STATE_STOP) {
				{p++; cs = 966; goto _out;}
			}
		}
	}
	{
		s->line_counter++;
	}
	goto st966;
tr2735:
	{
		if (s->decimal_counter == 0 && s->number64 < UINT32_MAX) {
			s->number64 *= pow(10, s->decimals);
		} else if (s->decimal_counter <= s->decimals &&
				 s->number64_tmp < UINT32_MAX) {
			s->number64 *= pow(10, s->decimals - s->decimal_counter);
			s->number64 += s->number64_tmp * pow(10, s->decimals);
		} else {
			WARN(ZS_FLOAT_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->number64 <= 9000000000ULL) {
			s->loc.hp = s->number64;
		} else {
			WARN(ZS_BAD_NUMBER);
			p--; {goto st316;}
		}
	}
	goto st966;
tr2736:
	{
		if (s->decimal_counter == 0 && s->number64 < UINT32_MAX) {
			s->number64 *= pow(10, s->decimals);
		} else if (s->decimal_counter <= s->decimals &&
				 s->number64_tmp < UINT32_MAX) {
			s->number64 *= pow(10, s->decimals - s->decimal_counter);
			s->number64 += s->number64_tmp * pow(10, s->decimals);
		} else {
			WARN(ZS_FLOAT_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->number64 <= 9000000000ULL) {
			s->loc.hp = s->number64;
		} else {
			WARN(ZS_BAD_NUMBER);
			p--; {goto st316;}
		}
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st966;
tr2737:
	{
		if (s->decimal_counter == 0 && s->number64 < UINT32_MAX) {
			s->number64 *= pow(10, s->decimals);
		} else if (s->decimal_counter <= s->decimals &&
				 s->number64_tmp < UINT32_MAX) {
			s->number64 *= pow(10, s->decimals - s->decimal_counter);
			s->number64 += s->number64_tmp * pow(10, s->decimals);
		} else {
			WARN(ZS_FLOAT_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->number64 <= 9000000000ULL) {
			s->loc.hp = s->number64;
		} else {
			WARN(ZS_BAD_NUMBER);
			p--; {goto st316;}
		}
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st966;
tr2741:
	{
		if (s->decimal_counter == 0 && s->number64 < UINT32_MAX) {
			s->number64 *= pow(10, s->decimals);
		} else if (s->decimal_counter <= s->decimals &&
				 s->number64_tmp < UINT32_MAX) {
			s->number64 *= pow(10, s->decimals - s->decimal_counter);
			s->number64 += s->number64_tmp * pow(10, s->decimals);
		} else {
			WARN(ZS_FLOAT_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->number64 <= 9000000000ULL) {
			s->loc.hp = s->number64;
		} else {
			WARN(ZS_BAD_NUMBER);
			p--; {goto st316;}
		}
	}
	{
		s->line_counter++;
	}
	goto st966;
tr2785:
	{
		s->number64_tmp = s->number64;
	}
	{
		if (s->decimal_counter == 0 && s->number64 < UINT32_MAX) {
			s->number64 *= pow(10, s->decimals);
		} else if (s->decimal_counter <= s->decimals &&
				 s->number64_tmp < UINT32_MAX) {
			s->number64 *= pow(10, s->decimals - s->decimal_counter);
			s->number64 += s->number64_tmp * pow(10, s->decimals);
		} else {
			WARN(ZS_FLOAT_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->number64 <= 9000000000ULL) {
			s->loc.hp = s->number64;
		} else {
			WARN(ZS_BAD_NUMBER);
			p--; {goto st316;}
		}
	}
	goto st966;
tr2786:
	{
		s->number64_tmp = s->number64;
	}
	{
		if (s->decimal_counter == 0 && s->number64 < UINT32_MAX) {
			s->number64 *= pow(10, s->decimals);
		} else if (s->decimal_counter <= s->decimals &&
				 s->number64_tmp < UINT32_MAX) {
			s->number64 *= pow(10, s->decimals - s->decimal_counter);
			s->number64 += s->number64_tmp * pow(10, s->decimals);
		} else {
			WARN(ZS_FLOAT_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->number64 <= 9000000000ULL) {
			s->loc.hp = s->number64;
		} else {
			WARN(ZS_BAD_NUMBER);
			p--; {goto st316;}
		}
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st966;
tr2787:
	{
		s->number64_tmp = s->number64;
	}
	{
		if (s->decimal_counter == 0 && s->number64 < UINT32_MAX) {
			s->number64 *= pow(10, s->decimals);
		} else if (s->decimal_counter <= s->decimals &&
				 s->number64_tmp < UINT32_MAX) {
			s->number64 *= pow(10, s->decimals - s->decimal_counter);
			s->number64 += s->number64_tmp * pow(10, s->decimals);
		} else {
			WARN(ZS_FLOAT_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->number64 <= 9000000000ULL) {
			s->loc.hp = s->number64;
		} else {
			WARN(ZS_BAD_NUMBER);
			p--; {goto st316;}
		}
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st966;
tr2790:
	{
		s->number64_tmp = s->number64;
	}
	{
		if (s->decimal_counter == 0 && s->number64 < UINT32_MAX) {
			s->number64 *= pow(10, s->decimals);
		} else if (s->decimal_counter <= s->decimals &&
				 s->number64_tmp < UINT32_MAX) {
			s->number64 *= pow(10, s->decimals - s->decimal_counter);
			s->number64 += s->number64_tmp * pow(10, s->decimals);
		} else {
			WARN(ZS_FLOAT_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->number64 <= 9000000000ULL) {
			s->loc.hp = s->number64;
		} else {
			WARN(ZS_BAD_NUMBER);
			p--; {goto st316;}
		}
	}
	{
		s->line_counter++;
	}
	goto st966;
st966:
	if ( ++p == pe )
		goto _test_eof966;
case 966:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(2688 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 !s->multiline  ) _widec += 512;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(2688 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		if (
 !s->multiline  ) _widec += 512;
	}
	switch( _widec ) {
		case 9: goto st966;
		case 32: goto st966;
		case 40: goto tr2747;
		case 41: goto tr2748;
		case 3082: goto tr2750;
		case 3131: goto tr2751;
		case 3338: goto tr2713;
		case 3387: goto tr2713;
		case 3594: goto tr2752;
		case 3643: goto tr2753;
	}
	if ( 48 <= _widec && _widec <= 57 )
		goto tr2749;
	goto tr2604;
tr2758:
	{
		// Overflow check: 10*(s->number64) + fc - '0' <= UINT64_MAX
		if ((s->number64 < (UINT64_MAX / 10)) ||   // Dominant fast check.
			((s->number64 == (UINT64_MAX / 10)) && // Marginal case.
			 ((uint8_t)(*p) <= (UINT64_MAX % 10) + '0')
			)
		   ) {
			s->number64 *= 10;
			s->number64 += digit_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_NUMBER64_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st967;
tr2749:
	{
		s->decimals = 2;
	}
	{
		s->decimal_counter = 0;
	}
	{
		s->number64 = 0;
	}
	{
		// Overflow check: 10*(s->number64) + fc - '0' <= UINT64_MAX
		if ((s->number64 < (UINT64_MAX / 10)) ||   // Dominant fast check.
			((s->number64 == (UINT64_MAX / 10)) && // Marginal case.
			 ((uint8_t)(*p) <= (UINT64_MAX % 10) + '0')
			)
		   ) {
			s->number64 *= 10;
			s->number64 += digit_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_NUMBER64_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st967;
st967:
	if ( ++p == pe )
		goto _test_eof967;
case 967:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(2688 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 !s->multiline  ) _widec += 512;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(2688 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		if (
 !s->multiline  ) _widec += 512;
	}
	switch( _widec ) {
		case 9: goto tr2754;
		case 32: goto tr2754;
		case 40: goto tr2755;
		case 41: goto tr2756;
		case 46: goto st970;
		case 109: goto tr2754;
		case 3082: goto tr2759;
		case 3131: goto tr2760;
		case 3338: goto tr2761;
		case 3387: goto tr2761;
		case 3594: goto tr2762;
		case 3643: goto tr2763;
	}
	if ( 48 <= _widec && _widec <= 57 )
		goto tr2758;
	goto tr2604;
tr2765:
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st968;
tr2766:
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st968;
tr2767:
	{
		s->line_counter++;
	}
	goto st968;
tr2772:
	{
		s->buffer[s->buffer_length++] = 0;

		// Execute the comment callback.
		if (s->process.automatic && s->process.comment != NULL) {
			s->process.comment(s);

			// Stop if required from the callback.
			if (s->state == ZS_STATE_STOP) {
				{p++; cs = 968; goto _out;}
			}
		}
	}
	{
		s->line_counter++;
	}
	goto st968;
tr2754:
	{
		if (s->decimal_counter == 0 && s->number64 < UINT32_MAX) {
			s->number64 *= pow(10, s->decimals);
		} else if (s->decimal_counter <= s->decimals &&
				 s->number64_tmp < UINT32_MAX) {
			s->number64 *= pow(10, s->decimals - s->decimal_counter);
			s->number64 += s->number64_tmp * pow(10, s->decimals);
		} else {
			WARN(ZS_FLOAT_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->number64 <= 9000000000ULL) {
			s->loc.vp = s->number64;
		} else {
			WARN(ZS_BAD_NUMBER);
			p--; {goto st316;}
		}
	}
	goto st968;
tr2755:
	{
		if (s->decimal_counter == 0 && s->number64 < UINT32_MAX) {
			s->number64 *= pow(10, s->decimals);
		} else if (s->decimal_counter <= s->decimals &&
				 s->number64_tmp < UINT32_MAX) {
			s->number64 *= pow(10, s->decimals - s->decimal_counter);
			s->number64 += s->number64_tmp * pow(10, s->decimals);
		} else {
			WARN(ZS_FLOAT_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->number64 <= 9000000000ULL) {
			s->loc.vp = s->number64;
		} else {
			WARN(ZS_BAD_NUMBER);
			p--; {goto st316;}
		}
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st968;
tr2756:
	{
		if (s->decimal_counter == 0 && s->number64 < UINT32_MAX) {
			s->number64 *= pow(10, s->decimals);
		} else if (s->decimal_counter <= s->decimals &&
				 s->number64_tmp < UINT32_MAX) {
			s->number64 *= pow(10, s->decimals - s->decimal_counter);
			s->number64 += s->number64_tmp * pow(10, s->decimals);
		} else {
			WARN(ZS_FLOAT_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->number64 <= 9000000000ULL) {
			s->loc.vp = s->number64;
		} else {
			WARN(ZS_BAD_NUMBER);
			p--; {goto st316;}
		}
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st968;
tr2759:
	{
		if (s->decimal_counter == 0 && s->number64 < UINT32_MAX) {
			s->number64 *= pow(10, s->decimals);
		} else if (s->decimal_counter <= s->decimals &&
				 s->number64_tmp < UINT32_MAX) {
			s->number64 *= pow(10, s->decimals - s->decimal_counter);
			s->number64 += s->number64_tmp * pow(10, s->decimals);
		} else {
			WARN(ZS_FLOAT_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->number64 <= 9000000000ULL) {
			s->loc.vp = s->number64;
		} else {
			WARN(ZS_BAD_NUMBER);
			p--; {goto st316;}
		}
	}
	{
		s->line_counter++;
	}
	goto st968;
tr2773:
	{
		s->number64_tmp = s->number64;
	}
	{
		if (s->decimal_counter == 0 && s->number64 < UINT32_MAX) {
			s->number64 *= pow(10, s->decimals);
		} else if (s->decimal_counter <= s->decimals &&
				 s->number64_tmp < UINT32_MAX) {
			s->number64 *= pow(10, s->decimals - s->decimal_counter);
			s->number64 += s->number64_tmp * pow(10, s->decimals);
		} else {
			WARN(ZS_FLOAT_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->number64 <= 9000000000ULL) {
			s->loc.vp = s->number64;
		} else {
			WARN(ZS_BAD_NUMBER);
			p--; {goto st316;}
		}
	}
	goto st968;
tr2774:
	{
		s->number64_tmp = s->number64;
	}
	{
		if (s->decimal_counter == 0 && s->number64 < UINT32_MAX) {
			s->number64 *= pow(10, s->decimals);
		} else if (s->decimal_counter <= s->decimals &&
				 s->number64_tmp < UINT32_MAX) {
			s->number64 *= pow(10, s->decimals - s->decimal_counter);
			s->number64 += s->number64_tmp * pow(10, s->decimals);
		} else {
			WARN(ZS_FLOAT_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->number64 <= 9000000000ULL) {
			s->loc.vp = s->number64;
		} else {
			WARN(ZS_BAD_NUMBER);
			p--; {goto st316;}
		}
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st968;
tr2775:
	{
		s->number64_tmp = s->number64;
	}
	{
		if (s->decimal_counter == 0 && s->number64 < UINT32_MAX) {
			s->number64 *= pow(10, s->decimals);
		} else if (s->decimal_counter <= s->decimals &&
				 s->number64_tmp < UINT32_MAX) {
			s->number64 *= pow(10, s->decimals - s->decimal_counter);
			s->number64 += s->number64_tmp * pow(10, s->decimals);
		} else {
			WARN(ZS_FLOAT_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->number64 <= 9000000000ULL) {
			s->loc.vp = s->number64;
		} else {
			WARN(ZS_BAD_NUMBER);
			p--; {goto st316;}
		}
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st968;
tr2777:
	{
		s->number64_tmp = s->number64;
	}
	{
		if (s->decimal_counter == 0 && s->number64 < UINT32_MAX) {
			s->number64 *= pow(10, s->decimals);
		} else if (s->decimal_counter <= s->decimals &&
				 s->number64_tmp < UINT32_MAX) {
			s->number64 *= pow(10, s->decimals - s->decimal_counter);
			s->number64 += s->number64_tmp * pow(10, s->decimals);
		} else {
			WARN(ZS_FLOAT_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->number64 <= 9000000000ULL) {
			s->loc.vp = s->number64;
		} else {
			WARN(ZS_BAD_NUMBER);
			p--; {goto st316;}
		}
	}
	{
		s->line_counter++;
	}
	goto st968;
st968:
	if ( ++p == pe )
		goto _test_eof968;
case 968:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(2688 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 !s->multiline  ) _widec += 512;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(2688 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		if (
 !s->multiline  ) _widec += 512;
	}
	switch( _widec ) {
		case 9: goto st968;
		case 32: goto st968;
		case 40: goto tr2765;
		case 41: goto tr2766;
		case 3082: goto tr2767;
		case 3131: goto tr2768;
		case 3338: goto tr2713;
		case 3387: goto tr2713;
		case 3594: goto tr2769;
		case 3643: goto tr2770;
	}
	goto tr2604;
tr2768:
	{
		s->buffer_length = 0;
	}
	goto st969;
tr2771:
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		}
	}
	goto st969;
tr2760:
	{
		if (s->decimal_counter == 0 && s->number64 < UINT32_MAX) {
			s->number64 *= pow(10, s->decimals);
		} else if (s->decimal_counter <= s->decimals &&
				 s->number64_tmp < UINT32_MAX) {
			s->number64 *= pow(10, s->decimals - s->decimal_counter);
			s->number64 += s->number64_tmp * pow(10, s->decimals);
		} else {
			WARN(ZS_FLOAT_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->number64 <= 9000000000ULL) {
			s->loc.vp = s->number64;
		} else {
			WARN(ZS_BAD_NUMBER);
			p--; {goto st316;}
		}
	}
	{
		s->buffer_length = 0;
	}
	goto st969;
tr2778:
	{
		s->number64_tmp = s->number64;
	}
	{
		if (s->decimal_counter == 0 && s->number64 < UINT32_MAX) {
			s->number64 *= pow(10, s->decimals);
		} else if (s->decimal_counter <= s->decimals &&
				 s->number64_tmp < UINT32_MAX) {
			s->number64 *= pow(10, s->decimals - s->decimal_counter);
			s->number64 += s->number64_tmp * pow(10, s->decimals);
		} else {
			WARN(ZS_FLOAT_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->number64 <= 9000000000ULL) {
			s->loc.vp = s->number64;
		} else {
			WARN(ZS_BAD_NUMBER);
			p--; {goto st316;}
		}
	}
	{
		s->buffer_length = 0;
	}
	goto st969;
st969:
	if ( ++p == pe )
		goto _test_eof969;
case 969:
	_widec = (*p);
	if ( (*p) < 10 ) {
		if ( (*p) <= 9 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) > 10 ) {
		if ( 11 <= (*p) )
 {			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	if ( _widec == 2058 )
		goto tr2772;
	if ( 1920 <= _widec && _widec <= 2175 )
		goto tr2771;
	goto tr2604;
tr2704:
	{
		if (s->decimal_counter == 0 && s->number64 < UINT32_MAX) {
			s->number64 *= pow(10, s->decimals);
		} else if (s->decimal_counter <= s->decimals &&
				 s->number64_tmp < UINT32_MAX) {
			s->number64 *= pow(10, s->decimals - s->decimal_counter);
			s->number64 += s->number64_tmp * pow(10, s->decimals);
		} else {
			WARN(ZS_FLOAT_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if ((s->loc.alt_sign ==  1 && s->number64 <= 4284967295) ||
		    (s->loc.alt_sign == -1 && s->number64 <=   10000000))
		{
			s->loc.alt = (uint32_t)(s->number64);
		} else {
			WARN(ZS_BAD_NUMBER);
			p--; {goto st316;}
		}
	}
	{
		// Write version.
		*(rdata_tail) = 0;
		rdata_tail += 1;
		// Write size.
		*(rdata_tail) = loc64to8(s->loc.siz);
		rdata_tail += 1;
		// Write horizontal precision.
		*(rdata_tail) = loc64to8(s->loc.hp);
		rdata_tail += 1;
		// Write vertical precision.
		*(rdata_tail) = loc64to8(s->loc.vp);
		rdata_tail += 1;
		// Write latitude.
		*((uint32_t *)rdata_tail) = htonl(LOC_LAT_ZERO + s->loc.lat_sign *
			(3600000 * s->loc.d1 + 60000 * s->loc.m1 + s->loc.s1));
		rdata_tail += 4;
		// Write longitude.
		*((uint32_t *)rdata_tail) = htonl(LOC_LONG_ZERO + s->loc.long_sign *
			(3600000 * s->loc.d2 + 60000 * s->loc.m2 + s->loc.s2));
		rdata_tail += 4;
		// Write altitude.
		*((uint32_t *)rdata_tail) = htonl(LOC_ALT_ZERO + s->loc.alt_sign *
			(s->loc.alt));
		rdata_tail += 4;
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1493;
tr2713:
	{
		// Write version.
		*(rdata_tail) = 0;
		rdata_tail += 1;
		// Write size.
		*(rdata_tail) = loc64to8(s->loc.siz);
		rdata_tail += 1;
		// Write horizontal precision.
		*(rdata_tail) = loc64to8(s->loc.hp);
		rdata_tail += 1;
		// Write vertical precision.
		*(rdata_tail) = loc64to8(s->loc.vp);
		rdata_tail += 1;
		// Write latitude.
		*((uint32_t *)rdata_tail) = htonl(LOC_LAT_ZERO + s->loc.lat_sign *
			(3600000 * s->loc.d1 + 60000 * s->loc.m1 + s->loc.s1));
		rdata_tail += 4;
		// Write longitude.
		*((uint32_t *)rdata_tail) = htonl(LOC_LONG_ZERO + s->loc.long_sign *
			(3600000 * s->loc.d2 + 60000 * s->loc.m2 + s->loc.s2));
		rdata_tail += 4;
		// Write altitude.
		*((uint32_t *)rdata_tail) = htonl(LOC_ALT_ZERO + s->loc.alt_sign *
			(s->loc.alt));
		rdata_tail += 4;
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1493;
tr2724:
	{
		if (s->decimal_counter == 0 && s->number64 < UINT32_MAX) {
			s->number64 *= pow(10, s->decimals);
		} else if (s->decimal_counter <= s->decimals &&
				 s->number64_tmp < UINT32_MAX) {
			s->number64 *= pow(10, s->decimals - s->decimal_counter);
			s->number64 += s->number64_tmp * pow(10, s->decimals);
		} else {
			WARN(ZS_FLOAT_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->number64 <= 9000000000ULL) {
			s->loc.siz = s->number64;
		} else {
			WARN(ZS_BAD_NUMBER);
			p--; {goto st316;}
		}
	}
	{
		// Write version.
		*(rdata_tail) = 0;
		rdata_tail += 1;
		// Write size.
		*(rdata_tail) = loc64to8(s->loc.siz);
		rdata_tail += 1;
		// Write horizontal precision.
		*(rdata_tail) = loc64to8(s->loc.hp);
		rdata_tail += 1;
		// Write vertical precision.
		*(rdata_tail) = loc64to8(s->loc.vp);
		rdata_tail += 1;
		// Write latitude.
		*((uint32_t *)rdata_tail) = htonl(LOC_LAT_ZERO + s->loc.lat_sign *
			(3600000 * s->loc.d1 + 60000 * s->loc.m1 + s->loc.s1));
		rdata_tail += 4;
		// Write longitude.
		*((uint32_t *)rdata_tail) = htonl(LOC_LONG_ZERO + s->loc.long_sign *
			(3600000 * s->loc.d2 + 60000 * s->loc.m2 + s->loc.s2));
		rdata_tail += 4;
		// Write altitude.
		*((uint32_t *)rdata_tail) = htonl(LOC_ALT_ZERO + s->loc.alt_sign *
			(s->loc.alt));
		rdata_tail += 4;
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1493;
tr2743:
	{
		if (s->decimal_counter == 0 && s->number64 < UINT32_MAX) {
			s->number64 *= pow(10, s->decimals);
		} else if (s->decimal_counter <= s->decimals &&
				 s->number64_tmp < UINT32_MAX) {
			s->number64 *= pow(10, s->decimals - s->decimal_counter);
			s->number64 += s->number64_tmp * pow(10, s->decimals);
		} else {
			WARN(ZS_FLOAT_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->number64 <= 9000000000ULL) {
			s->loc.hp = s->number64;
		} else {
			WARN(ZS_BAD_NUMBER);
			p--; {goto st316;}
		}
	}
	{
		// Write version.
		*(rdata_tail) = 0;
		rdata_tail += 1;
		// Write size.
		*(rdata_tail) = loc64to8(s->loc.siz);
		rdata_tail += 1;
		// Write horizontal precision.
		*(rdata_tail) = loc64to8(s->loc.hp);
		rdata_tail += 1;
		// Write vertical precision.
		*(rdata_tail) = loc64to8(s->loc.vp);
		rdata_tail += 1;
		// Write latitude.
		*((uint32_t *)rdata_tail) = htonl(LOC_LAT_ZERO + s->loc.lat_sign *
			(3600000 * s->loc.d1 + 60000 * s->loc.m1 + s->loc.s1));
		rdata_tail += 4;
		// Write longitude.
		*((uint32_t *)rdata_tail) = htonl(LOC_LONG_ZERO + s->loc.long_sign *
			(3600000 * s->loc.d2 + 60000 * s->loc.m2 + s->loc.s2));
		rdata_tail += 4;
		// Write altitude.
		*((uint32_t *)rdata_tail) = htonl(LOC_ALT_ZERO + s->loc.alt_sign *
			(s->loc.alt));
		rdata_tail += 4;
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1493;
tr2761:
	{
		if (s->decimal_counter == 0 && s->number64 < UINT32_MAX) {
			s->number64 *= pow(10, s->decimals);
		} else if (s->decimal_counter <= s->decimals &&
				 s->number64_tmp < UINT32_MAX) {
			s->number64 *= pow(10, s->decimals - s->decimal_counter);
			s->number64 += s->number64_tmp * pow(10, s->decimals);
		} else {
			WARN(ZS_FLOAT_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->number64 <= 9000000000ULL) {
			s->loc.vp = s->number64;
		} else {
			WARN(ZS_BAD_NUMBER);
			p--; {goto st316;}
		}
	}
	{
		// Write version.
		*(rdata_tail) = 0;
		rdata_tail += 1;
		// Write size.
		*(rdata_tail) = loc64to8(s->loc.siz);
		rdata_tail += 1;
		// Write horizontal precision.
		*(rdata_tail) = loc64to8(s->loc.hp);
		rdata_tail += 1;
		// Write vertical precision.
		*(rdata_tail) = loc64to8(s->loc.vp);
		rdata_tail += 1;
		// Write latitude.
		*((uint32_t *)rdata_tail) = htonl(LOC_LAT_ZERO + s->loc.lat_sign *
			(3600000 * s->loc.d1 + 60000 * s->loc.m1 + s->loc.s1));
		rdata_tail += 4;
		// Write longitude.
		*((uint32_t *)rdata_tail) = htonl(LOC_LONG_ZERO + s->loc.long_sign *
			(3600000 * s->loc.d2 + 60000 * s->loc.m2 + s->loc.s2));
		rdata_tail += 4;
		// Write altitude.
		*((uint32_t *)rdata_tail) = htonl(LOC_ALT_ZERO + s->loc.alt_sign *
			(s->loc.alt));
		rdata_tail += 4;
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1493;
tr2779:
	{
		s->number64_tmp = s->number64;
	}
	{
		if (s->decimal_counter == 0 && s->number64 < UINT32_MAX) {
			s->number64 *= pow(10, s->decimals);
		} else if (s->decimal_counter <= s->decimals &&
				 s->number64_tmp < UINT32_MAX) {
			s->number64 *= pow(10, s->decimals - s->decimal_counter);
			s->number64 += s->number64_tmp * pow(10, s->decimals);
		} else {
			WARN(ZS_FLOAT_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->number64 <= 9000000000ULL) {
			s->loc.vp = s->number64;
		} else {
			WARN(ZS_BAD_NUMBER);
			p--; {goto st316;}
		}
	}
	{
		// Write version.
		*(rdata_tail) = 0;
		rdata_tail += 1;
		// Write size.
		*(rdata_tail) = loc64to8(s->loc.siz);
		rdata_tail += 1;
		// Write horizontal precision.
		*(rdata_tail) = loc64to8(s->loc.hp);
		rdata_tail += 1;
		// Write vertical precision.
		*(rdata_tail) = loc64to8(s->loc.vp);
		rdata_tail += 1;
		// Write latitude.
		*((uint32_t *)rdata_tail) = htonl(LOC_LAT_ZERO + s->loc.lat_sign *
			(3600000 * s->loc.d1 + 60000 * s->loc.m1 + s->loc.s1));
		rdata_tail += 4;
		// Write longitude.
		*((uint32_t *)rdata_tail) = htonl(LOC_LONG_ZERO + s->loc.long_sign *
			(3600000 * s->loc.d2 + 60000 * s->loc.m2 + s->loc.s2));
		rdata_tail += 4;
		// Write altitude.
		*((uint32_t *)rdata_tail) = htonl(LOC_ALT_ZERO + s->loc.alt_sign *
			(s->loc.alt));
		rdata_tail += 4;
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1493;
tr2792:
	{
		s->number64_tmp = s->number64;
	}
	{
		if (s->decimal_counter == 0 && s->number64 < UINT32_MAX) {
			s->number64 *= pow(10, s->decimals);
		} else if (s->decimal_counter <= s->decimals &&
				 s->number64_tmp < UINT32_MAX) {
			s->number64 *= pow(10, s->decimals - s->decimal_counter);
			s->number64 += s->number64_tmp * pow(10, s->decimals);
		} else {
			WARN(ZS_FLOAT_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->number64 <= 9000000000ULL) {
			s->loc.hp = s->number64;
		} else {
			WARN(ZS_BAD_NUMBER);
			p--; {goto st316;}
		}
	}
	{
		// Write version.
		*(rdata_tail) = 0;
		rdata_tail += 1;
		// Write size.
		*(rdata_tail) = loc64to8(s->loc.siz);
		rdata_tail += 1;
		// Write horizontal precision.
		*(rdata_tail) = loc64to8(s->loc.hp);
		rdata_tail += 1;
		// Write vertical precision.
		*(rdata_tail) = loc64to8(s->loc.vp);
		rdata_tail += 1;
		// Write latitude.
		*((uint32_t *)rdata_tail) = htonl(LOC_LAT_ZERO + s->loc.lat_sign *
			(3600000 * s->loc.d1 + 60000 * s->loc.m1 + s->loc.s1));
		rdata_tail += 4;
		// Write longitude.
		*((uint32_t *)rdata_tail) = htonl(LOC_LONG_ZERO + s->loc.long_sign *
			(3600000 * s->loc.d2 + 60000 * s->loc.m2 + s->loc.s2));
		rdata_tail += 4;
		// Write altitude.
		*((uint32_t *)rdata_tail) = htonl(LOC_ALT_ZERO + s->loc.alt_sign *
			(s->loc.alt));
		rdata_tail += 4;
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1493;
tr2805:
	{
		s->number64_tmp = s->number64;
	}
	{
		if (s->decimal_counter == 0 && s->number64 < UINT32_MAX) {
			s->number64 *= pow(10, s->decimals);
		} else if (s->decimal_counter <= s->decimals &&
				 s->number64_tmp < UINT32_MAX) {
			s->number64 *= pow(10, s->decimals - s->decimal_counter);
			s->number64 += s->number64_tmp * pow(10, s->decimals);
		} else {
			WARN(ZS_FLOAT_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->number64 <= 9000000000ULL) {
			s->loc.siz = s->number64;
		} else {
			WARN(ZS_BAD_NUMBER);
			p--; {goto st316;}
		}
	}
	{
		// Write version.
		*(rdata_tail) = 0;
		rdata_tail += 1;
		// Write size.
		*(rdata_tail) = loc64to8(s->loc.siz);
		rdata_tail += 1;
		// Write horizontal precision.
		*(rdata_tail) = loc64to8(s->loc.hp);
		rdata_tail += 1;
		// Write vertical precision.
		*(rdata_tail) = loc64to8(s->loc.vp);
		rdata_tail += 1;
		// Write latitude.
		*((uint32_t *)rdata_tail) = htonl(LOC_LAT_ZERO + s->loc.lat_sign *
			(3600000 * s->loc.d1 + 60000 * s->loc.m1 + s->loc.s1));
		rdata_tail += 4;
		// Write longitude.
		*((uint32_t *)rdata_tail) = htonl(LOC_LONG_ZERO + s->loc.long_sign *
			(3600000 * s->loc.d2 + 60000 * s->loc.m2 + s->loc.s2));
		rdata_tail += 4;
		// Write altitude.
		*((uint32_t *)rdata_tail) = htonl(LOC_ALT_ZERO + s->loc.alt_sign *
			(s->loc.alt));
		rdata_tail += 4;
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1493;
tr2818:
	{
		s->number64_tmp = s->number64;
	}
	{
		if (s->decimal_counter == 0 && s->number64 < UINT32_MAX) {
			s->number64 *= pow(10, s->decimals);
		} else if (s->decimal_counter <= s->decimals &&
				 s->number64_tmp < UINT32_MAX) {
			s->number64 *= pow(10, s->decimals - s->decimal_counter);
			s->number64 += s->number64_tmp * pow(10, s->decimals);
		} else {
			WARN(ZS_FLOAT_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if ((s->loc.alt_sign ==  1 && s->number64 <= 4284967295) ||
		    (s->loc.alt_sign == -1 && s->number64 <=   10000000))
		{
			s->loc.alt = (uint32_t)(s->number64);
		} else {
			WARN(ZS_BAD_NUMBER);
			p--; {goto st316;}
		}
	}
	{
		// Write version.
		*(rdata_tail) = 0;
		rdata_tail += 1;
		// Write size.
		*(rdata_tail) = loc64to8(s->loc.siz);
		rdata_tail += 1;
		// Write horizontal precision.
		*(rdata_tail) = loc64to8(s->loc.hp);
		rdata_tail += 1;
		// Write vertical precision.
		*(rdata_tail) = loc64to8(s->loc.vp);
		rdata_tail += 1;
		// Write latitude.
		*((uint32_t *)rdata_tail) = htonl(LOC_LAT_ZERO + s->loc.lat_sign *
			(3600000 * s->loc.d1 + 60000 * s->loc.m1 + s->loc.s1));
		rdata_tail += 4;
		// Write longitude.
		*((uint32_t *)rdata_tail) = htonl(LOC_LONG_ZERO + s->loc.long_sign *
			(3600000 * s->loc.d2 + 60000 * s->loc.m2 + s->loc.s2));
		rdata_tail += 4;
		// Write altitude.
		*((uint32_t *)rdata_tail) = htonl(LOC_ALT_ZERO + s->loc.alt_sign *
			(s->loc.alt));
		rdata_tail += 4;
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1493;
st1493:
	if ( ++p == pe )
		goto _test_eof1493;
case 1493:
	goto st0;
tr2769:
	{
		s->line_counter++;
	}
	{
		// Write version.
		*(rdata_tail) = 0;
		rdata_tail += 1;
		// Write size.
		*(rdata_tail) = loc64to8(s->loc.siz);
		rdata_tail += 1;
		// Write horizontal precision.
		*(rdata_tail) = loc64to8(s->loc.hp);
		rdata_tail += 1;
		// Write vertical precision.
		*(rdata_tail) = loc64to8(s->loc.vp);
		rdata_tail += 1;
		// Write latitude.
		*((uint32_t *)rdata_tail) = htonl(LOC_LAT_ZERO + s->loc.lat_sign *
			(3600000 * s->loc.d1 + 60000 * s->loc.m1 + s->loc.s1));
		rdata_tail += 4;
		// Write longitude.
		*((uint32_t *)rdata_tail) = htonl(LOC_LONG_ZERO + s->loc.long_sign *
			(3600000 * s->loc.d2 + 60000 * s->loc.m2 + s->loc.s2));
		rdata_tail += 4;
		// Write altitude.
		*((uint32_t *)rdata_tail) = htonl(LOC_ALT_ZERO + s->loc.alt_sign *
			(s->loc.alt));
		rdata_tail += 4;
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1494;
tr2762:
	{
		if (s->decimal_counter == 0 && s->number64 < UINT32_MAX) {
			s->number64 *= pow(10, s->decimals);
		} else if (s->decimal_counter <= s->decimals &&
				 s->number64_tmp < UINT32_MAX) {
			s->number64 *= pow(10, s->decimals - s->decimal_counter);
			s->number64 += s->number64_tmp * pow(10, s->decimals);
		} else {
			WARN(ZS_FLOAT_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->number64 <= 9000000000ULL) {
			s->loc.vp = s->number64;
		} else {
			WARN(ZS_BAD_NUMBER);
			p--; {goto st316;}
		}
	}
	{
		s->line_counter++;
	}
	{
		// Write version.
		*(rdata_tail) = 0;
		rdata_tail += 1;
		// Write size.
		*(rdata_tail) = loc64to8(s->loc.siz);
		rdata_tail += 1;
		// Write horizontal precision.
		*(rdata_tail) = loc64to8(s->loc.hp);
		rdata_tail += 1;
		// Write vertical precision.
		*(rdata_tail) = loc64to8(s->loc.vp);
		rdata_tail += 1;
		// Write latitude.
		*((uint32_t *)rdata_tail) = htonl(LOC_LAT_ZERO + s->loc.lat_sign *
			(3600000 * s->loc.d1 + 60000 * s->loc.m1 + s->loc.s1));
		rdata_tail += 4;
		// Write longitude.
		*((uint32_t *)rdata_tail) = htonl(LOC_LONG_ZERO + s->loc.long_sign *
			(3600000 * s->loc.d2 + 60000 * s->loc.m2 + s->loc.s2));
		rdata_tail += 4;
		// Write altitude.
		*((uint32_t *)rdata_tail) = htonl(LOC_ALT_ZERO + s->loc.alt_sign *
			(s->loc.alt));
		rdata_tail += 4;
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1494;
tr2780:
	{
		s->number64_tmp = s->number64;
	}
	{
		if (s->decimal_counter == 0 && s->number64 < UINT32_MAX) {
			s->number64 *= pow(10, s->decimals);
		} else if (s->decimal_counter <= s->decimals &&
				 s->number64_tmp < UINT32_MAX) {
			s->number64 *= pow(10, s->decimals - s->decimal_counter);
			s->number64 += s->number64_tmp * pow(10, s->decimals);
		} else {
			WARN(ZS_FLOAT_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->number64 <= 9000000000ULL) {
			s->loc.vp = s->number64;
		} else {
			WARN(ZS_BAD_NUMBER);
			p--; {goto st316;}
		}
	}
	{
		s->line_counter++;
	}
	{
		// Write version.
		*(rdata_tail) = 0;
		rdata_tail += 1;
		// Write size.
		*(rdata_tail) = loc64to8(s->loc.siz);
		rdata_tail += 1;
		// Write horizontal precision.
		*(rdata_tail) = loc64to8(s->loc.hp);
		rdata_tail += 1;
		// Write vertical precision.
		*(rdata_tail) = loc64to8(s->loc.vp);
		rdata_tail += 1;
		// Write latitude.
		*((uint32_t *)rdata_tail) = htonl(LOC_LAT_ZERO + s->loc.lat_sign *
			(3600000 * s->loc.d1 + 60000 * s->loc.m1 + s->loc.s1));
		rdata_tail += 4;
		// Write longitude.
		*((uint32_t *)rdata_tail) = htonl(LOC_LONG_ZERO + s->loc.long_sign *
			(3600000 * s->loc.d2 + 60000 * s->loc.m2 + s->loc.s2));
		rdata_tail += 4;
		// Write altitude.
		*((uint32_t *)rdata_tail) = htonl(LOC_ALT_ZERO + s->loc.alt_sign *
			(s->loc.alt));
		rdata_tail += 4;
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1494;
st1494:
	if ( ++p == pe )
		goto _test_eof1494;
case 1494:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(2688 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 !s->multiline  ) _widec += 512;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(2688 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		if (
 !s->multiline  ) _widec += 512;
	}
	switch( _widec ) {
		case 9: goto st968;
		case 32: goto st968;
		case 40: goto tr2765;
		case 41: goto tr2766;
		case 3082: goto tr2767;
		case 3131: goto tr2768;
		case 3338: goto tr2713;
		case 3387: goto tr2713;
		case 3594: goto tr2769;
		case 3643: goto tr2770;
	}
	goto tr2604;
tr2770:
	{
		s->buffer_length = 0;
	}
	{
		// Write version.
		*(rdata_tail) = 0;
		rdata_tail += 1;
		// Write size.
		*(rdata_tail) = loc64to8(s->loc.siz);
		rdata_tail += 1;
		// Write horizontal precision.
		*(rdata_tail) = loc64to8(s->loc.hp);
		rdata_tail += 1;
		// Write vertical precision.
		*(rdata_tail) = loc64to8(s->loc.vp);
		rdata_tail += 1;
		// Write latitude.
		*((uint32_t *)rdata_tail) = htonl(LOC_LAT_ZERO + s->loc.lat_sign *
			(3600000 * s->loc.d1 + 60000 * s->loc.m1 + s->loc.s1));
		rdata_tail += 4;
		// Write longitude.
		*((uint32_t *)rdata_tail) = htonl(LOC_LONG_ZERO + s->loc.long_sign *
			(3600000 * s->loc.d2 + 60000 * s->loc.m2 + s->loc.s2));
		rdata_tail += 4;
		// Write altitude.
		*((uint32_t *)rdata_tail) = htonl(LOC_ALT_ZERO + s->loc.alt_sign *
			(s->loc.alt));
		rdata_tail += 4;
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1495;
tr2763:
	{
		if (s->decimal_counter == 0 && s->number64 < UINT32_MAX) {
			s->number64 *= pow(10, s->decimals);
		} else if (s->decimal_counter <= s->decimals &&
				 s->number64_tmp < UINT32_MAX) {
			s->number64 *= pow(10, s->decimals - s->decimal_counter);
			s->number64 += s->number64_tmp * pow(10, s->decimals);
		} else {
			WARN(ZS_FLOAT_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->number64 <= 9000000000ULL) {
			s->loc.vp = s->number64;
		} else {
			WARN(ZS_BAD_NUMBER);
			p--; {goto st316;}
		}
	}
	{
		s->buffer_length = 0;
	}
	{
		// Write version.
		*(rdata_tail) = 0;
		rdata_tail += 1;
		// Write size.
		*(rdata_tail) = loc64to8(s->loc.siz);
		rdata_tail += 1;
		// Write horizontal precision.
		*(rdata_tail) = loc64to8(s->loc.hp);
		rdata_tail += 1;
		// Write vertical precision.
		*(rdata_tail) = loc64to8(s->loc.vp);
		rdata_tail += 1;
		// Write latitude.
		*((uint32_t *)rdata_tail) = htonl(LOC_LAT_ZERO + s->loc.lat_sign *
			(3600000 * s->loc.d1 + 60000 * s->loc.m1 + s->loc.s1));
		rdata_tail += 4;
		// Write longitude.
		*((uint32_t *)rdata_tail) = htonl(LOC_LONG_ZERO + s->loc.long_sign *
			(3600000 * s->loc.d2 + 60000 * s->loc.m2 + s->loc.s2));
		rdata_tail += 4;
		// Write altitude.
		*((uint32_t *)rdata_tail) = htonl(LOC_ALT_ZERO + s->loc.alt_sign *
			(s->loc.alt));
		rdata_tail += 4;
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1495;
tr2781:
	{
		s->number64_tmp = s->number64;
	}
	{
		if (s->decimal_counter == 0 && s->number64 < UINT32_MAX) {
			s->number64 *= pow(10, s->decimals);
		} else if (s->decimal_counter <= s->decimals &&
				 s->number64_tmp < UINT32_MAX) {
			s->number64 *= pow(10, s->decimals - s->decimal_counter);
			s->number64 += s->number64_tmp * pow(10, s->decimals);
		} else {
			WARN(ZS_FLOAT_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->number64 <= 9000000000ULL) {
			s->loc.vp = s->number64;
		} else {
			WARN(ZS_BAD_NUMBER);
			p--; {goto st316;}
		}
	}
	{
		s->buffer_length = 0;
	}
	{
		// Write version.
		*(rdata_tail) = 0;
		rdata_tail += 1;
		// Write size.
		*(rdata_tail) = loc64to8(s->loc.siz);
		rdata_tail += 1;
		// Write horizontal precision.
		*(rdata_tail) = loc64to8(s->loc.hp);
		rdata_tail += 1;
		// Write vertical precision.
		*(rdata_tail) = loc64to8(s->loc.vp);
		rdata_tail += 1;
		// Write latitude.
		*((uint32_t *)rdata_tail) = htonl(LOC_LAT_ZERO + s->loc.lat_sign *
			(3600000 * s->loc.d1 + 60000 * s->loc.m1 + s->loc.s1));
		rdata_tail += 4;
		// Write longitude.
		*((uint32_t *)rdata_tail) = htonl(LOC_LONG_ZERO + s->loc.long_sign *
			(3600000 * s->loc.d2 + 60000 * s->loc.m2 + s->loc.s2));
		rdata_tail += 4;
		// Write altitude.
		*((uint32_t *)rdata_tail) = htonl(LOC_ALT_ZERO + s->loc.alt_sign *
			(s->loc.alt));
		rdata_tail += 4;
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1495;
st1495:
	if ( ++p == pe )
		goto _test_eof1495;
case 1495:
	_widec = (*p);
	if ( (*p) < 10 ) {
		if ( (*p) <= 9 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) > 10 ) {
		if ( 11 <= (*p) )
 {			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	if ( _widec == 2058 )
		goto tr2772;
	if ( 1920 <= _widec && _widec <= 2175 )
		goto tr2771;
	goto tr2604;
st970:
	if ( ++p == pe )
		goto _test_eof970;
case 970:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(2688 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 !s->multiline  ) _widec += 512;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(2688 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		if (
 !s->multiline  ) _widec += 512;
	}
	switch( _widec ) {
		case 9: goto tr2773;
		case 32: goto tr2773;
		case 40: goto tr2774;
		case 41: goto tr2775;
		case 109: goto tr2773;
		case 3082: goto tr2777;
		case 3131: goto tr2778;
		case 3338: goto tr2779;
		case 3387: goto tr2779;
		case 3594: goto tr2780;
		case 3643: goto tr2781;
	}
	if ( 48 <= _widec && _widec <= 57 )
		goto tr2776;
	goto tr2604;
tr2776:
	{
		s->number64_tmp = s->number64;
	}
	{
		s->number64 = 0;
	}
	{
		// Overflow check: 10*(s->number64) + fc - '0' <= UINT64_MAX
		if ((s->number64 < (UINT64_MAX / 10)) ||   // Dominant fast check.
			((s->number64 == (UINT64_MAX / 10)) && // Marginal case.
			 ((uint8_t)(*p) <= (UINT64_MAX % 10) + '0')
			)
		   ) {
			s->number64 *= 10;
			s->number64 += digit_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_NUMBER64_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		s->decimal_counter++;
	}
	goto st971;
tr2782:
	{
		// Overflow check: 10*(s->number64) + fc - '0' <= UINT64_MAX
		if ((s->number64 < (UINT64_MAX / 10)) ||   // Dominant fast check.
			((s->number64 == (UINT64_MAX / 10)) && // Marginal case.
			 ((uint8_t)(*p) <= (UINT64_MAX % 10) + '0')
			)
		   ) {
			s->number64 *= 10;
			s->number64 += digit_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_NUMBER64_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		s->decimal_counter++;
	}
	goto st971;
st971:
	if ( ++p == pe )
		goto _test_eof971;
case 971:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(2688 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 !s->multiline  ) _widec += 512;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(2688 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		if (
 !s->multiline  ) _widec += 512;
	}
	switch( _widec ) {
		case 9: goto tr2754;
		case 32: goto tr2754;
		case 40: goto tr2755;
		case 41: goto tr2756;
		case 109: goto tr2754;
		case 3082: goto tr2759;
		case 3131: goto tr2760;
		case 3338: goto tr2761;
		case 3387: goto tr2761;
		case 3594: goto tr2762;
		case 3643: goto tr2763;
	}
	if ( 48 <= _widec && _widec <= 57 )
		goto tr2782;
	goto tr2604;
tr2751:
	{
		s->buffer_length = 0;
	}
	goto st972;
tr2783:
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		}
	}
	goto st972;
tr2742:
	{
		if (s->decimal_counter == 0 && s->number64 < UINT32_MAX) {
			s->number64 *= pow(10, s->decimals);
		} else if (s->decimal_counter <= s->decimals &&
				 s->number64_tmp < UINT32_MAX) {
			s->number64 *= pow(10, s->decimals - s->decimal_counter);
			s->number64 += s->number64_tmp * pow(10, s->decimals);
		} else {
			WARN(ZS_FLOAT_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->number64 <= 9000000000ULL) {
			s->loc.hp = s->number64;
		} else {
			WARN(ZS_BAD_NUMBER);
			p--; {goto st316;}
		}
	}
	{
		s->buffer_length = 0;
	}
	goto st972;
tr2791:
	{
		s->number64_tmp = s->number64;
	}
	{
		if (s->decimal_counter == 0 && s->number64 < UINT32_MAX) {
			s->number64 *= pow(10, s->decimals);
		} else if (s->decimal_counter <= s->decimals &&
				 s->number64_tmp < UINT32_MAX) {
			s->number64 *= pow(10, s->decimals - s->decimal_counter);
			s->number64 += s->number64_tmp * pow(10, s->decimals);
		} else {
			WARN(ZS_FLOAT_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->number64 <= 9000000000ULL) {
			s->loc.hp = s->number64;
		} else {
			WARN(ZS_BAD_NUMBER);
			p--; {goto st316;}
		}
	}
	{
		s->buffer_length = 0;
	}
	goto st972;
st972:
	if ( ++p == pe )
		goto _test_eof972;
case 972:
	_widec = (*p);
	if ( (*p) < 10 ) {
		if ( (*p) <= 9 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) > 10 ) {
		if ( 11 <= (*p) )
 {			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	if ( _widec == 2058 )
		goto tr2784;
	if ( 1920 <= _widec && _widec <= 2175 )
		goto tr2783;
	goto tr2604;
tr2752:
	{
		s->line_counter++;
	}
	{
		// Write version.
		*(rdata_tail) = 0;
		rdata_tail += 1;
		// Write size.
		*(rdata_tail) = loc64to8(s->loc.siz);
		rdata_tail += 1;
		// Write horizontal precision.
		*(rdata_tail) = loc64to8(s->loc.hp);
		rdata_tail += 1;
		// Write vertical precision.
		*(rdata_tail) = loc64to8(s->loc.vp);
		rdata_tail += 1;
		// Write latitude.
		*((uint32_t *)rdata_tail) = htonl(LOC_LAT_ZERO + s->loc.lat_sign *
			(3600000 * s->loc.d1 + 60000 * s->loc.m1 + s->loc.s1));
		rdata_tail += 4;
		// Write longitude.
		*((uint32_t *)rdata_tail) = htonl(LOC_LONG_ZERO + s->loc.long_sign *
			(3600000 * s->loc.d2 + 60000 * s->loc.m2 + s->loc.s2));
		rdata_tail += 4;
		// Write altitude.
		*((uint32_t *)rdata_tail) = htonl(LOC_ALT_ZERO + s->loc.alt_sign *
			(s->loc.alt));
		rdata_tail += 4;
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1496;
tr2744:
	{
		if (s->decimal_counter == 0 && s->number64 < UINT32_MAX) {
			s->number64 *= pow(10, s->decimals);
		} else if (s->decimal_counter <= s->decimals &&
				 s->number64_tmp < UINT32_MAX) {
			s->number64 *= pow(10, s->decimals - s->decimal_counter);
			s->number64 += s->number64_tmp * pow(10, s->decimals);
		} else {
			WARN(ZS_FLOAT_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->number64 <= 9000000000ULL) {
			s->loc.hp = s->number64;
		} else {
			WARN(ZS_BAD_NUMBER);
			p--; {goto st316;}
		}
	}
	{
		s->line_counter++;
	}
	{
		// Write version.
		*(rdata_tail) = 0;
		rdata_tail += 1;
		// Write size.
		*(rdata_tail) = loc64to8(s->loc.siz);
		rdata_tail += 1;
		// Write horizontal precision.
		*(rdata_tail) = loc64to8(s->loc.hp);
		rdata_tail += 1;
		// Write vertical precision.
		*(rdata_tail) = loc64to8(s->loc.vp);
		rdata_tail += 1;
		// Write latitude.
		*((uint32_t *)rdata_tail) = htonl(LOC_LAT_ZERO + s->loc.lat_sign *
			(3600000 * s->loc.d1 + 60000 * s->loc.m1 + s->loc.s1));
		rdata_tail += 4;
		// Write longitude.
		*((uint32_t *)rdata_tail) = htonl(LOC_LONG_ZERO + s->loc.long_sign *
			(3600000 * s->loc.d2 + 60000 * s->loc.m2 + s->loc.s2));
		rdata_tail += 4;
		// Write altitude.
		*((uint32_t *)rdata_tail) = htonl(LOC_ALT_ZERO + s->loc.alt_sign *
			(s->loc.alt));
		rdata_tail += 4;
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1496;
tr2793:
	{
		s->number64_tmp = s->number64;
	}
	{
		if (s->decimal_counter == 0 && s->number64 < UINT32_MAX) {
			s->number64 *= pow(10, s->decimals);
		} else if (s->decimal_counter <= s->decimals &&
				 s->number64_tmp < UINT32_MAX) {
			s->number64 *= pow(10, s->decimals - s->decimal_counter);
			s->number64 += s->number64_tmp * pow(10, s->decimals);
		} else {
			WARN(ZS_FLOAT_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->number64 <= 9000000000ULL) {
			s->loc.hp = s->number64;
		} else {
			WARN(ZS_BAD_NUMBER);
			p--; {goto st316;}
		}
	}
	{
		s->line_counter++;
	}
	{
		// Write version.
		*(rdata_tail) = 0;
		rdata_tail += 1;
		// Write size.
		*(rdata_tail) = loc64to8(s->loc.siz);
		rdata_tail += 1;
		// Write horizontal precision.
		*(rdata_tail) = loc64to8(s->loc.hp);
		rdata_tail += 1;
		// Write vertical precision.
		*(rdata_tail) = loc64to8(s->loc.vp);
		rdata_tail += 1;
		// Write latitude.
		*((uint32_t *)rdata_tail) = htonl(LOC_LAT_ZERO + s->loc.lat_sign *
			(3600000 * s->loc.d1 + 60000 * s->loc.m1 + s->loc.s1));
		rdata_tail += 4;
		// Write longitude.
		*((uint32_t *)rdata_tail) = htonl(LOC_LONG_ZERO + s->loc.long_sign *
			(3600000 * s->loc.d2 + 60000 * s->loc.m2 + s->loc.s2));
		rdata_tail += 4;
		// Write altitude.
		*((uint32_t *)rdata_tail) = htonl(LOC_ALT_ZERO + s->loc.alt_sign *
			(s->loc.alt));
		rdata_tail += 4;
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1496;
st1496:
	if ( ++p == pe )
		goto _test_eof1496;
case 1496:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(2688 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 !s->multiline  ) _widec += 512;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(2688 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		if (
 !s->multiline  ) _widec += 512;
	}
	switch( _widec ) {
		case 9: goto st966;
		case 32: goto st966;
		case 40: goto tr2747;
		case 41: goto tr2748;
		case 3082: goto tr2750;
		case 3131: goto tr2751;
		case 3338: goto tr2713;
		case 3387: goto tr2713;
		case 3594: goto tr2752;
		case 3643: goto tr2753;
	}
	if ( 48 <= _widec && _widec <= 57 )
		goto tr2749;
	goto tr2604;
tr2753:
	{
		s->buffer_length = 0;
	}
	{
		// Write version.
		*(rdata_tail) = 0;
		rdata_tail += 1;
		// Write size.
		*(rdata_tail) = loc64to8(s->loc.siz);
		rdata_tail += 1;
		// Write horizontal precision.
		*(rdata_tail) = loc64to8(s->loc.hp);
		rdata_tail += 1;
		// Write vertical precision.
		*(rdata_tail) = loc64to8(s->loc.vp);
		rdata_tail += 1;
		// Write latitude.
		*((uint32_t *)rdata_tail) = htonl(LOC_LAT_ZERO + s->loc.lat_sign *
			(3600000 * s->loc.d1 + 60000 * s->loc.m1 + s->loc.s1));
		rdata_tail += 4;
		// Write longitude.
		*((uint32_t *)rdata_tail) = htonl(LOC_LONG_ZERO + s->loc.long_sign *
			(3600000 * s->loc.d2 + 60000 * s->loc.m2 + s->loc.s2));
		rdata_tail += 4;
		// Write altitude.
		*((uint32_t *)rdata_tail) = htonl(LOC_ALT_ZERO + s->loc.alt_sign *
			(s->loc.alt));
		rdata_tail += 4;
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1497;
tr2745:
	{
		if (s->decimal_counter == 0 && s->number64 < UINT32_MAX) {
			s->number64 *= pow(10, s->decimals);
		} else if (s->decimal_counter <= s->decimals &&
				 s->number64_tmp < UINT32_MAX) {
			s->number64 *= pow(10, s->decimals - s->decimal_counter);
			s->number64 += s->number64_tmp * pow(10, s->decimals);
		} else {
			WARN(ZS_FLOAT_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->number64 <= 9000000000ULL) {
			s->loc.hp = s->number64;
		} else {
			WARN(ZS_BAD_NUMBER);
			p--; {goto st316;}
		}
	}
	{
		s->buffer_length = 0;
	}
	{
		// Write version.
		*(rdata_tail) = 0;
		rdata_tail += 1;
		// Write size.
		*(rdata_tail) = loc64to8(s->loc.siz);
		rdata_tail += 1;
		// Write horizontal precision.
		*(rdata_tail) = loc64to8(s->loc.hp);
		rdata_tail += 1;
		// Write vertical precision.
		*(rdata_tail) = loc64to8(s->loc.vp);
		rdata_tail += 1;
		// Write latitude.
		*((uint32_t *)rdata_tail) = htonl(LOC_LAT_ZERO + s->loc.lat_sign *
			(3600000 * s->loc.d1 + 60000 * s->loc.m1 + s->loc.s1));
		rdata_tail += 4;
		// Write longitude.
		*((uint32_t *)rdata_tail) = htonl(LOC_LONG_ZERO + s->loc.long_sign *
			(3600000 * s->loc.d2 + 60000 * s->loc.m2 + s->loc.s2));
		rdata_tail += 4;
		// Write altitude.
		*((uint32_t *)rdata_tail) = htonl(LOC_ALT_ZERO + s->loc.alt_sign *
			(s->loc.alt));
		rdata_tail += 4;
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1497;
tr2794:
	{
		s->number64_tmp = s->number64;
	}
	{
		if (s->decimal_counter == 0 && s->number64 < UINT32_MAX) {
			s->number64 *= pow(10, s->decimals);
		} else if (s->decimal_counter <= s->decimals &&
				 s->number64_tmp < UINT32_MAX) {
			s->number64 *= pow(10, s->decimals - s->decimal_counter);
			s->number64 += s->number64_tmp * pow(10, s->decimals);
		} else {
			WARN(ZS_FLOAT_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->number64 <= 9000000000ULL) {
			s->loc.hp = s->number64;
		} else {
			WARN(ZS_BAD_NUMBER);
			p--; {goto st316;}
		}
	}
	{
		s->buffer_length = 0;
	}
	{
		// Write version.
		*(rdata_tail) = 0;
		rdata_tail += 1;
		// Write size.
		*(rdata_tail) = loc64to8(s->loc.siz);
		rdata_tail += 1;
		// Write horizontal precision.
		*(rdata_tail) = loc64to8(s->loc.hp);
		rdata_tail += 1;
		// Write vertical precision.
		*(rdata_tail) = loc64to8(s->loc.vp);
		rdata_tail += 1;
		// Write latitude.
		*((uint32_t *)rdata_tail) = htonl(LOC_LAT_ZERO + s->loc.lat_sign *
			(3600000 * s->loc.d1 + 60000 * s->loc.m1 + s->loc.s1));
		rdata_tail += 4;
		// Write longitude.
		*((uint32_t *)rdata_tail) = htonl(LOC_LONG_ZERO + s->loc.long_sign *
			(3600000 * s->loc.d2 + 60000 * s->loc.m2 + s->loc.s2));
		rdata_tail += 4;
		// Write altitude.
		*((uint32_t *)rdata_tail) = htonl(LOC_ALT_ZERO + s->loc.alt_sign *
			(s->loc.alt));
		rdata_tail += 4;
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1497;
st1497:
	if ( ++p == pe )
		goto _test_eof1497;
case 1497:
	_widec = (*p);
	if ( (*p) < 10 ) {
		if ( (*p) <= 9 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) > 10 ) {
		if ( 11 <= (*p) )
 {			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	if ( _widec == 2058 )
		goto tr2784;
	if ( 1920 <= _widec && _widec <= 2175 )
		goto tr2783;
	goto tr2604;
st973:
	if ( ++p == pe )
		goto _test_eof973;
case 973:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(2688 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 !s->multiline  ) _widec += 512;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(2688 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		if (
 !s->multiline  ) _widec += 512;
	}
	switch( _widec ) {
		case 9: goto tr2785;
		case 32: goto tr2785;
		case 40: goto tr2786;
		case 41: goto tr2787;
		case 109: goto tr2789;
		case 3082: goto tr2790;
		case 3131: goto tr2791;
		case 3338: goto tr2792;
		case 3387: goto tr2792;
		case 3594: goto tr2793;
		case 3643: goto tr2794;
	}
	if ( 48 <= _widec && _widec <= 57 )
		goto tr2788;
	goto tr2604;
tr2788:
	{
		s->number64_tmp = s->number64;
	}
	{
		s->number64 = 0;
	}
	{
		// Overflow check: 10*(s->number64) + fc - '0' <= UINT64_MAX
		if ((s->number64 < (UINT64_MAX / 10)) ||   // Dominant fast check.
			((s->number64 == (UINT64_MAX / 10)) && // Marginal case.
			 ((uint8_t)(*p) <= (UINT64_MAX % 10) + '0')
			)
		   ) {
			s->number64 *= 10;
			s->number64 += digit_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_NUMBER64_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		s->decimal_counter++;
	}
	goto st974;
tr2795:
	{
		// Overflow check: 10*(s->number64) + fc - '0' <= UINT64_MAX
		if ((s->number64 < (UINT64_MAX / 10)) ||   // Dominant fast check.
			((s->number64 == (UINT64_MAX / 10)) && // Marginal case.
			 ((uint8_t)(*p) <= (UINT64_MAX % 10) + '0')
			)
		   ) {
			s->number64 *= 10;
			s->number64 += digit_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_NUMBER64_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		s->decimal_counter++;
	}
	goto st974;
st974:
	if ( ++p == pe )
		goto _test_eof974;
case 974:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(2688 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 !s->multiline  ) _widec += 512;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(2688 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		if (
 !s->multiline  ) _widec += 512;
	}
	switch( _widec ) {
		case 9: goto tr2735;
		case 32: goto tr2735;
		case 40: goto tr2736;
		case 41: goto tr2737;
		case 109: goto tr2740;
		case 3082: goto tr2741;
		case 3131: goto tr2742;
		case 3338: goto tr2743;
		case 3387: goto tr2743;
		case 3594: goto tr2744;
		case 3643: goto tr2745;
	}
	if ( 48 <= _widec && _widec <= 57 )
		goto tr2795;
	goto tr2604;
tr2740:
	{
		if (s->decimal_counter == 0 && s->number64 < UINT32_MAX) {
			s->number64 *= pow(10, s->decimals);
		} else if (s->decimal_counter <= s->decimals &&
				 s->number64_tmp < UINT32_MAX) {
			s->number64 *= pow(10, s->decimals - s->decimal_counter);
			s->number64 += s->number64_tmp * pow(10, s->decimals);
		} else {
			WARN(ZS_FLOAT_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->number64 <= 9000000000ULL) {
			s->loc.hp = s->number64;
		} else {
			WARN(ZS_BAD_NUMBER);
			p--; {goto st316;}
		}
	}
	goto st975;
tr2789:
	{
		s->number64_tmp = s->number64;
	}
	{
		if (s->decimal_counter == 0 && s->number64 < UINT32_MAX) {
			s->number64 *= pow(10, s->decimals);
		} else if (s->decimal_counter <= s->decimals &&
				 s->number64_tmp < UINT32_MAX) {
			s->number64 *= pow(10, s->decimals - s->decimal_counter);
			s->number64 += s->number64_tmp * pow(10, s->decimals);
		} else {
			WARN(ZS_FLOAT_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->number64 <= 9000000000ULL) {
			s->loc.hp = s->number64;
		} else {
			WARN(ZS_BAD_NUMBER);
			p--; {goto st316;}
		}
	}
	goto st975;
st975:
	if ( ++p == pe )
		goto _test_eof975;
case 975:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(2688 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 !s->multiline  ) _widec += 512;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(2688 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		if (
 !s->multiline  ) _widec += 512;
	}
	switch( _widec ) {
		case 9: goto st966;
		case 32: goto st966;
		case 40: goto tr2747;
		case 41: goto tr2748;
		case 3082: goto tr2750;
		case 3131: goto tr2751;
		case 3338: goto tr2713;
		case 3387: goto tr2713;
		case 3594: goto tr2752;
		case 3643: goto tr2753;
	}
	goto tr2604;
tr2732:
	{
		s->buffer_length = 0;
	}
	goto st976;
tr2796:
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		}
	}
	goto st976;
tr2723:
	{
		if (s->decimal_counter == 0 && s->number64 < UINT32_MAX) {
			s->number64 *= pow(10, s->decimals);
		} else if (s->decimal_counter <= s->decimals &&
				 s->number64_tmp < UINT32_MAX) {
			s->number64 *= pow(10, s->decimals - s->decimal_counter);
			s->number64 += s->number64_tmp * pow(10, s->decimals);
		} else {
			WARN(ZS_FLOAT_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->number64 <= 9000000000ULL) {
			s->loc.siz = s->number64;
		} else {
			WARN(ZS_BAD_NUMBER);
			p--; {goto st316;}
		}
	}
	{
		s->buffer_length = 0;
	}
	goto st976;
tr2804:
	{
		s->number64_tmp = s->number64;
	}
	{
		if (s->decimal_counter == 0 && s->number64 < UINT32_MAX) {
			s->number64 *= pow(10, s->decimals);
		} else if (s->decimal_counter <= s->decimals &&
				 s->number64_tmp < UINT32_MAX) {
			s->number64 *= pow(10, s->decimals - s->decimal_counter);
			s->number64 += s->number64_tmp * pow(10, s->decimals);
		} else {
			WARN(ZS_FLOAT_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->number64 <= 9000000000ULL) {
			s->loc.siz = s->number64;
		} else {
			WARN(ZS_BAD_NUMBER);
			p--; {goto st316;}
		}
	}
	{
		s->buffer_length = 0;
	}
	goto st976;
st976:
	if ( ++p == pe )
		goto _test_eof976;
case 976:
	_widec = (*p);
	if ( (*p) < 10 ) {
		if ( (*p) <= 9 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) > 10 ) {
		if ( 11 <= (*p) )
 {			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	if ( _widec == 2058 )
		goto tr2797;
	if ( 1920 <= _widec && _widec <= 2175 )
		goto tr2796;
	goto tr2604;
tr2733:
	{
		s->line_counter++;
	}
	{
		// Write version.
		*(rdata_tail) = 0;
		rdata_tail += 1;
		// Write size.
		*(rdata_tail) = loc64to8(s->loc.siz);
		rdata_tail += 1;
		// Write horizontal precision.
		*(rdata_tail) = loc64to8(s->loc.hp);
		rdata_tail += 1;
		// Write vertical precision.
		*(rdata_tail) = loc64to8(s->loc.vp);
		rdata_tail += 1;
		// Write latitude.
		*((uint32_t *)rdata_tail) = htonl(LOC_LAT_ZERO + s->loc.lat_sign *
			(3600000 * s->loc.d1 + 60000 * s->loc.m1 + s->loc.s1));
		rdata_tail += 4;
		// Write longitude.
		*((uint32_t *)rdata_tail) = htonl(LOC_LONG_ZERO + s->loc.long_sign *
			(3600000 * s->loc.d2 + 60000 * s->loc.m2 + s->loc.s2));
		rdata_tail += 4;
		// Write altitude.
		*((uint32_t *)rdata_tail) = htonl(LOC_ALT_ZERO + s->loc.alt_sign *
			(s->loc.alt));
		rdata_tail += 4;
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1498;
tr2725:
	{
		if (s->decimal_counter == 0 && s->number64 < UINT32_MAX) {
			s->number64 *= pow(10, s->decimals);
		} else if (s->decimal_counter <= s->decimals &&
				 s->number64_tmp < UINT32_MAX) {
			s->number64 *= pow(10, s->decimals - s->decimal_counter);
			s->number64 += s->number64_tmp * pow(10, s->decimals);
		} else {
			WARN(ZS_FLOAT_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->number64 <= 9000000000ULL) {
			s->loc.siz = s->number64;
		} else {
			WARN(ZS_BAD_NUMBER);
			p--; {goto st316;}
		}
	}
	{
		s->line_counter++;
	}
	{
		// Write version.
		*(rdata_tail) = 0;
		rdata_tail += 1;
		// Write size.
		*(rdata_tail) = loc64to8(s->loc.siz);
		rdata_tail += 1;
		// Write horizontal precision.
		*(rdata_tail) = loc64to8(s->loc.hp);
		rdata_tail += 1;
		// Write vertical precision.
		*(rdata_tail) = loc64to8(s->loc.vp);
		rdata_tail += 1;
		// Write latitude.
		*((uint32_t *)rdata_tail) = htonl(LOC_LAT_ZERO + s->loc.lat_sign *
			(3600000 * s->loc.d1 + 60000 * s->loc.m1 + s->loc.s1));
		rdata_tail += 4;
		// Write longitude.
		*((uint32_t *)rdata_tail) = htonl(LOC_LONG_ZERO + s->loc.long_sign *
			(3600000 * s->loc.d2 + 60000 * s->loc.m2 + s->loc.s2));
		rdata_tail += 4;
		// Write altitude.
		*((uint32_t *)rdata_tail) = htonl(LOC_ALT_ZERO + s->loc.alt_sign *
			(s->loc.alt));
		rdata_tail += 4;
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1498;
tr2806:
	{
		s->number64_tmp = s->number64;
	}
	{
		if (s->decimal_counter == 0 && s->number64 < UINT32_MAX) {
			s->number64 *= pow(10, s->decimals);
		} else if (s->decimal_counter <= s->decimals &&
				 s->number64_tmp < UINT32_MAX) {
			s->number64 *= pow(10, s->decimals - s->decimal_counter);
			s->number64 += s->number64_tmp * pow(10, s->decimals);
		} else {
			WARN(ZS_FLOAT_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->number64 <= 9000000000ULL) {
			s->loc.siz = s->number64;
		} else {
			WARN(ZS_BAD_NUMBER);
			p--; {goto st316;}
		}
	}
	{
		s->line_counter++;
	}
	{
		// Write version.
		*(rdata_tail) = 0;
		rdata_tail += 1;
		// Write size.
		*(rdata_tail) = loc64to8(s->loc.siz);
		rdata_tail += 1;
		// Write horizontal precision.
		*(rdata_tail) = loc64to8(s->loc.hp);
		rdata_tail += 1;
		// Write vertical precision.
		*(rdata_tail) = loc64to8(s->loc.vp);
		rdata_tail += 1;
		// Write latitude.
		*((uint32_t *)rdata_tail) = htonl(LOC_LAT_ZERO + s->loc.lat_sign *
			(3600000 * s->loc.d1 + 60000 * s->loc.m1 + s->loc.s1));
		rdata_tail += 4;
		// Write longitude.
		*((uint32_t *)rdata_tail) = htonl(LOC_LONG_ZERO + s->loc.long_sign *
			(3600000 * s->loc.d2 + 60000 * s->loc.m2 + s->loc.s2));
		rdata_tail += 4;
		// Write altitude.
		*((uint32_t *)rdata_tail) = htonl(LOC_ALT_ZERO + s->loc.alt_sign *
			(s->loc.alt));
		rdata_tail += 4;
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1498;
st1498:
	if ( ++p == pe )
		goto _test_eof1498;
case 1498:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(2688 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 !s->multiline  ) _widec += 512;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(2688 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		if (
 !s->multiline  ) _widec += 512;
	}
	switch( _widec ) {
		case 9: goto st964;
		case 32: goto st964;
		case 40: goto tr2728;
		case 41: goto tr2729;
		case 3082: goto tr2731;
		case 3131: goto tr2732;
		case 3338: goto tr2713;
		case 3387: goto tr2713;
		case 3594: goto tr2733;
		case 3643: goto tr2734;
	}
	if ( 48 <= _widec && _widec <= 57 )
		goto tr2730;
	goto tr2604;
tr2734:
	{
		s->buffer_length = 0;
	}
	{
		// Write version.
		*(rdata_tail) = 0;
		rdata_tail += 1;
		// Write size.
		*(rdata_tail) = loc64to8(s->loc.siz);
		rdata_tail += 1;
		// Write horizontal precision.
		*(rdata_tail) = loc64to8(s->loc.hp);
		rdata_tail += 1;
		// Write vertical precision.
		*(rdata_tail) = loc64to8(s->loc.vp);
		rdata_tail += 1;
		// Write latitude.
		*((uint32_t *)rdata_tail) = htonl(LOC_LAT_ZERO + s->loc.lat_sign *
			(3600000 * s->loc.d1 + 60000 * s->loc.m1 + s->loc.s1));
		rdata_tail += 4;
		// Write longitude.
		*((uint32_t *)rdata_tail) = htonl(LOC_LONG_ZERO + s->loc.long_sign *
			(3600000 * s->loc.d2 + 60000 * s->loc.m2 + s->loc.s2));
		rdata_tail += 4;
		// Write altitude.
		*((uint32_t *)rdata_tail) = htonl(LOC_ALT_ZERO + s->loc.alt_sign *
			(s->loc.alt));
		rdata_tail += 4;
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1499;
tr2726:
	{
		if (s->decimal_counter == 0 && s->number64 < UINT32_MAX) {
			s->number64 *= pow(10, s->decimals);
		} else if (s->decimal_counter <= s->decimals &&
				 s->number64_tmp < UINT32_MAX) {
			s->number64 *= pow(10, s->decimals - s->decimal_counter);
			s->number64 += s->number64_tmp * pow(10, s->decimals);
		} else {
			WARN(ZS_FLOAT_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->number64 <= 9000000000ULL) {
			s->loc.siz = s->number64;
		} else {
			WARN(ZS_BAD_NUMBER);
			p--; {goto st316;}
		}
	}
	{
		s->buffer_length = 0;
	}
	{
		// Write version.
		*(rdata_tail) = 0;
		rdata_tail += 1;
		// Write size.
		*(rdata_tail) = loc64to8(s->loc.siz);
		rdata_tail += 1;
		// Write horizontal precision.
		*(rdata_tail) = loc64to8(s->loc.hp);
		rdata_tail += 1;
		// Write vertical precision.
		*(rdata_tail) = loc64to8(s->loc.vp);
		rdata_tail += 1;
		// Write latitude.
		*((uint32_t *)rdata_tail) = htonl(LOC_LAT_ZERO + s->loc.lat_sign *
			(3600000 * s->loc.d1 + 60000 * s->loc.m1 + s->loc.s1));
		rdata_tail += 4;
		// Write longitude.
		*((uint32_t *)rdata_tail) = htonl(LOC_LONG_ZERO + s->loc.long_sign *
			(3600000 * s->loc.d2 + 60000 * s->loc.m2 + s->loc.s2));
		rdata_tail += 4;
		// Write altitude.
		*((uint32_t *)rdata_tail) = htonl(LOC_ALT_ZERO + s->loc.alt_sign *
			(s->loc.alt));
		rdata_tail += 4;
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1499;
tr2807:
	{
		s->number64_tmp = s->number64;
	}
	{
		if (s->decimal_counter == 0 && s->number64 < UINT32_MAX) {
			s->number64 *= pow(10, s->decimals);
		} else if (s->decimal_counter <= s->decimals &&
				 s->number64_tmp < UINT32_MAX) {
			s->number64 *= pow(10, s->decimals - s->decimal_counter);
			s->number64 += s->number64_tmp * pow(10, s->decimals);
		} else {
			WARN(ZS_FLOAT_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->number64 <= 9000000000ULL) {
			s->loc.siz = s->number64;
		} else {
			WARN(ZS_BAD_NUMBER);
			p--; {goto st316;}
		}
	}
	{
		s->buffer_length = 0;
	}
	{
		// Write version.
		*(rdata_tail) = 0;
		rdata_tail += 1;
		// Write size.
		*(rdata_tail) = loc64to8(s->loc.siz);
		rdata_tail += 1;
		// Write horizontal precision.
		*(rdata_tail) = loc64to8(s->loc.hp);
		rdata_tail += 1;
		// Write vertical precision.
		*(rdata_tail) = loc64to8(s->loc.vp);
		rdata_tail += 1;
		// Write latitude.
		*((uint32_t *)rdata_tail) = htonl(LOC_LAT_ZERO + s->loc.lat_sign *
			(3600000 * s->loc.d1 + 60000 * s->loc.m1 + s->loc.s1));
		rdata_tail += 4;
		// Write longitude.
		*((uint32_t *)rdata_tail) = htonl(LOC_LONG_ZERO + s->loc.long_sign *
			(3600000 * s->loc.d2 + 60000 * s->loc.m2 + s->loc.s2));
		rdata_tail += 4;
		// Write altitude.
		*((uint32_t *)rdata_tail) = htonl(LOC_ALT_ZERO + s->loc.alt_sign *
			(s->loc.alt));
		rdata_tail += 4;
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1499;
st1499:
	if ( ++p == pe )
		goto _test_eof1499;
case 1499:
	_widec = (*p);
	if ( (*p) < 10 ) {
		if ( (*p) <= 9 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) > 10 ) {
		if ( 11 <= (*p) )
 {			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	if ( _widec == 2058 )
		goto tr2797;
	if ( 1920 <= _widec && _widec <= 2175 )
		goto tr2796;
	goto tr2604;
st977:
	if ( ++p == pe )
		goto _test_eof977;
case 977:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(2688 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 !s->multiline  ) _widec += 512;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(2688 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		if (
 !s->multiline  ) _widec += 512;
	}
	switch( _widec ) {
		case 9: goto tr2798;
		case 32: goto tr2798;
		case 40: goto tr2799;
		case 41: goto tr2800;
		case 109: goto tr2802;
		case 3082: goto tr2803;
		case 3131: goto tr2804;
		case 3338: goto tr2805;
		case 3387: goto tr2805;
		case 3594: goto tr2806;
		case 3643: goto tr2807;
	}
	if ( 48 <= _widec && _widec <= 57 )
		goto tr2801;
	goto tr2604;
tr2801:
	{
		s->number64_tmp = s->number64;
	}
	{
		s->number64 = 0;
	}
	{
		// Overflow check: 10*(s->number64) + fc - '0' <= UINT64_MAX
		if ((s->number64 < (UINT64_MAX / 10)) ||   // Dominant fast check.
			((s->number64 == (UINT64_MAX / 10)) && // Marginal case.
			 ((uint8_t)(*p) <= (UINT64_MAX % 10) + '0')
			)
		   ) {
			s->number64 *= 10;
			s->number64 += digit_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_NUMBER64_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		s->decimal_counter++;
	}
	goto st978;
tr2808:
	{
		// Overflow check: 10*(s->number64) + fc - '0' <= UINT64_MAX
		if ((s->number64 < (UINT64_MAX / 10)) ||   // Dominant fast check.
			((s->number64 == (UINT64_MAX / 10)) && // Marginal case.
			 ((uint8_t)(*p) <= (UINT64_MAX % 10) + '0')
			)
		   ) {
			s->number64 *= 10;
			s->number64 += digit_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_NUMBER64_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		s->decimal_counter++;
	}
	goto st978;
st978:
	if ( ++p == pe )
		goto _test_eof978;
case 978:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(2688 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 !s->multiline  ) _widec += 512;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(2688 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		if (
 !s->multiline  ) _widec += 512;
	}
	switch( _widec ) {
		case 9: goto tr2716;
		case 32: goto tr2716;
		case 40: goto tr2717;
		case 41: goto tr2718;
		case 109: goto tr2721;
		case 3082: goto tr2722;
		case 3131: goto tr2723;
		case 3338: goto tr2724;
		case 3387: goto tr2724;
		case 3594: goto tr2725;
		case 3643: goto tr2726;
	}
	if ( 48 <= _widec && _widec <= 57 )
		goto tr2808;
	goto tr2604;
tr2721:
	{
		if (s->decimal_counter == 0 && s->number64 < UINT32_MAX) {
			s->number64 *= pow(10, s->decimals);
		} else if (s->decimal_counter <= s->decimals &&
				 s->number64_tmp < UINT32_MAX) {
			s->number64 *= pow(10, s->decimals - s->decimal_counter);
			s->number64 += s->number64_tmp * pow(10, s->decimals);
		} else {
			WARN(ZS_FLOAT_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->number64 <= 9000000000ULL) {
			s->loc.siz = s->number64;
		} else {
			WARN(ZS_BAD_NUMBER);
			p--; {goto st316;}
		}
	}
	goto st979;
tr2802:
	{
		s->number64_tmp = s->number64;
	}
	{
		if (s->decimal_counter == 0 && s->number64 < UINT32_MAX) {
			s->number64 *= pow(10, s->decimals);
		} else if (s->decimal_counter <= s->decimals &&
				 s->number64_tmp < UINT32_MAX) {
			s->number64 *= pow(10, s->decimals - s->decimal_counter);
			s->number64 += s->number64_tmp * pow(10, s->decimals);
		} else {
			WARN(ZS_FLOAT_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->number64 <= 9000000000ULL) {
			s->loc.siz = s->number64;
		} else {
			WARN(ZS_BAD_NUMBER);
			p--; {goto st316;}
		}
	}
	goto st979;
st979:
	if ( ++p == pe )
		goto _test_eof979;
case 979:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(2688 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 !s->multiline  ) _widec += 512;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(2688 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		if (
 !s->multiline  ) _widec += 512;
	}
	switch( _widec ) {
		case 9: goto st964;
		case 32: goto st964;
		case 40: goto tr2728;
		case 41: goto tr2729;
		case 3082: goto tr2731;
		case 3131: goto tr2732;
		case 3338: goto tr2713;
		case 3387: goto tr2713;
		case 3594: goto tr2733;
		case 3643: goto tr2734;
	}
	goto tr2604;
tr2712:
	{
		s->buffer_length = 0;
	}
	goto st980;
tr2809:
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		}
	}
	goto st980;
tr2703:
	{
		if (s->decimal_counter == 0 && s->number64 < UINT32_MAX) {
			s->number64 *= pow(10, s->decimals);
		} else if (s->decimal_counter <= s->decimals &&
				 s->number64_tmp < UINT32_MAX) {
			s->number64 *= pow(10, s->decimals - s->decimal_counter);
			s->number64 += s->number64_tmp * pow(10, s->decimals);
		} else {
			WARN(ZS_FLOAT_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if ((s->loc.alt_sign ==  1 && s->number64 <= 4284967295) ||
		    (s->loc.alt_sign == -1 && s->number64 <=   10000000))
		{
			s->loc.alt = (uint32_t)(s->number64);
		} else {
			WARN(ZS_BAD_NUMBER);
			p--; {goto st316;}
		}
	}
	{
		s->buffer_length = 0;
	}
	goto st980;
tr2817:
	{
		s->number64_tmp = s->number64;
	}
	{
		if (s->decimal_counter == 0 && s->number64 < UINT32_MAX) {
			s->number64 *= pow(10, s->decimals);
		} else if (s->decimal_counter <= s->decimals &&
				 s->number64_tmp < UINT32_MAX) {
			s->number64 *= pow(10, s->decimals - s->decimal_counter);
			s->number64 += s->number64_tmp * pow(10, s->decimals);
		} else {
			WARN(ZS_FLOAT_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if ((s->loc.alt_sign ==  1 && s->number64 <= 4284967295) ||
		    (s->loc.alt_sign == -1 && s->number64 <=   10000000))
		{
			s->loc.alt = (uint32_t)(s->number64);
		} else {
			WARN(ZS_BAD_NUMBER);
			p--; {goto st316;}
		}
	}
	{
		s->buffer_length = 0;
	}
	goto st980;
st980:
	if ( ++p == pe )
		goto _test_eof980;
case 980:
	_widec = (*p);
	if ( (*p) < 10 ) {
		if ( (*p) <= 9 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) > 10 ) {
		if ( 11 <= (*p) )
 {			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	if ( _widec == 2058 )
		goto tr2810;
	if ( 1920 <= _widec && _widec <= 2175 )
		goto tr2809;
	goto tr2604;
tr2705:
	{
		if (s->decimal_counter == 0 && s->number64 < UINT32_MAX) {
			s->number64 *= pow(10, s->decimals);
		} else if (s->decimal_counter <= s->decimals &&
				 s->number64_tmp < UINT32_MAX) {
			s->number64 *= pow(10, s->decimals - s->decimal_counter);
			s->number64 += s->number64_tmp * pow(10, s->decimals);
		} else {
			WARN(ZS_FLOAT_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if ((s->loc.alt_sign ==  1 && s->number64 <= 4284967295) ||
		    (s->loc.alt_sign == -1 && s->number64 <=   10000000))
		{
			s->loc.alt = (uint32_t)(s->number64);
		} else {
			WARN(ZS_BAD_NUMBER);
			p--; {goto st316;}
		}
	}
	{
		s->line_counter++;
	}
	{
		// Write version.
		*(rdata_tail) = 0;
		rdata_tail += 1;
		// Write size.
		*(rdata_tail) = loc64to8(s->loc.siz);
		rdata_tail += 1;
		// Write horizontal precision.
		*(rdata_tail) = loc64to8(s->loc.hp);
		rdata_tail += 1;
		// Write vertical precision.
		*(rdata_tail) = loc64to8(s->loc.vp);
		rdata_tail += 1;
		// Write latitude.
		*((uint32_t *)rdata_tail) = htonl(LOC_LAT_ZERO + s->loc.lat_sign *
			(3600000 * s->loc.d1 + 60000 * s->loc.m1 + s->loc.s1));
		rdata_tail += 4;
		// Write longitude.
		*((uint32_t *)rdata_tail) = htonl(LOC_LONG_ZERO + s->loc.long_sign *
			(3600000 * s->loc.d2 + 60000 * s->loc.m2 + s->loc.s2));
		rdata_tail += 4;
		// Write altitude.
		*((uint32_t *)rdata_tail) = htonl(LOC_ALT_ZERO + s->loc.alt_sign *
			(s->loc.alt));
		rdata_tail += 4;
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1500;
tr2714:
	{
		s->line_counter++;
	}
	{
		// Write version.
		*(rdata_tail) = 0;
		rdata_tail += 1;
		// Write size.
		*(rdata_tail) = loc64to8(s->loc.siz);
		rdata_tail += 1;
		// Write horizontal precision.
		*(rdata_tail) = loc64to8(s->loc.hp);
		rdata_tail += 1;
		// Write vertical precision.
		*(rdata_tail) = loc64to8(s->loc.vp);
		rdata_tail += 1;
		// Write latitude.
		*((uint32_t *)rdata_tail) = htonl(LOC_LAT_ZERO + s->loc.lat_sign *
			(3600000 * s->loc.d1 + 60000 * s->loc.m1 + s->loc.s1));
		rdata_tail += 4;
		// Write longitude.
		*((uint32_t *)rdata_tail) = htonl(LOC_LONG_ZERO + s->loc.long_sign *
			(3600000 * s->loc.d2 + 60000 * s->loc.m2 + s->loc.s2));
		rdata_tail += 4;
		// Write altitude.
		*((uint32_t *)rdata_tail) = htonl(LOC_ALT_ZERO + s->loc.alt_sign *
			(s->loc.alt));
		rdata_tail += 4;
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1500;
tr2819:
	{
		s->number64_tmp = s->number64;
	}
	{
		if (s->decimal_counter == 0 && s->number64 < UINT32_MAX) {
			s->number64 *= pow(10, s->decimals);
		} else if (s->decimal_counter <= s->decimals &&
				 s->number64_tmp < UINT32_MAX) {
			s->number64 *= pow(10, s->decimals - s->decimal_counter);
			s->number64 += s->number64_tmp * pow(10, s->decimals);
		} else {
			WARN(ZS_FLOAT_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if ((s->loc.alt_sign ==  1 && s->number64 <= 4284967295) ||
		    (s->loc.alt_sign == -1 && s->number64 <=   10000000))
		{
			s->loc.alt = (uint32_t)(s->number64);
		} else {
			WARN(ZS_BAD_NUMBER);
			p--; {goto st316;}
		}
	}
	{
		s->line_counter++;
	}
	{
		// Write version.
		*(rdata_tail) = 0;
		rdata_tail += 1;
		// Write size.
		*(rdata_tail) = loc64to8(s->loc.siz);
		rdata_tail += 1;
		// Write horizontal precision.
		*(rdata_tail) = loc64to8(s->loc.hp);
		rdata_tail += 1;
		// Write vertical precision.
		*(rdata_tail) = loc64to8(s->loc.vp);
		rdata_tail += 1;
		// Write latitude.
		*((uint32_t *)rdata_tail) = htonl(LOC_LAT_ZERO + s->loc.lat_sign *
			(3600000 * s->loc.d1 + 60000 * s->loc.m1 + s->loc.s1));
		rdata_tail += 4;
		// Write longitude.
		*((uint32_t *)rdata_tail) = htonl(LOC_LONG_ZERO + s->loc.long_sign *
			(3600000 * s->loc.d2 + 60000 * s->loc.m2 + s->loc.s2));
		rdata_tail += 4;
		// Write altitude.
		*((uint32_t *)rdata_tail) = htonl(LOC_ALT_ZERO + s->loc.alt_sign *
			(s->loc.alt));
		rdata_tail += 4;
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1500;
st1500:
	if ( ++p == pe )
		goto _test_eof1500;
case 1500:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(2688 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 !s->multiline  ) _widec += 512;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(2688 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		if (
 !s->multiline  ) _widec += 512;
	}
	switch( _widec ) {
		case 9: goto st962;
		case 32: goto st962;
		case 40: goto tr2708;
		case 41: goto tr2709;
		case 3082: goto tr2711;
		case 3131: goto tr2712;
		case 3338: goto tr2713;
		case 3387: goto tr2713;
		case 3594: goto tr2714;
		case 3643: goto tr2715;
	}
	if ( 48 <= _widec && _widec <= 57 )
		goto tr2710;
	goto tr2604;
tr2706:
	{
		if (s->decimal_counter == 0 && s->number64 < UINT32_MAX) {
			s->number64 *= pow(10, s->decimals);
		} else if (s->decimal_counter <= s->decimals &&
				 s->number64_tmp < UINT32_MAX) {
			s->number64 *= pow(10, s->decimals - s->decimal_counter);
			s->number64 += s->number64_tmp * pow(10, s->decimals);
		} else {
			WARN(ZS_FLOAT_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if ((s->loc.alt_sign ==  1 && s->number64 <= 4284967295) ||
		    (s->loc.alt_sign == -1 && s->number64 <=   10000000))
		{
			s->loc.alt = (uint32_t)(s->number64);
		} else {
			WARN(ZS_BAD_NUMBER);
			p--; {goto st316;}
		}
	}
	{
		s->buffer_length = 0;
	}
	{
		// Write version.
		*(rdata_tail) = 0;
		rdata_tail += 1;
		// Write size.
		*(rdata_tail) = loc64to8(s->loc.siz);
		rdata_tail += 1;
		// Write horizontal precision.
		*(rdata_tail) = loc64to8(s->loc.hp);
		rdata_tail += 1;
		// Write vertical precision.
		*(rdata_tail) = loc64to8(s->loc.vp);
		rdata_tail += 1;
		// Write latitude.
		*((uint32_t *)rdata_tail) = htonl(LOC_LAT_ZERO + s->loc.lat_sign *
			(3600000 * s->loc.d1 + 60000 * s->loc.m1 + s->loc.s1));
		rdata_tail += 4;
		// Write longitude.
		*((uint32_t *)rdata_tail) = htonl(LOC_LONG_ZERO + s->loc.long_sign *
			(3600000 * s->loc.d2 + 60000 * s->loc.m2 + s->loc.s2));
		rdata_tail += 4;
		// Write altitude.
		*((uint32_t *)rdata_tail) = htonl(LOC_ALT_ZERO + s->loc.alt_sign *
			(s->loc.alt));
		rdata_tail += 4;
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1501;
tr2715:
	{
		s->buffer_length = 0;
	}
	{
		// Write version.
		*(rdata_tail) = 0;
		rdata_tail += 1;
		// Write size.
		*(rdata_tail) = loc64to8(s->loc.siz);
		rdata_tail += 1;
		// Write horizontal precision.
		*(rdata_tail) = loc64to8(s->loc.hp);
		rdata_tail += 1;
		// Write vertical precision.
		*(rdata_tail) = loc64to8(s->loc.vp);
		rdata_tail += 1;
		// Write latitude.
		*((uint32_t *)rdata_tail) = htonl(LOC_LAT_ZERO + s->loc.lat_sign *
			(3600000 * s->loc.d1 + 60000 * s->loc.m1 + s->loc.s1));
		rdata_tail += 4;
		// Write longitude.
		*((uint32_t *)rdata_tail) = htonl(LOC_LONG_ZERO + s->loc.long_sign *
			(3600000 * s->loc.d2 + 60000 * s->loc.m2 + s->loc.s2));
		rdata_tail += 4;
		// Write altitude.
		*((uint32_t *)rdata_tail) = htonl(LOC_ALT_ZERO + s->loc.alt_sign *
			(s->loc.alt));
		rdata_tail += 4;
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1501;
tr2820:
	{
		s->number64_tmp = s->number64;
	}
	{
		if (s->decimal_counter == 0 && s->number64 < UINT32_MAX) {
			s->number64 *= pow(10, s->decimals);
		} else if (s->decimal_counter <= s->decimals &&
				 s->number64_tmp < UINT32_MAX) {
			s->number64 *= pow(10, s->decimals - s->decimal_counter);
			s->number64 += s->number64_tmp * pow(10, s->decimals);
		} else {
			WARN(ZS_FLOAT_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if ((s->loc.alt_sign ==  1 && s->number64 <= 4284967295) ||
		    (s->loc.alt_sign == -1 && s->number64 <=   10000000))
		{
			s->loc.alt = (uint32_t)(s->number64);
		} else {
			WARN(ZS_BAD_NUMBER);
			p--; {goto st316;}
		}
	}
	{
		s->buffer_length = 0;
	}
	{
		// Write version.
		*(rdata_tail) = 0;
		rdata_tail += 1;
		// Write size.
		*(rdata_tail) = loc64to8(s->loc.siz);
		rdata_tail += 1;
		// Write horizontal precision.
		*(rdata_tail) = loc64to8(s->loc.hp);
		rdata_tail += 1;
		// Write vertical precision.
		*(rdata_tail) = loc64to8(s->loc.vp);
		rdata_tail += 1;
		// Write latitude.
		*((uint32_t *)rdata_tail) = htonl(LOC_LAT_ZERO + s->loc.lat_sign *
			(3600000 * s->loc.d1 + 60000 * s->loc.m1 + s->loc.s1));
		rdata_tail += 4;
		// Write longitude.
		*((uint32_t *)rdata_tail) = htonl(LOC_LONG_ZERO + s->loc.long_sign *
			(3600000 * s->loc.d2 + 60000 * s->loc.m2 + s->loc.s2));
		rdata_tail += 4;
		// Write altitude.
		*((uint32_t *)rdata_tail) = htonl(LOC_ALT_ZERO + s->loc.alt_sign *
			(s->loc.alt));
		rdata_tail += 4;
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1501;
st1501:
	if ( ++p == pe )
		goto _test_eof1501;
case 1501:
	_widec = (*p);
	if ( (*p) < 10 ) {
		if ( (*p) <= 9 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) > 10 ) {
		if ( 11 <= (*p) )
 {			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	if ( _widec == 2058 )
		goto tr2810;
	if ( 1920 <= _widec && _widec <= 2175 )
		goto tr2809;
	goto tr2604;
st981:
	if ( ++p == pe )
		goto _test_eof981;
case 981:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(2688 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 !s->multiline  ) _widec += 512;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(2688 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		if (
 !s->multiline  ) _widec += 512;
	}
	switch( _widec ) {
		case 9: goto tr2811;
		case 32: goto tr2811;
		case 40: goto tr2812;
		case 41: goto tr2813;
		case 109: goto tr2815;
		case 3082: goto tr2816;
		case 3131: goto tr2817;
		case 3338: goto tr2818;
		case 3387: goto tr2818;
		case 3594: goto tr2819;
		case 3643: goto tr2820;
	}
	if ( 48 <= _widec && _widec <= 57 )
		goto tr2814;
	goto tr2604;
tr2814:
	{
		s->number64_tmp = s->number64;
	}
	{
		s->number64 = 0;
	}
	{
		// Overflow check: 10*(s->number64) + fc - '0' <= UINT64_MAX
		if ((s->number64 < (UINT64_MAX / 10)) ||   // Dominant fast check.
			((s->number64 == (UINT64_MAX / 10)) && // Marginal case.
			 ((uint8_t)(*p) <= (UINT64_MAX % 10) + '0')
			)
		   ) {
			s->number64 *= 10;
			s->number64 += digit_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_NUMBER64_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		s->decimal_counter++;
	}
	goto st982;
tr2821:
	{
		// Overflow check: 10*(s->number64) + fc - '0' <= UINT64_MAX
		if ((s->number64 < (UINT64_MAX / 10)) ||   // Dominant fast check.
			((s->number64 == (UINT64_MAX / 10)) && // Marginal case.
			 ((uint8_t)(*p) <= (UINT64_MAX % 10) + '0')
			)
		   ) {
			s->number64 *= 10;
			s->number64 += digit_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_NUMBER64_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		s->decimal_counter++;
	}
	goto st982;
st982:
	if ( ++p == pe )
		goto _test_eof982;
case 982:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(2688 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 !s->multiline  ) _widec += 512;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(2688 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		if (
 !s->multiline  ) _widec += 512;
	}
	switch( _widec ) {
		case 9: goto tr2696;
		case 32: goto tr2696;
		case 40: goto tr2697;
		case 41: goto tr2698;
		case 109: goto tr2701;
		case 3082: goto tr2702;
		case 3131: goto tr2703;
		case 3338: goto tr2704;
		case 3387: goto tr2704;
		case 3594: goto tr2705;
		case 3643: goto tr2706;
	}
	if ( 48 <= _widec && _widec <= 57 )
		goto tr2821;
	goto tr2604;
tr2701:
	{
		if (s->decimal_counter == 0 && s->number64 < UINT32_MAX) {
			s->number64 *= pow(10, s->decimals);
		} else if (s->decimal_counter <= s->decimals &&
				 s->number64_tmp < UINT32_MAX) {
			s->number64 *= pow(10, s->decimals - s->decimal_counter);
			s->number64 += s->number64_tmp * pow(10, s->decimals);
		} else {
			WARN(ZS_FLOAT_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if ((s->loc.alt_sign ==  1 && s->number64 <= 4284967295) ||
		    (s->loc.alt_sign == -1 && s->number64 <=   10000000))
		{
			s->loc.alt = (uint32_t)(s->number64);
		} else {
			WARN(ZS_BAD_NUMBER);
			p--; {goto st316;}
		}
	}
	goto st983;
tr2815:
	{
		s->number64_tmp = s->number64;
	}
	{
		if (s->decimal_counter == 0 && s->number64 < UINT32_MAX) {
			s->number64 *= pow(10, s->decimals);
		} else if (s->decimal_counter <= s->decimals &&
				 s->number64_tmp < UINT32_MAX) {
			s->number64 *= pow(10, s->decimals - s->decimal_counter);
			s->number64 += s->number64_tmp * pow(10, s->decimals);
		} else {
			WARN(ZS_FLOAT_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if ((s->loc.alt_sign ==  1 && s->number64 <= 4284967295) ||
		    (s->loc.alt_sign == -1 && s->number64 <=   10000000))
		{
			s->loc.alt = (uint32_t)(s->number64);
		} else {
			WARN(ZS_BAD_NUMBER);
			p--; {goto st316;}
		}
	}
	goto st983;
st983:
	if ( ++p == pe )
		goto _test_eof983;
case 983:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(2688 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 !s->multiline  ) _widec += 512;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(2688 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		if (
 !s->multiline  ) _widec += 512;
	}
	switch( _widec ) {
		case 9: goto st962;
		case 32: goto st962;
		case 40: goto tr2708;
		case 41: goto tr2709;
		case 3082: goto tr2711;
		case 3131: goto tr2712;
		case 3338: goto tr2713;
		case 3387: goto tr2713;
		case 3594: goto tr2714;
		case 3643: goto tr2715;
	}
	goto tr2604;
tr2692:
	{
		s->buffer_length = 0;
	}
	goto st984;
tr2822:
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		}
	}
	goto st984;
tr2828:
	{
		s->loc.long_sign = -1;
	}
	{
		s->buffer_length = 0;
	}
	goto st984;
st984:
	if ( ++p == pe )
		goto _test_eof984;
case 984:
	_widec = (*p);
	if ( (*p) < 10 ) {
		if ( (*p) <= 9 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) > 10 ) {
		if ( 11 <= (*p) )
 {			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	if ( _widec == 2058 )
		goto tr2823;
	if ( 1920 <= _widec && _widec <= 2175 )
		goto tr2822;
	goto tr2604;
st985:
	if ( ++p == pe )
		goto _test_eof985;
case 985:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr2824;
		case 32: goto tr2824;
		case 40: goto tr2825;
		case 41: goto tr2826;
		case 2058: goto tr2827;
		case 2107: goto tr2828;
	}
	goto tr2604;
tr2687:
	{
		s->buffer_length = 0;
	}
	goto st986;
tr2829:
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		}
	}
	goto st986;
tr2682:
	{
		if (s->decimal_counter == 0 && s->number64 < UINT32_MAX) {
			s->number64 *= pow(10, s->decimals);
		} else if (s->decimal_counter <= s->decimals &&
				 s->number64_tmp < UINT32_MAX) {
			s->number64 *= pow(10, s->decimals - s->decimal_counter);
			s->number64 += s->number64_tmp * pow(10, s->decimals);
		} else {
			WARN(ZS_FLOAT_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->number64 <= 59999) {
			s->loc.s2 = (uint32_t)(s->number64);
		} else {
			WARN(ZS_BAD_NUMBER);
			p--; {goto st316;}
		}
	}
	{
		s->buffer_length = 0;
	}
	goto st986;
tr2836:
	{
		s->number64_tmp = s->number64;
	}
	{
		if (s->decimal_counter == 0 && s->number64 < UINT32_MAX) {
			s->number64 *= pow(10, s->decimals);
		} else if (s->decimal_counter <= s->decimals &&
				 s->number64_tmp < UINT32_MAX) {
			s->number64 *= pow(10, s->decimals - s->decimal_counter);
			s->number64 += s->number64_tmp * pow(10, s->decimals);
		} else {
			WARN(ZS_FLOAT_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->number64 <= 59999) {
			s->loc.s2 = (uint32_t)(s->number64);
		} else {
			WARN(ZS_BAD_NUMBER);
			p--; {goto st316;}
		}
	}
	{
		s->buffer_length = 0;
	}
	goto st986;
st986:
	if ( ++p == pe )
		goto _test_eof986;
case 986:
	_widec = (*p);
	if ( (*p) < 10 ) {
		if ( (*p) <= 9 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) > 10 ) {
		if ( 11 <= (*p) )
 {			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	if ( _widec == 2058 )
		goto tr2830;
	if ( 1920 <= _widec && _widec <= 2175 )
		goto tr2829;
	goto tr2604;
st987:
	if ( ++p == pe )
		goto _test_eof987;
case 987:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr2831;
		case 32: goto tr2831;
		case 40: goto tr2832;
		case 41: goto tr2833;
		case 2058: goto tr2835;
		case 2107: goto tr2836;
	}
	if ( 48 <= _widec && _widec <= 57 )
		goto tr2834;
	goto tr2604;
tr2834:
	{
		s->number64_tmp = s->number64;
	}
	{
		s->number64 = 0;
	}
	{
		// Overflow check: 10*(s->number64) + fc - '0' <= UINT64_MAX
		if ((s->number64 < (UINT64_MAX / 10)) ||   // Dominant fast check.
			((s->number64 == (UINT64_MAX / 10)) && // Marginal case.
			 ((uint8_t)(*p) <= (UINT64_MAX % 10) + '0')
			)
		   ) {
			s->number64 *= 10;
			s->number64 += digit_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_NUMBER64_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		s->decimal_counter++;
	}
	goto st988;
tr2837:
	{
		// Overflow check: 10*(s->number64) + fc - '0' <= UINT64_MAX
		if ((s->number64 < (UINT64_MAX / 10)) ||   // Dominant fast check.
			((s->number64 == (UINT64_MAX / 10)) && // Marginal case.
			 ((uint8_t)(*p) <= (UINT64_MAX % 10) + '0')
			)
		   ) {
			s->number64 *= 10;
			s->number64 += digit_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_NUMBER64_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		s->decimal_counter++;
	}
	goto st988;
st988:
	if ( ++p == pe )
		goto _test_eof988;
case 988:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr2676;
		case 32: goto tr2676;
		case 40: goto tr2677;
		case 41: goto tr2678;
		case 2058: goto tr2681;
		case 2107: goto tr2682;
	}
	if ( 48 <= _widec && _widec <= 57 )
		goto tr2837;
	goto tr2604;
tr2675:
	{
		s->buffer_length = 0;
	}
	goto st989;
tr2838:
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		}
	}
	goto st989;
tr2669:
	{
		if (s->number64 <= 59) {
			s->loc.m2 = (uint32_t)(s->number64);
		} else {
			WARN(ZS_BAD_NUMBER);
			p--; {goto st316;}
		}
	}
	{
		s->buffer_length = 0;
	}
	goto st989;
st989:
	if ( ++p == pe )
		goto _test_eof989;
case 989:
	_widec = (*p);
	if ( (*p) < 10 ) {
		if ( (*p) <= 9 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) > 10 ) {
		if ( 11 <= (*p) )
 {			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	if ( _widec == 2058 )
		goto tr2839;
	if ( 1920 <= _widec && _widec <= 2175 )
		goto tr2838;
	goto tr2604;
tr2663:
	{
		s->buffer_length = 0;
	}
	goto st990;
tr2840:
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		}
	}
	goto st990;
tr2655:
	{
		if (s->number64 <= 180) {
			s->loc.d2 = (uint32_t)(s->number64);
		} else {
			WARN(ZS_BAD_NUMBER);
			p--; {goto st316;}
		}
	}
	{
		s->buffer_length = 0;
	}
	goto st990;
st990:
	if ( ++p == pe )
		goto _test_eof990;
case 990:
	_widec = (*p);
	if ( (*p) < 10 ) {
		if ( (*p) <= 9 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) > 10 ) {
		if ( 11 <= (*p) )
 {			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	if ( _widec == 2058 )
		goto tr2841;
	if ( 1920 <= _widec && _widec <= 2175 )
		goto tr2840;
	goto tr2604;
tr2648:
	{
		s->buffer_length = 0;
	}
	goto st991;
tr2842:
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		}
	}
	goto st991;
tr2848:
	{
		s->loc.lat_sign = -1;
	}
	{
		s->buffer_length = 0;
	}
	goto st991;
st991:
	if ( ++p == pe )
		goto _test_eof991;
case 991:
	_widec = (*p);
	if ( (*p) < 10 ) {
		if ( (*p) <= 9 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) > 10 ) {
		if ( 11 <= (*p) )
 {			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	if ( _widec == 2058 )
		goto tr2843;
	if ( 1920 <= _widec && _widec <= 2175 )
		goto tr2842;
	goto tr2604;
st992:
	if ( ++p == pe )
		goto _test_eof992;
case 992:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr2844;
		case 32: goto tr2844;
		case 40: goto tr2845;
		case 41: goto tr2846;
		case 2058: goto tr2847;
		case 2107: goto tr2848;
	}
	goto tr2604;
tr2643:
	{
		s->buffer_length = 0;
	}
	goto st993;
tr2849:
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		}
	}
	goto st993;
tr2638:
	{
		if (s->decimal_counter == 0 && s->number64 < UINT32_MAX) {
			s->number64 *= pow(10, s->decimals);
		} else if (s->decimal_counter <= s->decimals &&
				 s->number64_tmp < UINT32_MAX) {
			s->number64 *= pow(10, s->decimals - s->decimal_counter);
			s->number64 += s->number64_tmp * pow(10, s->decimals);
		} else {
			WARN(ZS_FLOAT_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->number64 <= 59999) {
			s->loc.s1 = (uint32_t)(s->number64);
		} else {
			WARN(ZS_BAD_NUMBER);
			p--; {goto st316;}
		}
	}
	{
		s->buffer_length = 0;
	}
	goto st993;
tr2856:
	{
		s->number64_tmp = s->number64;
	}
	{
		if (s->decimal_counter == 0 && s->number64 < UINT32_MAX) {
			s->number64 *= pow(10, s->decimals);
		} else if (s->decimal_counter <= s->decimals &&
				 s->number64_tmp < UINT32_MAX) {
			s->number64 *= pow(10, s->decimals - s->decimal_counter);
			s->number64 += s->number64_tmp * pow(10, s->decimals);
		} else {
			WARN(ZS_FLOAT_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->number64 <= 59999) {
			s->loc.s1 = (uint32_t)(s->number64);
		} else {
			WARN(ZS_BAD_NUMBER);
			p--; {goto st316;}
		}
	}
	{
		s->buffer_length = 0;
	}
	goto st993;
st993:
	if ( ++p == pe )
		goto _test_eof993;
case 993:
	_widec = (*p);
	if ( (*p) < 10 ) {
		if ( (*p) <= 9 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) > 10 ) {
		if ( 11 <= (*p) )
 {			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	if ( _widec == 2058 )
		goto tr2850;
	if ( 1920 <= _widec && _widec <= 2175 )
		goto tr2849;
	goto tr2604;
st994:
	if ( ++p == pe )
		goto _test_eof994;
case 994:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr2851;
		case 32: goto tr2851;
		case 40: goto tr2852;
		case 41: goto tr2853;
		case 2058: goto tr2855;
		case 2107: goto tr2856;
	}
	if ( 48 <= _widec && _widec <= 57 )
		goto tr2854;
	goto tr2604;
tr2854:
	{
		s->number64_tmp = s->number64;
	}
	{
		s->number64 = 0;
	}
	{
		// Overflow check: 10*(s->number64) + fc - '0' <= UINT64_MAX
		if ((s->number64 < (UINT64_MAX / 10)) ||   // Dominant fast check.
			((s->number64 == (UINT64_MAX / 10)) && // Marginal case.
			 ((uint8_t)(*p) <= (UINT64_MAX % 10) + '0')
			)
		   ) {
			s->number64 *= 10;
			s->number64 += digit_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_NUMBER64_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		s->decimal_counter++;
	}
	goto st995;
tr2857:
	{
		// Overflow check: 10*(s->number64) + fc - '0' <= UINT64_MAX
		if ((s->number64 < (UINT64_MAX / 10)) ||   // Dominant fast check.
			((s->number64 == (UINT64_MAX / 10)) && // Marginal case.
			 ((uint8_t)(*p) <= (UINT64_MAX % 10) + '0')
			)
		   ) {
			s->number64 *= 10;
			s->number64 += digit_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_NUMBER64_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		s->decimal_counter++;
	}
	goto st995;
st995:
	if ( ++p == pe )
		goto _test_eof995;
case 995:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr2632;
		case 32: goto tr2632;
		case 40: goto tr2633;
		case 41: goto tr2634;
		case 2058: goto tr2637;
		case 2107: goto tr2638;
	}
	if ( 48 <= _widec && _widec <= 57 )
		goto tr2857;
	goto tr2604;
tr2631:
	{
		s->buffer_length = 0;
	}
	goto st996;
tr2858:
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		}
	}
	goto st996;
tr2625:
	{
		if (s->number64 <= 59) {
			s->loc.m1 = (uint32_t)(s->number64);
		} else {
			WARN(ZS_BAD_NUMBER);
			p--; {goto st316;}
		}
	}
	{
		s->buffer_length = 0;
	}
	goto st996;
st996:
	if ( ++p == pe )
		goto _test_eof996;
case 996:
	_widec = (*p);
	if ( (*p) < 10 ) {
		if ( (*p) <= 9 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) > 10 ) {
		if ( 11 <= (*p) )
 {			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	if ( _widec == 2058 )
		goto tr2859;
	if ( 1920 <= _widec && _widec <= 2175 )
		goto tr2858;
	goto tr2604;
tr2619:
	{
		s->buffer_length = 0;
	}
	goto st997;
tr2860:
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		}
	}
	goto st997;
tr2611:
	{
		if (s->number64 <= 90) {
			s->loc.d1 = (uint32_t)(s->number64);
		} else {
			WARN(ZS_BAD_NUMBER);
			p--; {goto st316;}
		}
	}
	{
		s->buffer_length = 0;
	}
	goto st997;
st997:
	if ( ++p == pe )
		goto _test_eof997;
case 997:
	_widec = (*p);
	if ( (*p) < 10 ) {
		if ( (*p) <= 9 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) > 10 ) {
		if ( 11 <= (*p) )
 {			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	if ( _widec == 2058 )
		goto tr2861;
	if ( 1920 <= _widec && _widec <= 2175 )
		goto tr2860;
	goto tr2604;
st998:
	if ( ++p == pe )
		goto _test_eof998;
case 998:
	if ( 48 <= (*p) && (*p) <= 57 )
		goto tr2862;
	goto tr2396;
tr2862:
	{
		s->number64 = 0;
	}
	{
		// Overflow check: 10*(s->number64) + fc - '0' <= UINT64_MAX
		if ((s->number64 < (UINT64_MAX / 10)) ||   // Dominant fast check.
			((s->number64 == (UINT64_MAX / 10)) && // Marginal case.
			 ((uint8_t)(*p) <= (UINT64_MAX % 10) + '0')
			)
		   ) {
			s->number64 *= 10;
			s->number64 += digit_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_NUMBER64_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st999;
tr2866:
	{
		// Overflow check: 10*(s->number64) + fc - '0' <= UINT64_MAX
		if ((s->number64 < (UINT64_MAX / 10)) ||   // Dominant fast check.
			((s->number64 == (UINT64_MAX / 10)) && // Marginal case.
			 ((uint8_t)(*p) <= (UINT64_MAX % 10) + '0')
			)
		   ) {
			s->number64 *= 10;
			s->number64 += digit_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_NUMBER64_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st999;
st999:
	if ( ++p == pe )
		goto _test_eof999;
case 999:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr2863;
		case 32: goto tr2863;
		case 40: goto tr2864;
		case 41: goto tr2865;
		case 2058: goto tr2867;
		case 2107: goto tr2868;
	}
	if ( 48 <= _widec && _widec <= 57 )
		goto tr2866;
	goto tr2396;
tr2870:
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st1000;
tr2871:
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st1000;
tr2873:
	{
		s->line_counter++;
	}
	goto st1000;
tr2905:
	{
		s->buffer[s->buffer_length++] = 0;

		// Execute the comment callback.
		if (s->process.automatic && s->process.comment != NULL) {
			s->process.comment(s);

			// Stop if required from the callback.
			if (s->state == ZS_STATE_STOP) {
				{p++; cs = 1000; goto _out;}
			}
		}
	}
	{
		s->line_counter++;
	}
	goto st1000;
tr2863:
	{
		if (s->number64 <= UINT16_MAX) {
			uint16_t num16 = htons((uint16_t)s->number64);
			memcpy(rdata_tail, &num16, 2);
			rdata_tail += 2;
		} else {
			WARN(ZS_NUMBER16_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st1000;
tr2864:
	{
		if (s->number64 <= UINT16_MAX) {
			uint16_t num16 = htons((uint16_t)s->number64);
			memcpy(rdata_tail, &num16, 2);
			rdata_tail += 2;
		} else {
			WARN(ZS_NUMBER16_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st1000;
tr2865:
	{
		if (s->number64 <= UINT16_MAX) {
			uint16_t num16 = htons((uint16_t)s->number64);
			memcpy(rdata_tail, &num16, 2);
			rdata_tail += 2;
		} else {
			WARN(ZS_NUMBER16_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st1000;
tr2867:
	{
		if (s->number64 <= UINT16_MAX) {
			uint16_t num16 = htons((uint16_t)s->number64);
			memcpy(rdata_tail, &num16, 2);
			rdata_tail += 2;
		} else {
			WARN(ZS_NUMBER16_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		s->line_counter++;
	}
	goto st1000;
st1000:
	if ( ++p == pe )
		goto _test_eof1000;
case 1000:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto st1000;
		case 32: goto st1000;
		case 40: goto tr2870;
		case 41: goto tr2871;
		case 2058: goto tr2873;
		case 2107: goto tr2874;
	}
	if ( 48 <= _widec && _widec <= 57 )
		goto tr2872;
	goto tr2396;
tr2872:
	{
		s->number64 = 0;
	}
	{
		// Overflow check: 10*(s->number64) + fc - '0' <= UINT64_MAX
		if ((s->number64 < (UINT64_MAX / 10)) ||   // Dominant fast check.
			((s->number64 == (UINT64_MAX / 10)) && // Marginal case.
			 ((uint8_t)(*p) <= (UINT64_MAX % 10) + '0')
			)
		   ) {
			s->number64 *= 10;
			s->number64 += digit_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_NUMBER64_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st1001;
tr2878:
	{
		// Overflow check: 10*(s->number64) + fc - '0' <= UINT64_MAX
		if ((s->number64 < (UINT64_MAX / 10)) ||   // Dominant fast check.
			((s->number64 == (UINT64_MAX / 10)) && // Marginal case.
			 ((uint8_t)(*p) <= (UINT64_MAX % 10) + '0')
			)
		   ) {
			s->number64 *= 10;
			s->number64 += digit_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_NUMBER64_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st1001;
st1001:
	if ( ++p == pe )
		goto _test_eof1001;
case 1001:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr2875;
		case 32: goto tr2875;
		case 40: goto tr2876;
		case 41: goto tr2877;
		case 2058: goto tr2879;
		case 2107: goto tr2880;
	}
	if ( 48 <= _widec && _widec <= 57 )
		goto tr2878;
	goto tr2396;
tr2882:
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st1002;
tr2883:
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st1002;
tr2885:
	{
		s->line_counter++;
	}
	goto st1002;
tr2903:
	{
		s->buffer[s->buffer_length++] = 0;

		// Execute the comment callback.
		if (s->process.automatic && s->process.comment != NULL) {
			s->process.comment(s);

			// Stop if required from the callback.
			if (s->state == ZS_STATE_STOP) {
				{p++; cs = 1002; goto _out;}
			}
		}
	}
	{
		s->line_counter++;
	}
	goto st1002;
tr2875:
	{
		if (s->number64 <= UINT16_MAX) {
			uint16_t num16 = htons((uint16_t)s->number64);
			memcpy(rdata_tail, &num16, 2);
			rdata_tail += 2;
		} else {
			WARN(ZS_NUMBER16_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st1002;
tr2876:
	{
		if (s->number64 <= UINT16_MAX) {
			uint16_t num16 = htons((uint16_t)s->number64);
			memcpy(rdata_tail, &num16, 2);
			rdata_tail += 2;
		} else {
			WARN(ZS_NUMBER16_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st1002;
tr2877:
	{
		if (s->number64 <= UINT16_MAX) {
			uint16_t num16 = htons((uint16_t)s->number64);
			memcpy(rdata_tail, &num16, 2);
			rdata_tail += 2;
		} else {
			WARN(ZS_NUMBER16_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st1002;
tr2879:
	{
		if (s->number64 <= UINT16_MAX) {
			uint16_t num16 = htons((uint16_t)s->number64);
			memcpy(rdata_tail, &num16, 2);
			rdata_tail += 2;
		} else {
			WARN(ZS_NUMBER16_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		s->line_counter++;
	}
	goto st1002;
st1002:
	if ( ++p == pe )
		goto _test_eof1002;
case 1002:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto st1002;
		case 32: goto st1002;
		case 40: goto tr2882;
		case 41: goto tr2883;
		case 2058: goto tr2885;
		case 2107: goto tr2886;
	}
	if ( 48 <= _widec && _widec <= 57 )
		goto tr2884;
	goto tr2396;
tr2884:
	{
		s->number64 = 0;
	}
	{
		// Overflow check: 10*(s->number64) + fc - '0' <= UINT64_MAX
		if ((s->number64 < (UINT64_MAX / 10)) ||   // Dominant fast check.
			((s->number64 == (UINT64_MAX / 10)) && // Marginal case.
			 ((uint8_t)(*p) <= (UINT64_MAX % 10) + '0')
			)
		   ) {
			s->number64 *= 10;
			s->number64 += digit_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_NUMBER64_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st1003;
tr2890:
	{
		// Overflow check: 10*(s->number64) + fc - '0' <= UINT64_MAX
		if ((s->number64 < (UINT64_MAX / 10)) ||   // Dominant fast check.
			((s->number64 == (UINT64_MAX / 10)) && // Marginal case.
			 ((uint8_t)(*p) <= (UINT64_MAX % 10) + '0')
			)
		   ) {
			s->number64 *= 10;
			s->number64 += digit_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_NUMBER64_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st1003;
st1003:
	if ( ++p == pe )
		goto _test_eof1003;
case 1003:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr2887;
		case 32: goto tr2887;
		case 40: goto tr2888;
		case 41: goto tr2889;
		case 2058: goto tr2891;
		case 2107: goto tr2892;
	}
	if ( 48 <= _widec && _widec <= 57 )
		goto tr2890;
	goto tr2396;
tr2894:
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st1004;
tr2895:
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st1004;
tr2897:
	{
		s->line_counter++;
	}
	goto st1004;
tr2901:
	{
		s->buffer[s->buffer_length++] = 0;

		// Execute the comment callback.
		if (s->process.automatic && s->process.comment != NULL) {
			s->process.comment(s);

			// Stop if required from the callback.
			if (s->state == ZS_STATE_STOP) {
				{p++; cs = 1004; goto _out;}
			}
		}
	}
	{
		s->line_counter++;
	}
	goto st1004;
tr2887:
	{
		if (s->number64 <= UINT16_MAX) {
			uint16_t num16 = htons((uint16_t)s->number64);
			memcpy(rdata_tail, &num16, 2);
			rdata_tail += 2;
		} else {
			WARN(ZS_NUMBER16_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st1004;
tr2888:
	{
		if (s->number64 <= UINT16_MAX) {
			uint16_t num16 = htons((uint16_t)s->number64);
			memcpy(rdata_tail, &num16, 2);
			rdata_tail += 2;
		} else {
			WARN(ZS_NUMBER16_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st1004;
tr2889:
	{
		if (s->number64 <= UINT16_MAX) {
			uint16_t num16 = htons((uint16_t)s->number64);
			memcpy(rdata_tail, &num16, 2);
			rdata_tail += 2;
		} else {
			WARN(ZS_NUMBER16_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st1004;
tr2891:
	{
		if (s->number64 <= UINT16_MAX) {
			uint16_t num16 = htons((uint16_t)s->number64);
			memcpy(rdata_tail, &num16, 2);
			rdata_tail += 2;
		} else {
			WARN(ZS_NUMBER16_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		s->line_counter++;
	}
	goto st1004;
st1004:
	if ( ++p == pe )
		goto _test_eof1004;
case 1004:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto st1004;
		case 32: goto st1004;
		case 40: goto tr2894;
		case 41: goto tr2895;
		case 42: goto tr2896;
		case 92: goto tr2896;
		case 95: goto tr2896;
		case 2058: goto tr2897;
		case 2107: goto tr2898;
	}
	if ( _widec < 64 ) {
		if ( 45 <= _widec && _widec <= 57 )
			goto tr2896;
	} else if ( _widec > 90 ) {
		if ( 97 <= _widec && _widec <= 122 )
			goto tr2896;
	} else
		goto tr2896;
	goto tr77;
tr2896:
	{
		s->dname = rdata_tail;
	}
	{ p--; {stack[top++] = 1005;goto st318;} }
	goto st1005;
st1005:
	if ( ++p == pe )
		goto _test_eof1005;
case 1005:
	switch( (*p) ) {
		case 32: goto tr2899;
		case 59: goto tr2899;
	}
	if ( (*p) > 10 ) {
		if ( 40 <= (*p) && (*p) <= 41 )
			goto tr2899;
	} else if ( (*p) >= 9 )
		goto tr2899;
	goto tr77;
tr2899:
	{
		rdata_tail += s->dname_tmp_length;
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1502;
st1502:
	if ( ++p == pe )
		goto _test_eof1502;
case 1502:
	goto st0;
tr2898:
	{
		s->buffer_length = 0;
	}
	goto st1006;
tr2900:
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		}
	}
	goto st1006;
tr2892:
	{
		if (s->number64 <= UINT16_MAX) {
			uint16_t num16 = htons((uint16_t)s->number64);
			memcpy(rdata_tail, &num16, 2);
			rdata_tail += 2;
		} else {
			WARN(ZS_NUMBER16_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		s->buffer_length = 0;
	}
	goto st1006;
st1006:
	if ( ++p == pe )
		goto _test_eof1006;
case 1006:
	_widec = (*p);
	if ( (*p) < 10 ) {
		if ( (*p) <= 9 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) > 10 ) {
		if ( 11 <= (*p) )
 {			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	if ( _widec == 2058 )
		goto tr2901;
	if ( 1920 <= _widec && _widec <= 2175 )
		goto tr2900;
	goto tr77;
tr2886:
	{
		s->buffer_length = 0;
	}
	goto st1007;
tr2902:
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		}
	}
	goto st1007;
tr2880:
	{
		if (s->number64 <= UINT16_MAX) {
			uint16_t num16 = htons((uint16_t)s->number64);
			memcpy(rdata_tail, &num16, 2);
			rdata_tail += 2;
		} else {
			WARN(ZS_NUMBER16_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		s->buffer_length = 0;
	}
	goto st1007;
st1007:
	if ( ++p == pe )
		goto _test_eof1007;
case 1007:
	_widec = (*p);
	if ( (*p) < 10 ) {
		if ( (*p) <= 9 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) > 10 ) {
		if ( 11 <= (*p) )
 {			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	if ( _widec == 2058 )
		goto tr2903;
	if ( 1920 <= _widec && _widec <= 2175 )
		goto tr2902;
	goto tr77;
tr2874:
	{
		s->buffer_length = 0;
	}
	goto st1008;
tr2904:
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		}
	}
	goto st1008;
tr2868:
	{
		if (s->number64 <= UINT16_MAX) {
			uint16_t num16 = htons((uint16_t)s->number64);
			memcpy(rdata_tail, &num16, 2);
			rdata_tail += 2;
		} else {
			WARN(ZS_NUMBER16_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		s->buffer_length = 0;
	}
	goto st1008;
st1008:
	if ( ++p == pe )
		goto _test_eof1008;
case 1008:
	_widec = (*p);
	if ( (*p) < 10 ) {
		if ( (*p) <= 9 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) > 10 ) {
		if ( 11 <= (*p) )
 {			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	if ( _widec == 2058 )
		goto tr2905;
	if ( 1920 <= _widec && _widec <= 2175 )
		goto tr2904;
	goto tr77;
st1009:
	if ( ++p == pe )
		goto _test_eof1009;
case 1009:
	if ( 48 <= (*p) && (*p) <= 57 )
		goto tr2906;
	goto tr2396;
tr2906:
	{
		s->number64 = 0;
	}
	{
		// Overflow check: 10*(s->number64) + fc - '0' <= UINT64_MAX
		if ((s->number64 < (UINT64_MAX / 10)) ||   // Dominant fast check.
			((s->number64 == (UINT64_MAX / 10)) && // Marginal case.
			 ((uint8_t)(*p) <= (UINT64_MAX % 10) + '0')
			)
		   ) {
			s->number64 *= 10;
			s->number64 += digit_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_NUMBER64_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st1010;
tr2910:
	{
		// Overflow check: 10*(s->number64) + fc - '0' <= UINT64_MAX
		if ((s->number64 < (UINT64_MAX / 10)) ||   // Dominant fast check.
			((s->number64 == (UINT64_MAX / 10)) && // Marginal case.
			 ((uint8_t)(*p) <= (UINT64_MAX % 10) + '0')
			)
		   ) {
			s->number64 *= 10;
			s->number64 += digit_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_NUMBER64_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st1010;
st1010:
	if ( ++p == pe )
		goto _test_eof1010;
case 1010:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr2907;
		case 32: goto tr2907;
		case 40: goto tr2908;
		case 41: goto tr2909;
		case 2058: goto tr2911;
		case 2107: goto tr2912;
	}
	if ( 48 <= _widec && _widec <= 57 )
		goto tr2910;
	goto tr2396;
tr2914:
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st1011;
tr2915:
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st1011;
tr2917:
	{
		s->line_counter++;
	}
	goto st1011;
tr2974:
	{
		s->buffer[s->buffer_length++] = 0;

		// Execute the comment callback.
		if (s->process.automatic && s->process.comment != NULL) {
			s->process.comment(s);

			// Stop if required from the callback.
			if (s->state == ZS_STATE_STOP) {
				{p++; cs = 1011; goto _out;}
			}
		}
	}
	{
		s->line_counter++;
	}
	goto st1011;
tr2907:
	{
		if (s->number64 <= UINT16_MAX) {
			uint16_t num16 = htons((uint16_t)s->number64);
			memcpy(rdata_tail, &num16, 2);
			rdata_tail += 2;
		} else {
			WARN(ZS_NUMBER16_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st1011;
tr2908:
	{
		if (s->number64 <= UINT16_MAX) {
			uint16_t num16 = htons((uint16_t)s->number64);
			memcpy(rdata_tail, &num16, 2);
			rdata_tail += 2;
		} else {
			WARN(ZS_NUMBER16_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st1011;
tr2909:
	{
		if (s->number64 <= UINT16_MAX) {
			uint16_t num16 = htons((uint16_t)s->number64);
			memcpy(rdata_tail, &num16, 2);
			rdata_tail += 2;
		} else {
			WARN(ZS_NUMBER16_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st1011;
tr2911:
	{
		if (s->number64 <= UINT16_MAX) {
			uint16_t num16 = htons((uint16_t)s->number64);
			memcpy(rdata_tail, &num16, 2);
			rdata_tail += 2;
		} else {
			WARN(ZS_NUMBER16_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		s->line_counter++;
	}
	goto st1011;
st1011:
	if ( ++p == pe )
		goto _test_eof1011;
case 1011:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto st1011;
		case 32: goto st1011;
		case 40: goto tr2914;
		case 41: goto tr2915;
		case 2058: goto tr2917;
		case 2107: goto tr2918;
	}
	if ( 48 <= _widec && _widec <= 57 )
		goto tr2916;
	goto tr2396;
tr2916:
	{
		s->number64 = 0;
	}
	{
		// Overflow check: 10*(s->number64) + fc - '0' <= UINT64_MAX
		if ((s->number64 < (UINT64_MAX / 10)) ||   // Dominant fast check.
			((s->number64 == (UINT64_MAX / 10)) && // Marginal case.
			 ((uint8_t)(*p) <= (UINT64_MAX % 10) + '0')
			)
		   ) {
			s->number64 *= 10;
			s->number64 += digit_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_NUMBER64_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st1012;
tr2922:
	{
		// Overflow check: 10*(s->number64) + fc - '0' <= UINT64_MAX
		if ((s->number64 < (UINT64_MAX / 10)) ||   // Dominant fast check.
			((s->number64 == (UINT64_MAX / 10)) && // Marginal case.
			 ((uint8_t)(*p) <= (UINT64_MAX % 10) + '0')
			)
		   ) {
			s->number64 *= 10;
			s->number64 += digit_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_NUMBER64_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st1012;
st1012:
	if ( ++p == pe )
		goto _test_eof1012;
case 1012:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr2919;
		case 32: goto tr2919;
		case 40: goto tr2920;
		case 41: goto tr2921;
		case 2058: goto tr2923;
		case 2107: goto tr2924;
	}
	if ( 48 <= _widec && _widec <= 57 )
		goto tr2922;
	goto tr2396;
tr2927:
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st1013;
tr2928:
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st1013;
tr2929:
	{
		s->line_counter++;
	}
	goto st1013;
tr2972:
	{
		s->buffer[s->buffer_length++] = 0;

		// Execute the comment callback.
		if (s->process.automatic && s->process.comment != NULL) {
			s->process.comment(s);

			// Stop if required from the callback.
			if (s->state == ZS_STATE_STOP) {
				{p++; cs = 1013; goto _out;}
			}
		}
	}
	{
		s->line_counter++;
	}
	goto st1013;
tr2919:
	{
		if (s->number64 <= UINT16_MAX) {
			uint16_t num16 = htons((uint16_t)s->number64);
			memcpy(rdata_tail, &num16, 2);
			rdata_tail += 2;
		} else {
			WARN(ZS_NUMBER16_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st1013;
tr2920:
	{
		if (s->number64 <= UINT16_MAX) {
			uint16_t num16 = htons((uint16_t)s->number64);
			memcpy(rdata_tail, &num16, 2);
			rdata_tail += 2;
		} else {
			WARN(ZS_NUMBER16_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st1013;
tr2921:
	{
		if (s->number64 <= UINT16_MAX) {
			uint16_t num16 = htons((uint16_t)s->number64);
			memcpy(rdata_tail, &num16, 2);
			rdata_tail += 2;
		} else {
			WARN(ZS_NUMBER16_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st1013;
tr2923:
	{
		if (s->number64 <= UINT16_MAX) {
			uint16_t num16 = htons((uint16_t)s->number64);
			memcpy(rdata_tail, &num16, 2);
			rdata_tail += 2;
		} else {
			WARN(ZS_NUMBER16_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		s->line_counter++;
	}
	goto st1013;
st1013:
	if ( ++p == pe )
		goto _test_eof1013;
case 1013:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto st1013;
		case 32: goto st1013;
		case 40: goto tr2927;
		case 41: goto tr2928;
		case 2058: goto tr2929;
		case 2107: goto tr2930;
	}
	if ( _widec < 11 ) {
		if ( _widec <= 8 )
			goto tr2925;
	} else if ( _widec > 58 ) {
		if ( 60 <= _widec )
			goto tr2925;
	} else
		goto tr2925;
	goto tr77;
tr2925:
	{
		if (rdata_tail <= rdata_stop) {
			s->item_length_location = rdata_tail++;
		} else {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{ p--; {stack[top++] = 1014;goto st327;} }
	goto st1014;
st1014:
	if ( ++p == pe )
		goto _test_eof1014;
case 1014:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr2931;
		case 32: goto tr2931;
		case 40: goto tr2932;
		case 41: goto tr2933;
		case 2058: goto tr2934;
		case 2107: goto tr2935;
	}
	goto tr77;
tr2938:
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st1015;
tr2939:
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st1015;
tr2940:
	{
		s->line_counter++;
	}
	goto st1015;
tr2970:
	{
		s->buffer[s->buffer_length++] = 0;

		// Execute the comment callback.
		if (s->process.automatic && s->process.comment != NULL) {
			s->process.comment(s);

			// Stop if required from the callback.
			if (s->state == ZS_STATE_STOP) {
				{p++; cs = 1015; goto _out;}
			}
		}
	}
	{
		s->line_counter++;
	}
	goto st1015;
tr2931:
	{
		s->item_length = rdata_tail - s->item_length_location - 1;
		if (s->comma_list && s->item_length == 0) {
			WARN(ZS_EMPTY_LIST_ITEM);
			p--; {goto st316;}
		}
		if (s->item_length <= MAX_ITEM_LENGTH) {
			*(s->item_length_location) = (uint8_t)(s->item_length);
		} else {
			WARN(ZS_ITEM_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st1015;
tr2932:
	{
		s->item_length = rdata_tail - s->item_length_location - 1;
		if (s->comma_list && s->item_length == 0) {
			WARN(ZS_EMPTY_LIST_ITEM);
			p--; {goto st316;}
		}
		if (s->item_length <= MAX_ITEM_LENGTH) {
			*(s->item_length_location) = (uint8_t)(s->item_length);
		} else {
			WARN(ZS_ITEM_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st1015;
tr2933:
	{
		s->item_length = rdata_tail - s->item_length_location - 1;
		if (s->comma_list && s->item_length == 0) {
			WARN(ZS_EMPTY_LIST_ITEM);
			p--; {goto st316;}
		}
		if (s->item_length <= MAX_ITEM_LENGTH) {
			*(s->item_length_location) = (uint8_t)(s->item_length);
		} else {
			WARN(ZS_ITEM_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st1015;
tr2934:
	{
		s->item_length = rdata_tail - s->item_length_location - 1;
		if (s->comma_list && s->item_length == 0) {
			WARN(ZS_EMPTY_LIST_ITEM);
			p--; {goto st316;}
		}
		if (s->item_length <= MAX_ITEM_LENGTH) {
			*(s->item_length_location) = (uint8_t)(s->item_length);
		} else {
			WARN(ZS_ITEM_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		s->line_counter++;
	}
	goto st1015;
st1015:
	if ( ++p == pe )
		goto _test_eof1015;
case 1015:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto st1015;
		case 32: goto st1015;
		case 40: goto tr2938;
		case 41: goto tr2939;
		case 2058: goto tr2940;
		case 2107: goto tr2941;
	}
	if ( _widec < 11 ) {
		if ( _widec <= 8 )
			goto tr2936;
	} else if ( _widec > 58 ) {
		if ( 60 <= _widec )
			goto tr2936;
	} else
		goto tr2936;
	goto tr77;
tr2936:
	{
		if (rdata_tail <= rdata_stop) {
			s->item_length_location = rdata_tail++;
		} else {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{ p--; {stack[top++] = 1016;goto st327;} }
	goto st1016;
st1016:
	if ( ++p == pe )
		goto _test_eof1016;
case 1016:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr2942;
		case 32: goto tr2942;
		case 40: goto tr2943;
		case 41: goto tr2944;
		case 2058: goto tr2945;
		case 2107: goto tr2946;
	}
	goto tr77;
tr2949:
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st1017;
tr2950:
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st1017;
tr2951:
	{
		s->line_counter++;
	}
	goto st1017;
tr2968:
	{
		s->buffer[s->buffer_length++] = 0;

		// Execute the comment callback.
		if (s->process.automatic && s->process.comment != NULL) {
			s->process.comment(s);

			// Stop if required from the callback.
			if (s->state == ZS_STATE_STOP) {
				{p++; cs = 1017; goto _out;}
			}
		}
	}
	{
		s->line_counter++;
	}
	goto st1017;
tr2942:
	{
		s->item_length = rdata_tail - s->item_length_location - 1;
		if (s->comma_list && s->item_length == 0) {
			WARN(ZS_EMPTY_LIST_ITEM);
			p--; {goto st316;}
		}
		if (s->item_length <= MAX_ITEM_LENGTH) {
			*(s->item_length_location) = (uint8_t)(s->item_length);
		} else {
			WARN(ZS_ITEM_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st1017;
tr2943:
	{
		s->item_length = rdata_tail - s->item_length_location - 1;
		if (s->comma_list && s->item_length == 0) {
			WARN(ZS_EMPTY_LIST_ITEM);
			p--; {goto st316;}
		}
		if (s->item_length <= MAX_ITEM_LENGTH) {
			*(s->item_length_location) = (uint8_t)(s->item_length);
		} else {
			WARN(ZS_ITEM_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st1017;
tr2944:
	{
		s->item_length = rdata_tail - s->item_length_location - 1;
		if (s->comma_list && s->item_length == 0) {
			WARN(ZS_EMPTY_LIST_ITEM);
			p--; {goto st316;}
		}
		if (s->item_length <= MAX_ITEM_LENGTH) {
			*(s->item_length_location) = (uint8_t)(s->item_length);
		} else {
			WARN(ZS_ITEM_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st1017;
tr2945:
	{
		s->item_length = rdata_tail - s->item_length_location - 1;
		if (s->comma_list && s->item_length == 0) {
			WARN(ZS_EMPTY_LIST_ITEM);
			p--; {goto st316;}
		}
		if (s->item_length <= MAX_ITEM_LENGTH) {
			*(s->item_length_location) = (uint8_t)(s->item_length);
		} else {
			WARN(ZS_ITEM_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		s->line_counter++;
	}
	goto st1017;
st1017:
	if ( ++p == pe )
		goto _test_eof1017;
case 1017:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto st1017;
		case 32: goto st1017;
		case 40: goto tr2949;
		case 41: goto tr2950;
		case 2058: goto tr2951;
		case 2107: goto tr2952;
	}
	if ( _widec < 11 ) {
		if ( _widec <= 8 )
			goto tr2947;
	} else if ( _widec > 58 ) {
		if ( 60 <= _widec )
			goto tr2947;
	} else
		goto tr2947;
	goto tr77;
tr2947:
	{
		if (rdata_tail <= rdata_stop) {
			s->item_length_location = rdata_tail++;
		} else {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{ p--; {stack[top++] = 1018;goto st327;} }
	goto st1018;
st1018:
	if ( ++p == pe )
		goto _test_eof1018;
case 1018:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr2953;
		case 32: goto tr2953;
		case 40: goto tr2954;
		case 41: goto tr2955;
		case 2058: goto tr2956;
		case 2107: goto tr2957;
	}
	goto tr77;
tr2959:
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st1019;
tr2960:
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st1019;
tr2962:
	{
		s->line_counter++;
	}
	goto st1019;
tr2966:
	{
		s->buffer[s->buffer_length++] = 0;

		// Execute the comment callback.
		if (s->process.automatic && s->process.comment != NULL) {
			s->process.comment(s);

			// Stop if required from the callback.
			if (s->state == ZS_STATE_STOP) {
				{p++; cs = 1019; goto _out;}
			}
		}
	}
	{
		s->line_counter++;
	}
	goto st1019;
tr2953:
	{
		s->item_length = rdata_tail - s->item_length_location - 1;
		if (s->comma_list && s->item_length == 0) {
			WARN(ZS_EMPTY_LIST_ITEM);
			p--; {goto st316;}
		}
		if (s->item_length <= MAX_ITEM_LENGTH) {
			*(s->item_length_location) = (uint8_t)(s->item_length);
		} else {
			WARN(ZS_ITEM_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st1019;
tr2954:
	{
		s->item_length = rdata_tail - s->item_length_location - 1;
		if (s->comma_list && s->item_length == 0) {
			WARN(ZS_EMPTY_LIST_ITEM);
			p--; {goto st316;}
		}
		if (s->item_length <= MAX_ITEM_LENGTH) {
			*(s->item_length_location) = (uint8_t)(s->item_length);
		} else {
			WARN(ZS_ITEM_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st1019;
tr2955:
	{
		s->item_length = rdata_tail - s->item_length_location - 1;
		if (s->comma_list && s->item_length == 0) {
			WARN(ZS_EMPTY_LIST_ITEM);
			p--; {goto st316;}
		}
		if (s->item_length <= MAX_ITEM_LENGTH) {
			*(s->item_length_location) = (uint8_t)(s->item_length);
		} else {
			WARN(ZS_ITEM_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st1019;
tr2956:
	{
		s->item_length = rdata_tail - s->item_length_location - 1;
		if (s->comma_list && s->item_length == 0) {
			WARN(ZS_EMPTY_LIST_ITEM);
			p--; {goto st316;}
		}
		if (s->item_length <= MAX_ITEM_LENGTH) {
			*(s->item_length_location) = (uint8_t)(s->item_length);
		} else {
			WARN(ZS_ITEM_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		s->line_counter++;
	}
	goto st1019;
st1019:
	if ( ++p == pe )
		goto _test_eof1019;
case 1019:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto st1019;
		case 32: goto st1019;
		case 40: goto tr2959;
		case 41: goto tr2960;
		case 42: goto tr2961;
		case 92: goto tr2961;
		case 95: goto tr2961;
		case 2058: goto tr2962;
		case 2107: goto tr2963;
	}
	if ( _widec < 64 ) {
		if ( 45 <= _widec && _widec <= 57 )
			goto tr2961;
	} else if ( _widec > 90 ) {
		if ( 97 <= _widec && _widec <= 122 )
			goto tr2961;
	} else
		goto tr2961;
	goto tr77;
tr2961:
	{
		s->dname = rdata_tail;
	}
	{ p--; {stack[top++] = 1020;goto st318;} }
	goto st1020;
st1020:
	if ( ++p == pe )
		goto _test_eof1020;
case 1020:
	switch( (*p) ) {
		case 32: goto tr2964;
		case 59: goto tr2964;
	}
	if ( (*p) > 10 ) {
		if ( 40 <= (*p) && (*p) <= 41 )
			goto tr2964;
	} else if ( (*p) >= 9 )
		goto tr2964;
	goto tr77;
tr2964:
	{
		rdata_tail += s->dname_tmp_length;
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1503;
st1503:
	if ( ++p == pe )
		goto _test_eof1503;
case 1503:
	goto st0;
tr2963:
	{
		s->buffer_length = 0;
	}
	goto st1021;
tr2965:
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		}
	}
	goto st1021;
tr2957:
	{
		s->item_length = rdata_tail - s->item_length_location - 1;
		if (s->comma_list && s->item_length == 0) {
			WARN(ZS_EMPTY_LIST_ITEM);
			p--; {goto st316;}
		}
		if (s->item_length <= MAX_ITEM_LENGTH) {
			*(s->item_length_location) = (uint8_t)(s->item_length);
		} else {
			WARN(ZS_ITEM_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		s->buffer_length = 0;
	}
	goto st1021;
st1021:
	if ( ++p == pe )
		goto _test_eof1021;
case 1021:
	_widec = (*p);
	if ( (*p) < 10 ) {
		if ( (*p) <= 9 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) > 10 ) {
		if ( 11 <= (*p) )
 {			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	if ( _widec == 2058 )
		goto tr2966;
	if ( 1920 <= _widec && _widec <= 2175 )
		goto tr2965;
	goto tr77;
tr2952:
	{
		s->buffer_length = 0;
	}
	goto st1022;
tr2967:
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		}
	}
	goto st1022;
tr2946:
	{
		s->item_length = rdata_tail - s->item_length_location - 1;
		if (s->comma_list && s->item_length == 0) {
			WARN(ZS_EMPTY_LIST_ITEM);
			p--; {goto st316;}
		}
		if (s->item_length <= MAX_ITEM_LENGTH) {
			*(s->item_length_location) = (uint8_t)(s->item_length);
		} else {
			WARN(ZS_ITEM_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		s->buffer_length = 0;
	}
	goto st1022;
st1022:
	if ( ++p == pe )
		goto _test_eof1022;
case 1022:
	_widec = (*p);
	if ( (*p) < 10 ) {
		if ( (*p) <= 9 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) > 10 ) {
		if ( 11 <= (*p) )
 {			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	if ( _widec == 2058 )
		goto tr2968;
	if ( 1920 <= _widec && _widec <= 2175 )
		goto tr2967;
	goto tr77;
tr2941:
	{
		s->buffer_length = 0;
	}
	goto st1023;
tr2969:
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		}
	}
	goto st1023;
tr2935:
	{
		s->item_length = rdata_tail - s->item_length_location - 1;
		if (s->comma_list && s->item_length == 0) {
			WARN(ZS_EMPTY_LIST_ITEM);
			p--; {goto st316;}
		}
		if (s->item_length <= MAX_ITEM_LENGTH) {
			*(s->item_length_location) = (uint8_t)(s->item_length);
		} else {
			WARN(ZS_ITEM_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		s->buffer_length = 0;
	}
	goto st1023;
st1023:
	if ( ++p == pe )
		goto _test_eof1023;
case 1023:
	_widec = (*p);
	if ( (*p) < 10 ) {
		if ( (*p) <= 9 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) > 10 ) {
		if ( 11 <= (*p) )
 {			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	if ( _widec == 2058 )
		goto tr2970;
	if ( 1920 <= _widec && _widec <= 2175 )
		goto tr2969;
	goto tr77;
tr2930:
	{
		s->buffer_length = 0;
	}
	goto st1024;
tr2971:
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		}
	}
	goto st1024;
tr2924:
	{
		if (s->number64 <= UINT16_MAX) {
			uint16_t num16 = htons((uint16_t)s->number64);
			memcpy(rdata_tail, &num16, 2);
			rdata_tail += 2;
		} else {
			WARN(ZS_NUMBER16_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		s->buffer_length = 0;
	}
	goto st1024;
st1024:
	if ( ++p == pe )
		goto _test_eof1024;
case 1024:
	_widec = (*p);
	if ( (*p) < 10 ) {
		if ( (*p) <= 9 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) > 10 ) {
		if ( 11 <= (*p) )
 {			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	if ( _widec == 2058 )
		goto tr2972;
	if ( 1920 <= _widec && _widec <= 2175 )
		goto tr2971;
	goto tr77;
tr2918:
	{
		s->buffer_length = 0;
	}
	goto st1025;
tr2973:
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		}
	}
	goto st1025;
tr2912:
	{
		if (s->number64 <= UINT16_MAX) {
			uint16_t num16 = htons((uint16_t)s->number64);
			memcpy(rdata_tail, &num16, 2);
			rdata_tail += 2;
		} else {
			WARN(ZS_NUMBER16_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		s->buffer_length = 0;
	}
	goto st1025;
st1025:
	if ( ++p == pe )
		goto _test_eof1025;
case 1025:
	_widec = (*p);
	if ( (*p) < 10 ) {
		if ( (*p) <= 9 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) > 10 ) {
		if ( 11 <= (*p) )
 {			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	if ( _widec == 2058 )
		goto tr2974;
	if ( 1920 <= _widec && _widec <= 2175 )
		goto tr2973;
	goto tr77;
st1026:
	if ( ++p == pe )
		goto _test_eof1026;
case 1026:
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr2975;
	} else if ( (*p) > 90 ) {
		if ( 97 <= (*p) && (*p) <= 122 )
			goto tr2975;
	} else
		goto tr2975;
	goto tr77;
tr2975:
	{ p--; {stack[top++] = 1027;goto st845;} }
	goto st1027;
st1027:
	if ( ++p == pe )
		goto _test_eof1027;
case 1027:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto st1028;
		case 32: goto st1028;
		case 40: goto tr2977;
		case 41: goto tr2978;
		case 2058: goto tr2979;
		case 2107: goto tr2980;
	}
	goto tr77;
tr2977:
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st1028;
tr2978:
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st1028;
tr2979:
	{
		s->line_counter++;
	}
	goto st1028;
tr3006:
	{
		s->buffer[s->buffer_length++] = 0;

		// Execute the comment callback.
		if (s->process.automatic && s->process.comment != NULL) {
			s->process.comment(s);

			// Stop if required from the callback.
			if (s->state == ZS_STATE_STOP) {
				{p++; cs = 1028; goto _out;}
			}
		}
	}
	{
		s->line_counter++;
	}
	goto st1028;
st1028:
	if ( ++p == pe )
		goto _test_eof1028;
case 1028:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto st1028;
		case 32: goto st1028;
		case 40: goto tr2977;
		case 41: goto tr2978;
		case 2058: goto tr2979;
		case 2107: goto tr2980;
	}
	if ( 48 <= _widec && _widec <= 57 )
		goto tr2981;
	goto tr2396;
tr2981:
	{
		s->number64 = 0;
	}
	{
		// Overflow check: 10*(s->number64) + fc - '0' <= UINT64_MAX
		if ((s->number64 < (UINT64_MAX / 10)) ||   // Dominant fast check.
			((s->number64 == (UINT64_MAX / 10)) && // Marginal case.
			 ((uint8_t)(*p) <= (UINT64_MAX % 10) + '0')
			)
		   ) {
			s->number64 *= 10;
			s->number64 += digit_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_NUMBER64_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st1029;
tr2985:
	{
		// Overflow check: 10*(s->number64) + fc - '0' <= UINT64_MAX
		if ((s->number64 < (UINT64_MAX / 10)) ||   // Dominant fast check.
			((s->number64 == (UINT64_MAX / 10)) && // Marginal case.
			 ((uint8_t)(*p) <= (UINT64_MAX % 10) + '0')
			)
		   ) {
			s->number64 *= 10;
			s->number64 += digit_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_NUMBER64_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st1029;
st1029:
	if ( ++p == pe )
		goto _test_eof1029;
case 1029:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr2982;
		case 32: goto tr2982;
		case 40: goto tr2983;
		case 41: goto tr2984;
		case 2058: goto tr2986;
		case 2107: goto tr2987;
	}
	if ( 48 <= _widec && _widec <= 57 )
		goto tr2985;
	goto tr2396;
tr2989:
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st1030;
tr2990:
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st1030;
tr2992:
	{
		s->line_counter++;
	}
	goto st1030;
tr3004:
	{
		s->buffer[s->buffer_length++] = 0;

		// Execute the comment callback.
		if (s->process.automatic && s->process.comment != NULL) {
			s->process.comment(s);

			// Stop if required from the callback.
			if (s->state == ZS_STATE_STOP) {
				{p++; cs = 1030; goto _out;}
			}
		}
	}
	{
		s->line_counter++;
	}
	goto st1030;
tr2982:
	{
		if (s->number64 <= UINT16_MAX) {
			uint16_t num16 = htons((uint16_t)s->number64);
			memcpy(rdata_tail, &num16, 2);
			rdata_tail += 2;
		} else {
			WARN(ZS_NUMBER16_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st1030;
tr2983:
	{
		if (s->number64 <= UINT16_MAX) {
			uint16_t num16 = htons((uint16_t)s->number64);
			memcpy(rdata_tail, &num16, 2);
			rdata_tail += 2;
		} else {
			WARN(ZS_NUMBER16_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st1030;
tr2984:
	{
		if (s->number64 <= UINT16_MAX) {
			uint16_t num16 = htons((uint16_t)s->number64);
			memcpy(rdata_tail, &num16, 2);
			rdata_tail += 2;
		} else {
			WARN(ZS_NUMBER16_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st1030;
tr2986:
	{
		if (s->number64 <= UINT16_MAX) {
			uint16_t num16 = htons((uint16_t)s->number64);
			memcpy(rdata_tail, &num16, 2);
			rdata_tail += 2;
		} else {
			WARN(ZS_NUMBER16_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		s->line_counter++;
	}
	goto st1030;
st1030:
	if ( ++p == pe )
		goto _test_eof1030;
case 1030:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto st1030;
		case 32: goto st1030;
		case 40: goto tr2989;
		case 41: goto tr2990;
		case 2058: goto tr2992;
		case 2107: goto tr2993;
	}
	if ( _widec < 65 ) {
		if ( 48 <= _widec && _widec <= 57 )
			goto tr2991;
	} else if ( _widec > 90 ) {
		if ( 97 <= _widec && _widec <= 122 )
			goto tr2991;
	} else
		goto tr2991;
	goto tr77;
tr2991:
	{ p--; {stack[top++] = 1031;goto st741;} }
	goto st1031;
st1031:
	if ( ++p == pe )
		goto _test_eof1031;
case 1031:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto st1032;
		case 32: goto st1032;
		case 40: goto tr2995;
		case 41: goto tr2996;
		case 2058: goto tr2997;
		case 2107: goto tr2998;
	}
	goto tr77;
tr2995:
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st1032;
tr2996:
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st1032;
tr2997:
	{
		s->line_counter++;
	}
	goto st1032;
tr3002:
	{
		s->buffer[s->buffer_length++] = 0;

		// Execute the comment callback.
		if (s->process.automatic && s->process.comment != NULL) {
			s->process.comment(s);

			// Stop if required from the callback.
			if (s->state == ZS_STATE_STOP) {
				{p++; cs = 1032; goto _out;}
			}
		}
	}
	{
		s->line_counter++;
	}
	goto st1032;
st1032:
	if ( ++p == pe )
		goto _test_eof1032;
case 1032:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto st1032;
		case 32: goto st1032;
		case 40: goto tr2995;
		case 41: goto tr2996;
		case 43: goto tr2999;
		case 2058: goto tr2997;
		case 2107: goto tr2998;
	}
	if ( _widec < 65 ) {
		if ( 47 <= _widec && _widec <= 57 )
			goto tr2999;
	} else if ( _widec > 90 ) {
		if ( 97 <= _widec && _widec <= 122 )
			goto tr2999;
	} else
		goto tr2999;
	goto tr77;
tr2999:
	{ p--; {stack[top++] = 1033;goto st378;} }
	goto st1033;
st1033:
	if ( ++p == pe )
		goto _test_eof1033;
case 1033:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(2176 + ((*p) - -128));
			if (
 !s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(2176 + ((*p) - -128));
		if (
 !s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 2570: goto tr3000;
		case 2619: goto tr3000;
	}
	goto tr77;
tr3000:
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1504;
st1504:
	if ( ++p == pe )
		goto _test_eof1504;
case 1504:
	goto st0;
tr2998:
	{
		s->buffer_length = 0;
	}
	goto st1034;
tr3001:
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		}
	}
	goto st1034;
st1034:
	if ( ++p == pe )
		goto _test_eof1034;
case 1034:
	_widec = (*p);
	if ( (*p) < 10 ) {
		if ( (*p) <= 9 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) > 10 ) {
		if ( 11 <= (*p) )
 {			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	if ( _widec == 2058 )
		goto tr3002;
	if ( 1920 <= _widec && _widec <= 2175 )
		goto tr3001;
	goto tr77;
tr2993:
	{
		s->buffer_length = 0;
	}
	goto st1035;
tr3003:
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		}
	}
	goto st1035;
tr2987:
	{
		if (s->number64 <= UINT16_MAX) {
			uint16_t num16 = htons((uint16_t)s->number64);
			memcpy(rdata_tail, &num16, 2);
			rdata_tail += 2;
		} else {
			WARN(ZS_NUMBER16_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		s->buffer_length = 0;
	}
	goto st1035;
st1035:
	if ( ++p == pe )
		goto _test_eof1035;
case 1035:
	_widec = (*p);
	if ( (*p) < 10 ) {
		if ( (*p) <= 9 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) > 10 ) {
		if ( 11 <= (*p) )
 {			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	if ( _widec == 2058 )
		goto tr3004;
	if ( 1920 <= _widec && _widec <= 2175 )
		goto tr3003;
	goto tr77;
tr2980:
	{
		s->buffer_length = 0;
	}
	goto st1036;
tr3005:
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		}
	}
	goto st1036;
st1036:
	if ( ++p == pe )
		goto _test_eof1036;
case 1036:
	_widec = (*p);
	if ( (*p) < 10 ) {
		if ( (*p) <= 9 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) > 10 ) {
		if ( 11 <= (*p) )
 {			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	if ( _widec == 2058 )
		goto tr3006;
	if ( 1920 <= _widec && _widec <= 2175 )
		goto tr3005;
	goto tr77;
tr3010:
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st1037;
tr3011:
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st1037;
tr3014:
	{
		s->line_counter++;
	}
	goto st1037;
tr3037:
	{
		s->buffer[s->buffer_length++] = 0;

		// Execute the comment callback.
		if (s->process.automatic && s->process.comment != NULL) {
			s->process.comment(s);

			// Stop if required from the callback.
			if (s->state == ZS_STATE_STOP) {
				{p++; cs = 1037; goto _out;}
			}
		}
	}
	{
		s->line_counter++;
	}
	goto st1037;
tr3027:
	{
		if ((s->apl.addr_family == 1 && s->number64 <= 32) ||
		    (s->apl.addr_family == 2 && s->number64 <= 128)) {
			s->apl.prefix_length = (uint8_t)(s->number64);
		} else {
			WARN(ZS_BAD_APL);
			p--; {goto st316;}
		}
	}
	{
		// Copy address to buffer.
		uint8_t len;
		switch (s->apl.addr_family) {
		case 1:
			len = ZS_INET4_ADDR_LENGTH;
			memcpy(s->buffer, s->addr, len);
			break;
		case 2:
			len = ZS_INET6_ADDR_LENGTH;
			memcpy(s->buffer, s->addr, len);
			break;
		default:
			WARN(ZS_BAD_APL);
			p--; {goto st316;}
		}
		// Find prefix without trailing zeroes.
		while (len > 0) {
			if ((s->buffer[len - 1] & 255) != 0) {
				break;
			}
			len--;
		}
		// Check for rdata overflow.
		if (rdata_tail + 4 + len > rdata_stop + 1) {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
		// Write address family.
		uint16_t af = htons(s->apl.addr_family);
		memcpy(rdata_tail, &af, sizeof(af));
		rdata_tail += 2;
		// Write prefix length in bits.
		*(rdata_tail) = s->apl.prefix_length;
		rdata_tail += 1;
		// Write negation flag + prefix length in bytes.
		*(rdata_tail) = len + s->apl.excl_flag;
		rdata_tail += 1;
		// Write address prefix non-null data.
		memcpy(rdata_tail, s->buffer, len);
		rdata_tail += len;
	}
	goto st1037;
tr3028:
	{
		if ((s->apl.addr_family == 1 && s->number64 <= 32) ||
		    (s->apl.addr_family == 2 && s->number64 <= 128)) {
			s->apl.prefix_length = (uint8_t)(s->number64);
		} else {
			WARN(ZS_BAD_APL);
			p--; {goto st316;}
		}
	}
	{
		// Copy address to buffer.
		uint8_t len;
		switch (s->apl.addr_family) {
		case 1:
			len = ZS_INET4_ADDR_LENGTH;
			memcpy(s->buffer, s->addr, len);
			break;
		case 2:
			len = ZS_INET6_ADDR_LENGTH;
			memcpy(s->buffer, s->addr, len);
			break;
		default:
			WARN(ZS_BAD_APL);
			p--; {goto st316;}
		}
		// Find prefix without trailing zeroes.
		while (len > 0) {
			if ((s->buffer[len - 1] & 255) != 0) {
				break;
			}
			len--;
		}
		// Check for rdata overflow.
		if (rdata_tail + 4 + len > rdata_stop + 1) {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
		// Write address family.
		uint16_t af = htons(s->apl.addr_family);
		memcpy(rdata_tail, &af, sizeof(af));
		rdata_tail += 2;
		// Write prefix length in bits.
		*(rdata_tail) = s->apl.prefix_length;
		rdata_tail += 1;
		// Write negation flag + prefix length in bytes.
		*(rdata_tail) = len + s->apl.excl_flag;
		rdata_tail += 1;
		// Write address prefix non-null data.
		memcpy(rdata_tail, s->buffer, len);
		rdata_tail += len;
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st1037;
tr3029:
	{
		if ((s->apl.addr_family == 1 && s->number64 <= 32) ||
		    (s->apl.addr_family == 2 && s->number64 <= 128)) {
			s->apl.prefix_length = (uint8_t)(s->number64);
		} else {
			WARN(ZS_BAD_APL);
			p--; {goto st316;}
		}
	}
	{
		// Copy address to buffer.
		uint8_t len;
		switch (s->apl.addr_family) {
		case 1:
			len = ZS_INET4_ADDR_LENGTH;
			memcpy(s->buffer, s->addr, len);
			break;
		case 2:
			len = ZS_INET6_ADDR_LENGTH;
			memcpy(s->buffer, s->addr, len);
			break;
		default:
			WARN(ZS_BAD_APL);
			p--; {goto st316;}
		}
		// Find prefix without trailing zeroes.
		while (len > 0) {
			if ((s->buffer[len - 1] & 255) != 0) {
				break;
			}
			len--;
		}
		// Check for rdata overflow.
		if (rdata_tail + 4 + len > rdata_stop + 1) {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
		// Write address family.
		uint16_t af = htons(s->apl.addr_family);
		memcpy(rdata_tail, &af, sizeof(af));
		rdata_tail += 2;
		// Write prefix length in bits.
		*(rdata_tail) = s->apl.prefix_length;
		rdata_tail += 1;
		// Write negation flag + prefix length in bytes.
		*(rdata_tail) = len + s->apl.excl_flag;
		rdata_tail += 1;
		// Write address prefix non-null data.
		memcpy(rdata_tail, s->buffer, len);
		rdata_tail += len;
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st1037;
tr3031:
	{
		if ((s->apl.addr_family == 1 && s->number64 <= 32) ||
		    (s->apl.addr_family == 2 && s->number64 <= 128)) {
			s->apl.prefix_length = (uint8_t)(s->number64);
		} else {
			WARN(ZS_BAD_APL);
			p--; {goto st316;}
		}
	}
	{
		// Copy address to buffer.
		uint8_t len;
		switch (s->apl.addr_family) {
		case 1:
			len = ZS_INET4_ADDR_LENGTH;
			memcpy(s->buffer, s->addr, len);
			break;
		case 2:
			len = ZS_INET6_ADDR_LENGTH;
			memcpy(s->buffer, s->addr, len);
			break;
		default:
			WARN(ZS_BAD_APL);
			p--; {goto st316;}
		}
		// Find prefix without trailing zeroes.
		while (len > 0) {
			if ((s->buffer[len - 1] & 255) != 0) {
				break;
			}
			len--;
		}
		// Check for rdata overflow.
		if (rdata_tail + 4 + len > rdata_stop + 1) {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
		// Write address family.
		uint16_t af = htons(s->apl.addr_family);
		memcpy(rdata_tail, &af, sizeof(af));
		rdata_tail += 2;
		// Write prefix length in bits.
		*(rdata_tail) = s->apl.prefix_length;
		rdata_tail += 1;
		// Write negation flag + prefix length in bytes.
		*(rdata_tail) = len + s->apl.excl_flag;
		rdata_tail += 1;
		// Write address prefix non-null data.
		memcpy(rdata_tail, s->buffer, len);
		rdata_tail += len;
	}
	{
		s->line_counter++;
	}
	goto st1037;
st1037:
	if ( ++p == pe )
		goto _test_eof1037;
case 1037:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(2688 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 !s->multiline  ) _widec += 512;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(2688 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		if (
 !s->multiline  ) _widec += 512;
	}
	switch( _widec ) {
		case 9: goto st1037;
		case 32: goto st1037;
		case 33: goto tr3009;
		case 40: goto tr3010;
		case 41: goto tr3011;
		case 49: goto tr3012;
		case 50: goto tr3013;
		case 3082: goto tr3014;
		case 3131: goto tr3015;
		case 3338: goto tr3016;
		case 3387: goto tr3016;
		case 3594: goto tr3017;
		case 3643: goto tr3018;
	}
	goto tr3007;
tr3009:
	{
		memset(&(s->apl), 0, sizeof(s->apl));
	}
	{
		s->apl.excl_flag = 128; // dec 128  = bin 10000000.
	}
	goto st1038;
st1038:
	if ( ++p == pe )
		goto _test_eof1038;
case 1038:
	switch( (*p) ) {
		case 49: goto tr3019;
		case 50: goto tr3020;
	}
	goto tr3007;
tr3012:
	{
		memset(&(s->apl), 0, sizeof(s->apl));
	}
	{
		s->apl.addr_family = 1;
	}
	goto st1039;
tr3019:
	{
		s->apl.addr_family = 1;
	}
	goto st1039;
st1039:
	if ( ++p == pe )
		goto _test_eof1039;
case 1039:
	if ( (*p) == 58 )
		goto st1040;
	goto tr3007;
st1040:
	if ( ++p == pe )
		goto _test_eof1040;
case 1040:
	if ( (*p) == 46 )
		goto tr3023;
	if ( 48 <= (*p) && (*p) <= 57 )
		goto tr3023;
	goto tr3022;
tr3024:
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		} else {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st1041;
tr3023:
	{
		s->buffer_length = 0;
	}
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		} else {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st1041;
st1041:
	if ( ++p == pe )
		goto _test_eof1041;
case 1041:
	if ( (*p) == 47 )
		goto tr3025;
	if ( 46 <= (*p) && (*p) <= 57 )
		goto tr3024;
	goto tr3022;
tr3025:
	{
		s->buffer[s->buffer_length] = 0;

		if (inet_pton(AF_INET, (char *)s->buffer, s->addr) <= 0) {
			WARN(ZS_BAD_IPV4);
			p--; {goto st316;}
		}
	}
	goto st1042;
tr3041:
	{
		s->buffer[s->buffer_length] = 0;

		if (inet_pton(AF_INET6, (char *)s->buffer, s->addr) <= 0) {
			WARN(ZS_BAD_IPV6);
			p--; {goto st316;}
		}
	}
	goto st1042;
st1042:
	if ( ++p == pe )
		goto _test_eof1042;
case 1042:
	if ( 48 <= (*p) && (*p) <= 57 )
		goto tr3026;
	goto tr3007;
tr3026:
	{
		s->number64 = 0;
	}
	{
		// Overflow check: 10*(s->number64) + fc - '0' <= UINT64_MAX
		if ((s->number64 < (UINT64_MAX / 10)) ||   // Dominant fast check.
			((s->number64 == (UINT64_MAX / 10)) && // Marginal case.
			 ((uint8_t)(*p) <= (UINT64_MAX % 10) + '0')
			)
		   ) {
			s->number64 *= 10;
			s->number64 += digit_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_NUMBER64_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st1043;
tr3030:
	{
		// Overflow check: 10*(s->number64) + fc - '0' <= UINT64_MAX
		if ((s->number64 < (UINT64_MAX / 10)) ||   // Dominant fast check.
			((s->number64 == (UINT64_MAX / 10)) && // Marginal case.
			 ((uint8_t)(*p) <= (UINT64_MAX % 10) + '0')
			)
		   ) {
			s->number64 *= 10;
			s->number64 += digit_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_NUMBER64_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st1043;
st1043:
	if ( ++p == pe )
		goto _test_eof1043;
case 1043:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(2688 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 !s->multiline  ) _widec += 512;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(2688 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		if (
 !s->multiline  ) _widec += 512;
	}
	switch( _widec ) {
		case 9: goto tr3027;
		case 32: goto tr3027;
		case 40: goto tr3028;
		case 41: goto tr3029;
		case 3082: goto tr3031;
		case 3131: goto tr3032;
		case 3338: goto tr3033;
		case 3387: goto tr3033;
		case 3594: goto tr3034;
		case 3643: goto tr3035;
	}
	if ( 48 <= _widec && _widec <= 57 )
		goto tr3030;
	goto tr3007;
tr3015:
	{
		s->buffer_length = 0;
	}
	goto st1044;
tr3036:
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		}
	}
	goto st1044;
tr3032:
	{
		if ((s->apl.addr_family == 1 && s->number64 <= 32) ||
		    (s->apl.addr_family == 2 && s->number64 <= 128)) {
			s->apl.prefix_length = (uint8_t)(s->number64);
		} else {
			WARN(ZS_BAD_APL);
			p--; {goto st316;}
		}
	}
	{
		// Copy address to buffer.
		uint8_t len;
		switch (s->apl.addr_family) {
		case 1:
			len = ZS_INET4_ADDR_LENGTH;
			memcpy(s->buffer, s->addr, len);
			break;
		case 2:
			len = ZS_INET6_ADDR_LENGTH;
			memcpy(s->buffer, s->addr, len);
			break;
		default:
			WARN(ZS_BAD_APL);
			p--; {goto st316;}
		}
		// Find prefix without trailing zeroes.
		while (len > 0) {
			if ((s->buffer[len - 1] & 255) != 0) {
				break;
			}
			len--;
		}
		// Check for rdata overflow.
		if (rdata_tail + 4 + len > rdata_stop + 1) {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
		// Write address family.
		uint16_t af = htons(s->apl.addr_family);
		memcpy(rdata_tail, &af, sizeof(af));
		rdata_tail += 2;
		// Write prefix length in bits.
		*(rdata_tail) = s->apl.prefix_length;
		rdata_tail += 1;
		// Write negation flag + prefix length in bytes.
		*(rdata_tail) = len + s->apl.excl_flag;
		rdata_tail += 1;
		// Write address prefix non-null data.
		memcpy(rdata_tail, s->buffer, len);
		rdata_tail += len;
	}
	{
		s->buffer_length = 0;
	}
	goto st1044;
st1044:
	if ( ++p == pe )
		goto _test_eof1044;
case 1044:
	_widec = (*p);
	if ( (*p) < 10 ) {
		if ( (*p) <= 9 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) > 10 ) {
		if ( 11 <= (*p) )
 {			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	if ( _widec == 2058 )
		goto tr3037;
	if ( 1920 <= _widec && _widec <= 2175 )
		goto tr3036;
	goto tr77;
tr3016:
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1505;
tr3033:
	{
		if ((s->apl.addr_family == 1 && s->number64 <= 32) ||
		    (s->apl.addr_family == 2 && s->number64 <= 128)) {
			s->apl.prefix_length = (uint8_t)(s->number64);
		} else {
			WARN(ZS_BAD_APL);
			p--; {goto st316;}
		}
	}
	{
		// Copy address to buffer.
		uint8_t len;
		switch (s->apl.addr_family) {
		case 1:
			len = ZS_INET4_ADDR_LENGTH;
			memcpy(s->buffer, s->addr, len);
			break;
		case 2:
			len = ZS_INET6_ADDR_LENGTH;
			memcpy(s->buffer, s->addr, len);
			break;
		default:
			WARN(ZS_BAD_APL);
			p--; {goto st316;}
		}
		// Find prefix without trailing zeroes.
		while (len > 0) {
			if ((s->buffer[len - 1] & 255) != 0) {
				break;
			}
			len--;
		}
		// Check for rdata overflow.
		if (rdata_tail + 4 + len > rdata_stop + 1) {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
		// Write address family.
		uint16_t af = htons(s->apl.addr_family);
		memcpy(rdata_tail, &af, sizeof(af));
		rdata_tail += 2;
		// Write prefix length in bits.
		*(rdata_tail) = s->apl.prefix_length;
		rdata_tail += 1;
		// Write negation flag + prefix length in bytes.
		*(rdata_tail) = len + s->apl.excl_flag;
		rdata_tail += 1;
		// Write address prefix non-null data.
		memcpy(rdata_tail, s->buffer, len);
		rdata_tail += len;
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1505;
st1505:
	if ( ++p == pe )
		goto _test_eof1505;
case 1505:
	goto st0;
tr3017:
	{
		s->line_counter++;
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1506;
tr3034:
	{
		if ((s->apl.addr_family == 1 && s->number64 <= 32) ||
		    (s->apl.addr_family == 2 && s->number64 <= 128)) {
			s->apl.prefix_length = (uint8_t)(s->number64);
		} else {
			WARN(ZS_BAD_APL);
			p--; {goto st316;}
		}
	}
	{
		// Copy address to buffer.
		uint8_t len;
		switch (s->apl.addr_family) {
		case 1:
			len = ZS_INET4_ADDR_LENGTH;
			memcpy(s->buffer, s->addr, len);
			break;
		case 2:
			len = ZS_INET6_ADDR_LENGTH;
			memcpy(s->buffer, s->addr, len);
			break;
		default:
			WARN(ZS_BAD_APL);
			p--; {goto st316;}
		}
		// Find prefix without trailing zeroes.
		while (len > 0) {
			if ((s->buffer[len - 1] & 255) != 0) {
				break;
			}
			len--;
		}
		// Check for rdata overflow.
		if (rdata_tail + 4 + len > rdata_stop + 1) {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
		// Write address family.
		uint16_t af = htons(s->apl.addr_family);
		memcpy(rdata_tail, &af, sizeof(af));
		rdata_tail += 2;
		// Write prefix length in bits.
		*(rdata_tail) = s->apl.prefix_length;
		rdata_tail += 1;
		// Write negation flag + prefix length in bytes.
		*(rdata_tail) = len + s->apl.excl_flag;
		rdata_tail += 1;
		// Write address prefix non-null data.
		memcpy(rdata_tail, s->buffer, len);
		rdata_tail += len;
	}
	{
		s->line_counter++;
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1506;
st1506:
	if ( ++p == pe )
		goto _test_eof1506;
case 1506:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(2688 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 !s->multiline  ) _widec += 512;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(2688 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		if (
 !s->multiline  ) _widec += 512;
	}
	switch( _widec ) {
		case 9: goto st1037;
		case 32: goto st1037;
		case 33: goto tr3009;
		case 40: goto tr3010;
		case 41: goto tr3011;
		case 49: goto tr3012;
		case 50: goto tr3013;
		case 3082: goto tr3014;
		case 3131: goto tr3015;
		case 3338: goto tr3016;
		case 3387: goto tr3016;
		case 3594: goto tr3017;
		case 3643: goto tr3018;
	}
	goto tr3007;
tr3013:
	{
		memset(&(s->apl), 0, sizeof(s->apl));
	}
	{
		s->apl.addr_family = 2;
	}
	goto st1045;
tr3020:
	{
		s->apl.addr_family = 2;
	}
	goto st1045;
st1045:
	if ( ++p == pe )
		goto _test_eof1045;
case 1045:
	if ( (*p) == 58 )
		goto st1046;
	goto tr3007;
st1046:
	if ( ++p == pe )
		goto _test_eof1046;
case 1046:
	if ( (*p) == 46 )
		goto tr3039;
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 58 )
			goto tr3039;
	} else if ( (*p) > 70 ) {
		if ( 97 <= (*p) && (*p) <= 102 )
			goto tr3039;
	} else
		goto tr3039;
	goto tr3022;
tr3040:
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		} else {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st1047;
tr3039:
	{
		s->buffer_length = 0;
	}
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		} else {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st1047;
st1047:
	if ( ++p == pe )
		goto _test_eof1047;
case 1047:
	if ( (*p) == 47 )
		goto tr3041;
	if ( (*p) < 65 ) {
		if ( 46 <= (*p) && (*p) <= 58 )
			goto tr3040;
	} else if ( (*p) > 70 ) {
		if ( 97 <= (*p) && (*p) <= 102 )
			goto tr3040;
	} else
		goto tr3040;
	goto tr3022;
tr3018:
	{
		s->buffer_length = 0;
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1507;
tr3035:
	{
		if ((s->apl.addr_family == 1 && s->number64 <= 32) ||
		    (s->apl.addr_family == 2 && s->number64 <= 128)) {
			s->apl.prefix_length = (uint8_t)(s->number64);
		} else {
			WARN(ZS_BAD_APL);
			p--; {goto st316;}
		}
	}
	{
		// Copy address to buffer.
		uint8_t len;
		switch (s->apl.addr_family) {
		case 1:
			len = ZS_INET4_ADDR_LENGTH;
			memcpy(s->buffer, s->addr, len);
			break;
		case 2:
			len = ZS_INET6_ADDR_LENGTH;
			memcpy(s->buffer, s->addr, len);
			break;
		default:
			WARN(ZS_BAD_APL);
			p--; {goto st316;}
		}
		// Find prefix without trailing zeroes.
		while (len > 0) {
			if ((s->buffer[len - 1] & 255) != 0) {
				break;
			}
			len--;
		}
		// Check for rdata overflow.
		if (rdata_tail + 4 + len > rdata_stop + 1) {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
		// Write address family.
		uint16_t af = htons(s->apl.addr_family);
		memcpy(rdata_tail, &af, sizeof(af));
		rdata_tail += 2;
		// Write prefix length in bits.
		*(rdata_tail) = s->apl.prefix_length;
		rdata_tail += 1;
		// Write negation flag + prefix length in bytes.
		*(rdata_tail) = len + s->apl.excl_flag;
		rdata_tail += 1;
		// Write address prefix non-null data.
		memcpy(rdata_tail, s->buffer, len);
		rdata_tail += len;
	}
	{
		s->buffer_length = 0;
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1507;
st1507:
	if ( ++p == pe )
		goto _test_eof1507;
case 1507:
	_widec = (*p);
	if ( (*p) < 10 ) {
		if ( (*p) <= 9 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) > 10 ) {
		if ( 11 <= (*p) )
 {			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	if ( _widec == 2058 )
		goto tr3037;
	if ( 1920 <= _widec && _widec <= 2175 )
		goto tr3036;
	goto tr77;
st1048:
	if ( ++p == pe )
		goto _test_eof1048;
case 1048:
	if ( 48 <= (*p) && (*p) <= 57 )
		goto tr3042;
	goto tr2396;
tr3042:
	{
		s->number64 = 0;
	}
	{
		// Overflow check: 10*(s->number64) + fc - '0' <= UINT64_MAX
		if ((s->number64 < (UINT64_MAX / 10)) ||   // Dominant fast check.
			((s->number64 == (UINT64_MAX / 10)) && // Marginal case.
			 ((uint8_t)(*p) <= (UINT64_MAX % 10) + '0')
			)
		   ) {
			s->number64 *= 10;
			s->number64 += digit_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_NUMBER64_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st1049;
tr3046:
	{
		// Overflow check: 10*(s->number64) + fc - '0' <= UINT64_MAX
		if ((s->number64 < (UINT64_MAX / 10)) ||   // Dominant fast check.
			((s->number64 == (UINT64_MAX / 10)) && // Marginal case.
			 ((uint8_t)(*p) <= (UINT64_MAX % 10) + '0')
			)
		   ) {
			s->number64 *= 10;
			s->number64 += digit_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_NUMBER64_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st1049;
st1049:
	if ( ++p == pe )
		goto _test_eof1049;
case 1049:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr3043;
		case 32: goto tr3043;
		case 40: goto tr3044;
		case 41: goto tr3045;
		case 2058: goto tr3047;
		case 2107: goto tr3048;
	}
	if ( 48 <= _widec && _widec <= 57 )
		goto tr3046;
	goto tr2396;
tr3050:
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st1050;
tr3051:
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st1050;
tr3053:
	{
		s->line_counter++;
	}
	goto st1050;
tr3090:
	{
		s->buffer[s->buffer_length++] = 0;

		// Execute the comment callback.
		if (s->process.automatic && s->process.comment != NULL) {
			s->process.comment(s);

			// Stop if required from the callback.
			if (s->state == ZS_STATE_STOP) {
				{p++; cs = 1050; goto _out;}
			}
		}
	}
	{
		s->line_counter++;
	}
	goto st1050;
tr3043:
	{
		if (s->number64 <= UINT16_MAX) {
			uint16_t num16 = htons((uint16_t)s->number64);
			memcpy(rdata_tail, &num16, 2);
			rdata_tail += 2;
		} else {
			WARN(ZS_NUMBER16_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st1050;
tr3044:
	{
		if (s->number64 <= UINT16_MAX) {
			uint16_t num16 = htons((uint16_t)s->number64);
			memcpy(rdata_tail, &num16, 2);
			rdata_tail += 2;
		} else {
			WARN(ZS_NUMBER16_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st1050;
tr3045:
	{
		if (s->number64 <= UINT16_MAX) {
			uint16_t num16 = htons((uint16_t)s->number64);
			memcpy(rdata_tail, &num16, 2);
			rdata_tail += 2;
		} else {
			WARN(ZS_NUMBER16_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st1050;
tr3047:
	{
		if (s->number64 <= UINT16_MAX) {
			uint16_t num16 = htons((uint16_t)s->number64);
			memcpy(rdata_tail, &num16, 2);
			rdata_tail += 2;
		} else {
			WARN(ZS_NUMBER16_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		s->line_counter++;
	}
	goto st1050;
st1050:
	if ( ++p == pe )
		goto _test_eof1050;
case 1050:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto st1050;
		case 32: goto st1050;
		case 40: goto tr3050;
		case 41: goto tr3051;
		case 2058: goto tr3053;
		case 2107: goto tr3054;
	}
	if ( _widec < 65 ) {
		if ( 48 <= _widec && _widec <= 57 )
			goto tr3052;
	} else if ( _widec > 90 ) {
		if ( 97 <= _widec && _widec <= 122 )
			goto tr3052;
	} else
		goto tr3052;
	goto tr77;
tr3052:
	{ p--; {stack[top++] = 1051;goto st741;} }
	goto st1051;
st1051:
	if ( ++p == pe )
		goto _test_eof1051;
case 1051:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto st1052;
		case 32: goto st1052;
		case 40: goto tr3056;
		case 41: goto tr3057;
		case 2058: goto tr3058;
		case 2107: goto tr3059;
	}
	goto tr77;
tr3056:
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st1052;
tr3057:
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st1052;
tr3058:
	{
		s->line_counter++;
	}
	goto st1052;
tr3088:
	{
		s->buffer[s->buffer_length++] = 0;

		// Execute the comment callback.
		if (s->process.automatic && s->process.comment != NULL) {
			s->process.comment(s);

			// Stop if required from the callback.
			if (s->state == ZS_STATE_STOP) {
				{p++; cs = 1052; goto _out;}
			}
		}
	}
	{
		s->line_counter++;
	}
	goto st1052;
st1052:
	if ( ++p == pe )
		goto _test_eof1052;
case 1052:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto st1052;
		case 32: goto st1052;
		case 40: goto tr3056;
		case 41: goto tr3057;
		case 2058: goto tr3058;
		case 2107: goto tr3059;
	}
	if ( 48 <= _widec && _widec <= 57 )
		goto tr3060;
	goto tr2396;
tr3060:
	{
		s->number64 = 0;
	}
	{
		// Overflow check: 10*(s->number64) + fc - '0' <= UINT64_MAX
		if ((s->number64 < (UINT64_MAX / 10)) ||   // Dominant fast check.
			((s->number64 == (UINT64_MAX / 10)) && // Marginal case.
			 ((uint8_t)(*p) <= (UINT64_MAX % 10) + '0')
			)
		   ) {
			s->number64 *= 10;
			s->number64 += digit_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_NUMBER64_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st1053;
tr3064:
	{
		// Overflow check: 10*(s->number64) + fc - '0' <= UINT64_MAX
		if ((s->number64 < (UINT64_MAX / 10)) ||   // Dominant fast check.
			((s->number64 == (UINT64_MAX / 10)) && // Marginal case.
			 ((uint8_t)(*p) <= (UINT64_MAX % 10) + '0')
			)
		   ) {
			s->number64 *= 10;
			s->number64 += digit_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_NUMBER64_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st1053;
st1053:
	if ( ++p == pe )
		goto _test_eof1053;
case 1053:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr3061;
		case 32: goto tr3061;
		case 40: goto tr3062;
		case 41: goto tr3063;
		case 2058: goto tr3065;
		case 2107: goto tr3066;
	}
	if ( 48 <= _widec && _widec <= 57 )
		goto tr3064;
	goto tr2396;
tr3069:
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st1054;
tr3070:
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st1054;
tr3072:
	{
		s->line_counter++;
	}
	goto st1054;
tr3086:
	{
		s->buffer[s->buffer_length++] = 0;

		// Execute the comment callback.
		if (s->process.automatic && s->process.comment != NULL) {
			s->process.comment(s);

			// Stop if required from the callback.
			if (s->state == ZS_STATE_STOP) {
				{p++; cs = 1054; goto _out;}
			}
		}
	}
	{
		s->line_counter++;
	}
	goto st1054;
tr3061:
	{
		if (s->number64 <= UINT8_MAX) {
			*rdata_tail = (uint8_t)(s->number64);
			rdata_tail += 1;
		} else {
			WARN(ZS_NUMBER8_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st1054;
tr3062:
	{
		if (s->number64 <= UINT8_MAX) {
			*rdata_tail = (uint8_t)(s->number64);
			rdata_tail += 1;
		} else {
			WARN(ZS_NUMBER8_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st1054;
tr3063:
	{
		if (s->number64 <= UINT8_MAX) {
			*rdata_tail = (uint8_t)(s->number64);
			rdata_tail += 1;
		} else {
			WARN(ZS_NUMBER8_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st1054;
tr3065:
	{
		if (s->number64 <= UINT8_MAX) {
			*rdata_tail = (uint8_t)(s->number64);
			rdata_tail += 1;
		} else {
			WARN(ZS_NUMBER8_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		s->line_counter++;
	}
	goto st1054;
st1054:
	if ( ++p == pe )
		goto _test_eof1054;
case 1054:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto st1054;
		case 32: goto st1054;
		case 40: goto tr3069;
		case 41: goto tr3070;
		case 2058: goto tr3072;
		case 2107: goto tr3073;
	}
	if ( _widec < 65 ) {
		if ( 48 <= _widec && _widec <= 57 )
			goto tr3071;
	} else if ( _widec > 70 ) {
		if ( 97 <= _widec && _widec <= 102 )
			goto tr3071;
	} else
		goto tr3071;
	goto tr3067;
tr3071:
	{
		if (rdata_tail <= rdata_stop) {
			*rdata_tail = first_hex_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st1055;
st1055:
	if ( ++p == pe )
		goto _test_eof1055;
case 1055:
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr3074;
	} else if ( (*p) > 70 ) {
		if ( 97 <= (*p) && (*p) <= 102 )
			goto tr3074;
	} else
		goto tr3074;
	goto tr3067;
tr3076:
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st1056;
tr3077:
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st1056;
tr3078:
	{
		s->line_counter++;
	}
	goto st1056;
tr3084:
	{
		s->buffer[s->buffer_length++] = 0;

		// Execute the comment callback.
		if (s->process.automatic && s->process.comment != NULL) {
			s->process.comment(s);

			// Stop if required from the callback.
			if (s->state == ZS_STATE_STOP) {
				{p++; cs = 1056; goto _out;}
			}
		}
	}
	{
		s->line_counter++;
	}
	goto st1056;
tr3074:
	{
		*rdata_tail += second_hex_to_num[(uint8_t)(*p)];
		rdata_tail++;
	}
	goto st1056;
st1056:
	if ( ++p == pe )
		goto _test_eof1056;
case 1056:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(2688 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 !s->multiline  ) _widec += 512;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(2688 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		if (
 !s->multiline  ) _widec += 512;
	}
	switch( _widec ) {
		case 9: goto st1056;
		case 32: goto st1056;
		case 40: goto tr3076;
		case 41: goto tr3077;
		case 3082: goto tr3078;
		case 3131: goto tr3079;
		case 3338: goto tr3080;
		case 3387: goto tr3080;
		case 3594: goto tr3081;
		case 3643: goto tr3082;
	}
	if ( _widec < 65 ) {
		if ( 48 <= _widec && _widec <= 57 )
			goto tr3071;
	} else if ( _widec > 70 ) {
		if ( 97 <= _widec && _widec <= 102 )
			goto tr3071;
	} else
		goto tr3071;
	goto tr3067;
tr3079:
	{
		s->buffer_length = 0;
	}
	goto st1057;
tr3083:
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		}
	}
	goto st1057;
st1057:
	if ( ++p == pe )
		goto _test_eof1057;
case 1057:
	_widec = (*p);
	if ( (*p) < 10 ) {
		if ( (*p) <= 9 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) > 10 ) {
		if ( 11 <= (*p) )
 {			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	if ( _widec == 2058 )
		goto tr3084;
	if ( 1920 <= _widec && _widec <= 2175 )
		goto tr3083;
	goto tr3067;
tr3080:
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1508;
st1508:
	if ( ++p == pe )
		goto _test_eof1508;
case 1508:
	goto st0;
tr3081:
	{
		s->line_counter++;
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1509;
st1509:
	if ( ++p == pe )
		goto _test_eof1509;
case 1509:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(2688 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 !s->multiline  ) _widec += 512;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(2688 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		if (
 !s->multiline  ) _widec += 512;
	}
	switch( _widec ) {
		case 9: goto st1056;
		case 32: goto st1056;
		case 40: goto tr3076;
		case 41: goto tr3077;
		case 3082: goto tr3078;
		case 3131: goto tr3079;
		case 3338: goto tr3080;
		case 3387: goto tr3080;
		case 3594: goto tr3081;
		case 3643: goto tr3082;
	}
	if ( _widec < 65 ) {
		if ( 48 <= _widec && _widec <= 57 )
			goto tr3071;
	} else if ( _widec > 70 ) {
		if ( 97 <= _widec && _widec <= 102 )
			goto tr3071;
	} else
		goto tr3071;
	goto tr3067;
tr3082:
	{
		s->buffer_length = 0;
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1510;
st1510:
	if ( ++p == pe )
		goto _test_eof1510;
case 1510:
	_widec = (*p);
	if ( (*p) < 10 ) {
		if ( (*p) <= 9 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) > 10 ) {
		if ( 11 <= (*p) )
 {			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	if ( _widec == 2058 )
		goto tr3084;
	if ( 1920 <= _widec && _widec <= 2175 )
		goto tr3083;
	goto tr3067;
tr3073:
	{
		s->buffer_length = 0;
	}
	goto st1058;
tr3085:
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		}
	}
	goto st1058;
tr3066:
	{
		if (s->number64 <= UINT8_MAX) {
			*rdata_tail = (uint8_t)(s->number64);
			rdata_tail += 1;
		} else {
			WARN(ZS_NUMBER8_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		s->buffer_length = 0;
	}
	goto st1058;
st1058:
	if ( ++p == pe )
		goto _test_eof1058;
case 1058:
	_widec = (*p);
	if ( (*p) < 10 ) {
		if ( (*p) <= 9 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) > 10 ) {
		if ( 11 <= (*p) )
 {			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	if ( _widec == 2058 )
		goto tr3086;
	if ( 1920 <= _widec && _widec <= 2175 )
		goto tr3085;
	goto tr77;
tr3059:
	{
		s->buffer_length = 0;
	}
	goto st1059;
tr3087:
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		}
	}
	goto st1059;
st1059:
	if ( ++p == pe )
		goto _test_eof1059;
case 1059:
	_widec = (*p);
	if ( (*p) < 10 ) {
		if ( (*p) <= 9 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) > 10 ) {
		if ( 11 <= (*p) )
 {			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	if ( _widec == 2058 )
		goto tr3088;
	if ( 1920 <= _widec && _widec <= 2175 )
		goto tr3087;
	goto tr77;
tr3054:
	{
		s->buffer_length = 0;
	}
	goto st1060;
tr3089:
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		}
	}
	goto st1060;
tr3048:
	{
		if (s->number64 <= UINT16_MAX) {
			uint16_t num16 = htons((uint16_t)s->number64);
			memcpy(rdata_tail, &num16, 2);
			rdata_tail += 2;
		} else {
			WARN(ZS_NUMBER16_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		s->buffer_length = 0;
	}
	goto st1060;
st1060:
	if ( ++p == pe )
		goto _test_eof1060;
case 1060:
	_widec = (*p);
	if ( (*p) < 10 ) {
		if ( (*p) <= 9 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) > 10 ) {
		if ( 11 <= (*p) )
 {			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	if ( _widec == 2058 )
		goto tr3090;
	if ( 1920 <= _widec && _widec <= 2175 )
		goto tr3089;
	goto tr77;
st1061:
	if ( ++p == pe )
		goto _test_eof1061;
case 1061:
	if ( 48 <= (*p) && (*p) <= 57 )
		goto tr3091;
	goto tr2396;
tr3091:
	{
		s->number64 = 0;
	}
	{
		// Overflow check: 10*(s->number64) + fc - '0' <= UINT64_MAX
		if ((s->number64 < (UINT64_MAX / 10)) ||   // Dominant fast check.
			((s->number64 == (UINT64_MAX / 10)) && // Marginal case.
			 ((uint8_t)(*p) <= (UINT64_MAX % 10) + '0')
			)
		   ) {
			s->number64 *= 10;
			s->number64 += digit_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_NUMBER64_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st1062;
tr3095:
	{
		// Overflow check: 10*(s->number64) + fc - '0' <= UINT64_MAX
		if ((s->number64 < (UINT64_MAX / 10)) ||   // Dominant fast check.
			((s->number64 == (UINT64_MAX / 10)) && // Marginal case.
			 ((uint8_t)(*p) <= (UINT64_MAX % 10) + '0')
			)
		   ) {
			s->number64 *= 10;
			s->number64 += digit_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_NUMBER64_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st1062;
st1062:
	if ( ++p == pe )
		goto _test_eof1062;
case 1062:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr3092;
		case 32: goto tr3092;
		case 40: goto tr3093;
		case 41: goto tr3094;
		case 2058: goto tr3096;
		case 2107: goto tr3097;
	}
	if ( 48 <= _widec && _widec <= 57 )
		goto tr3095;
	goto tr2396;
tr3099:
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st1063;
tr3100:
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st1063;
tr3102:
	{
		s->line_counter++;
	}
	goto st1063;
tr3130:
	{
		s->buffer[s->buffer_length++] = 0;

		// Execute the comment callback.
		if (s->process.automatic && s->process.comment != NULL) {
			s->process.comment(s);

			// Stop if required from the callback.
			if (s->state == ZS_STATE_STOP) {
				{p++; cs = 1063; goto _out;}
			}
		}
	}
	{
		s->line_counter++;
	}
	goto st1063;
tr3092:
	{
		if (s->number64 <= UINT8_MAX) {
			*rdata_tail = (uint8_t)(s->number64);
			rdata_tail += 1;
		} else {
			WARN(ZS_NUMBER8_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st1063;
tr3093:
	{
		if (s->number64 <= UINT8_MAX) {
			*rdata_tail = (uint8_t)(s->number64);
			rdata_tail += 1;
		} else {
			WARN(ZS_NUMBER8_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st1063;
tr3094:
	{
		if (s->number64 <= UINT8_MAX) {
			*rdata_tail = (uint8_t)(s->number64);
			rdata_tail += 1;
		} else {
			WARN(ZS_NUMBER8_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st1063;
tr3096:
	{
		if (s->number64 <= UINT8_MAX) {
			*rdata_tail = (uint8_t)(s->number64);
			rdata_tail += 1;
		} else {
			WARN(ZS_NUMBER8_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		s->line_counter++;
	}
	goto st1063;
st1063:
	if ( ++p == pe )
		goto _test_eof1063;
case 1063:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto st1063;
		case 32: goto st1063;
		case 40: goto tr3099;
		case 41: goto tr3100;
		case 2058: goto tr3102;
		case 2107: goto tr3103;
	}
	if ( 48 <= _widec && _widec <= 57 )
		goto tr3101;
	goto tr2396;
tr3101:
	{
		s->number64 = 0;
	}
	{
		// Overflow check: 10*(s->number64) + fc - '0' <= UINT64_MAX
		if ((s->number64 < (UINT64_MAX / 10)) ||   // Dominant fast check.
			((s->number64 == (UINT64_MAX / 10)) && // Marginal case.
			 ((uint8_t)(*p) <= (UINT64_MAX % 10) + '0')
			)
		   ) {
			s->number64 *= 10;
			s->number64 += digit_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_NUMBER64_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st1064;
tr3107:
	{
		// Overflow check: 10*(s->number64) + fc - '0' <= UINT64_MAX
		if ((s->number64 < (UINT64_MAX / 10)) ||   // Dominant fast check.
			((s->number64 == (UINT64_MAX / 10)) && // Marginal case.
			 ((uint8_t)(*p) <= (UINT64_MAX % 10) + '0')
			)
		   ) {
			s->number64 *= 10;
			s->number64 += digit_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_NUMBER64_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st1064;
st1064:
	if ( ++p == pe )
		goto _test_eof1064;
case 1064:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr3104;
		case 32: goto tr3104;
		case 40: goto tr3105;
		case 41: goto tr3106;
		case 2058: goto tr3108;
		case 2107: goto tr3109;
	}
	if ( 48 <= _widec && _widec <= 57 )
		goto tr3107;
	goto tr2396;
tr3111:
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st1065;
tr3112:
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st1065;
tr3114:
	{
		s->line_counter++;
	}
	goto st1065;
tr3128:
	{
		s->buffer[s->buffer_length++] = 0;

		// Execute the comment callback.
		if (s->process.automatic && s->process.comment != NULL) {
			s->process.comment(s);

			// Stop if required from the callback.
			if (s->state == ZS_STATE_STOP) {
				{p++; cs = 1065; goto _out;}
			}
		}
	}
	{
		s->line_counter++;
	}
	goto st1065;
tr3104:
	{
		if (s->number64 <= UINT8_MAX) {
			*rdata_tail = (uint8_t)(s->number64);
			rdata_tail += 1;
		} else {
			WARN(ZS_NUMBER8_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st1065;
tr3105:
	{
		if (s->number64 <= UINT8_MAX) {
			*rdata_tail = (uint8_t)(s->number64);
			rdata_tail += 1;
		} else {
			WARN(ZS_NUMBER8_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st1065;
tr3106:
	{
		if (s->number64 <= UINT8_MAX) {
			*rdata_tail = (uint8_t)(s->number64);
			rdata_tail += 1;
		} else {
			WARN(ZS_NUMBER8_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st1065;
tr3108:
	{
		if (s->number64 <= UINT8_MAX) {
			*rdata_tail = (uint8_t)(s->number64);
			rdata_tail += 1;
		} else {
			WARN(ZS_NUMBER8_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		s->line_counter++;
	}
	goto st1065;
st1065:
	if ( ++p == pe )
		goto _test_eof1065;
case 1065:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto st1065;
		case 32: goto st1065;
		case 40: goto tr3111;
		case 41: goto tr3112;
		case 2058: goto tr3114;
		case 2107: goto tr3115;
	}
	if ( _widec < 65 ) {
		if ( 48 <= _widec && _widec <= 57 )
			goto tr3113;
	} else if ( _widec > 70 ) {
		if ( 97 <= _widec && _widec <= 102 )
			goto tr3113;
	} else
		goto tr3113;
	goto tr3067;
tr3113:
	{
		if (rdata_tail <= rdata_stop) {
			*rdata_tail = first_hex_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st1066;
st1066:
	if ( ++p == pe )
		goto _test_eof1066;
case 1066:
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr3116;
	} else if ( (*p) > 70 ) {
		if ( 97 <= (*p) && (*p) <= 102 )
			goto tr3116;
	} else
		goto tr3116;
	goto tr3067;
tr3118:
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st1067;
tr3119:
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st1067;
tr3120:
	{
		s->line_counter++;
	}
	goto st1067;
tr3126:
	{
		s->buffer[s->buffer_length++] = 0;

		// Execute the comment callback.
		if (s->process.automatic && s->process.comment != NULL) {
			s->process.comment(s);

			// Stop if required from the callback.
			if (s->state == ZS_STATE_STOP) {
				{p++; cs = 1067; goto _out;}
			}
		}
	}
	{
		s->line_counter++;
	}
	goto st1067;
tr3116:
	{
		*rdata_tail += second_hex_to_num[(uint8_t)(*p)];
		rdata_tail++;
	}
	goto st1067;
st1067:
	if ( ++p == pe )
		goto _test_eof1067;
case 1067:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(2688 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 !s->multiline  ) _widec += 512;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(2688 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		if (
 !s->multiline  ) _widec += 512;
	}
	switch( _widec ) {
		case 9: goto st1067;
		case 32: goto st1067;
		case 40: goto tr3118;
		case 41: goto tr3119;
		case 3082: goto tr3120;
		case 3131: goto tr3121;
		case 3338: goto tr3122;
		case 3387: goto tr3122;
		case 3594: goto tr3123;
		case 3643: goto tr3124;
	}
	if ( _widec < 65 ) {
		if ( 48 <= _widec && _widec <= 57 )
			goto tr3113;
	} else if ( _widec > 70 ) {
		if ( 97 <= _widec && _widec <= 102 )
			goto tr3113;
	} else
		goto tr3113;
	goto tr3067;
tr3121:
	{
		s->buffer_length = 0;
	}
	goto st1068;
tr3125:
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		}
	}
	goto st1068;
st1068:
	if ( ++p == pe )
		goto _test_eof1068;
case 1068:
	_widec = (*p);
	if ( (*p) < 10 ) {
		if ( (*p) <= 9 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) > 10 ) {
		if ( 11 <= (*p) )
 {			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	if ( _widec == 2058 )
		goto tr3126;
	if ( 1920 <= _widec && _widec <= 2175 )
		goto tr3125;
	goto tr3067;
tr3122:
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1511;
st1511:
	if ( ++p == pe )
		goto _test_eof1511;
case 1511:
	goto st0;
tr3123:
	{
		s->line_counter++;
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1512;
st1512:
	if ( ++p == pe )
		goto _test_eof1512;
case 1512:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(2688 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 !s->multiline  ) _widec += 512;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(2688 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		if (
 !s->multiline  ) _widec += 512;
	}
	switch( _widec ) {
		case 9: goto st1067;
		case 32: goto st1067;
		case 40: goto tr3118;
		case 41: goto tr3119;
		case 3082: goto tr3120;
		case 3131: goto tr3121;
		case 3338: goto tr3122;
		case 3387: goto tr3122;
		case 3594: goto tr3123;
		case 3643: goto tr3124;
	}
	if ( _widec < 65 ) {
		if ( 48 <= _widec && _widec <= 57 )
			goto tr3113;
	} else if ( _widec > 70 ) {
		if ( 97 <= _widec && _widec <= 102 )
			goto tr3113;
	} else
		goto tr3113;
	goto tr3067;
tr3124:
	{
		s->buffer_length = 0;
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1513;
st1513:
	if ( ++p == pe )
		goto _test_eof1513;
case 1513:
	_widec = (*p);
	if ( (*p) < 10 ) {
		if ( (*p) <= 9 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) > 10 ) {
		if ( 11 <= (*p) )
 {			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	if ( _widec == 2058 )
		goto tr3126;
	if ( 1920 <= _widec && _widec <= 2175 )
		goto tr3125;
	goto tr3067;
tr3115:
	{
		s->buffer_length = 0;
	}
	goto st1069;
tr3127:
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		}
	}
	goto st1069;
tr3109:
	{
		if (s->number64 <= UINT8_MAX) {
			*rdata_tail = (uint8_t)(s->number64);
			rdata_tail += 1;
		} else {
			WARN(ZS_NUMBER8_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		s->buffer_length = 0;
	}
	goto st1069;
st1069:
	if ( ++p == pe )
		goto _test_eof1069;
case 1069:
	_widec = (*p);
	if ( (*p) < 10 ) {
		if ( (*p) <= 9 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) > 10 ) {
		if ( 11 <= (*p) )
 {			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	if ( _widec == 2058 )
		goto tr3128;
	if ( 1920 <= _widec && _widec <= 2175 )
		goto tr3127;
	goto tr77;
tr3103:
	{
		s->buffer_length = 0;
	}
	goto st1070;
tr3129:
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		}
	}
	goto st1070;
tr3097:
	{
		if (s->number64 <= UINT8_MAX) {
			*rdata_tail = (uint8_t)(s->number64);
			rdata_tail += 1;
		} else {
			WARN(ZS_NUMBER8_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		s->buffer_length = 0;
	}
	goto st1070;
st1070:
	if ( ++p == pe )
		goto _test_eof1070;
case 1070:
	_widec = (*p);
	if ( (*p) < 10 ) {
		if ( (*p) <= 9 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) > 10 ) {
		if ( 11 <= (*p) )
 {			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	if ( _widec == 2058 )
		goto tr3130;
	if ( 1920 <= _widec && _widec <= 2175 )
		goto tr3129;
	goto tr77;
st1071:
	if ( ++p == pe )
		goto _test_eof1071;
case 1071:
	if ( 48 <= (*p) && (*p) <= 57 )
		goto tr3131;
	goto tr2396;
tr3131:
	{
		s->number64 = 0;
	}
	{
		// Overflow check: 10*(s->number64) + fc - '0' <= UINT64_MAX
		if ((s->number64 < (UINT64_MAX / 10)) ||   // Dominant fast check.
			((s->number64 == (UINT64_MAX / 10)) && // Marginal case.
			 ((uint8_t)(*p) <= (UINT64_MAX % 10) + '0')
			)
		   ) {
			s->number64 *= 10;
			s->number64 += digit_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_NUMBER64_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st1072;
tr3135:
	{
		// Overflow check: 10*(s->number64) + fc - '0' <= UINT64_MAX
		if ((s->number64 < (UINT64_MAX / 10)) ||   // Dominant fast check.
			((s->number64 == (UINT64_MAX / 10)) && // Marginal case.
			 ((uint8_t)(*p) <= (UINT64_MAX % 10) + '0')
			)
		   ) {
			s->number64 *= 10;
			s->number64 += digit_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_NUMBER64_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st1072;
st1072:
	if ( ++p == pe )
		goto _test_eof1072;
case 1072:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr3132;
		case 32: goto tr3132;
		case 40: goto tr3133;
		case 41: goto tr3134;
		case 2058: goto tr3136;
		case 2107: goto tr3137;
	}
	if ( 48 <= _widec && _widec <= 57 )
		goto tr3135;
	goto tr2396;
tr3140:
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st1073;
tr3141:
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st1073;
tr3146:
	{
		s->line_counter++;
	}
	goto st1073;
tr3339:
	{
		s->buffer[s->buffer_length++] = 0;

		// Execute the comment callback.
		if (s->process.automatic && s->process.comment != NULL) {
			s->process.comment(s);

			// Stop if required from the callback.
			if (s->state == ZS_STATE_STOP) {
				{p++; cs = 1073; goto _out;}
			}
		}
	}
	{
		s->line_counter++;
	}
	goto st1073;
tr3132:
	{
		if (s->number64 <= UINT8_MAX) {
			*rdata_tail = (uint8_t)(s->number64);
			rdata_tail += 1;
		} else {
			WARN(ZS_NUMBER8_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st1073;
tr3133:
	{
		if (s->number64 <= UINT8_MAX) {
			*rdata_tail = (uint8_t)(s->number64);
			rdata_tail += 1;
		} else {
			WARN(ZS_NUMBER8_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st1073;
tr3134:
	{
		if (s->number64 <= UINT8_MAX) {
			*rdata_tail = (uint8_t)(s->number64);
			rdata_tail += 1;
		} else {
			WARN(ZS_NUMBER8_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st1073;
tr3136:
	{
		if (s->number64 <= UINT8_MAX) {
			*rdata_tail = (uint8_t)(s->number64);
			rdata_tail += 1;
		} else {
			WARN(ZS_NUMBER8_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		s->line_counter++;
	}
	goto st1073;
st1073:
	if ( ++p == pe )
		goto _test_eof1073;
case 1073:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto st1073;
		case 32: goto st1073;
		case 40: goto tr3140;
		case 41: goto tr3141;
		case 48: goto tr3142;
		case 49: goto tr3143;
		case 50: goto tr3144;
		case 51: goto tr3145;
		case 2058: goto tr3146;
		case 2107: goto tr3147;
	}
	goto tr3138;
tr3142:
	{
		*(rdata_tail++) = 0;
	}
	goto st1074;
st1074:
	if ( ++p == pe )
		goto _test_eof1074;
case 1074:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto st1075;
		case 32: goto st1075;
		case 40: goto tr3149;
		case 41: goto tr3150;
		case 2058: goto tr3151;
		case 2107: goto tr3152;
	}
	goto tr3138;
tr3149:
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st1075;
tr3150:
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st1075;
tr3151:
	{
		s->line_counter++;
	}
	goto st1075;
tr3201:
	{
		s->buffer[s->buffer_length++] = 0;

		// Execute the comment callback.
		if (s->process.automatic && s->process.comment != NULL) {
			s->process.comment(s);

			// Stop if required from the callback.
			if (s->state == ZS_STATE_STOP) {
				{p++; cs = 1075; goto _out;}
			}
		}
	}
	{
		s->line_counter++;
	}
	goto st1075;
st1075:
	if ( ++p == pe )
		goto _test_eof1075;
case 1075:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto st1075;
		case 32: goto st1075;
		case 40: goto tr3149;
		case 41: goto tr3150;
		case 2058: goto tr3151;
		case 2107: goto tr3152;
	}
	if ( 48 <= _widec && _widec <= 57 )
		goto tr3154;
	goto tr3153;
tr3154:
	{
		s->number64 = 0;
	}
	{
		// Overflow check: 10*(s->number64) + fc - '0' <= UINT64_MAX
		if ((s->number64 < (UINT64_MAX / 10)) ||   // Dominant fast check.
			((s->number64 == (UINT64_MAX / 10)) && // Marginal case.
			 ((uint8_t)(*p) <= (UINT64_MAX % 10) + '0')
			)
		   ) {
			s->number64 *= 10;
			s->number64 += digit_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_NUMBER64_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st1076;
tr3158:
	{
		// Overflow check: 10*(s->number64) + fc - '0' <= UINT64_MAX
		if ((s->number64 < (UINT64_MAX / 10)) ||   // Dominant fast check.
			((s->number64 == (UINT64_MAX / 10)) && // Marginal case.
			 ((uint8_t)(*p) <= (UINT64_MAX % 10) + '0')
			)
		   ) {
			s->number64 *= 10;
			s->number64 += digit_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_NUMBER64_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st1076;
st1076:
	if ( ++p == pe )
		goto _test_eof1076;
case 1076:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr3155;
		case 32: goto tr3155;
		case 40: goto tr3156;
		case 41: goto tr3157;
		case 2058: goto tr3159;
		case 2107: goto tr3160;
	}
	if ( 48 <= _widec && _widec <= 57 )
		goto tr3158;
	goto tr3153;
tr3162:
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st1077;
tr3163:
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st1077;
tr3165:
	{
		s->line_counter++;
	}
	goto st1077;
tr3199:
	{
		s->buffer[s->buffer_length++] = 0;

		// Execute the comment callback.
		if (s->process.automatic && s->process.comment != NULL) {
			s->process.comment(s);

			// Stop if required from the callback.
			if (s->state == ZS_STATE_STOP) {
				{p++; cs = 1077; goto _out;}
			}
		}
	}
	{
		s->line_counter++;
	}
	goto st1077;
tr3155:
	{
		if (s->number64 <= UINT8_MAX) {
			*rdata_tail = (uint8_t)(s->number64);
			rdata_tail += 1;
		} else {
			WARN(ZS_NUMBER8_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st1077;
tr3156:
	{
		if (s->number64 <= UINT8_MAX) {
			*rdata_tail = (uint8_t)(s->number64);
			rdata_tail += 1;
		} else {
			WARN(ZS_NUMBER8_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st1077;
tr3157:
	{
		if (s->number64 <= UINT8_MAX) {
			*rdata_tail = (uint8_t)(s->number64);
			rdata_tail += 1;
		} else {
			WARN(ZS_NUMBER8_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st1077;
tr3159:
	{
		if (s->number64 <= UINT8_MAX) {
			*rdata_tail = (uint8_t)(s->number64);
			rdata_tail += 1;
		} else {
			WARN(ZS_NUMBER8_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		s->line_counter++;
	}
	goto st1077;
st1077:
	if ( ++p == pe )
		goto _test_eof1077;
case 1077:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto st1077;
		case 32: goto st1077;
		case 40: goto tr3162;
		case 41: goto tr3163;
		case 46: goto st1078;
		case 2058: goto tr3165;
		case 2107: goto tr3166;
	}
	goto tr3138;
st1078:
	if ( ++p == pe )
		goto _test_eof1078;
case 1078:
	_widec = (*p);
	if ( (*p) < 32 ) {
		if ( (*p) > 9 ) {
			if ( 10 <= (*p) && (*p) <= 10 ) {
				_widec = (short)(9856 + ((*p) - -128));
				if (
 s->multiline  ) _widec += 256;
				if (
 !s->multiline  ) _widec += 512;
				if (
 s->number64 != 0  ) _widec += 1024;
				if (
 s->number64 == 0  ) _widec += 2048;
			}
		} else if ( (*p) >= 9 ) {
			_widec = (short)(6784 + ((*p) - -128));
			if (
 s->number64 != 0  ) _widec += 256;
			if (
 s->number64 == 0  ) _widec += 512;
		}
	} else if ( (*p) > 32 ) {
		if ( (*p) < 41 ) {
			if ( 40 <= (*p) && (*p) <= 40 ) {
				_widec = (short)(6784 + ((*p) - -128));
				if (
 s->number64 != 0  ) _widec += 256;
				if (
 s->number64 == 0  ) _widec += 512;
			}
		} else if ( (*p) > 41 ) {
			if ( 59 <= (*p) && (*p) <= 59 ) {
				_widec = (short)(9856 + ((*p) - -128));
				if (
 s->multiline  ) _widec += 256;
				if (
 !s->multiline  ) _widec += 512;
				if (
 s->number64 != 0  ) _widec += 1024;
				if (
 s->number64 == 0  ) _widec += 2048;
			}
		} else {
			_widec = (short)(6784 + ((*p) - -128));
			if (
 s->number64 != 0  ) _widec += 256;
			if (
 s->number64 == 0  ) _widec += 512;
		}
	} else {
		_widec = (short)(6784 + ((*p) - -128));
		if (
 s->number64 != 0  ) _widec += 256;
		if (
 s->number64 == 0  ) _widec += 512;
	}
	switch( _widec ) {
		case 7177: goto st1079;
		case 7200: goto st1079;
		case 7208: goto tr3169;
		case 7209: goto tr3170;
		case 7433: goto st1082;
		case 7456: goto st1082;
		case 7464: goto tr3172;
		case 7465: goto tr3173;
		case 7689: goto st1084;
		case 7712: goto st1084;
		case 7720: goto tr3175;
		case 7721: goto tr3176;
		case 10506: goto tr3177;
		case 10555: goto tr3177;
		case 10762: goto tr3177;
		case 10811: goto tr3177;
		case 11274: goto tr3178;
		case 11323: goto tr3179;
		case 11530: goto tr3177;
		case 11579: goto tr3177;
		case 11786: goto tr3180;
		case 11835: goto tr3181;
		case 12298: goto tr3182;
		case 12347: goto tr3183;
		case 12554: goto tr3177;
		case 12603: goto tr3177;
		case 12810: goto tr3184;
		case 12859: goto tr3185;
		case 13322: goto tr3186;
		case 13371: goto tr3187;
		case 13578: goto tr3177;
		case 13627: goto tr3177;
		case 13834: goto tr3188;
		case 13883: goto tr3189;
	}
	goto tr3167;
tr3169:
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st1079;
tr3170:
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st1079;
tr3178:
	{
		s->line_counter++;
	}
	goto st1079;
tr3193:
	{
		s->buffer[s->buffer_length++] = 0;

		// Execute the comment callback.
		if (s->process.automatic && s->process.comment != NULL) {
			s->process.comment(s);

			// Stop if required from the callback.
			if (s->state == ZS_STATE_STOP) {
				{p++; cs = 1079; goto _out;}
			}
		}
	}
	{
		s->line_counter++;
	}
	goto st1079;
tr3223:
	{
		s->buffer[s->buffer_length] = 0;

		if (inet_pton(AF_INET, (char *)s->buffer, s->addr) <= 0) {
			WARN(ZS_BAD_IPV4);
			p--; {goto st316;}
		}
	}
	{
		if (rdata_tail + ZS_INET4_ADDR_LENGTH > rdata_stop + 1) {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
		memcpy(rdata_tail, s->addr, ZS_INET4_ADDR_LENGTH);
		rdata_tail += ZS_INET4_ADDR_LENGTH;
	}
	goto st1079;
tr3268:
	{
		s->buffer[s->buffer_length] = 0;

		if (inet_pton(AF_INET6, (char *)s->buffer, s->addr) <= 0) {
			WARN(ZS_BAD_IPV6);
			p--; {goto st316;}
		}
	}
	{
		if (rdata_tail + ZS_INET6_ADDR_LENGTH > rdata_stop + 1) {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
		memcpy(rdata_tail, s->addr, ZS_INET6_ADDR_LENGTH);
		rdata_tail += ZS_INET6_ADDR_LENGTH;
	}
	goto st1079;
tr3312:
	{
		rdata_tail += s->dname_tmp_length;
	}
	goto st1079;
tr3313:
	{
		rdata_tail += s->dname_tmp_length;
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st1079;
tr3314:
	{
		rdata_tail += s->dname_tmp_length;
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st1079;
tr3322:
	{
		rdata_tail += s->dname_tmp_length;
	}
	{
		s->line_counter++;
	}
	goto st1079;
tr3224:
	{
		s->buffer[s->buffer_length] = 0;

		if (inet_pton(AF_INET, (char *)s->buffer, s->addr) <= 0) {
			WARN(ZS_BAD_IPV4);
			p--; {goto st316;}
		}
	}
	{
		if (rdata_tail + ZS_INET4_ADDR_LENGTH > rdata_stop + 1) {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
		memcpy(rdata_tail, s->addr, ZS_INET4_ADDR_LENGTH);
		rdata_tail += ZS_INET4_ADDR_LENGTH;
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st1079;
tr3225:
	{
		s->buffer[s->buffer_length] = 0;

		if (inet_pton(AF_INET, (char *)s->buffer, s->addr) <= 0) {
			WARN(ZS_BAD_IPV4);
			p--; {goto st316;}
		}
	}
	{
		if (rdata_tail + ZS_INET4_ADDR_LENGTH > rdata_stop + 1) {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
		memcpy(rdata_tail, s->addr, ZS_INET4_ADDR_LENGTH);
		rdata_tail += ZS_INET4_ADDR_LENGTH;
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st1079;
tr3233:
	{
		s->buffer[s->buffer_length] = 0;

		if (inet_pton(AF_INET, (char *)s->buffer, s->addr) <= 0) {
			WARN(ZS_BAD_IPV4);
			p--; {goto st316;}
		}
	}
	{
		if (rdata_tail + ZS_INET4_ADDR_LENGTH > rdata_stop + 1) {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
		memcpy(rdata_tail, s->addr, ZS_INET4_ADDR_LENGTH);
		rdata_tail += ZS_INET4_ADDR_LENGTH;
	}
	{
		s->line_counter++;
	}
	goto st1079;
tr3269:
	{
		s->buffer[s->buffer_length] = 0;

		if (inet_pton(AF_INET6, (char *)s->buffer, s->addr) <= 0) {
			WARN(ZS_BAD_IPV6);
			p--; {goto st316;}
		}
	}
	{
		if (rdata_tail + ZS_INET6_ADDR_LENGTH > rdata_stop + 1) {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
		memcpy(rdata_tail, s->addr, ZS_INET6_ADDR_LENGTH);
		rdata_tail += ZS_INET6_ADDR_LENGTH;
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st1079;
tr3270:
	{
		s->buffer[s->buffer_length] = 0;

		if (inet_pton(AF_INET6, (char *)s->buffer, s->addr) <= 0) {
			WARN(ZS_BAD_IPV6);
			p--; {goto st316;}
		}
	}
	{
		if (rdata_tail + ZS_INET6_ADDR_LENGTH > rdata_stop + 1) {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
		memcpy(rdata_tail, s->addr, ZS_INET6_ADDR_LENGTH);
		rdata_tail += ZS_INET6_ADDR_LENGTH;
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st1079;
tr3278:
	{
		s->buffer[s->buffer_length] = 0;

		if (inet_pton(AF_INET6, (char *)s->buffer, s->addr) <= 0) {
			WARN(ZS_BAD_IPV6);
			p--; {goto st316;}
		}
	}
	{
		if (rdata_tail + ZS_INET6_ADDR_LENGTH > rdata_stop + 1) {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
		memcpy(rdata_tail, s->addr, ZS_INET6_ADDR_LENGTH);
		rdata_tail += ZS_INET6_ADDR_LENGTH;
	}
	{
		s->line_counter++;
	}
	goto st1079;
st1079:
	if ( ++p == pe )
		goto _test_eof1079;
case 1079:
	_widec = (*p);
	if ( (*p) < 43 ) {
		if ( (*p) < 32 ) {
			if ( (*p) > 9 ) {
				if ( 10 <= (*p) && (*p) <= 10 ) {
					_widec = (short)(4224 + ((*p) - -128));
					if (
 s->multiline  ) _widec += 256;
					if (
 s->number64 != 0  ) _widec += 512;
				}
			} else if ( (*p) >= 9 ) {
				_widec = (short)(3712 + ((*p) - -128));
				if (
 s->number64 != 0  ) _widec += 256;
			}
		} else if ( (*p) > 32 ) {
			if ( (*p) > 40 ) {
				if ( 41 <= (*p) && (*p) <= 41 ) {
					_widec = (short)(3712 + ((*p) - -128));
					if (
 s->number64 != 0  ) _widec += 256;
				}
			} else if ( (*p) >= 40 ) {
				_widec = (short)(3712 + ((*p) - -128));
				if (
 s->number64 != 0  ) _widec += 256;
			}
		} else {
			_widec = (short)(3712 + ((*p) - -128));
			if (
 s->number64 != 0  ) _widec += 256;
		}
	} else if ( (*p) > 43 ) {
		if ( (*p) < 59 ) {
			if ( (*p) > 47 ) {
				if ( 48 <= (*p) && (*p) <= 57 ) {
					_widec = (short)(3712 + ((*p) - -128));
					if (
 s->number64 != 0  ) _widec += 256;
				}
			} else if ( (*p) >= 47 ) {
				_widec = (short)(3712 + ((*p) - -128));
				if (
 s->number64 != 0  ) _widec += 256;
			}
		} else if ( (*p) > 59 ) {
			if ( (*p) > 90 ) {
				if ( 97 <= (*p) && (*p) <= 122 ) {
					_widec = (short)(3712 + ((*p) - -128));
					if (
 s->number64 != 0  ) _widec += 256;
				}
			} else if ( (*p) >= 65 ) {
				_widec = (short)(3712 + ((*p) - -128));
				if (
 s->number64 != 0  ) _widec += 256;
			}
		} else {
			_widec = (short)(4224 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 s->number64 != 0  ) _widec += 512;
		}
	} else {
		_widec = (short)(3712 + ((*p) - -128));
		if (
 s->number64 != 0  ) _widec += 256;
	}
	switch( _widec ) {
		case 4105: goto st1079;
		case 4128: goto st1079;
		case 4136: goto tr3169;
		case 4137: goto tr3170;
		case 4139: goto tr3191;
		case 5130: goto tr3178;
		case 5179: goto tr3179;
	}
	if ( _widec < 4161 ) {
		if ( 4143 <= _widec && _widec <= 4153 )
			goto tr3191;
	} else if ( _widec > 4186 ) {
		if ( 4193 <= _widec && _widec <= 4218 )
			goto tr3191;
	} else
		goto tr3191;
	goto tr3190;
tr3191:
	{ p--; {stack[top++] = 1080;goto st378;} }
	goto st1080;
st1080:
	if ( ++p == pe )
		goto _test_eof1080;
case 1080:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(2176 + ((*p) - -128));
			if (
 !s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(2176 + ((*p) - -128));
		if (
 !s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 2570: goto tr3177;
		case 2619: goto tr3177;
	}
	goto tr3190;
tr3177:
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1514;
tr3232:
	{
		s->buffer[s->buffer_length] = 0;

		if (inet_pton(AF_INET, (char *)s->buffer, s->addr) <= 0) {
			WARN(ZS_BAD_IPV4);
			p--; {goto st316;}
		}
	}
	{
		if (rdata_tail + ZS_INET4_ADDR_LENGTH > rdata_stop + 1) {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
		memcpy(rdata_tail, s->addr, ZS_INET4_ADDR_LENGTH);
		rdata_tail += ZS_INET4_ADDR_LENGTH;
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1514;
tr3321:
	{
		rdata_tail += s->dname_tmp_length;
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1514;
tr3277:
	{
		s->buffer[s->buffer_length] = 0;

		if (inet_pton(AF_INET6, (char *)s->buffer, s->addr) <= 0) {
			WARN(ZS_BAD_IPV6);
			p--; {goto st316;}
		}
	}
	{
		if (rdata_tail + ZS_INET6_ADDR_LENGTH > rdata_stop + 1) {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
		memcpy(rdata_tail, s->addr, ZS_INET6_ADDR_LENGTH);
		rdata_tail += ZS_INET6_ADDR_LENGTH;
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1514;
st1514:
	if ( ++p == pe )
		goto _test_eof1514;
case 1514:
	goto st0;
tr3179:
	{
		s->buffer_length = 0;
	}
	goto st1081;
tr3192:
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		}
	}
	goto st1081;
tr3323:
	{
		rdata_tail += s->dname_tmp_length;
	}
	{
		s->buffer_length = 0;
	}
	goto st1081;
tr3234:
	{
		s->buffer[s->buffer_length] = 0;

		if (inet_pton(AF_INET, (char *)s->buffer, s->addr) <= 0) {
			WARN(ZS_BAD_IPV4);
			p--; {goto st316;}
		}
	}
	{
		if (rdata_tail + ZS_INET4_ADDR_LENGTH > rdata_stop + 1) {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
		memcpy(rdata_tail, s->addr, ZS_INET4_ADDR_LENGTH);
		rdata_tail += ZS_INET4_ADDR_LENGTH;
	}
	{
		s->buffer_length = 0;
	}
	goto st1081;
tr3279:
	{
		s->buffer[s->buffer_length] = 0;

		if (inet_pton(AF_INET6, (char *)s->buffer, s->addr) <= 0) {
			WARN(ZS_BAD_IPV6);
			p--; {goto st316;}
		}
	}
	{
		if (rdata_tail + ZS_INET6_ADDR_LENGTH > rdata_stop + 1) {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
		memcpy(rdata_tail, s->addr, ZS_INET6_ADDR_LENGTH);
		rdata_tail += ZS_INET6_ADDR_LENGTH;
	}
	{
		s->buffer_length = 0;
	}
	goto st1081;
st1081:
	if ( ++p == pe )
		goto _test_eof1081;
case 1081:
	_widec = (*p);
	if ( (*p) < 10 ) {
		if ( (*p) <= 9 ) {
			_widec = (short)(4224 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 s->number64 != 0  ) _widec += 512;
		}
	} else if ( (*p) > 10 ) {
		if ( 11 <= (*p) )
 {			_widec = (short)(4224 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 s->number64 != 0  ) _widec += 512;
		}
	} else {
		_widec = (short)(4224 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		if (
 s->number64 != 0  ) _widec += 512;
	}
	if ( _widec == 5130 )
		goto tr3193;
	if ( 4992 <= _widec && _widec <= 5247 )
		goto tr3192;
	goto tr3190;
tr3172:
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st1082;
tr3173:
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st1082;
tr3182:
	{
		s->line_counter++;
	}
	goto st1082;
tr3195:
	{
		s->buffer[s->buffer_length++] = 0;

		// Execute the comment callback.
		if (s->process.automatic && s->process.comment != NULL) {
			s->process.comment(s);

			// Stop if required from the callback.
			if (s->state == ZS_STATE_STOP) {
				{p++; cs = 1082; goto _out;}
			}
		}
	}
	{
		s->line_counter++;
	}
	goto st1082;
tr3226:
	{
		s->buffer[s->buffer_length] = 0;

		if (inet_pton(AF_INET, (char *)s->buffer, s->addr) <= 0) {
			WARN(ZS_BAD_IPV4);
			p--; {goto st316;}
		}
	}
	{
		if (rdata_tail + ZS_INET4_ADDR_LENGTH > rdata_stop + 1) {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
		memcpy(rdata_tail, s->addr, ZS_INET4_ADDR_LENGTH);
		rdata_tail += ZS_INET4_ADDR_LENGTH;
	}
	goto st1082;
tr3271:
	{
		s->buffer[s->buffer_length] = 0;

		if (inet_pton(AF_INET6, (char *)s->buffer, s->addr) <= 0) {
			WARN(ZS_BAD_IPV6);
			p--; {goto st316;}
		}
	}
	{
		if (rdata_tail + ZS_INET6_ADDR_LENGTH > rdata_stop + 1) {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
		memcpy(rdata_tail, s->addr, ZS_INET6_ADDR_LENGTH);
		rdata_tail += ZS_INET6_ADDR_LENGTH;
	}
	goto st1082;
tr3315:
	{
		rdata_tail += s->dname_tmp_length;
	}
	goto st1082;
tr3316:
	{
		rdata_tail += s->dname_tmp_length;
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st1082;
tr3317:
	{
		rdata_tail += s->dname_tmp_length;
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st1082;
tr3326:
	{
		rdata_tail += s->dname_tmp_length;
	}
	{
		s->line_counter++;
	}
	goto st1082;
tr3227:
	{
		s->buffer[s->buffer_length] = 0;

		if (inet_pton(AF_INET, (char *)s->buffer, s->addr) <= 0) {
			WARN(ZS_BAD_IPV4);
			p--; {goto st316;}
		}
	}
	{
		if (rdata_tail + ZS_INET4_ADDR_LENGTH > rdata_stop + 1) {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
		memcpy(rdata_tail, s->addr, ZS_INET4_ADDR_LENGTH);
		rdata_tail += ZS_INET4_ADDR_LENGTH;
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st1082;
tr3228:
	{
		s->buffer[s->buffer_length] = 0;

		if (inet_pton(AF_INET, (char *)s->buffer, s->addr) <= 0) {
			WARN(ZS_BAD_IPV4);
			p--; {goto st316;}
		}
	}
	{
		if (rdata_tail + ZS_INET4_ADDR_LENGTH > rdata_stop + 1) {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
		memcpy(rdata_tail, s->addr, ZS_INET4_ADDR_LENGTH);
		rdata_tail += ZS_INET4_ADDR_LENGTH;
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st1082;
tr3237:
	{
		s->buffer[s->buffer_length] = 0;

		if (inet_pton(AF_INET, (char *)s->buffer, s->addr) <= 0) {
			WARN(ZS_BAD_IPV4);
			p--; {goto st316;}
		}
	}
	{
		if (rdata_tail + ZS_INET4_ADDR_LENGTH > rdata_stop + 1) {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
		memcpy(rdata_tail, s->addr, ZS_INET4_ADDR_LENGTH);
		rdata_tail += ZS_INET4_ADDR_LENGTH;
	}
	{
		s->line_counter++;
	}
	goto st1082;
tr3272:
	{
		s->buffer[s->buffer_length] = 0;

		if (inet_pton(AF_INET6, (char *)s->buffer, s->addr) <= 0) {
			WARN(ZS_BAD_IPV6);
			p--; {goto st316;}
		}
	}
	{
		if (rdata_tail + ZS_INET6_ADDR_LENGTH > rdata_stop + 1) {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
		memcpy(rdata_tail, s->addr, ZS_INET6_ADDR_LENGTH);
		rdata_tail += ZS_INET6_ADDR_LENGTH;
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st1082;
tr3273:
	{
		s->buffer[s->buffer_length] = 0;

		if (inet_pton(AF_INET6, (char *)s->buffer, s->addr) <= 0) {
			WARN(ZS_BAD_IPV6);
			p--; {goto st316;}
		}
	}
	{
		if (rdata_tail + ZS_INET6_ADDR_LENGTH > rdata_stop + 1) {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
		memcpy(rdata_tail, s->addr, ZS_INET6_ADDR_LENGTH);
		rdata_tail += ZS_INET6_ADDR_LENGTH;
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st1082;
tr3282:
	{
		s->buffer[s->buffer_length] = 0;

		if (inet_pton(AF_INET6, (char *)s->buffer, s->addr) <= 0) {
			WARN(ZS_BAD_IPV6);
			p--; {goto st316;}
		}
	}
	{
		if (rdata_tail + ZS_INET6_ADDR_LENGTH > rdata_stop + 1) {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
		memcpy(rdata_tail, s->addr, ZS_INET6_ADDR_LENGTH);
		rdata_tail += ZS_INET6_ADDR_LENGTH;
	}
	{
		s->line_counter++;
	}
	goto st1082;
st1082:
	if ( ++p == pe )
		goto _test_eof1082;
case 1082:
	_widec = (*p);
	if ( (*p) < 32 ) {
		if ( (*p) > 9 ) {
			if ( 10 <= (*p) && (*p) <= 10 ) {
				_widec = (short)(13952 + ((*p) - -128));
				if (
 s->multiline  ) _widec += 256;
				if (
 !s->multiline  ) _widec += 512;
				if (
 s->number64 == 0  ) _widec += 1024;
			}
		} else if ( (*p) >= 9 ) {
			_widec = (short)(5248 + ((*p) - -128));
			if (
 s->number64 == 0  ) _widec += 256;
		}
	} else if ( (*p) > 32 ) {
		if ( (*p) < 41 ) {
			if ( 40 <= (*p) && (*p) <= 40 ) {
				_widec = (short)(5248 + ((*p) - -128));
				if (
 s->number64 == 0  ) _widec += 256;
			}
		} else if ( (*p) > 41 ) {
			if ( 59 <= (*p) && (*p) <= 59 ) {
				_widec = (short)(13952 + ((*p) - -128));
				if (
 s->multiline  ) _widec += 256;
				if (
 !s->multiline  ) _widec += 512;
				if (
 s->number64 == 0  ) _widec += 1024;
			}
		} else {
			_widec = (short)(5248 + ((*p) - -128));
			if (
 s->number64 == 0  ) _widec += 256;
		}
	} else {
		_widec = (short)(5248 + ((*p) - -128));
		if (
 s->number64 == 0  ) _widec += 256;
	}
	switch( _widec ) {
		case 5641: goto st1082;
		case 5664: goto st1082;
		case 5672: goto tr3172;
		case 5673: goto tr3173;
		case 14602: goto tr3177;
		case 14651: goto tr3177;
		case 14858: goto tr3177;
		case 14907: goto tr3177;
		case 15370: goto tr3182;
		case 15419: goto tr3183;
		case 15626: goto tr3177;
		case 15675: goto tr3177;
		case 15882: goto tr3184;
		case 15931: goto tr3185;
	}
	goto tr3190;
tr3183:
	{
		s->buffer_length = 0;
	}
	goto st1083;
tr3194:
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		}
	}
	goto st1083;
tr3327:
	{
		rdata_tail += s->dname_tmp_length;
	}
	{
		s->buffer_length = 0;
	}
	goto st1083;
tr3238:
	{
		s->buffer[s->buffer_length] = 0;

		if (inet_pton(AF_INET, (char *)s->buffer, s->addr) <= 0) {
			WARN(ZS_BAD_IPV4);
			p--; {goto st316;}
		}
	}
	{
		if (rdata_tail + ZS_INET4_ADDR_LENGTH > rdata_stop + 1) {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
		memcpy(rdata_tail, s->addr, ZS_INET4_ADDR_LENGTH);
		rdata_tail += ZS_INET4_ADDR_LENGTH;
	}
	{
		s->buffer_length = 0;
	}
	goto st1083;
tr3283:
	{
		s->buffer[s->buffer_length] = 0;

		if (inet_pton(AF_INET6, (char *)s->buffer, s->addr) <= 0) {
			WARN(ZS_BAD_IPV6);
			p--; {goto st316;}
		}
	}
	{
		if (rdata_tail + ZS_INET6_ADDR_LENGTH > rdata_stop + 1) {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
		memcpy(rdata_tail, s->addr, ZS_INET6_ADDR_LENGTH);
		rdata_tail += ZS_INET6_ADDR_LENGTH;
	}
	{
		s->buffer_length = 0;
	}
	goto st1083;
st1083:
	if ( ++p == pe )
		goto _test_eof1083;
case 1083:
	_widec = (*p);
	if ( (*p) < 10 ) {
		if ( (*p) <= 9 ) {
			_widec = (short)(5760 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 s->number64 == 0  ) _widec += 512;
		}
	} else if ( (*p) > 10 ) {
		if ( 11 <= (*p) )
 {			_widec = (short)(5760 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 s->number64 == 0  ) _widec += 512;
		}
	} else {
		_widec = (short)(5760 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		if (
 s->number64 == 0  ) _widec += 512;
	}
	if ( _widec == 6666 )
		goto tr3195;
	if ( 6528 <= _widec && _widec <= 6783 )
		goto tr3194;
	goto tr3190;
tr3184:
	{
		s->line_counter++;
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1515;
tr3239:
	{
		s->buffer[s->buffer_length] = 0;

		if (inet_pton(AF_INET, (char *)s->buffer, s->addr) <= 0) {
			WARN(ZS_BAD_IPV4);
			p--; {goto st316;}
		}
	}
	{
		if (rdata_tail + ZS_INET4_ADDR_LENGTH > rdata_stop + 1) {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
		memcpy(rdata_tail, s->addr, ZS_INET4_ADDR_LENGTH);
		rdata_tail += ZS_INET4_ADDR_LENGTH;
	}
	{
		s->line_counter++;
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1515;
tr3284:
	{
		s->buffer[s->buffer_length] = 0;

		if (inet_pton(AF_INET6, (char *)s->buffer, s->addr) <= 0) {
			WARN(ZS_BAD_IPV6);
			p--; {goto st316;}
		}
	}
	{
		if (rdata_tail + ZS_INET6_ADDR_LENGTH > rdata_stop + 1) {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
		memcpy(rdata_tail, s->addr, ZS_INET6_ADDR_LENGTH);
		rdata_tail += ZS_INET6_ADDR_LENGTH;
	}
	{
		s->line_counter++;
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1515;
tr3328:
	{
		rdata_tail += s->dname_tmp_length;
	}
	{
		s->line_counter++;
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1515;
st1515:
	if ( ++p == pe )
		goto _test_eof1515;
case 1515:
	_widec = (*p);
	if ( (*p) < 32 ) {
		if ( (*p) > 9 ) {
			if ( 10 <= (*p) && (*p) <= 10 ) {
				_widec = (short)(13952 + ((*p) - -128));
				if (
 s->multiline  ) _widec += 256;
				if (
 !s->multiline  ) _widec += 512;
				if (
 s->number64 == 0  ) _widec += 1024;
			}
		} else if ( (*p) >= 9 ) {
			_widec = (short)(5248 + ((*p) - -128));
			if (
 s->number64 == 0  ) _widec += 256;
		}
	} else if ( (*p) > 32 ) {
		if ( (*p) < 41 ) {
			if ( 40 <= (*p) && (*p) <= 40 ) {
				_widec = (short)(5248 + ((*p) - -128));
				if (
 s->number64 == 0  ) _widec += 256;
			}
		} else if ( (*p) > 41 ) {
			if ( 59 <= (*p) && (*p) <= 59 ) {
				_widec = (short)(13952 + ((*p) - -128));
				if (
 s->multiline  ) _widec += 256;
				if (
 !s->multiline  ) _widec += 512;
				if (
 s->number64 == 0  ) _widec += 1024;
			}
		} else {
			_widec = (short)(5248 + ((*p) - -128));
			if (
 s->number64 == 0  ) _widec += 256;
		}
	} else {
		_widec = (short)(5248 + ((*p) - -128));
		if (
 s->number64 == 0  ) _widec += 256;
	}
	switch( _widec ) {
		case 5641: goto st1082;
		case 5664: goto st1082;
		case 5672: goto tr3172;
		case 5673: goto tr3173;
		case 14602: goto tr3177;
		case 14651: goto tr3177;
		case 14858: goto tr3177;
		case 14907: goto tr3177;
		case 15370: goto tr3182;
		case 15419: goto tr3183;
		case 15626: goto tr3177;
		case 15675: goto tr3177;
		case 15882: goto tr3184;
		case 15931: goto tr3185;
	}
	goto tr3190;
tr3185:
	{
		s->buffer_length = 0;
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1516;
tr3240:
	{
		s->buffer[s->buffer_length] = 0;

		if (inet_pton(AF_INET, (char *)s->buffer, s->addr) <= 0) {
			WARN(ZS_BAD_IPV4);
			p--; {goto st316;}
		}
	}
	{
		if (rdata_tail + ZS_INET4_ADDR_LENGTH > rdata_stop + 1) {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
		memcpy(rdata_tail, s->addr, ZS_INET4_ADDR_LENGTH);
		rdata_tail += ZS_INET4_ADDR_LENGTH;
	}
	{
		s->buffer_length = 0;
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1516;
tr3285:
	{
		s->buffer[s->buffer_length] = 0;

		if (inet_pton(AF_INET6, (char *)s->buffer, s->addr) <= 0) {
			WARN(ZS_BAD_IPV6);
			p--; {goto st316;}
		}
	}
	{
		if (rdata_tail + ZS_INET6_ADDR_LENGTH > rdata_stop + 1) {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
		memcpy(rdata_tail, s->addr, ZS_INET6_ADDR_LENGTH);
		rdata_tail += ZS_INET6_ADDR_LENGTH;
	}
	{
		s->buffer_length = 0;
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1516;
tr3329:
	{
		rdata_tail += s->dname_tmp_length;
	}
	{
		s->buffer_length = 0;
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1516;
st1516:
	if ( ++p == pe )
		goto _test_eof1516;
case 1516:
	_widec = (*p);
	if ( (*p) < 10 ) {
		if ( (*p) <= 9 ) {
			_widec = (short)(5760 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 s->number64 == 0  ) _widec += 512;
		}
	} else if ( (*p) > 10 ) {
		if ( 11 <= (*p) )
 {			_widec = (short)(5760 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 s->number64 == 0  ) _widec += 512;
		}
	} else {
		_widec = (short)(5760 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		if (
 s->number64 == 0  ) _widec += 512;
	}
	if ( _widec == 6666 )
		goto tr3195;
	if ( 6528 <= _widec && _widec <= 6783 )
		goto tr3194;
	goto tr3190;
tr3175:
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st1084;
tr3176:
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st1084;
tr3186:
	{
		s->line_counter++;
	}
	goto st1084;
tr3197:
	{
		s->buffer[s->buffer_length++] = 0;

		// Execute the comment callback.
		if (s->process.automatic && s->process.comment != NULL) {
			s->process.comment(s);

			// Stop if required from the callback.
			if (s->state == ZS_STATE_STOP) {
				{p++; cs = 1084; goto _out;}
			}
		}
	}
	{
		s->line_counter++;
	}
	goto st1084;
tr3229:
	{
		s->buffer[s->buffer_length] = 0;

		if (inet_pton(AF_INET, (char *)s->buffer, s->addr) <= 0) {
			WARN(ZS_BAD_IPV4);
			p--; {goto st316;}
		}
	}
	{
		if (rdata_tail + ZS_INET4_ADDR_LENGTH > rdata_stop + 1) {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
		memcpy(rdata_tail, s->addr, ZS_INET4_ADDR_LENGTH);
		rdata_tail += ZS_INET4_ADDR_LENGTH;
	}
	goto st1084;
tr3274:
	{
		s->buffer[s->buffer_length] = 0;

		if (inet_pton(AF_INET6, (char *)s->buffer, s->addr) <= 0) {
			WARN(ZS_BAD_IPV6);
			p--; {goto st316;}
		}
	}
	{
		if (rdata_tail + ZS_INET6_ADDR_LENGTH > rdata_stop + 1) {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
		memcpy(rdata_tail, s->addr, ZS_INET6_ADDR_LENGTH);
		rdata_tail += ZS_INET6_ADDR_LENGTH;
	}
	goto st1084;
tr3318:
	{
		rdata_tail += s->dname_tmp_length;
	}
	goto st1084;
tr3319:
	{
		rdata_tail += s->dname_tmp_length;
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st1084;
tr3320:
	{
		rdata_tail += s->dname_tmp_length;
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st1084;
tr3330:
	{
		rdata_tail += s->dname_tmp_length;
	}
	{
		s->line_counter++;
	}
	goto st1084;
tr3230:
	{
		s->buffer[s->buffer_length] = 0;

		if (inet_pton(AF_INET, (char *)s->buffer, s->addr) <= 0) {
			WARN(ZS_BAD_IPV4);
			p--; {goto st316;}
		}
	}
	{
		if (rdata_tail + ZS_INET4_ADDR_LENGTH > rdata_stop + 1) {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
		memcpy(rdata_tail, s->addr, ZS_INET4_ADDR_LENGTH);
		rdata_tail += ZS_INET4_ADDR_LENGTH;
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st1084;
tr3231:
	{
		s->buffer[s->buffer_length] = 0;

		if (inet_pton(AF_INET, (char *)s->buffer, s->addr) <= 0) {
			WARN(ZS_BAD_IPV4);
			p--; {goto st316;}
		}
	}
	{
		if (rdata_tail + ZS_INET4_ADDR_LENGTH > rdata_stop + 1) {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
		memcpy(rdata_tail, s->addr, ZS_INET4_ADDR_LENGTH);
		rdata_tail += ZS_INET4_ADDR_LENGTH;
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st1084;
tr3241:
	{
		s->buffer[s->buffer_length] = 0;

		if (inet_pton(AF_INET, (char *)s->buffer, s->addr) <= 0) {
			WARN(ZS_BAD_IPV4);
			p--; {goto st316;}
		}
	}
	{
		if (rdata_tail + ZS_INET4_ADDR_LENGTH > rdata_stop + 1) {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
		memcpy(rdata_tail, s->addr, ZS_INET4_ADDR_LENGTH);
		rdata_tail += ZS_INET4_ADDR_LENGTH;
	}
	{
		s->line_counter++;
	}
	goto st1084;
tr3275:
	{
		s->buffer[s->buffer_length] = 0;

		if (inet_pton(AF_INET6, (char *)s->buffer, s->addr) <= 0) {
			WARN(ZS_BAD_IPV6);
			p--; {goto st316;}
		}
	}
	{
		if (rdata_tail + ZS_INET6_ADDR_LENGTH > rdata_stop + 1) {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
		memcpy(rdata_tail, s->addr, ZS_INET6_ADDR_LENGTH);
		rdata_tail += ZS_INET6_ADDR_LENGTH;
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st1084;
tr3276:
	{
		s->buffer[s->buffer_length] = 0;

		if (inet_pton(AF_INET6, (char *)s->buffer, s->addr) <= 0) {
			WARN(ZS_BAD_IPV6);
			p--; {goto st316;}
		}
	}
	{
		if (rdata_tail + ZS_INET6_ADDR_LENGTH > rdata_stop + 1) {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
		memcpy(rdata_tail, s->addr, ZS_INET6_ADDR_LENGTH);
		rdata_tail += ZS_INET6_ADDR_LENGTH;
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st1084;
tr3286:
	{
		s->buffer[s->buffer_length] = 0;

		if (inet_pton(AF_INET6, (char *)s->buffer, s->addr) <= 0) {
			WARN(ZS_BAD_IPV6);
			p--; {goto st316;}
		}
	}
	{
		if (rdata_tail + ZS_INET6_ADDR_LENGTH > rdata_stop + 1) {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
		memcpy(rdata_tail, s->addr, ZS_INET6_ADDR_LENGTH);
		rdata_tail += ZS_INET6_ADDR_LENGTH;
	}
	{
		s->line_counter++;
	}
	goto st1084;
st1084:
	if ( ++p == pe )
		goto _test_eof1084;
case 1084:
	_widec = (*p);
	if ( (*p) < 43 ) {
		if ( (*p) < 32 ) {
			if ( (*p) > 9 ) {
				if ( 10 <= (*p) && (*p) <= 10 ) {
					_widec = (short)(9856 + ((*p) - -128));
					if (
 s->multiline  ) _widec += 256;
					if (
 !s->multiline  ) _widec += 512;
					if (
 s->number64 != 0  ) _widec += 1024;
					if (
 s->number64 == 0  ) _widec += 2048;
				}
			} else if ( (*p) >= 9 ) {
				_widec = (short)(6784 + ((*p) - -128));
				if (
 s->number64 != 0  ) _widec += 256;
				if (
 s->number64 == 0  ) _widec += 512;
			}
		} else if ( (*p) > 32 ) {
			if ( (*p) > 40 ) {
				if ( 41 <= (*p) && (*p) <= 41 ) {
					_widec = (short)(6784 + ((*p) - -128));
					if (
 s->number64 != 0  ) _widec += 256;
					if (
 s->number64 == 0  ) _widec += 512;
				}
			} else if ( (*p) >= 40 ) {
				_widec = (short)(6784 + ((*p) - -128));
				if (
 s->number64 != 0  ) _widec += 256;
				if (
 s->number64 == 0  ) _widec += 512;
			}
		} else {
			_widec = (short)(6784 + ((*p) - -128));
			if (
 s->number64 != 0  ) _widec += 256;
			if (
 s->number64 == 0  ) _widec += 512;
		}
	} else if ( (*p) > 43 ) {
		if ( (*p) < 59 ) {
			if ( (*p) > 47 ) {
				if ( 48 <= (*p) && (*p) <= 57 ) {
					_widec = (short)(3712 + ((*p) - -128));
					if (
 s->number64 != 0  ) _widec += 256;
				}
			} else if ( (*p) >= 47 ) {
				_widec = (short)(3712 + ((*p) - -128));
				if (
 s->number64 != 0  ) _widec += 256;
			}
		} else if ( (*p) > 59 ) {
			if ( (*p) > 90 ) {
				if ( 97 <= (*p) && (*p) <= 122 ) {
					_widec = (short)(3712 + ((*p) - -128));
					if (
 s->number64 != 0  ) _widec += 256;
				}
			} else if ( (*p) >= 65 ) {
				_widec = (short)(3712 + ((*p) - -128));
				if (
 s->number64 != 0  ) _widec += 256;
			}
		} else {
			_widec = (short)(9856 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 !s->multiline  ) _widec += 512;
			if (
 s->number64 != 0  ) _widec += 1024;
			if (
 s->number64 == 0  ) _widec += 2048;
		}
	} else {
		_widec = (short)(3712 + ((*p) - -128));
		if (
 s->number64 != 0  ) _widec += 256;
	}
	switch( _widec ) {
		case 4139: goto tr3191;
		case 7177: goto st1079;
		case 7200: goto st1079;
		case 7208: goto tr3169;
		case 7209: goto tr3170;
		case 7433: goto st1082;
		case 7456: goto st1082;
		case 7464: goto tr3172;
		case 7465: goto tr3173;
		case 7689: goto st1084;
		case 7712: goto st1084;
		case 7720: goto tr3175;
		case 7721: goto tr3176;
		case 10506: goto tr3177;
		case 10555: goto tr3177;
		case 10762: goto tr3177;
		case 10811: goto tr3177;
		case 11274: goto tr3178;
		case 11323: goto tr3179;
		case 11530: goto tr3177;
		case 11579: goto tr3177;
		case 11786: goto tr3180;
		case 11835: goto tr3181;
		case 12298: goto tr3182;
		case 12347: goto tr3183;
		case 12554: goto tr3177;
		case 12603: goto tr3177;
		case 12810: goto tr3184;
		case 12859: goto tr3185;
		case 13322: goto tr3186;
		case 13371: goto tr3187;
		case 13578: goto tr3177;
		case 13627: goto tr3177;
		case 13834: goto tr3188;
		case 13883: goto tr3189;
	}
	if ( _widec < 4161 ) {
		if ( 4143 <= _widec && _widec <= 4153 )
			goto tr3191;
	} else if ( _widec > 4186 ) {
		if ( 4193 <= _widec && _widec <= 4218 )
			goto tr3191;
	} else
		goto tr3191;
	goto tr3190;
tr3180:
	{
		s->line_counter++;
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1517;
tr3235:
	{
		s->buffer[s->buffer_length] = 0;

		if (inet_pton(AF_INET, (char *)s->buffer, s->addr) <= 0) {
			WARN(ZS_BAD_IPV4);
			p--; {goto st316;}
		}
	}
	{
		if (rdata_tail + ZS_INET4_ADDR_LENGTH > rdata_stop + 1) {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
		memcpy(rdata_tail, s->addr, ZS_INET4_ADDR_LENGTH);
		rdata_tail += ZS_INET4_ADDR_LENGTH;
	}
	{
		s->line_counter++;
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1517;
tr3280:
	{
		s->buffer[s->buffer_length] = 0;

		if (inet_pton(AF_INET6, (char *)s->buffer, s->addr) <= 0) {
			WARN(ZS_BAD_IPV6);
			p--; {goto st316;}
		}
	}
	{
		if (rdata_tail + ZS_INET6_ADDR_LENGTH > rdata_stop + 1) {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
		memcpy(rdata_tail, s->addr, ZS_INET6_ADDR_LENGTH);
		rdata_tail += ZS_INET6_ADDR_LENGTH;
	}
	{
		s->line_counter++;
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1517;
tr3324:
	{
		rdata_tail += s->dname_tmp_length;
	}
	{
		s->line_counter++;
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1517;
st1517:
	if ( ++p == pe )
		goto _test_eof1517;
case 1517:
	_widec = (*p);
	if ( (*p) < 43 ) {
		if ( (*p) < 32 ) {
			if ( (*p) > 9 ) {
				if ( 10 <= (*p) && (*p) <= 10 ) {
					_widec = (short)(4224 + ((*p) - -128));
					if (
 s->multiline  ) _widec += 256;
					if (
 s->number64 != 0  ) _widec += 512;
				}
			} else if ( (*p) >= 9 ) {
				_widec = (short)(3712 + ((*p) - -128));
				if (
 s->number64 != 0  ) _widec += 256;
			}
		} else if ( (*p) > 32 ) {
			if ( (*p) > 40 ) {
				if ( 41 <= (*p) && (*p) <= 41 ) {
					_widec = (short)(3712 + ((*p) - -128));
					if (
 s->number64 != 0  ) _widec += 256;
				}
			} else if ( (*p) >= 40 ) {
				_widec = (short)(3712 + ((*p) - -128));
				if (
 s->number64 != 0  ) _widec += 256;
			}
		} else {
			_widec = (short)(3712 + ((*p) - -128));
			if (
 s->number64 != 0  ) _widec += 256;
		}
	} else if ( (*p) > 43 ) {
		if ( (*p) < 59 ) {
			if ( (*p) > 47 ) {
				if ( 48 <= (*p) && (*p) <= 57 ) {
					_widec = (short)(3712 + ((*p) - -128));
					if (
 s->number64 != 0  ) _widec += 256;
				}
			} else if ( (*p) >= 47 ) {
				_widec = (short)(3712 + ((*p) - -128));
				if (
 s->number64 != 0  ) _widec += 256;
			}
		} else if ( (*p) > 59 ) {
			if ( (*p) > 90 ) {
				if ( 97 <= (*p) && (*p) <= 122 ) {
					_widec = (short)(3712 + ((*p) - -128));
					if (
 s->number64 != 0  ) _widec += 256;
				}
			} else if ( (*p) >= 65 ) {
				_widec = (short)(3712 + ((*p) - -128));
				if (
 s->number64 != 0  ) _widec += 256;
			}
		} else {
			_widec = (short)(4224 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 s->number64 != 0  ) _widec += 512;
		}
	} else {
		_widec = (short)(3712 + ((*p) - -128));
		if (
 s->number64 != 0  ) _widec += 256;
	}
	switch( _widec ) {
		case 4105: goto st1079;
		case 4128: goto st1079;
		case 4136: goto tr3169;
		case 4137: goto tr3170;
		case 4139: goto tr3191;
		case 5130: goto tr3178;
		case 5179: goto tr3179;
	}
	if ( _widec < 4161 ) {
		if ( 4143 <= _widec && _widec <= 4153 )
			goto tr3191;
	} else if ( _widec > 4186 ) {
		if ( 4193 <= _widec && _widec <= 4218 )
			goto tr3191;
	} else
		goto tr3191;
	goto tr3190;
tr3181:
	{
		s->buffer_length = 0;
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1518;
tr3236:
	{
		s->buffer[s->buffer_length] = 0;

		if (inet_pton(AF_INET, (char *)s->buffer, s->addr) <= 0) {
			WARN(ZS_BAD_IPV4);
			p--; {goto st316;}
		}
	}
	{
		if (rdata_tail + ZS_INET4_ADDR_LENGTH > rdata_stop + 1) {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
		memcpy(rdata_tail, s->addr, ZS_INET4_ADDR_LENGTH);
		rdata_tail += ZS_INET4_ADDR_LENGTH;
	}
	{
		s->buffer_length = 0;
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1518;
tr3281:
	{
		s->buffer[s->buffer_length] = 0;

		if (inet_pton(AF_INET6, (char *)s->buffer, s->addr) <= 0) {
			WARN(ZS_BAD_IPV6);
			p--; {goto st316;}
		}
	}
	{
		if (rdata_tail + ZS_INET6_ADDR_LENGTH > rdata_stop + 1) {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
		memcpy(rdata_tail, s->addr, ZS_INET6_ADDR_LENGTH);
		rdata_tail += ZS_INET6_ADDR_LENGTH;
	}
	{
		s->buffer_length = 0;
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1518;
tr3325:
	{
		rdata_tail += s->dname_tmp_length;
	}
	{
		s->buffer_length = 0;
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1518;
st1518:
	if ( ++p == pe )
		goto _test_eof1518;
case 1518:
	_widec = (*p);
	if ( (*p) < 10 ) {
		if ( (*p) <= 9 ) {
			_widec = (short)(4224 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 s->number64 != 0  ) _widec += 512;
		}
	} else if ( (*p) > 10 ) {
		if ( 11 <= (*p) )
 {			_widec = (short)(4224 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 s->number64 != 0  ) _widec += 512;
		}
	} else {
		_widec = (short)(4224 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		if (
 s->number64 != 0  ) _widec += 512;
	}
	if ( _widec == 5130 )
		goto tr3193;
	if ( 4992 <= _widec && _widec <= 5247 )
		goto tr3192;
	goto tr3190;
tr3187:
	{
		s->buffer_length = 0;
	}
	goto st1085;
tr3196:
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		}
	}
	goto st1085;
tr3331:
	{
		rdata_tail += s->dname_tmp_length;
	}
	{
		s->buffer_length = 0;
	}
	goto st1085;
tr3242:
	{
		s->buffer[s->buffer_length] = 0;

		if (inet_pton(AF_INET, (char *)s->buffer, s->addr) <= 0) {
			WARN(ZS_BAD_IPV4);
			p--; {goto st316;}
		}
	}
	{
		if (rdata_tail + ZS_INET4_ADDR_LENGTH > rdata_stop + 1) {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
		memcpy(rdata_tail, s->addr, ZS_INET4_ADDR_LENGTH);
		rdata_tail += ZS_INET4_ADDR_LENGTH;
	}
	{
		s->buffer_length = 0;
	}
	goto st1085;
tr3287:
	{
		s->buffer[s->buffer_length] = 0;

		if (inet_pton(AF_INET6, (char *)s->buffer, s->addr) <= 0) {
			WARN(ZS_BAD_IPV6);
			p--; {goto st316;}
		}
	}
	{
		if (rdata_tail + ZS_INET6_ADDR_LENGTH > rdata_stop + 1) {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
		memcpy(rdata_tail, s->addr, ZS_INET6_ADDR_LENGTH);
		rdata_tail += ZS_INET6_ADDR_LENGTH;
	}
	{
		s->buffer_length = 0;
	}
	goto st1085;
st1085:
	if ( ++p == pe )
		goto _test_eof1085;
case 1085:
	_widec = (*p);
	if ( (*p) < 10 ) {
		if ( (*p) <= 9 ) {
			_widec = (short)(7808 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 s->number64 != 0  ) _widec += 512;
			if (
 s->number64 == 0  ) _widec += 1024;
		}
	} else if ( (*p) > 10 ) {
		if ( 11 <= (*p) )
 {			_widec = (short)(7808 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 s->number64 != 0  ) _widec += 512;
			if (
 s->number64 == 0  ) _widec += 1024;
		}
	} else {
		_widec = (short)(7808 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		if (
 s->number64 != 0  ) _widec += 512;
		if (
 s->number64 == 0  ) _widec += 1024;
	}
	switch( _widec ) {
		case 8714: goto tr3193;
		case 9226: goto tr3195;
		case 9738: goto tr3197;
	}
	if ( _widec < 9088 ) {
		if ( 8576 <= _widec && _widec <= 8831 )
			goto tr3192;
	} else if ( _widec > 9343 ) {
		if ( 9600 <= _widec && _widec <= 9855 )
			goto tr3196;
	} else
		goto tr3194;
	goto tr3190;
tr3188:
	{
		s->line_counter++;
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1519;
tr3243:
	{
		s->buffer[s->buffer_length] = 0;

		if (inet_pton(AF_INET, (char *)s->buffer, s->addr) <= 0) {
			WARN(ZS_BAD_IPV4);
			p--; {goto st316;}
		}
	}
	{
		if (rdata_tail + ZS_INET4_ADDR_LENGTH > rdata_stop + 1) {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
		memcpy(rdata_tail, s->addr, ZS_INET4_ADDR_LENGTH);
		rdata_tail += ZS_INET4_ADDR_LENGTH;
	}
	{
		s->line_counter++;
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1519;
tr3288:
	{
		s->buffer[s->buffer_length] = 0;

		if (inet_pton(AF_INET6, (char *)s->buffer, s->addr) <= 0) {
			WARN(ZS_BAD_IPV6);
			p--; {goto st316;}
		}
	}
	{
		if (rdata_tail + ZS_INET6_ADDR_LENGTH > rdata_stop + 1) {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
		memcpy(rdata_tail, s->addr, ZS_INET6_ADDR_LENGTH);
		rdata_tail += ZS_INET6_ADDR_LENGTH;
	}
	{
		s->line_counter++;
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1519;
tr3332:
	{
		rdata_tail += s->dname_tmp_length;
	}
	{
		s->line_counter++;
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1519;
st1519:
	if ( ++p == pe )
		goto _test_eof1519;
case 1519:
	_widec = (*p);
	if ( (*p) < 43 ) {
		if ( (*p) < 32 ) {
			if ( (*p) > 9 ) {
				if ( 10 <= (*p) && (*p) <= 10 ) {
					_widec = (short)(9856 + ((*p) - -128));
					if (
 s->multiline  ) _widec += 256;
					if (
 !s->multiline  ) _widec += 512;
					if (
 s->number64 != 0  ) _widec += 1024;
					if (
 s->number64 == 0  ) _widec += 2048;
				}
			} else if ( (*p) >= 9 ) {
				_widec = (short)(6784 + ((*p) - -128));
				if (
 s->number64 != 0  ) _widec += 256;
				if (
 s->number64 == 0  ) _widec += 512;
			}
		} else if ( (*p) > 32 ) {
			if ( (*p) > 40 ) {
				if ( 41 <= (*p) && (*p) <= 41 ) {
					_widec = (short)(6784 + ((*p) - -128));
					if (
 s->number64 != 0  ) _widec += 256;
					if (
 s->number64 == 0  ) _widec += 512;
				}
			} else if ( (*p) >= 40 ) {
				_widec = (short)(6784 + ((*p) - -128));
				if (
 s->number64 != 0  ) _widec += 256;
				if (
 s->number64 == 0  ) _widec += 512;
			}
		} else {
			_widec = (short)(6784 + ((*p) - -128));
			if (
 s->number64 != 0  ) _widec += 256;
			if (
 s->number64 == 0  ) _widec += 512;
		}
	} else if ( (*p) > 43 ) {
		if ( (*p) < 59 ) {
			if ( (*p) > 47 ) {
				if ( 48 <= (*p) && (*p) <= 57 ) {
					_widec = (short)(3712 + ((*p) - -128));
					if (
 s->number64 != 0  ) _widec += 256;
				}
			} else if ( (*p) >= 47 ) {
				_widec = (short)(3712 + ((*p) - -128));
				if (
 s->number64 != 0  ) _widec += 256;
			}
		} else if ( (*p) > 59 ) {
			if ( (*p) > 90 ) {
				if ( 97 <= (*p) && (*p) <= 122 ) {
					_widec = (short)(3712 + ((*p) - -128));
					if (
 s->number64 != 0  ) _widec += 256;
				}
			} else if ( (*p) >= 65 ) {
				_widec = (short)(3712 + ((*p) - -128));
				if (
 s->number64 != 0  ) _widec += 256;
			}
		} else {
			_widec = (short)(9856 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 !s->multiline  ) _widec += 512;
			if (
 s->number64 != 0  ) _widec += 1024;
			if (
 s->number64 == 0  ) _widec += 2048;
		}
	} else {
		_widec = (short)(3712 + ((*p) - -128));
		if (
 s->number64 != 0  ) _widec += 256;
	}
	switch( _widec ) {
		case 4139: goto tr3191;
		case 7177: goto st1079;
		case 7200: goto st1079;
		case 7208: goto tr3169;
		case 7209: goto tr3170;
		case 7433: goto st1082;
		case 7456: goto st1082;
		case 7464: goto tr3172;
		case 7465: goto tr3173;
		case 7689: goto st1084;
		case 7712: goto st1084;
		case 7720: goto tr3175;
		case 7721: goto tr3176;
		case 10506: goto tr3177;
		case 10555: goto tr3177;
		case 10762: goto tr3177;
		case 10811: goto tr3177;
		case 11274: goto tr3178;
		case 11323: goto tr3179;
		case 11530: goto tr3177;
		case 11579: goto tr3177;
		case 11786: goto tr3180;
		case 11835: goto tr3181;
		case 12298: goto tr3182;
		case 12347: goto tr3183;
		case 12554: goto tr3177;
		case 12603: goto tr3177;
		case 12810: goto tr3184;
		case 12859: goto tr3185;
		case 13322: goto tr3186;
		case 13371: goto tr3187;
		case 13578: goto tr3177;
		case 13627: goto tr3177;
		case 13834: goto tr3188;
		case 13883: goto tr3189;
	}
	if ( _widec < 4161 ) {
		if ( 4143 <= _widec && _widec <= 4153 )
			goto tr3191;
	} else if ( _widec > 4186 ) {
		if ( 4193 <= _widec && _widec <= 4218 )
			goto tr3191;
	} else
		goto tr3191;
	goto tr3190;
tr3189:
	{
		s->buffer_length = 0;
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1520;
tr3244:
	{
		s->buffer[s->buffer_length] = 0;

		if (inet_pton(AF_INET, (char *)s->buffer, s->addr) <= 0) {
			WARN(ZS_BAD_IPV4);
			p--; {goto st316;}
		}
	}
	{
		if (rdata_tail + ZS_INET4_ADDR_LENGTH > rdata_stop + 1) {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
		memcpy(rdata_tail, s->addr, ZS_INET4_ADDR_LENGTH);
		rdata_tail += ZS_INET4_ADDR_LENGTH;
	}
	{
		s->buffer_length = 0;
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1520;
tr3289:
	{
		s->buffer[s->buffer_length] = 0;

		if (inet_pton(AF_INET6, (char *)s->buffer, s->addr) <= 0) {
			WARN(ZS_BAD_IPV6);
			p--; {goto st316;}
		}
	}
	{
		if (rdata_tail + ZS_INET6_ADDR_LENGTH > rdata_stop + 1) {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
		memcpy(rdata_tail, s->addr, ZS_INET6_ADDR_LENGTH);
		rdata_tail += ZS_INET6_ADDR_LENGTH;
	}
	{
		s->buffer_length = 0;
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1520;
tr3333:
	{
		rdata_tail += s->dname_tmp_length;
	}
	{
		s->buffer_length = 0;
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1520;
st1520:
	if ( ++p == pe )
		goto _test_eof1520;
case 1520:
	_widec = (*p);
	if ( (*p) < 10 ) {
		if ( (*p) <= 9 ) {
			_widec = (short)(7808 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 s->number64 != 0  ) _widec += 512;
			if (
 s->number64 == 0  ) _widec += 1024;
		}
	} else if ( (*p) > 10 ) {
		if ( 11 <= (*p) )
 {			_widec = (short)(7808 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 s->number64 != 0  ) _widec += 512;
			if (
 s->number64 == 0  ) _widec += 1024;
		}
	} else {
		_widec = (short)(7808 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		if (
 s->number64 != 0  ) _widec += 512;
		if (
 s->number64 == 0  ) _widec += 1024;
	}
	switch( _widec ) {
		case 8714: goto tr3193;
		case 9226: goto tr3195;
		case 9738: goto tr3197;
	}
	if ( _widec < 9088 ) {
		if ( 8576 <= _widec && _widec <= 8831 )
			goto tr3192;
	} else if ( _widec > 9343 ) {
		if ( 9600 <= _widec && _widec <= 9855 )
			goto tr3196;
	} else
		goto tr3194;
	goto tr3190;
tr3166:
	{
		s->buffer_length = 0;
	}
	goto st1086;
tr3198:
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		}
	}
	goto st1086;
tr3160:
	{
		if (s->number64 <= UINT8_MAX) {
			*rdata_tail = (uint8_t)(s->number64);
			rdata_tail += 1;
		} else {
			WARN(ZS_NUMBER8_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		s->buffer_length = 0;
	}
	goto st1086;
st1086:
	if ( ++p == pe )
		goto _test_eof1086;
case 1086:
	_widec = (*p);
	if ( (*p) < 10 ) {
		if ( (*p) <= 9 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) > 10 ) {
		if ( 11 <= (*p) )
 {			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	if ( _widec == 2058 )
		goto tr3199;
	if ( 1920 <= _widec && _widec <= 2175 )
		goto tr3198;
	goto tr3138;
tr3152:
	{
		s->buffer_length = 0;
	}
	goto st1087;
tr3200:
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		}
	}
	goto st1087;
st1087:
	if ( ++p == pe )
		goto _test_eof1087;
case 1087:
	_widec = (*p);
	if ( (*p) < 10 ) {
		if ( (*p) <= 9 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) > 10 ) {
		if ( 11 <= (*p) )
 {			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	if ( _widec == 2058 )
		goto tr3201;
	if ( 1920 <= _widec && _widec <= 2175 )
		goto tr3200;
	goto tr3138;
tr3143:
	{
		*(rdata_tail++) = 1;
	}
	goto st1088;
st1088:
	if ( ++p == pe )
		goto _test_eof1088;
case 1088:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto st1089;
		case 32: goto st1089;
		case 40: goto tr3203;
		case 41: goto tr3204;
		case 2058: goto tr3205;
		case 2107: goto tr3206;
	}
	goto tr3138;
tr3203:
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st1089;
tr3204:
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st1089;
tr3205:
	{
		s->line_counter++;
	}
	goto st1089;
tr3248:
	{
		s->buffer[s->buffer_length++] = 0;

		// Execute the comment callback.
		if (s->process.automatic && s->process.comment != NULL) {
			s->process.comment(s);

			// Stop if required from the callback.
			if (s->state == ZS_STATE_STOP) {
				{p++; cs = 1089; goto _out;}
			}
		}
	}
	{
		s->line_counter++;
	}
	goto st1089;
st1089:
	if ( ++p == pe )
		goto _test_eof1089;
case 1089:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto st1089;
		case 32: goto st1089;
		case 40: goto tr3203;
		case 41: goto tr3204;
		case 2058: goto tr3205;
		case 2107: goto tr3206;
	}
	if ( 48 <= _widec && _widec <= 57 )
		goto tr3207;
	goto tr3153;
tr3207:
	{
		s->number64 = 0;
	}
	{
		// Overflow check: 10*(s->number64) + fc - '0' <= UINT64_MAX
		if ((s->number64 < (UINT64_MAX / 10)) ||   // Dominant fast check.
			((s->number64 == (UINT64_MAX / 10)) && // Marginal case.
			 ((uint8_t)(*p) <= (UINT64_MAX % 10) + '0')
			)
		   ) {
			s->number64 *= 10;
			s->number64 += digit_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_NUMBER64_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st1090;
tr3211:
	{
		// Overflow check: 10*(s->number64) + fc - '0' <= UINT64_MAX
		if ((s->number64 < (UINT64_MAX / 10)) ||   // Dominant fast check.
			((s->number64 == (UINT64_MAX / 10)) && // Marginal case.
			 ((uint8_t)(*p) <= (UINT64_MAX % 10) + '0')
			)
		   ) {
			s->number64 *= 10;
			s->number64 += digit_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_NUMBER64_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st1090;
st1090:
	if ( ++p == pe )
		goto _test_eof1090;
case 1090:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr3208;
		case 32: goto tr3208;
		case 40: goto tr3209;
		case 41: goto tr3210;
		case 2058: goto tr3212;
		case 2107: goto tr3213;
	}
	if ( 48 <= _widec && _widec <= 57 )
		goto tr3211;
	goto tr3153;
tr3216:
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st1091;
tr3217:
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st1091;
tr3219:
	{
		s->line_counter++;
	}
	goto st1091;
tr3246:
	{
		s->buffer[s->buffer_length++] = 0;

		// Execute the comment callback.
		if (s->process.automatic && s->process.comment != NULL) {
			s->process.comment(s);

			// Stop if required from the callback.
			if (s->state == ZS_STATE_STOP) {
				{p++; cs = 1091; goto _out;}
			}
		}
	}
	{
		s->line_counter++;
	}
	goto st1091;
tr3208:
	{
		if (s->number64 <= UINT8_MAX) {
			*rdata_tail = (uint8_t)(s->number64);
			rdata_tail += 1;
		} else {
			WARN(ZS_NUMBER8_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st1091;
tr3209:
	{
		if (s->number64 <= UINT8_MAX) {
			*rdata_tail = (uint8_t)(s->number64);
			rdata_tail += 1;
		} else {
			WARN(ZS_NUMBER8_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st1091;
tr3210:
	{
		if (s->number64 <= UINT8_MAX) {
			*rdata_tail = (uint8_t)(s->number64);
			rdata_tail += 1;
		} else {
			WARN(ZS_NUMBER8_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st1091;
tr3212:
	{
		if (s->number64 <= UINT8_MAX) {
			*rdata_tail = (uint8_t)(s->number64);
			rdata_tail += 1;
		} else {
			WARN(ZS_NUMBER8_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		s->line_counter++;
	}
	goto st1091;
st1091:
	if ( ++p == pe )
		goto _test_eof1091;
case 1091:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto st1091;
		case 32: goto st1091;
		case 40: goto tr3216;
		case 41: goto tr3217;
		case 46: goto tr3218;
		case 2058: goto tr3219;
		case 2107: goto tr3220;
	}
	if ( 48 <= _widec && _widec <= 57 )
		goto tr3218;
	goto tr3214;
tr3222:
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		} else {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st1092;
tr3218:
	{
		s->buffer_length = 0;
	}
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		} else {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st1092;
st1092:
	if ( ++p == pe )
		goto _test_eof1092;
case 1092:
	_widec = (*p);
	if ( (*p) < 32 ) {
		if ( (*p) > 9 ) {
			if ( 10 <= (*p) && (*p) <= 10 ) {
				_widec = (short)(9856 + ((*p) - -128));
				if (
 s->multiline  ) _widec += 256;
				if (
 !s->multiline  ) _widec += 512;
				if (
 s->number64 != 0  ) _widec += 1024;
				if (
 s->number64 == 0  ) _widec += 2048;
			}
		} else if ( (*p) >= 9 ) {
			_widec = (short)(6784 + ((*p) - -128));
			if (
 s->number64 != 0  ) _widec += 256;
			if (
 s->number64 == 0  ) _widec += 512;
		}
	} else if ( (*p) > 32 ) {
		if ( (*p) < 41 ) {
			if ( 40 <= (*p) && (*p) <= 40 ) {
				_widec = (short)(6784 + ((*p) - -128));
				if (
 s->number64 != 0  ) _widec += 256;
				if (
 s->number64 == 0  ) _widec += 512;
			}
		} else if ( (*p) > 41 ) {
			if ( 59 <= (*p) && (*p) <= 59 ) {
				_widec = (short)(9856 + ((*p) - -128));
				if (
 s->multiline  ) _widec += 256;
				if (
 !s->multiline  ) _widec += 512;
				if (
 s->number64 != 0  ) _widec += 1024;
				if (
 s->number64 == 0  ) _widec += 2048;
			}
		} else {
			_widec = (short)(6784 + ((*p) - -128));
			if (
 s->number64 != 0  ) _widec += 256;
			if (
 s->number64 == 0  ) _widec += 512;
		}
	} else {
		_widec = (short)(6784 + ((*p) - -128));
		if (
 s->number64 != 0  ) _widec += 256;
		if (
 s->number64 == 0  ) _widec += 512;
	}
	switch( _widec ) {
		case 46: goto tr3222;
		case 7177: goto tr3223;
		case 7200: goto tr3223;
		case 7208: goto tr3224;
		case 7209: goto tr3225;
		case 7433: goto tr3226;
		case 7456: goto tr3226;
		case 7464: goto tr3227;
		case 7465: goto tr3228;
		case 7689: goto tr3229;
		case 7712: goto tr3229;
		case 7720: goto tr3230;
		case 7721: goto tr3231;
		case 10506: goto tr3232;
		case 10555: goto tr3232;
		case 10762: goto tr3232;
		case 10811: goto tr3232;
		case 11274: goto tr3233;
		case 11323: goto tr3234;
		case 11530: goto tr3232;
		case 11579: goto tr3232;
		case 11786: goto tr3235;
		case 11835: goto tr3236;
		case 12298: goto tr3237;
		case 12347: goto tr3238;
		case 12554: goto tr3232;
		case 12603: goto tr3232;
		case 12810: goto tr3239;
		case 12859: goto tr3240;
		case 13322: goto tr3241;
		case 13371: goto tr3242;
		case 13578: goto tr3232;
		case 13627: goto tr3232;
		case 13834: goto tr3243;
		case 13883: goto tr3244;
	}
	if ( 48 <= _widec && _widec <= 57 )
		goto tr3222;
	goto tr3221;
tr3220:
	{
		s->buffer_length = 0;
	}
	goto st1093;
tr3245:
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		}
	}
	goto st1093;
tr3213:
	{
		if (s->number64 <= UINT8_MAX) {
			*rdata_tail = (uint8_t)(s->number64);
			rdata_tail += 1;
		} else {
			WARN(ZS_NUMBER8_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		s->buffer_length = 0;
	}
	goto st1093;
st1093:
	if ( ++p == pe )
		goto _test_eof1093;
case 1093:
	_widec = (*p);
	if ( (*p) < 10 ) {
		if ( (*p) <= 9 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) > 10 ) {
		if ( 11 <= (*p) )
 {			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	if ( _widec == 2058 )
		goto tr3246;
	if ( 1920 <= _widec && _widec <= 2175 )
		goto tr3245;
	goto tr3138;
tr3206:
	{
		s->buffer_length = 0;
	}
	goto st1094;
tr3247:
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		}
	}
	goto st1094;
st1094:
	if ( ++p == pe )
		goto _test_eof1094;
case 1094:
	_widec = (*p);
	if ( (*p) < 10 ) {
		if ( (*p) <= 9 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) > 10 ) {
		if ( 11 <= (*p) )
 {			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	if ( _widec == 2058 )
		goto tr3248;
	if ( 1920 <= _widec && _widec <= 2175 )
		goto tr3247;
	goto tr3138;
tr3144:
	{
		*(rdata_tail++) = 2;
	}
	goto st1095;
st1095:
	if ( ++p == pe )
		goto _test_eof1095;
case 1095:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto st1096;
		case 32: goto st1096;
		case 40: goto tr3250;
		case 41: goto tr3251;
		case 2058: goto tr3252;
		case 2107: goto tr3253;
	}
	goto tr3138;
tr3250:
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st1096;
tr3251:
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st1096;
tr3252:
	{
		s->line_counter++;
	}
	goto st1096;
tr3293:
	{
		s->buffer[s->buffer_length++] = 0;

		// Execute the comment callback.
		if (s->process.automatic && s->process.comment != NULL) {
			s->process.comment(s);

			// Stop if required from the callback.
			if (s->state == ZS_STATE_STOP) {
				{p++; cs = 1096; goto _out;}
			}
		}
	}
	{
		s->line_counter++;
	}
	goto st1096;
st1096:
	if ( ++p == pe )
		goto _test_eof1096;
case 1096:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto st1096;
		case 32: goto st1096;
		case 40: goto tr3250;
		case 41: goto tr3251;
		case 2058: goto tr3252;
		case 2107: goto tr3253;
	}
	if ( 48 <= _widec && _widec <= 57 )
		goto tr3254;
	goto tr3153;
tr3254:
	{
		s->number64 = 0;
	}
	{
		// Overflow check: 10*(s->number64) + fc - '0' <= UINT64_MAX
		if ((s->number64 < (UINT64_MAX / 10)) ||   // Dominant fast check.
			((s->number64 == (UINT64_MAX / 10)) && // Marginal case.
			 ((uint8_t)(*p) <= (UINT64_MAX % 10) + '0')
			)
		   ) {
			s->number64 *= 10;
			s->number64 += digit_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_NUMBER64_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st1097;
tr3258:
	{
		// Overflow check: 10*(s->number64) + fc - '0' <= UINT64_MAX
		if ((s->number64 < (UINT64_MAX / 10)) ||   // Dominant fast check.
			((s->number64 == (UINT64_MAX / 10)) && // Marginal case.
			 ((uint8_t)(*p) <= (UINT64_MAX % 10) + '0')
			)
		   ) {
			s->number64 *= 10;
			s->number64 += digit_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_NUMBER64_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st1097;
st1097:
	if ( ++p == pe )
		goto _test_eof1097;
case 1097:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr3255;
		case 32: goto tr3255;
		case 40: goto tr3256;
		case 41: goto tr3257;
		case 2058: goto tr3259;
		case 2107: goto tr3260;
	}
	if ( 48 <= _widec && _widec <= 57 )
		goto tr3258;
	goto tr3153;
tr3262:
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st1098;
tr3263:
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st1098;
tr3265:
	{
		s->line_counter++;
	}
	goto st1098;
tr3291:
	{
		s->buffer[s->buffer_length++] = 0;

		// Execute the comment callback.
		if (s->process.automatic && s->process.comment != NULL) {
			s->process.comment(s);

			// Stop if required from the callback.
			if (s->state == ZS_STATE_STOP) {
				{p++; cs = 1098; goto _out;}
			}
		}
	}
	{
		s->line_counter++;
	}
	goto st1098;
tr3255:
	{
		if (s->number64 <= UINT8_MAX) {
			*rdata_tail = (uint8_t)(s->number64);
			rdata_tail += 1;
		} else {
			WARN(ZS_NUMBER8_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st1098;
tr3256:
	{
		if (s->number64 <= UINT8_MAX) {
			*rdata_tail = (uint8_t)(s->number64);
			rdata_tail += 1;
		} else {
			WARN(ZS_NUMBER8_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st1098;
tr3257:
	{
		if (s->number64 <= UINT8_MAX) {
			*rdata_tail = (uint8_t)(s->number64);
			rdata_tail += 1;
		} else {
			WARN(ZS_NUMBER8_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st1098;
tr3259:
	{
		if (s->number64 <= UINT8_MAX) {
			*rdata_tail = (uint8_t)(s->number64);
			rdata_tail += 1;
		} else {
			WARN(ZS_NUMBER8_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		s->line_counter++;
	}
	goto st1098;
st1098:
	if ( ++p == pe )
		goto _test_eof1098;
case 1098:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto st1098;
		case 32: goto st1098;
		case 40: goto tr3262;
		case 41: goto tr3263;
		case 46: goto tr3264;
		case 2058: goto tr3265;
		case 2107: goto tr3266;
	}
	if ( _widec < 65 ) {
		if ( 48 <= _widec && _widec <= 58 )
			goto tr3264;
	} else if ( _widec > 70 ) {
		if ( 97 <= _widec && _widec <= 102 )
			goto tr3264;
	} else
		goto tr3264;
	goto tr3214;
tr3267:
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		} else {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st1099;
tr3264:
	{
		s->buffer_length = 0;
	}
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		} else {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st1099;
st1099:
	if ( ++p == pe )
		goto _test_eof1099;
case 1099:
	_widec = (*p);
	if ( (*p) < 32 ) {
		if ( (*p) > 9 ) {
			if ( 10 <= (*p) && (*p) <= 10 ) {
				_widec = (short)(9856 + ((*p) - -128));
				if (
 s->multiline  ) _widec += 256;
				if (
 !s->multiline  ) _widec += 512;
				if (
 s->number64 != 0  ) _widec += 1024;
				if (
 s->number64 == 0  ) _widec += 2048;
			}
		} else if ( (*p) >= 9 ) {
			_widec = (short)(6784 + ((*p) - -128));
			if (
 s->number64 != 0  ) _widec += 256;
			if (
 s->number64 == 0  ) _widec += 512;
		}
	} else if ( (*p) > 32 ) {
		if ( (*p) < 41 ) {
			if ( 40 <= (*p) && (*p) <= 40 ) {
				_widec = (short)(6784 + ((*p) - -128));
				if (
 s->number64 != 0  ) _widec += 256;
				if (
 s->number64 == 0  ) _widec += 512;
			}
		} else if ( (*p) > 41 ) {
			if ( 59 <= (*p) && (*p) <= 59 ) {
				_widec = (short)(9856 + ((*p) - -128));
				if (
 s->multiline  ) _widec += 256;
				if (
 !s->multiline  ) _widec += 512;
				if (
 s->number64 != 0  ) _widec += 1024;
				if (
 s->number64 == 0  ) _widec += 2048;
			}
		} else {
			_widec = (short)(6784 + ((*p) - -128));
			if (
 s->number64 != 0  ) _widec += 256;
			if (
 s->number64 == 0  ) _widec += 512;
		}
	} else {
		_widec = (short)(6784 + ((*p) - -128));
		if (
 s->number64 != 0  ) _widec += 256;
		if (
 s->number64 == 0  ) _widec += 512;
	}
	switch( _widec ) {
		case 46: goto tr3267;
		case 7177: goto tr3268;
		case 7200: goto tr3268;
		case 7208: goto tr3269;
		case 7209: goto tr3270;
		case 7433: goto tr3271;
		case 7456: goto tr3271;
		case 7464: goto tr3272;
		case 7465: goto tr3273;
		case 7689: goto tr3274;
		case 7712: goto tr3274;
		case 7720: goto tr3275;
		case 7721: goto tr3276;
		case 10506: goto tr3277;
		case 10555: goto tr3277;
		case 10762: goto tr3277;
		case 10811: goto tr3277;
		case 11274: goto tr3278;
		case 11323: goto tr3279;
		case 11530: goto tr3277;
		case 11579: goto tr3277;
		case 11786: goto tr3280;
		case 11835: goto tr3281;
		case 12298: goto tr3282;
		case 12347: goto tr3283;
		case 12554: goto tr3277;
		case 12603: goto tr3277;
		case 12810: goto tr3284;
		case 12859: goto tr3285;
		case 13322: goto tr3286;
		case 13371: goto tr3287;
		case 13578: goto tr3277;
		case 13627: goto tr3277;
		case 13834: goto tr3288;
		case 13883: goto tr3289;
	}
	if ( _widec < 65 ) {
		if ( 48 <= _widec && _widec <= 58 )
			goto tr3267;
	} else if ( _widec > 70 ) {
		if ( 97 <= _widec && _widec <= 102 )
			goto tr3267;
	} else
		goto tr3267;
	goto tr3221;
tr3266:
	{
		s->buffer_length = 0;
	}
	goto st1100;
tr3290:
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		}
	}
	goto st1100;
tr3260:
	{
		if (s->number64 <= UINT8_MAX) {
			*rdata_tail = (uint8_t)(s->number64);
			rdata_tail += 1;
		} else {
			WARN(ZS_NUMBER8_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		s->buffer_length = 0;
	}
	goto st1100;
st1100:
	if ( ++p == pe )
		goto _test_eof1100;
case 1100:
	_widec = (*p);
	if ( (*p) < 10 ) {
		if ( (*p) <= 9 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) > 10 ) {
		if ( 11 <= (*p) )
 {			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	if ( _widec == 2058 )
		goto tr3291;
	if ( 1920 <= _widec && _widec <= 2175 )
		goto tr3290;
	goto tr3138;
tr3253:
	{
		s->buffer_length = 0;
	}
	goto st1101;
tr3292:
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		}
	}
	goto st1101;
st1101:
	if ( ++p == pe )
		goto _test_eof1101;
case 1101:
	_widec = (*p);
	if ( (*p) < 10 ) {
		if ( (*p) <= 9 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) > 10 ) {
		if ( 11 <= (*p) )
 {			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	if ( _widec == 2058 )
		goto tr3293;
	if ( 1920 <= _widec && _widec <= 2175 )
		goto tr3292;
	goto tr3138;
tr3145:
	{
		*(rdata_tail++) = 3;
	}
	goto st1102;
st1102:
	if ( ++p == pe )
		goto _test_eof1102;
case 1102:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto st1103;
		case 32: goto st1103;
		case 40: goto tr3295;
		case 41: goto tr3296;
		case 2058: goto tr3297;
		case 2107: goto tr3298;
	}
	goto tr3138;
tr3295:
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st1103;
tr3296:
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st1103;
tr3297:
	{
		s->line_counter++;
	}
	goto st1103;
tr3337:
	{
		s->buffer[s->buffer_length++] = 0;

		// Execute the comment callback.
		if (s->process.automatic && s->process.comment != NULL) {
			s->process.comment(s);

			// Stop if required from the callback.
			if (s->state == ZS_STATE_STOP) {
				{p++; cs = 1103; goto _out;}
			}
		}
	}
	{
		s->line_counter++;
	}
	goto st1103;
st1103:
	if ( ++p == pe )
		goto _test_eof1103;
case 1103:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto st1103;
		case 32: goto st1103;
		case 40: goto tr3295;
		case 41: goto tr3296;
		case 2058: goto tr3297;
		case 2107: goto tr3298;
	}
	if ( 48 <= _widec && _widec <= 57 )
		goto tr3299;
	goto tr3153;
tr3299:
	{
		s->number64 = 0;
	}
	{
		// Overflow check: 10*(s->number64) + fc - '0' <= UINT64_MAX
		if ((s->number64 < (UINT64_MAX / 10)) ||   // Dominant fast check.
			((s->number64 == (UINT64_MAX / 10)) && // Marginal case.
			 ((uint8_t)(*p) <= (UINT64_MAX % 10) + '0')
			)
		   ) {
			s->number64 *= 10;
			s->number64 += digit_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_NUMBER64_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st1104;
tr3303:
	{
		// Overflow check: 10*(s->number64) + fc - '0' <= UINT64_MAX
		if ((s->number64 < (UINT64_MAX / 10)) ||   // Dominant fast check.
			((s->number64 == (UINT64_MAX / 10)) && // Marginal case.
			 ((uint8_t)(*p) <= (UINT64_MAX % 10) + '0')
			)
		   ) {
			s->number64 *= 10;
			s->number64 += digit_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_NUMBER64_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st1104;
st1104:
	if ( ++p == pe )
		goto _test_eof1104;
case 1104:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr3300;
		case 32: goto tr3300;
		case 40: goto tr3301;
		case 41: goto tr3302;
		case 2058: goto tr3304;
		case 2107: goto tr3305;
	}
	if ( 48 <= _widec && _widec <= 57 )
		goto tr3303;
	goto tr3153;
tr3307:
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st1105;
tr3308:
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st1105;
tr3310:
	{
		s->line_counter++;
	}
	goto st1105;
tr3335:
	{
		s->buffer[s->buffer_length++] = 0;

		// Execute the comment callback.
		if (s->process.automatic && s->process.comment != NULL) {
			s->process.comment(s);

			// Stop if required from the callback.
			if (s->state == ZS_STATE_STOP) {
				{p++; cs = 1105; goto _out;}
			}
		}
	}
	{
		s->line_counter++;
	}
	goto st1105;
tr3300:
	{
		if (s->number64 <= UINT8_MAX) {
			*rdata_tail = (uint8_t)(s->number64);
			rdata_tail += 1;
		} else {
			WARN(ZS_NUMBER8_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st1105;
tr3301:
	{
		if (s->number64 <= UINT8_MAX) {
			*rdata_tail = (uint8_t)(s->number64);
			rdata_tail += 1;
		} else {
			WARN(ZS_NUMBER8_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st1105;
tr3302:
	{
		if (s->number64 <= UINT8_MAX) {
			*rdata_tail = (uint8_t)(s->number64);
			rdata_tail += 1;
		} else {
			WARN(ZS_NUMBER8_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st1105;
tr3304:
	{
		if (s->number64 <= UINT8_MAX) {
			*rdata_tail = (uint8_t)(s->number64);
			rdata_tail += 1;
		} else {
			WARN(ZS_NUMBER8_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		s->line_counter++;
	}
	goto st1105;
st1105:
	if ( ++p == pe )
		goto _test_eof1105;
case 1105:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto st1105;
		case 32: goto st1105;
		case 40: goto tr3307;
		case 41: goto tr3308;
		case 42: goto tr3309;
		case 92: goto tr3309;
		case 95: goto tr3309;
		case 2058: goto tr3310;
		case 2107: goto tr3311;
	}
	if ( _widec < 64 ) {
		if ( 45 <= _widec && _widec <= 57 )
			goto tr3309;
	} else if ( _widec > 90 ) {
		if ( 97 <= _widec && _widec <= 122 )
			goto tr3309;
	} else
		goto tr3309;
	goto tr3138;
tr3309:
	{
		s->dname = rdata_tail;
	}
	{ p--; {stack[top++] = 1106;goto st318;} }
	goto st1106;
st1106:
	if ( ++p == pe )
		goto _test_eof1106;
case 1106:
	_widec = (*p);
	if ( (*p) < 32 ) {
		if ( (*p) > 9 ) {
			if ( 10 <= (*p) && (*p) <= 10 ) {
				_widec = (short)(9856 + ((*p) - -128));
				if (
 s->multiline  ) _widec += 256;
				if (
 !s->multiline  ) _widec += 512;
				if (
 s->number64 != 0  ) _widec += 1024;
				if (
 s->number64 == 0  ) _widec += 2048;
			}
		} else if ( (*p) >= 9 ) {
			_widec = (short)(6784 + ((*p) - -128));
			if (
 s->number64 != 0  ) _widec += 256;
			if (
 s->number64 == 0  ) _widec += 512;
		}
	} else if ( (*p) > 32 ) {
		if ( (*p) < 41 ) {
			if ( 40 <= (*p) && (*p) <= 40 ) {
				_widec = (short)(6784 + ((*p) - -128));
				if (
 s->number64 != 0  ) _widec += 256;
				if (
 s->number64 == 0  ) _widec += 512;
			}
		} else if ( (*p) > 41 ) {
			if ( 59 <= (*p) && (*p) <= 59 ) {
				_widec = (short)(9856 + ((*p) - -128));
				if (
 s->multiline  ) _widec += 256;
				if (
 !s->multiline  ) _widec += 512;
				if (
 s->number64 != 0  ) _widec += 1024;
				if (
 s->number64 == 0  ) _widec += 2048;
			}
		} else {
			_widec = (short)(6784 + ((*p) - -128));
			if (
 s->number64 != 0  ) _widec += 256;
			if (
 s->number64 == 0  ) _widec += 512;
		}
	} else {
		_widec = (short)(6784 + ((*p) - -128));
		if (
 s->number64 != 0  ) _widec += 256;
		if (
 s->number64 == 0  ) _widec += 512;
	}
	switch( _widec ) {
		case 7177: goto tr3312;
		case 7200: goto tr3312;
		case 7208: goto tr3313;
		case 7209: goto tr3314;
		case 7433: goto tr3315;
		case 7456: goto tr3315;
		case 7464: goto tr3316;
		case 7465: goto tr3317;
		case 7689: goto tr3318;
		case 7712: goto tr3318;
		case 7720: goto tr3319;
		case 7721: goto tr3320;
		case 10506: goto tr3321;
		case 10555: goto tr3321;
		case 10762: goto tr3321;
		case 10811: goto tr3321;
		case 11274: goto tr3322;
		case 11323: goto tr3323;
		case 11530: goto tr3321;
		case 11579: goto tr3321;
		case 11786: goto tr3324;
		case 11835: goto tr3325;
		case 12298: goto tr3326;
		case 12347: goto tr3327;
		case 12554: goto tr3321;
		case 12603: goto tr3321;
		case 12810: goto tr3328;
		case 12859: goto tr3329;
		case 13322: goto tr3330;
		case 13371: goto tr3331;
		case 13578: goto tr3321;
		case 13627: goto tr3321;
		case 13834: goto tr3332;
		case 13883: goto tr3333;
	}
	goto tr3167;
tr3311:
	{
		s->buffer_length = 0;
	}
	goto st1107;
tr3334:
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		}
	}
	goto st1107;
tr3305:
	{
		if (s->number64 <= UINT8_MAX) {
			*rdata_tail = (uint8_t)(s->number64);
			rdata_tail += 1;
		} else {
			WARN(ZS_NUMBER8_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		s->buffer_length = 0;
	}
	goto st1107;
st1107:
	if ( ++p == pe )
		goto _test_eof1107;
case 1107:
	_widec = (*p);
	if ( (*p) < 10 ) {
		if ( (*p) <= 9 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) > 10 ) {
		if ( 11 <= (*p) )
 {			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	if ( _widec == 2058 )
		goto tr3335;
	if ( 1920 <= _widec && _widec <= 2175 )
		goto tr3334;
	goto tr3138;
tr3298:
	{
		s->buffer_length = 0;
	}
	goto st1108;
tr3336:
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		}
	}
	goto st1108;
st1108:
	if ( ++p == pe )
		goto _test_eof1108;
case 1108:
	_widec = (*p);
	if ( (*p) < 10 ) {
		if ( (*p) <= 9 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) > 10 ) {
		if ( 11 <= (*p) )
 {			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	if ( _widec == 2058 )
		goto tr3337;
	if ( 1920 <= _widec && _widec <= 2175 )
		goto tr3336;
	goto tr3138;
tr3147:
	{
		s->buffer_length = 0;
	}
	goto st1109;
tr3338:
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		}
	}
	goto st1109;
tr3137:
	{
		if (s->number64 <= UINT8_MAX) {
			*rdata_tail = (uint8_t)(s->number64);
			rdata_tail += 1;
		} else {
			WARN(ZS_NUMBER8_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		s->buffer_length = 0;
	}
	goto st1109;
st1109:
	if ( ++p == pe )
		goto _test_eof1109;
case 1109:
	_widec = (*p);
	if ( (*p) < 10 ) {
		if ( (*p) <= 9 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) > 10 ) {
		if ( 11 <= (*p) )
 {			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	if ( _widec == 2058 )
		goto tr3339;
	if ( 1920 <= _widec && _widec <= 2175 )
		goto tr3338;
	goto tr77;
st1110:
	if ( ++p == pe )
		goto _test_eof1110;
case 1110:
	switch( (*p) ) {
		case 65: goto st1111;
		case 67: goto st1145;
		case 68: goto st1166;
		case 69: goto st1180;
		case 72: goto st1187;
		case 73: goto st1196;
		case 75: goto st1204;
		case 76: goto st1208;
		case 77: goto st1216;
		case 78: goto st1222;
		case 79: goto st1238;
		case 80: goto st1248;
		case 82: goto st1251;
		case 83: goto st1258;
		case 84: goto st1277;
		case 85: goto st1287;
		case 87: goto st1290;
		case 90: goto st1296;
		case 97: goto st1111;
		case 99: goto st1145;
		case 100: goto st1166;
		case 101: goto st1180;
		case 104: goto st1187;
		case 105: goto st1196;
		case 107: goto st1204;
		case 108: goto st1208;
		case 109: goto st1216;
		case 110: goto st1222;
		case 111: goto st1238;
		case 112: goto st1248;
		case 114: goto st1251;
		case 115: goto st1258;
		case 116: goto st1277;
		case 117: goto st1287;
		case 119: goto st1290;
		case 122: goto st1296;
	}
	goto tr3340;
st1111:
	if ( ++p == pe )
		goto _test_eof1111;
case 1111:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr3359;
		case 32: goto tr3359;
		case 40: goto tr3360;
		case 41: goto tr3361;
		case 65: goto st1136;
		case 70: goto st1139;
		case 80: goto st1143;
		case 97: goto st1136;
		case 102: goto st1139;
		case 112: goto st1143;
		case 2058: goto tr3365;
		case 2107: goto tr3366;
	}
	goto tr3340;
tr3368:
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st1112;
tr3369:
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st1112;
tr3371:
	{
		s->line_counter++;
	}
	goto st1112;
tr3467:
	{
		s->buffer[s->buffer_length++] = 0;

		// Execute the comment callback.
		if (s->process.automatic && s->process.comment != NULL) {
			s->process.comment(s);

			// Stop if required from the callback.
			if (s->state == ZS_STATE_STOP) {
				{p++; cs = 1112; goto _out;}
			}
		}
	}
	{
		s->line_counter++;
	}
	goto st1112;
tr3828:
	{
		if (s->number64 <= UINT16_MAX) {
			uint16_t num16 = htons((uint16_t)s->number64);
			memcpy(rdata_tail, &num16, 2);
			rdata_tail += 2;
		} else {
			WARN(ZS_NUMBER16_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st1112;
tr3829:
	{
		if (s->number64 <= UINT16_MAX) {
			uint16_t num16 = htons((uint16_t)s->number64);
			memcpy(rdata_tail, &num16, 2);
			rdata_tail += 2;
		} else {
			WARN(ZS_NUMBER16_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st1112;
tr3830:
	{
		if (s->number64 <= UINT16_MAX) {
			uint16_t num16 = htons((uint16_t)s->number64);
			memcpy(rdata_tail, &num16, 2);
			rdata_tail += 2;
		} else {
			WARN(ZS_NUMBER16_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st1112;
tr3832:
	{
		if (s->number64 <= UINT16_MAX) {
			uint16_t num16 = htons((uint16_t)s->number64);
			memcpy(rdata_tail, &num16, 2);
			rdata_tail += 2;
		} else {
			WARN(ZS_NUMBER16_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		s->line_counter++;
	}
	goto st1112;
tr3359:
	{ type_num(KNOT_RRTYPE_A, &rdata_tail); }
	goto st1112;
tr3360:
	{ type_num(KNOT_RRTYPE_A, &rdata_tail); }
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st1112;
tr3361:
	{ type_num(KNOT_RRTYPE_A, &rdata_tail); }
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st1112;
tr3365:
	{ type_num(KNOT_RRTYPE_A, &rdata_tail); }
	{
		s->line_counter++;
	}
	goto st1112;
tr3470:
	{ type_num(KNOT_RRTYPE_AAAA, &rdata_tail); }
	goto st1112;
tr3471:
	{ type_num(KNOT_RRTYPE_AAAA, &rdata_tail); }
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st1112;
tr3472:
	{ type_num(KNOT_RRTYPE_AAAA, &rdata_tail); }
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st1112;
tr3473:
	{ type_num(KNOT_RRTYPE_AAAA, &rdata_tail); }
	{
		s->line_counter++;
	}
	goto st1112;
tr3478:
	{ type_num(KNOT_RRTYPE_AFSDB, &rdata_tail); }
	goto st1112;
tr3479:
	{ type_num(KNOT_RRTYPE_AFSDB, &rdata_tail); }
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st1112;
tr3480:
	{ type_num(KNOT_RRTYPE_AFSDB, &rdata_tail); }
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st1112;
tr3481:
	{ type_num(KNOT_RRTYPE_AFSDB, &rdata_tail); }
	{
		s->line_counter++;
	}
	goto st1112;
tr3484:
	{ type_num(KNOT_RRTYPE_APL, &rdata_tail); }
	goto st1112;
tr3485:
	{ type_num(KNOT_RRTYPE_APL, &rdata_tail); }
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st1112;
tr3486:
	{ type_num(KNOT_RRTYPE_APL, &rdata_tail); }
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st1112;
tr3487:
	{ type_num(KNOT_RRTYPE_APL, &rdata_tail); }
	{
		s->line_counter++;
	}
	goto st1112;
tr3495:
	{ type_num(KNOT_RRTYPE_CAA, &rdata_tail); }
	goto st1112;
tr3496:
	{ type_num(KNOT_RRTYPE_CAA, &rdata_tail); }
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st1112;
tr3497:
	{ type_num(KNOT_RRTYPE_CAA, &rdata_tail); }
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st1112;
tr3498:
	{ type_num(KNOT_RRTYPE_CAA, &rdata_tail); }
	{
		s->line_counter++;
	}
	goto st1112;
tr3506:
	{ type_num(KNOT_RRTYPE_CDNSKEY, &rdata_tail); }
	goto st1112;
tr3507:
	{ type_num(KNOT_RRTYPE_CDNSKEY, &rdata_tail); }
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st1112;
tr3508:
	{ type_num(KNOT_RRTYPE_CDNSKEY, &rdata_tail); }
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st1112;
tr3509:
	{ type_num(KNOT_RRTYPE_CDNSKEY, &rdata_tail); }
	{
		s->line_counter++;
	}
	goto st1112;
tr3511:
	{ type_num(KNOT_RRTYPE_CDS, &rdata_tail); }
	goto st1112;
tr3512:
	{ type_num(KNOT_RRTYPE_CDS, &rdata_tail); }
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st1112;
tr3513:
	{ type_num(KNOT_RRTYPE_CDS, &rdata_tail); }
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st1112;
tr3514:
	{ type_num(KNOT_RRTYPE_CDS, &rdata_tail); }
	{
		s->line_counter++;
	}
	goto st1112;
tr3518:
	{ type_num(KNOT_RRTYPE_CERT, &rdata_tail); }
	goto st1112;
tr3519:
	{ type_num(KNOT_RRTYPE_CERT, &rdata_tail); }
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st1112;
tr3520:
	{ type_num(KNOT_RRTYPE_CERT, &rdata_tail); }
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st1112;
tr3521:
	{ type_num(KNOT_RRTYPE_CERT, &rdata_tail); }
	{
		s->line_counter++;
	}
	goto st1112;
tr3526:
	{ type_num(KNOT_RRTYPE_CNAME, &rdata_tail); }
	goto st1112;
tr3527:
	{ type_num(KNOT_RRTYPE_CNAME, &rdata_tail); }
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st1112;
tr3528:
	{ type_num(KNOT_RRTYPE_CNAME, &rdata_tail); }
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st1112;
tr3529:
	{ type_num(KNOT_RRTYPE_CNAME, &rdata_tail); }
	{
		s->line_counter++;
	}
	goto st1112;
tr3534:
	{ type_num(KNOT_RRTYPE_CSYNC, &rdata_tail); }
	goto st1112;
tr3535:
	{ type_num(KNOT_RRTYPE_CSYNC, &rdata_tail); }
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st1112;
tr3536:
	{ type_num(KNOT_RRTYPE_CSYNC, &rdata_tail); }
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st1112;
tr3537:
	{ type_num(KNOT_RRTYPE_CSYNC, &rdata_tail); }
	{
		s->line_counter++;
	}
	goto st1112;
tr3545:
	{ type_num(KNOT_RRTYPE_DHCID, &rdata_tail); }
	goto st1112;
tr3546:
	{ type_num(KNOT_RRTYPE_DHCID, &rdata_tail); }
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st1112;
tr3547:
	{ type_num(KNOT_RRTYPE_DHCID, &rdata_tail); }
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st1112;
tr3548:
	{ type_num(KNOT_RRTYPE_DHCID, &rdata_tail); }
	{
		s->line_counter++;
	}
	goto st1112;
tr3554:
	{ type_num(KNOT_RRTYPE_DNAME, &rdata_tail); }
	goto st1112;
tr3555:
	{ type_num(KNOT_RRTYPE_DNAME, &rdata_tail); }
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st1112;
tr3556:
	{ type_num(KNOT_RRTYPE_DNAME, &rdata_tail); }
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st1112;
tr3557:
	{ type_num(KNOT_RRTYPE_DNAME, &rdata_tail); }
	{
		s->line_counter++;
	}
	goto st1112;
tr3562:
	{ type_num(KNOT_RRTYPE_DNSKEY, &rdata_tail); }
	goto st1112;
tr3563:
	{ type_num(KNOT_RRTYPE_DNSKEY, &rdata_tail); }
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st1112;
tr3564:
	{ type_num(KNOT_RRTYPE_DNSKEY, &rdata_tail); }
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st1112;
tr3565:
	{ type_num(KNOT_RRTYPE_DNSKEY, &rdata_tail); }
	{
		s->line_counter++;
	}
	goto st1112;
tr3567:
	{ type_num(KNOT_RRTYPE_DS, &rdata_tail); }
	goto st1112;
tr3568:
	{ type_num(KNOT_RRTYPE_DS, &rdata_tail); }
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st1112;
tr3569:
	{ type_num(KNOT_RRTYPE_DS, &rdata_tail); }
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st1112;
tr3570:
	{ type_num(KNOT_RRTYPE_DS, &rdata_tail); }
	{
		s->line_counter++;
	}
	goto st1112;
tr3577:
	{ type_num(KNOT_RRTYPE_EUI48, &rdata_tail); }
	goto st1112;
tr3578:
	{ type_num(KNOT_RRTYPE_EUI48, &rdata_tail); }
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st1112;
tr3579:
	{ type_num(KNOT_RRTYPE_EUI48, &rdata_tail); }
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st1112;
tr3580:
	{ type_num(KNOT_RRTYPE_EUI48, &rdata_tail); }
	{
		s->line_counter++;
	}
	goto st1112;
tr3583:
	{ type_num(KNOT_RRTYPE_EUI64, &rdata_tail); }
	goto st1112;
tr3584:
	{ type_num(KNOT_RRTYPE_EUI64, &rdata_tail); }
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st1112;
tr3585:
	{ type_num(KNOT_RRTYPE_EUI64, &rdata_tail); }
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st1112;
tr3586:
	{ type_num(KNOT_RRTYPE_EUI64, &rdata_tail); }
	{
		s->line_counter++;
	}
	goto st1112;
tr3593:
	{ type_num(KNOT_RRTYPE_HINFO, &rdata_tail); }
	goto st1112;
tr3594:
	{ type_num(KNOT_RRTYPE_HINFO, &rdata_tail); }
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st1112;
tr3595:
	{ type_num(KNOT_RRTYPE_HINFO, &rdata_tail); }
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st1112;
tr3596:
	{ type_num(KNOT_RRTYPE_HINFO, &rdata_tail); }
	{
		s->line_counter++;
	}
	goto st1112;
tr3601:
	{ type_num(KNOT_RRTYPE_HTTPS, &rdata_tail); }
	goto st1112;
tr3602:
	{ type_num(KNOT_RRTYPE_HTTPS, &rdata_tail); }
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st1112;
tr3603:
	{ type_num(KNOT_RRTYPE_HTTPS, &rdata_tail); }
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st1112;
tr3604:
	{ type_num(KNOT_RRTYPE_HTTPS, &rdata_tail); }
	{
		s->line_counter++;
	}
	goto st1112;
tr3613:
	{ type_num(KNOT_RRTYPE_IPSECKEY, &rdata_tail); }
	goto st1112;
tr3614:
	{ type_num(KNOT_RRTYPE_IPSECKEY, &rdata_tail); }
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st1112;
tr3615:
	{ type_num(KNOT_RRTYPE_IPSECKEY, &rdata_tail); }
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st1112;
tr3616:
	{ type_num(KNOT_RRTYPE_IPSECKEY, &rdata_tail); }
	{
		s->line_counter++;
	}
	goto st1112;
tr3621:
	{ type_num(KNOT_RRTYPE_KEY, &rdata_tail); }
	goto st1112;
tr3622:
	{ type_num(KNOT_RRTYPE_KEY, &rdata_tail); }
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st1112;
tr3623:
	{ type_num(KNOT_RRTYPE_KEY, &rdata_tail); }
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st1112;
tr3624:
	{ type_num(KNOT_RRTYPE_KEY, &rdata_tail); }
	{
		s->line_counter++;
	}
	goto st1112;
tr3626:
	{ type_num(KNOT_RRTYPE_KX, &rdata_tail); }
	goto st1112;
tr3627:
	{ type_num(KNOT_RRTYPE_KX, &rdata_tail); }
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st1112;
tr3628:
	{ type_num(KNOT_RRTYPE_KX, &rdata_tail); }
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st1112;
tr3629:
	{ type_num(KNOT_RRTYPE_KX, &rdata_tail); }
	{
		s->line_counter++;
	}
	goto st1112;
tr3636:
	{ type_num(KNOT_RRTYPE_L32, &rdata_tail); }
	goto st1112;
tr3637:
	{ type_num(KNOT_RRTYPE_L32, &rdata_tail); }
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st1112;
tr3638:
	{ type_num(KNOT_RRTYPE_L32, &rdata_tail); }
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st1112;
tr3639:
	{ type_num(KNOT_RRTYPE_L32, &rdata_tail); }
	{
		s->line_counter++;
	}
	goto st1112;
tr3642:
	{ type_num(KNOT_RRTYPE_L64, &rdata_tail); }
	goto st1112;
tr3643:
	{ type_num(KNOT_RRTYPE_L64, &rdata_tail); }
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st1112;
tr3644:
	{ type_num(KNOT_RRTYPE_L64, &rdata_tail); }
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st1112;
tr3645:
	{ type_num(KNOT_RRTYPE_L64, &rdata_tail); }
	{
		s->line_counter++;
	}
	goto st1112;
tr3648:
	{ type_num(KNOT_RRTYPE_LOC, &rdata_tail); }
	goto st1112;
tr3649:
	{ type_num(KNOT_RRTYPE_LOC, &rdata_tail); }
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st1112;
tr3650:
	{ type_num(KNOT_RRTYPE_LOC, &rdata_tail); }
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st1112;
tr3651:
	{ type_num(KNOT_RRTYPE_LOC, &rdata_tail); }
	{
		s->line_counter++;
	}
	goto st1112;
tr3653:
	{ type_num(KNOT_RRTYPE_LP, &rdata_tail); }
	goto st1112;
tr3654:
	{ type_num(KNOT_RRTYPE_LP, &rdata_tail); }
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st1112;
tr3655:
	{ type_num(KNOT_RRTYPE_LP, &rdata_tail); }
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st1112;
tr3656:
	{ type_num(KNOT_RRTYPE_LP, &rdata_tail); }
	{
		s->line_counter++;
	}
	goto st1112;
tr3663:
	{ type_num(KNOT_RRTYPE_MINFO, &rdata_tail); }
	goto st1112;
tr3664:
	{ type_num(KNOT_RRTYPE_MINFO, &rdata_tail); }
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st1112;
tr3665:
	{ type_num(KNOT_RRTYPE_MINFO, &rdata_tail); }
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st1112;
tr3666:
	{ type_num(KNOT_RRTYPE_MINFO, &rdata_tail); }
	{
		s->line_counter++;
	}
	goto st1112;
tr3668:
	{ type_num(KNOT_RRTYPE_MX, &rdata_tail); }
	goto st1112;
tr3669:
	{ type_num(KNOT_RRTYPE_MX, &rdata_tail); }
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st1112;
tr3670:
	{ type_num(KNOT_RRTYPE_MX, &rdata_tail); }
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st1112;
tr3671:
	{ type_num(KNOT_RRTYPE_MX, &rdata_tail); }
	{
		s->line_counter++;
	}
	goto st1112;
tr3679:
	{ type_num(KNOT_RRTYPE_NAPTR, &rdata_tail); }
	goto st1112;
tr3680:
	{ type_num(KNOT_RRTYPE_NAPTR, &rdata_tail); }
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st1112;
tr3681:
	{ type_num(KNOT_RRTYPE_NAPTR, &rdata_tail); }
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st1112;
tr3682:
	{ type_num(KNOT_RRTYPE_NAPTR, &rdata_tail); }
	{
		s->line_counter++;
	}
	goto st1112;
tr3685:
	{ type_num(KNOT_RRTYPE_NID, &rdata_tail); }
	goto st1112;
tr3686:
	{ type_num(KNOT_RRTYPE_NID, &rdata_tail); }
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st1112;
tr3687:
	{ type_num(KNOT_RRTYPE_NID, &rdata_tail); }
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st1112;
tr3688:
	{ type_num(KNOT_RRTYPE_NID, &rdata_tail); }
	{
		s->line_counter++;
	}
	goto st1112;
tr3690:
	{ type_num(KNOT_RRTYPE_NS, &rdata_tail); }
	goto st1112;
tr3691:
	{ type_num(KNOT_RRTYPE_NS, &rdata_tail); }
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st1112;
tr3692:
	{ type_num(KNOT_RRTYPE_NS, &rdata_tail); }
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st1112;
tr3694:
	{ type_num(KNOT_RRTYPE_NS, &rdata_tail); }
	{
		s->line_counter++;
	}
	goto st1112;
tr3697:
	{ type_num(KNOT_RRTYPE_NSEC, &rdata_tail); }
	goto st1112;
tr3698:
	{ type_num(KNOT_RRTYPE_NSEC, &rdata_tail); }
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st1112;
tr3699:
	{ type_num(KNOT_RRTYPE_NSEC, &rdata_tail); }
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st1112;
tr3701:
	{ type_num(KNOT_RRTYPE_NSEC, &rdata_tail); }
	{
		s->line_counter++;
	}
	goto st1112;
tr3703:
	{ type_num(KNOT_RRTYPE_NSEC3, &rdata_tail); }
	goto st1112;
tr3704:
	{ type_num(KNOT_RRTYPE_NSEC3, &rdata_tail); }
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st1112;
tr3705:
	{ type_num(KNOT_RRTYPE_NSEC3, &rdata_tail); }
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st1112;
tr3707:
	{ type_num(KNOT_RRTYPE_NSEC3, &rdata_tail); }
	{
		s->line_counter++;
	}
	goto st1112;
tr3713:
	{ type_num(KNOT_RRTYPE_NSEC3PARAM, &rdata_tail); }
	goto st1112;
tr3714:
	{ type_num(KNOT_RRTYPE_NSEC3PARAM, &rdata_tail); }
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st1112;
tr3715:
	{ type_num(KNOT_RRTYPE_NSEC3PARAM, &rdata_tail); }
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st1112;
tr3716:
	{ type_num(KNOT_RRTYPE_NSEC3PARAM, &rdata_tail); }
	{
		s->line_counter++;
	}
	goto st1112;
tr3727:
	{ type_num(KNOT_RRTYPE_OPENPGPKEY, &rdata_tail); }
	goto st1112;
tr3728:
	{ type_num(KNOT_RRTYPE_OPENPGPKEY, &rdata_tail); }
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st1112;
tr3729:
	{ type_num(KNOT_RRTYPE_OPENPGPKEY, &rdata_tail); }
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st1112;
tr3730:
	{ type_num(KNOT_RRTYPE_OPENPGPKEY, &rdata_tail); }
	{
		s->line_counter++;
	}
	goto st1112;
tr3734:
	{ type_num(KNOT_RRTYPE_PTR, &rdata_tail); }
	goto st1112;
tr3735:
	{ type_num(KNOT_RRTYPE_PTR, &rdata_tail); }
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st1112;
tr3736:
	{ type_num(KNOT_RRTYPE_PTR, &rdata_tail); }
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st1112;
tr3737:
	{ type_num(KNOT_RRTYPE_PTR, &rdata_tail); }
	{
		s->line_counter++;
	}
	goto st1112;
tr3742:
	{ type_num(KNOT_RRTYPE_RP, &rdata_tail); }
	goto st1112;
tr3743:
	{ type_num(KNOT_RRTYPE_RP, &rdata_tail); }
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st1112;
tr3744:
	{ type_num(KNOT_RRTYPE_RP, &rdata_tail); }
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st1112;
tr3745:
	{ type_num(KNOT_RRTYPE_RP, &rdata_tail); }
	{
		s->line_counter++;
	}
	goto st1112;
tr3750:
	{ type_num(KNOT_RRTYPE_RRSIG, &rdata_tail); }
	goto st1112;
tr3751:
	{ type_num(KNOT_RRTYPE_RRSIG, &rdata_tail); }
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st1112;
tr3752:
	{ type_num(KNOT_RRTYPE_RRSIG, &rdata_tail); }
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st1112;
tr3753:
	{ type_num(KNOT_RRTYPE_RRSIG, &rdata_tail); }
	{
		s->line_counter++;
	}
	goto st1112;
tr3755:
	{ type_num(KNOT_RRTYPE_RT, &rdata_tail); }
	goto st1112;
tr3756:
	{ type_num(KNOT_RRTYPE_RT, &rdata_tail); }
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st1112;
tr3757:
	{ type_num(KNOT_RRTYPE_RT, &rdata_tail); }
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st1112;
tr3758:
	{ type_num(KNOT_RRTYPE_RT, &rdata_tail); }
	{
		s->line_counter++;
	}
	goto st1112;
tr3770:
	{ type_num(KNOT_RRTYPE_SMIMEA, &rdata_tail); }
	goto st1112;
tr3771:
	{ type_num(KNOT_RRTYPE_SMIMEA, &rdata_tail); }
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st1112;
tr3772:
	{ type_num(KNOT_RRTYPE_SMIMEA, &rdata_tail); }
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st1112;
tr3773:
	{ type_num(KNOT_RRTYPE_SMIMEA, &rdata_tail); }
	{
		s->line_counter++;
	}
	goto st1112;
tr3776:
	{ type_num(KNOT_RRTYPE_SOA, &rdata_tail); }
	goto st1112;
tr3777:
	{ type_num(KNOT_RRTYPE_SOA, &rdata_tail); }
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st1112;
tr3778:
	{ type_num(KNOT_RRTYPE_SOA, &rdata_tail); }
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st1112;
tr3779:
	{ type_num(KNOT_RRTYPE_SOA, &rdata_tail); }
	{
		s->line_counter++;
	}
	goto st1112;
tr3782:
	{ type_num(KNOT_RRTYPE_SPF, &rdata_tail); }
	goto st1112;
tr3783:
	{ type_num(KNOT_RRTYPE_SPF, &rdata_tail); }
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st1112;
tr3784:
	{ type_num(KNOT_RRTYPE_SPF, &rdata_tail); }
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st1112;
tr3785:
	{ type_num(KNOT_RRTYPE_SPF, &rdata_tail); }
	{
		s->line_counter++;
	}
	goto st1112;
tr3788:
	{ type_num(KNOT_RRTYPE_SRV, &rdata_tail); }
	goto st1112;
tr3789:
	{ type_num(KNOT_RRTYPE_SRV, &rdata_tail); }
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st1112;
tr3790:
	{ type_num(KNOT_RRTYPE_SRV, &rdata_tail); }
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st1112;
tr3791:
	{ type_num(KNOT_RRTYPE_SRV, &rdata_tail); }
	{
		s->line_counter++;
	}
	goto st1112;
tr3796:
	{ type_num(KNOT_RRTYPE_SSHFP, &rdata_tail); }
	goto st1112;
tr3797:
	{ type_num(KNOT_RRTYPE_SSHFP, &rdata_tail); }
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st1112;
tr3798:
	{ type_num(KNOT_RRTYPE_SSHFP, &rdata_tail); }
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st1112;
tr3799:
	{ type_num(KNOT_RRTYPE_SSHFP, &rdata_tail); }
	{
		s->line_counter++;
	}
	goto st1112;
tr3803:
	{ type_num(KNOT_RRTYPE_SVCB, &rdata_tail); }
	goto st1112;
tr3804:
	{ type_num(KNOT_RRTYPE_SVCB, &rdata_tail); }
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st1112;
tr3805:
	{ type_num(KNOT_RRTYPE_SVCB, &rdata_tail); }
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st1112;
tr3806:
	{ type_num(KNOT_RRTYPE_SVCB, &rdata_tail); }
	{
		s->line_counter++;
	}
	goto st1112;
tr3813:
	{ type_num(KNOT_RRTYPE_TLSA, &rdata_tail); }
	goto st1112;
tr3814:
	{ type_num(KNOT_RRTYPE_TLSA, &rdata_tail); }
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st1112;
tr3815:
	{ type_num(KNOT_RRTYPE_TLSA, &rdata_tail); }
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st1112;
tr3816:
	{ type_num(KNOT_RRTYPE_TLSA, &rdata_tail); }
	{
		s->line_counter++;
	}
	goto st1112;
tr3819:
	{ type_num(KNOT_RRTYPE_TXT, &rdata_tail); }
	goto st1112;
tr3820:
	{ type_num(KNOT_RRTYPE_TXT, &rdata_tail); }
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st1112;
tr3821:
	{ type_num(KNOT_RRTYPE_TXT, &rdata_tail); }
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st1112;
tr3822:
	{ type_num(KNOT_RRTYPE_TXT, &rdata_tail); }
	{
		s->line_counter++;
	}
	goto st1112;
tr3836:
	{ type_num(KNOT_RRTYPE_URI, &rdata_tail); }
	goto st1112;
tr3837:
	{ type_num(KNOT_RRTYPE_URI, &rdata_tail); }
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st1112;
tr3838:
	{ type_num(KNOT_RRTYPE_URI, &rdata_tail); }
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st1112;
tr3839:
	{ type_num(KNOT_RRTYPE_URI, &rdata_tail); }
	{
		s->line_counter++;
	}
	goto st1112;
tr3846:
	{ type_num(KNOT_RRTYPE_WALLET, &rdata_tail); }
	goto st1112;
tr3847:
	{ type_num(KNOT_RRTYPE_WALLET, &rdata_tail); }
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st1112;
tr3848:
	{ type_num(KNOT_RRTYPE_WALLET, &rdata_tail); }
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st1112;
tr3849:
	{ type_num(KNOT_RRTYPE_WALLET, &rdata_tail); }
	{
		s->line_counter++;
	}
	goto st1112;
tr3856:
	{ type_num(KNOT_RRTYPE_ZONEMD, &rdata_tail); }
	goto st1112;
tr3857:
	{ type_num(KNOT_RRTYPE_ZONEMD, &rdata_tail); }
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st1112;
tr3858:
	{ type_num(KNOT_RRTYPE_ZONEMD, &rdata_tail); }
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st1112;
tr3859:
	{ type_num(KNOT_RRTYPE_ZONEMD, &rdata_tail); }
	{
		s->line_counter++;
	}
	goto st1112;
st1112:
	if ( ++p == pe )
		goto _test_eof1112;
case 1112:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto st1112;
		case 32: goto st1112;
		case 40: goto tr3368;
		case 41: goto tr3369;
		case 2058: goto tr3371;
		case 2107: goto tr3372;
	}
	if ( _widec < 65 ) {
		if ( 48 <= _widec && _widec <= 57 )
			goto tr3370;
	} else if ( _widec > 90 ) {
		if ( 97 <= _widec && _widec <= 122 )
			goto tr3370;
	} else
		goto tr3370;
	goto tr77;
tr3370:
	{ p--; {stack[top++] = 1113;goto st741;} }
	goto st1113;
st1113:
	if ( ++p == pe )
		goto _test_eof1113;
case 1113:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto st1114;
		case 32: goto st1114;
		case 40: goto tr3374;
		case 41: goto tr3375;
		case 2058: goto tr3376;
		case 2107: goto tr3377;
	}
	goto tr77;
tr3374:
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st1114;
tr3375:
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st1114;
tr3376:
	{
		s->line_counter++;
	}
	goto st1114;
tr3465:
	{
		s->buffer[s->buffer_length++] = 0;

		// Execute the comment callback.
		if (s->process.automatic && s->process.comment != NULL) {
			s->process.comment(s);

			// Stop if required from the callback.
			if (s->state == ZS_STATE_STOP) {
				{p++; cs = 1114; goto _out;}
			}
		}
	}
	{
		s->line_counter++;
	}
	goto st1114;
st1114:
	if ( ++p == pe )
		goto _test_eof1114;
case 1114:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto st1114;
		case 32: goto st1114;
		case 40: goto tr3374;
		case 41: goto tr3375;
		case 2058: goto tr3376;
		case 2107: goto tr3377;
	}
	if ( 48 <= _widec && _widec <= 57 )
		goto tr3378;
	goto tr2396;
tr3378:
	{
		s->number64 = 0;
	}
	{
		// Overflow check: 10*(s->number64) + fc - '0' <= UINT64_MAX
		if ((s->number64 < (UINT64_MAX / 10)) ||   // Dominant fast check.
			((s->number64 == (UINT64_MAX / 10)) && // Marginal case.
			 ((uint8_t)(*p) <= (UINT64_MAX % 10) + '0')
			)
		   ) {
			s->number64 *= 10;
			s->number64 += digit_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_NUMBER64_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st1115;
tr3382:
	{
		// Overflow check: 10*(s->number64) + fc - '0' <= UINT64_MAX
		if ((s->number64 < (UINT64_MAX / 10)) ||   // Dominant fast check.
			((s->number64 == (UINT64_MAX / 10)) && // Marginal case.
			 ((uint8_t)(*p) <= (UINT64_MAX % 10) + '0')
			)
		   ) {
			s->number64 *= 10;
			s->number64 += digit_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_NUMBER64_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st1115;
st1115:
	if ( ++p == pe )
		goto _test_eof1115;
case 1115:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr3379;
		case 32: goto tr3379;
		case 40: goto tr3380;
		case 41: goto tr3381;
		case 2058: goto tr3383;
		case 2107: goto tr3384;
	}
	if ( 48 <= _widec && _widec <= 57 )
		goto tr3382;
	goto tr2396;
tr3386:
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st1116;
tr3387:
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st1116;
tr3389:
	{
		s->line_counter++;
	}
	goto st1116;
tr3463:
	{
		s->buffer[s->buffer_length++] = 0;

		// Execute the comment callback.
		if (s->process.automatic && s->process.comment != NULL) {
			s->process.comment(s);

			// Stop if required from the callback.
			if (s->state == ZS_STATE_STOP) {
				{p++; cs = 1116; goto _out;}
			}
		}
	}
	{
		s->line_counter++;
	}
	goto st1116;
tr3379:
	{
		if (s->number64 <= UINT8_MAX) {
			*rdata_tail = (uint8_t)(s->number64);
			rdata_tail += 1;
		} else {
			WARN(ZS_NUMBER8_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st1116;
tr3380:
	{
		if (s->number64 <= UINT8_MAX) {
			*rdata_tail = (uint8_t)(s->number64);
			rdata_tail += 1;
		} else {
			WARN(ZS_NUMBER8_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st1116;
tr3381:
	{
		if (s->number64 <= UINT8_MAX) {
			*rdata_tail = (uint8_t)(s->number64);
			rdata_tail += 1;
		} else {
			WARN(ZS_NUMBER8_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st1116;
tr3383:
	{
		if (s->number64 <= UINT8_MAX) {
			*rdata_tail = (uint8_t)(s->number64);
			rdata_tail += 1;
		} else {
			WARN(ZS_NUMBER8_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		s->line_counter++;
	}
	goto st1116;
st1116:
	if ( ++p == pe )
		goto _test_eof1116;
case 1116:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto st1116;
		case 32: goto st1116;
		case 40: goto tr3386;
		case 41: goto tr3387;
		case 2058: goto tr3389;
		case 2107: goto tr3390;
	}
	if ( 48 <= _widec && _widec <= 57 )
		goto tr3388;
	goto tr2396;
tr3388:
	{
		s->number64 = 0;
	}
	{
		// Overflow check: 10*(s->number64) + fc - '0' <= UINT64_MAX
		if ((s->number64 < (UINT64_MAX / 10)) ||   // Dominant fast check.
			((s->number64 == (UINT64_MAX / 10)) && // Marginal case.
			 ((uint8_t)(*p) <= (UINT64_MAX % 10) + '0')
			)
		   ) {
			s->number64 *= 10;
			s->number64 += digit_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_NUMBER64_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st1117;
tr3394:
	{
		// Overflow check: 10*(s->number64) + fc - '0' <= UINT64_MAX
		if ((s->number64 < (UINT64_MAX / 10)) ||   // Dominant fast check.
			((s->number64 == (UINT64_MAX / 10)) && // Marginal case.
			 ((uint8_t)(*p) <= (UINT64_MAX % 10) + '0')
			)
		   ) {
			s->number64 *= 10;
			s->number64 += digit_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_NUMBER64_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st1117;
st1117:
	if ( ++p == pe )
		goto _test_eof1117;
case 1117:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr3391;
		case 32: goto tr3391;
		case 40: goto tr3392;
		case 41: goto tr3393;
		case 2058: goto tr3395;
		case 2107: goto tr3396;
	}
	if ( 48 <= _widec && _widec <= 57 )
		goto tr3394;
	goto tr2396;
tr3399:
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st1118;
tr3400:
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st1118;
tr3402:
	{
		s->line_counter++;
	}
	goto st1118;
tr3461:
	{
		s->buffer[s->buffer_length++] = 0;

		// Execute the comment callback.
		if (s->process.automatic && s->process.comment != NULL) {
			s->process.comment(s);

			// Stop if required from the callback.
			if (s->state == ZS_STATE_STOP) {
				{p++; cs = 1118; goto _out;}
			}
		}
	}
	{
		s->line_counter++;
	}
	goto st1118;
tr3391:
	{
		if (s->number64 <= UINT32_MAX) {
			uint32_t num32 = htonl((uint32_t)s->number64);
			memcpy(rdata_tail, &num32, 4);
			rdata_tail += 4;
		} else {
			WARN(ZS_NUMBER32_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st1118;
tr3392:
	{
		if (s->number64 <= UINT32_MAX) {
			uint32_t num32 = htonl((uint32_t)s->number64);
			memcpy(rdata_tail, &num32, 4);
			rdata_tail += 4;
		} else {
			WARN(ZS_NUMBER32_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st1118;
tr3393:
	{
		if (s->number64 <= UINT32_MAX) {
			uint32_t num32 = htonl((uint32_t)s->number64);
			memcpy(rdata_tail, &num32, 4);
			rdata_tail += 4;
		} else {
			WARN(ZS_NUMBER32_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st1118;
tr3395:
	{
		if (s->number64 <= UINT32_MAX) {
			uint32_t num32 = htonl((uint32_t)s->number64);
			memcpy(rdata_tail, &num32, 4);
			rdata_tail += 4;
		} else {
			WARN(ZS_NUMBER32_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		s->line_counter++;
	}
	goto st1118;
st1118:
	if ( ++p == pe )
		goto _test_eof1118;
case 1118:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto st1118;
		case 32: goto st1118;
		case 40: goto tr3399;
		case 41: goto tr3400;
		case 2058: goto tr3402;
		case 2107: goto tr3403;
	}
	if ( 48 <= _widec && _widec <= 57 )
		goto tr3401;
	goto tr3397;
tr3401:
	{
		s->buffer_length = 0;
	}
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		} else {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st1119;
tr3407:
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		} else {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st1119;
st1119:
	if ( ++p == pe )
		goto _test_eof1119;
case 1119:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr3404;
		case 32: goto tr3404;
		case 40: goto tr3405;
		case 41: goto tr3406;
		case 2058: goto tr3408;
		case 2107: goto tr3409;
	}
	if ( 48 <= _widec && _widec <= 57 )
		goto tr3407;
	goto tr3397;
tr3411:
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st1120;
tr3412:
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st1120;
tr3414:
	{
		s->line_counter++;
	}
	goto st1120;
tr3459:
	{
		s->buffer[s->buffer_length++] = 0;

		// Execute the comment callback.
		if (s->process.automatic && s->process.comment != NULL) {
			s->process.comment(s);

			// Stop if required from the callback.
			if (s->state == ZS_STATE_STOP) {
				{p++; cs = 1120; goto _out;}
			}
		}
	}
	{
		s->line_counter++;
	}
	goto st1120;
tr3404:
	{
		s->buffer[s->buffer_length] = 0;

		if (s->buffer_length == 14) { // Date; 14 = len("YYYYMMDDHHmmSS").
			uint32_t timestamp;
			int ret = date_to_timestamp(s->buffer, &timestamp);

			if (ret == ZS_OK) {
				*((uint32_t *)rdata_tail) = htonl(timestamp);
				rdata_tail += 4;
			} else {
				WARN(ret);
				p--; {goto st316;}
			}
		} else if (s->buffer_length <= 10) { // Timestamp format.
			char *end;

			s->number64 = strtoull((char *)(s->buffer), &end,  10);

			if (end == (char *)(s->buffer) || *end != '\0') {
				WARN(ZS_BAD_TIMESTAMP);
				p--; {goto st316;}
			}

			if (s->number64 <= UINT32_MAX) {
				*((uint32_t *)rdata_tail) = htonl((uint32_t)s->number64);
				rdata_tail += 4;
			} else {
				WARN(ZS_NUMBER32_OVERFLOW);
				p--; {goto st316;}
			}
		} else {
			WARN(ZS_BAD_TIMESTAMP_LENGTH);
			p--; {goto st316;}
		}
	}
	goto st1120;
tr3405:
	{
		s->buffer[s->buffer_length] = 0;

		if (s->buffer_length == 14) { // Date; 14 = len("YYYYMMDDHHmmSS").
			uint32_t timestamp;
			int ret = date_to_timestamp(s->buffer, &timestamp);

			if (ret == ZS_OK) {
				*((uint32_t *)rdata_tail) = htonl(timestamp);
				rdata_tail += 4;
			} else {
				WARN(ret);
				p--; {goto st316;}
			}
		} else if (s->buffer_length <= 10) { // Timestamp format.
			char *end;

			s->number64 = strtoull((char *)(s->buffer), &end,  10);

			if (end == (char *)(s->buffer) || *end != '\0') {
				WARN(ZS_BAD_TIMESTAMP);
				p--; {goto st316;}
			}

			if (s->number64 <= UINT32_MAX) {
				*((uint32_t *)rdata_tail) = htonl((uint32_t)s->number64);
				rdata_tail += 4;
			} else {
				WARN(ZS_NUMBER32_OVERFLOW);
				p--; {goto st316;}
			}
		} else {
			WARN(ZS_BAD_TIMESTAMP_LENGTH);
			p--; {goto st316;}
		}
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st1120;
tr3406:
	{
		s->buffer[s->buffer_length] = 0;

		if (s->buffer_length == 14) { // Date; 14 = len("YYYYMMDDHHmmSS").
			uint32_t timestamp;
			int ret = date_to_timestamp(s->buffer, &timestamp);

			if (ret == ZS_OK) {
				*((uint32_t *)rdata_tail) = htonl(timestamp);
				rdata_tail += 4;
			} else {
				WARN(ret);
				p--; {goto st316;}
			}
		} else if (s->buffer_length <= 10) { // Timestamp format.
			char *end;

			s->number64 = strtoull((char *)(s->buffer), &end,  10);

			if (end == (char *)(s->buffer) || *end != '\0') {
				WARN(ZS_BAD_TIMESTAMP);
				p--; {goto st316;}
			}

			if (s->number64 <= UINT32_MAX) {
				*((uint32_t *)rdata_tail) = htonl((uint32_t)s->number64);
				rdata_tail += 4;
			} else {
				WARN(ZS_NUMBER32_OVERFLOW);
				p--; {goto st316;}
			}
		} else {
			WARN(ZS_BAD_TIMESTAMP_LENGTH);
			p--; {goto st316;}
		}
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st1120;
tr3408:
	{
		s->buffer[s->buffer_length] = 0;

		if (s->buffer_length == 14) { // Date; 14 = len("YYYYMMDDHHmmSS").
			uint32_t timestamp;
			int ret = date_to_timestamp(s->buffer, &timestamp);

			if (ret == ZS_OK) {
				*((uint32_t *)rdata_tail) = htonl(timestamp);
				rdata_tail += 4;
			} else {
				WARN(ret);
				p--; {goto st316;}
			}
		} else if (s->buffer_length <= 10) { // Timestamp format.
			char *end;

			s->number64 = strtoull((char *)(s->buffer), &end,  10);

			if (end == (char *)(s->buffer) || *end != '\0') {
				WARN(ZS_BAD_TIMESTAMP);
				p--; {goto st316;}
			}

			if (s->number64 <= UINT32_MAX) {
				*((uint32_t *)rdata_tail) = htonl((uint32_t)s->number64);
				rdata_tail += 4;
			} else {
				WARN(ZS_NUMBER32_OVERFLOW);
				p--; {goto st316;}
			}
		} else {
			WARN(ZS_BAD_TIMESTAMP_LENGTH);
			p--; {goto st316;}
		}
	}
	{
		s->line_counter++;
	}
	goto st1120;
st1120:
	if ( ++p == pe )
		goto _test_eof1120;
case 1120:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto st1120;
		case 32: goto st1120;
		case 40: goto tr3411;
		case 41: goto tr3412;
		case 2058: goto tr3414;
		case 2107: goto tr3415;
	}
	if ( 48 <= _widec && _widec <= 57 )
		goto tr3413;
	goto tr3397;
tr3413:
	{
		s->buffer_length = 0;
	}
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		} else {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st1121;
tr3419:
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		} else {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st1121;
st1121:
	if ( ++p == pe )
		goto _test_eof1121;
case 1121:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr3416;
		case 32: goto tr3416;
		case 40: goto tr3417;
		case 41: goto tr3418;
		case 2058: goto tr3420;
		case 2107: goto tr3421;
	}
	if ( 48 <= _widec && _widec <= 57 )
		goto tr3419;
	goto tr3397;
tr3423:
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st1122;
tr3424:
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st1122;
tr3426:
	{
		s->line_counter++;
	}
	goto st1122;
tr3457:
	{
		s->buffer[s->buffer_length++] = 0;

		// Execute the comment callback.
		if (s->process.automatic && s->process.comment != NULL) {
			s->process.comment(s);

			// Stop if required from the callback.
			if (s->state == ZS_STATE_STOP) {
				{p++; cs = 1122; goto _out;}
			}
		}
	}
	{
		s->line_counter++;
	}
	goto st1122;
tr3416:
	{
		s->buffer[s->buffer_length] = 0;

		if (s->buffer_length == 14) { // Date; 14 = len("YYYYMMDDHHmmSS").
			uint32_t timestamp;
			int ret = date_to_timestamp(s->buffer, &timestamp);

			if (ret == ZS_OK) {
				*((uint32_t *)rdata_tail) = htonl(timestamp);
				rdata_tail += 4;
			} else {
				WARN(ret);
				p--; {goto st316;}
			}
		} else if (s->buffer_length <= 10) { // Timestamp format.
			char *end;

			s->number64 = strtoull((char *)(s->buffer), &end,  10);

			if (end == (char *)(s->buffer) || *end != '\0') {
				WARN(ZS_BAD_TIMESTAMP);
				p--; {goto st316;}
			}

			if (s->number64 <= UINT32_MAX) {
				*((uint32_t *)rdata_tail) = htonl((uint32_t)s->number64);
				rdata_tail += 4;
			} else {
				WARN(ZS_NUMBER32_OVERFLOW);
				p--; {goto st316;}
			}
		} else {
			WARN(ZS_BAD_TIMESTAMP_LENGTH);
			p--; {goto st316;}
		}
	}
	goto st1122;
tr3417:
	{
		s->buffer[s->buffer_length] = 0;

		if (s->buffer_length == 14) { // Date; 14 = len("YYYYMMDDHHmmSS").
			uint32_t timestamp;
			int ret = date_to_timestamp(s->buffer, &timestamp);

			if (ret == ZS_OK) {
				*((uint32_t *)rdata_tail) = htonl(timestamp);
				rdata_tail += 4;
			} else {
				WARN(ret);
				p--; {goto st316;}
			}
		} else if (s->buffer_length <= 10) { // Timestamp format.
			char *end;

			s->number64 = strtoull((char *)(s->buffer), &end,  10);

			if (end == (char *)(s->buffer) || *end != '\0') {
				WARN(ZS_BAD_TIMESTAMP);
				p--; {goto st316;}
			}

			if (s->number64 <= UINT32_MAX) {
				*((uint32_t *)rdata_tail) = htonl((uint32_t)s->number64);
				rdata_tail += 4;
			} else {
				WARN(ZS_NUMBER32_OVERFLOW);
				p--; {goto st316;}
			}
		} else {
			WARN(ZS_BAD_TIMESTAMP_LENGTH);
			p--; {goto st316;}
		}
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st1122;
tr3418:
	{
		s->buffer[s->buffer_length] = 0;

		if (s->buffer_length == 14) { // Date; 14 = len("YYYYMMDDHHmmSS").
			uint32_t timestamp;
			int ret = date_to_timestamp(s->buffer, &timestamp);

			if (ret == ZS_OK) {
				*((uint32_t *)rdata_tail) = htonl(timestamp);
				rdata_tail += 4;
			} else {
				WARN(ret);
				p--; {goto st316;}
			}
		} else if (s->buffer_length <= 10) { // Timestamp format.
			char *end;

			s->number64 = strtoull((char *)(s->buffer), &end,  10);

			if (end == (char *)(s->buffer) || *end != '\0') {
				WARN(ZS_BAD_TIMESTAMP);
				p--; {goto st316;}
			}

			if (s->number64 <= UINT32_MAX) {
				*((uint32_t *)rdata_tail) = htonl((uint32_t)s->number64);
				rdata_tail += 4;
			} else {
				WARN(ZS_NUMBER32_OVERFLOW);
				p--; {goto st316;}
			}
		} else {
			WARN(ZS_BAD_TIMESTAMP_LENGTH);
			p--; {goto st316;}
		}
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st1122;
tr3420:
	{
		s->buffer[s->buffer_length] = 0;

		if (s->buffer_length == 14) { // Date; 14 = len("YYYYMMDDHHmmSS").
			uint32_t timestamp;
			int ret = date_to_timestamp(s->buffer, &timestamp);

			if (ret == ZS_OK) {
				*((uint32_t *)rdata_tail) = htonl(timestamp);
				rdata_tail += 4;
			} else {
				WARN(ret);
				p--; {goto st316;}
			}
		} else if (s->buffer_length <= 10) { // Timestamp format.
			char *end;

			s->number64 = strtoull((char *)(s->buffer), &end,  10);

			if (end == (char *)(s->buffer) || *end != '\0') {
				WARN(ZS_BAD_TIMESTAMP);
				p--; {goto st316;}
			}

			if (s->number64 <= UINT32_MAX) {
				*((uint32_t *)rdata_tail) = htonl((uint32_t)s->number64);
				rdata_tail += 4;
			} else {
				WARN(ZS_NUMBER32_OVERFLOW);
				p--; {goto st316;}
			}
		} else {
			WARN(ZS_BAD_TIMESTAMP_LENGTH);
			p--; {goto st316;}
		}
	}
	{
		s->line_counter++;
	}
	goto st1122;
st1122:
	if ( ++p == pe )
		goto _test_eof1122;
case 1122:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto st1122;
		case 32: goto st1122;
		case 40: goto tr3423;
		case 41: goto tr3424;
		case 2058: goto tr3426;
		case 2107: goto tr3427;
	}
	if ( 48 <= _widec && _widec <= 57 )
		goto tr3425;
	goto tr2396;
tr3425:
	{
		s->number64 = 0;
	}
	{
		// Overflow check: 10*(s->number64) + fc - '0' <= UINT64_MAX
		if ((s->number64 < (UINT64_MAX / 10)) ||   // Dominant fast check.
			((s->number64 == (UINT64_MAX / 10)) && // Marginal case.
			 ((uint8_t)(*p) <= (UINT64_MAX % 10) + '0')
			)
		   ) {
			s->number64 *= 10;
			s->number64 += digit_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_NUMBER64_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st1123;
tr3431:
	{
		// Overflow check: 10*(s->number64) + fc - '0' <= UINT64_MAX
		if ((s->number64 < (UINT64_MAX / 10)) ||   // Dominant fast check.
			((s->number64 == (UINT64_MAX / 10)) && // Marginal case.
			 ((uint8_t)(*p) <= (UINT64_MAX % 10) + '0')
			)
		   ) {
			s->number64 *= 10;
			s->number64 += digit_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_NUMBER64_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st1123;
st1123:
	if ( ++p == pe )
		goto _test_eof1123;
case 1123:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr3428;
		case 32: goto tr3428;
		case 40: goto tr3429;
		case 41: goto tr3430;
		case 2058: goto tr3432;
		case 2107: goto tr3433;
	}
	if ( 48 <= _widec && _widec <= 57 )
		goto tr3431;
	goto tr2396;
tr3435:
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st1124;
tr3436:
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st1124;
tr3438:
	{
		s->line_counter++;
	}
	goto st1124;
tr3455:
	{
		s->buffer[s->buffer_length++] = 0;

		// Execute the comment callback.
		if (s->process.automatic && s->process.comment != NULL) {
			s->process.comment(s);

			// Stop if required from the callback.
			if (s->state == ZS_STATE_STOP) {
				{p++; cs = 1124; goto _out;}
			}
		}
	}
	{
		s->line_counter++;
	}
	goto st1124;
tr3428:
	{
		if (s->number64 <= UINT16_MAX) {
			uint16_t num16 = htons((uint16_t)s->number64);
			memcpy(rdata_tail, &num16, 2);
			rdata_tail += 2;
		} else {
			WARN(ZS_NUMBER16_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st1124;
tr3429:
	{
		if (s->number64 <= UINT16_MAX) {
			uint16_t num16 = htons((uint16_t)s->number64);
			memcpy(rdata_tail, &num16, 2);
			rdata_tail += 2;
		} else {
			WARN(ZS_NUMBER16_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st1124;
tr3430:
	{
		if (s->number64 <= UINT16_MAX) {
			uint16_t num16 = htons((uint16_t)s->number64);
			memcpy(rdata_tail, &num16, 2);
			rdata_tail += 2;
		} else {
			WARN(ZS_NUMBER16_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st1124;
tr3432:
	{
		if (s->number64 <= UINT16_MAX) {
			uint16_t num16 = htons((uint16_t)s->number64);
			memcpy(rdata_tail, &num16, 2);
			rdata_tail += 2;
		} else {
			WARN(ZS_NUMBER16_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		s->line_counter++;
	}
	goto st1124;
st1124:
	if ( ++p == pe )
		goto _test_eof1124;
case 1124:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto st1124;
		case 32: goto st1124;
		case 40: goto tr3435;
		case 41: goto tr3436;
		case 42: goto tr3437;
		case 92: goto tr3437;
		case 95: goto tr3437;
		case 2058: goto tr3438;
		case 2107: goto tr3439;
	}
	if ( _widec < 64 ) {
		if ( 45 <= _widec && _widec <= 57 )
			goto tr3437;
	} else if ( _widec > 90 ) {
		if ( 97 <= _widec && _widec <= 122 )
			goto tr3437;
	} else
		goto tr3437;
	goto tr77;
tr3437:
	{
		s->dname = rdata_tail;
	}
	{ p--; {stack[top++] = 1125;goto st318;} }
	goto st1125;
st1125:
	if ( ++p == pe )
		goto _test_eof1125;
case 1125:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr3440;
		case 32: goto tr3440;
		case 40: goto tr3441;
		case 41: goto tr3442;
		case 2058: goto tr3443;
		case 2107: goto tr3444;
	}
	goto tr77;
tr3446:
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st1126;
tr3447:
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st1126;
tr3449:
	{
		s->line_counter++;
	}
	goto st1126;
tr3453:
	{
		s->buffer[s->buffer_length++] = 0;

		// Execute the comment callback.
		if (s->process.automatic && s->process.comment != NULL) {
			s->process.comment(s);

			// Stop if required from the callback.
			if (s->state == ZS_STATE_STOP) {
				{p++; cs = 1126; goto _out;}
			}
		}
	}
	{
		s->line_counter++;
	}
	goto st1126;
tr3440:
	{
		rdata_tail += s->dname_tmp_length;
	}
	goto st1126;
tr3441:
	{
		rdata_tail += s->dname_tmp_length;
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st1126;
tr3442:
	{
		rdata_tail += s->dname_tmp_length;
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st1126;
tr3443:
	{
		rdata_tail += s->dname_tmp_length;
	}
	{
		s->line_counter++;
	}
	goto st1126;
st1126:
	if ( ++p == pe )
		goto _test_eof1126;
case 1126:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto st1126;
		case 32: goto st1126;
		case 40: goto tr3446;
		case 41: goto tr3447;
		case 43: goto tr3448;
		case 2058: goto tr3449;
		case 2107: goto tr3450;
	}
	if ( _widec < 65 ) {
		if ( 47 <= _widec && _widec <= 57 )
			goto tr3448;
	} else if ( _widec > 90 ) {
		if ( 97 <= _widec && _widec <= 122 )
			goto tr3448;
	} else
		goto tr3448;
	goto tr77;
tr3448:
	{ p--; {stack[top++] = 1127;goto st378;} }
	goto st1127;
st1127:
	if ( ++p == pe )
		goto _test_eof1127;
case 1127:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(2176 + ((*p) - -128));
			if (
 !s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(2176 + ((*p) - -128));
		if (
 !s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 2570: goto tr3451;
		case 2619: goto tr3451;
	}
	goto tr77;
tr3451:
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1521;
st1521:
	if ( ++p == pe )
		goto _test_eof1521;
case 1521:
	goto st0;
tr3450:
	{
		s->buffer_length = 0;
	}
	goto st1128;
tr3452:
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		}
	}
	goto st1128;
tr3444:
	{
		rdata_tail += s->dname_tmp_length;
	}
	{
		s->buffer_length = 0;
	}
	goto st1128;
st1128:
	if ( ++p == pe )
		goto _test_eof1128;
case 1128:
	_widec = (*p);
	if ( (*p) < 10 ) {
		if ( (*p) <= 9 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) > 10 ) {
		if ( 11 <= (*p) )
 {			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	if ( _widec == 2058 )
		goto tr3453;
	if ( 1920 <= _widec && _widec <= 2175 )
		goto tr3452;
	goto tr77;
tr3439:
	{
		s->buffer_length = 0;
	}
	goto st1129;
tr3454:
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		}
	}
	goto st1129;
tr3433:
	{
		if (s->number64 <= UINT16_MAX) {
			uint16_t num16 = htons((uint16_t)s->number64);
			memcpy(rdata_tail, &num16, 2);
			rdata_tail += 2;
		} else {
			WARN(ZS_NUMBER16_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		s->buffer_length = 0;
	}
	goto st1129;
st1129:
	if ( ++p == pe )
		goto _test_eof1129;
case 1129:
	_widec = (*p);
	if ( (*p) < 10 ) {
		if ( (*p) <= 9 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) > 10 ) {
		if ( 11 <= (*p) )
 {			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	if ( _widec == 2058 )
		goto tr3455;
	if ( 1920 <= _widec && _widec <= 2175 )
		goto tr3454;
	goto tr77;
tr3427:
	{
		s->buffer_length = 0;
	}
	goto st1130;
tr3456:
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		}
	}
	goto st1130;
tr3421:
	{
		s->buffer[s->buffer_length] = 0;

		if (s->buffer_length == 14) { // Date; 14 = len("YYYYMMDDHHmmSS").
			uint32_t timestamp;
			int ret = date_to_timestamp(s->buffer, &timestamp);

			if (ret == ZS_OK) {
				*((uint32_t *)rdata_tail) = htonl(timestamp);
				rdata_tail += 4;
			} else {
				WARN(ret);
				p--; {goto st316;}
			}
		} else if (s->buffer_length <= 10) { // Timestamp format.
			char *end;

			s->number64 = strtoull((char *)(s->buffer), &end,  10);

			if (end == (char *)(s->buffer) || *end != '\0') {
				WARN(ZS_BAD_TIMESTAMP);
				p--; {goto st316;}
			}

			if (s->number64 <= UINT32_MAX) {
				*((uint32_t *)rdata_tail) = htonl((uint32_t)s->number64);
				rdata_tail += 4;
			} else {
				WARN(ZS_NUMBER32_OVERFLOW);
				p--; {goto st316;}
			}
		} else {
			WARN(ZS_BAD_TIMESTAMP_LENGTH);
			p--; {goto st316;}
		}
	}
	{
		s->buffer_length = 0;
	}
	goto st1130;
st1130:
	if ( ++p == pe )
		goto _test_eof1130;
case 1130:
	_widec = (*p);
	if ( (*p) < 10 ) {
		if ( (*p) <= 9 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) > 10 ) {
		if ( 11 <= (*p) )
 {			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	if ( _widec == 2058 )
		goto tr3457;
	if ( 1920 <= _widec && _widec <= 2175 )
		goto tr3456;
	goto tr77;
tr3415:
	{
		s->buffer_length = 0;
	}
	goto st1131;
tr3458:
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		}
	}
	goto st1131;
tr3409:
	{
		s->buffer[s->buffer_length] = 0;

		if (s->buffer_length == 14) { // Date; 14 = len("YYYYMMDDHHmmSS").
			uint32_t timestamp;
			int ret = date_to_timestamp(s->buffer, &timestamp);

			if (ret == ZS_OK) {
				*((uint32_t *)rdata_tail) = htonl(timestamp);
				rdata_tail += 4;
			} else {
				WARN(ret);
				p--; {goto st316;}
			}
		} else if (s->buffer_length <= 10) { // Timestamp format.
			char *end;

			s->number64 = strtoull((char *)(s->buffer), &end,  10);

			if (end == (char *)(s->buffer) || *end != '\0') {
				WARN(ZS_BAD_TIMESTAMP);
				p--; {goto st316;}
			}

			if (s->number64 <= UINT32_MAX) {
				*((uint32_t *)rdata_tail) = htonl((uint32_t)s->number64);
				rdata_tail += 4;
			} else {
				WARN(ZS_NUMBER32_OVERFLOW);
				p--; {goto st316;}
			}
		} else {
			WARN(ZS_BAD_TIMESTAMP_LENGTH);
			p--; {goto st316;}
		}
	}
	{
		s->buffer_length = 0;
	}
	goto st1131;
st1131:
	if ( ++p == pe )
		goto _test_eof1131;
case 1131:
	_widec = (*p);
	if ( (*p) < 10 ) {
		if ( (*p) <= 9 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) > 10 ) {
		if ( 11 <= (*p) )
 {			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	if ( _widec == 2058 )
		goto tr3459;
	if ( 1920 <= _widec && _widec <= 2175 )
		goto tr3458;
	goto tr77;
tr3403:
	{
		s->buffer_length = 0;
	}
	goto st1132;
tr3460:
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		}
	}
	goto st1132;
tr3396:
	{
		if (s->number64 <= UINT32_MAX) {
			uint32_t num32 = htonl((uint32_t)s->number64);
			memcpy(rdata_tail, &num32, 4);
			rdata_tail += 4;
		} else {
			WARN(ZS_NUMBER32_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		s->buffer_length = 0;
	}
	goto st1132;
st1132:
	if ( ++p == pe )
		goto _test_eof1132;
case 1132:
	_widec = (*p);
	if ( (*p) < 10 ) {
		if ( (*p) <= 9 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) > 10 ) {
		if ( 11 <= (*p) )
 {			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	if ( _widec == 2058 )
		goto tr3461;
	if ( 1920 <= _widec && _widec <= 2175 )
		goto tr3460;
	goto tr77;
tr3390:
	{
		s->buffer_length = 0;
	}
	goto st1133;
tr3462:
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		}
	}
	goto st1133;
tr3384:
	{
		if (s->number64 <= UINT8_MAX) {
			*rdata_tail = (uint8_t)(s->number64);
			rdata_tail += 1;
		} else {
			WARN(ZS_NUMBER8_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		s->buffer_length = 0;
	}
	goto st1133;
st1133:
	if ( ++p == pe )
		goto _test_eof1133;
case 1133:
	_widec = (*p);
	if ( (*p) < 10 ) {
		if ( (*p) <= 9 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) > 10 ) {
		if ( 11 <= (*p) )
 {			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	if ( _widec == 2058 )
		goto tr3463;
	if ( 1920 <= _widec && _widec <= 2175 )
		goto tr3462;
	goto tr77;
tr3377:
	{
		s->buffer_length = 0;
	}
	goto st1134;
tr3464:
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		}
	}
	goto st1134;
st1134:
	if ( ++p == pe )
		goto _test_eof1134;
case 1134:
	_widec = (*p);
	if ( (*p) < 10 ) {
		if ( (*p) <= 9 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) > 10 ) {
		if ( 11 <= (*p) )
 {			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	if ( _widec == 2058 )
		goto tr3465;
	if ( 1920 <= _widec && _widec <= 2175 )
		goto tr3464;
	goto tr77;
tr3372:
	{
		s->buffer_length = 0;
	}
	goto st1135;
tr3466:
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		}
	}
	goto st1135;
tr3833:
	{
		if (s->number64 <= UINT16_MAX) {
			uint16_t num16 = htons((uint16_t)s->number64);
			memcpy(rdata_tail, &num16, 2);
			rdata_tail += 2;
		} else {
			WARN(ZS_NUMBER16_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		s->buffer_length = 0;
	}
	goto st1135;
tr3366:
	{ type_num(KNOT_RRTYPE_A, &rdata_tail); }
	{
		s->buffer_length = 0;
	}
	goto st1135;
tr3474:
	{ type_num(KNOT_RRTYPE_AAAA, &rdata_tail); }
	{
		s->buffer_length = 0;
	}
	goto st1135;
tr3482:
	{ type_num(KNOT_RRTYPE_AFSDB, &rdata_tail); }
	{
		s->buffer_length = 0;
	}
	goto st1135;
tr3488:
	{ type_num(KNOT_RRTYPE_APL, &rdata_tail); }
	{
		s->buffer_length = 0;
	}
	goto st1135;
tr3499:
	{ type_num(KNOT_RRTYPE_CAA, &rdata_tail); }
	{
		s->buffer_length = 0;
	}
	goto st1135;
tr3510:
	{ type_num(KNOT_RRTYPE_CDNSKEY, &rdata_tail); }
	{
		s->buffer_length = 0;
	}
	goto st1135;
tr3515:
	{ type_num(KNOT_RRTYPE_CDS, &rdata_tail); }
	{
		s->buffer_length = 0;
	}
	goto st1135;
tr3522:
	{ type_num(KNOT_RRTYPE_CERT, &rdata_tail); }
	{
		s->buffer_length = 0;
	}
	goto st1135;
tr3530:
	{ type_num(KNOT_RRTYPE_CNAME, &rdata_tail); }
	{
		s->buffer_length = 0;
	}
	goto st1135;
tr3538:
	{ type_num(KNOT_RRTYPE_CSYNC, &rdata_tail); }
	{
		s->buffer_length = 0;
	}
	goto st1135;
tr3549:
	{ type_num(KNOT_RRTYPE_DHCID, &rdata_tail); }
	{
		s->buffer_length = 0;
	}
	goto st1135;
tr3558:
	{ type_num(KNOT_RRTYPE_DNAME, &rdata_tail); }
	{
		s->buffer_length = 0;
	}
	goto st1135;
tr3566:
	{ type_num(KNOT_RRTYPE_DNSKEY, &rdata_tail); }
	{
		s->buffer_length = 0;
	}
	goto st1135;
tr3571:
	{ type_num(KNOT_RRTYPE_DS, &rdata_tail); }
	{
		s->buffer_length = 0;
	}
	goto st1135;
tr3581:
	{ type_num(KNOT_RRTYPE_EUI48, &rdata_tail); }
	{
		s->buffer_length = 0;
	}
	goto st1135;
tr3587:
	{ type_num(KNOT_RRTYPE_EUI64, &rdata_tail); }
	{
		s->buffer_length = 0;
	}
	goto st1135;
tr3597:
	{ type_num(KNOT_RRTYPE_HINFO, &rdata_tail); }
	{
		s->buffer_length = 0;
	}
	goto st1135;
tr3605:
	{ type_num(KNOT_RRTYPE_HTTPS, &rdata_tail); }
	{
		s->buffer_length = 0;
	}
	goto st1135;
tr3617:
	{ type_num(KNOT_RRTYPE_IPSECKEY, &rdata_tail); }
	{
		s->buffer_length = 0;
	}
	goto st1135;
tr3625:
	{ type_num(KNOT_RRTYPE_KEY, &rdata_tail); }
	{
		s->buffer_length = 0;
	}
	goto st1135;
tr3630:
	{ type_num(KNOT_RRTYPE_KX, &rdata_tail); }
	{
		s->buffer_length = 0;
	}
	goto st1135;
tr3640:
	{ type_num(KNOT_RRTYPE_L32, &rdata_tail); }
	{
		s->buffer_length = 0;
	}
	goto st1135;
tr3646:
	{ type_num(KNOT_RRTYPE_L64, &rdata_tail); }
	{
		s->buffer_length = 0;
	}
	goto st1135;
tr3652:
	{ type_num(KNOT_RRTYPE_LOC, &rdata_tail); }
	{
		s->buffer_length = 0;
	}
	goto st1135;
tr3657:
	{ type_num(KNOT_RRTYPE_LP, &rdata_tail); }
	{
		s->buffer_length = 0;
	}
	goto st1135;
tr3667:
	{ type_num(KNOT_RRTYPE_MINFO, &rdata_tail); }
	{
		s->buffer_length = 0;
	}
	goto st1135;
tr3672:
	{ type_num(KNOT_RRTYPE_MX, &rdata_tail); }
	{
		s->buffer_length = 0;
	}
	goto st1135;
tr3683:
	{ type_num(KNOT_RRTYPE_NAPTR, &rdata_tail); }
	{
		s->buffer_length = 0;
	}
	goto st1135;
tr3689:
	{ type_num(KNOT_RRTYPE_NID, &rdata_tail); }
	{
		s->buffer_length = 0;
	}
	goto st1135;
tr3695:
	{ type_num(KNOT_RRTYPE_NS, &rdata_tail); }
	{
		s->buffer_length = 0;
	}
	goto st1135;
tr3702:
	{ type_num(KNOT_RRTYPE_NSEC, &rdata_tail); }
	{
		s->buffer_length = 0;
	}
	goto st1135;
tr3708:
	{ type_num(KNOT_RRTYPE_NSEC3, &rdata_tail); }
	{
		s->buffer_length = 0;
	}
	goto st1135;
tr3717:
	{ type_num(KNOT_RRTYPE_NSEC3PARAM, &rdata_tail); }
	{
		s->buffer_length = 0;
	}
	goto st1135;
tr3731:
	{ type_num(KNOT_RRTYPE_OPENPGPKEY, &rdata_tail); }
	{
		s->buffer_length = 0;
	}
	goto st1135;
tr3738:
	{ type_num(KNOT_RRTYPE_PTR, &rdata_tail); }
	{
		s->buffer_length = 0;
	}
	goto st1135;
tr3746:
	{ type_num(KNOT_RRTYPE_RP, &rdata_tail); }
	{
		s->buffer_length = 0;
	}
	goto st1135;
tr3754:
	{ type_num(KNOT_RRTYPE_RRSIG, &rdata_tail); }
	{
		s->buffer_length = 0;
	}
	goto st1135;
tr3759:
	{ type_num(KNOT_RRTYPE_RT, &rdata_tail); }
	{
		s->buffer_length = 0;
	}
	goto st1135;
tr3774:
	{ type_num(KNOT_RRTYPE_SMIMEA, &rdata_tail); }
	{
		s->buffer_length = 0;
	}
	goto st1135;
tr3780:
	{ type_num(KNOT_RRTYPE_SOA, &rdata_tail); }
	{
		s->buffer_length = 0;
	}
	goto st1135;
tr3786:
	{ type_num(KNOT_RRTYPE_SPF, &rdata_tail); }
	{
		s->buffer_length = 0;
	}
	goto st1135;
tr3792:
	{ type_num(KNOT_RRTYPE_SRV, &rdata_tail); }
	{
		s->buffer_length = 0;
	}
	goto st1135;
tr3800:
	{ type_num(KNOT_RRTYPE_SSHFP, &rdata_tail); }
	{
		s->buffer_length = 0;
	}
	goto st1135;
tr3807:
	{ type_num(KNOT_RRTYPE_SVCB, &rdata_tail); }
	{
		s->buffer_length = 0;
	}
	goto st1135;
tr3817:
	{ type_num(KNOT_RRTYPE_TLSA, &rdata_tail); }
	{
		s->buffer_length = 0;
	}
	goto st1135;
tr3823:
	{ type_num(KNOT_RRTYPE_TXT, &rdata_tail); }
	{
		s->buffer_length = 0;
	}
	goto st1135;
tr3840:
	{ type_num(KNOT_RRTYPE_URI, &rdata_tail); }
	{
		s->buffer_length = 0;
	}
	goto st1135;
tr3850:
	{ type_num(KNOT_RRTYPE_WALLET, &rdata_tail); }
	{
		s->buffer_length = 0;
	}
	goto st1135;
tr3860:
	{ type_num(KNOT_RRTYPE_ZONEMD, &rdata_tail); }
	{
		s->buffer_length = 0;
	}
	goto st1135;
st1135:
	if ( ++p == pe )
		goto _test_eof1135;
case 1135:
	_widec = (*p);
	if ( (*p) < 10 ) {
		if ( (*p) <= 9 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) > 10 ) {
		if ( 11 <= (*p) )
 {			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	if ( _widec == 2058 )
		goto tr3467;
	if ( 1920 <= _widec && _widec <= 2175 )
		goto tr3466;
	goto tr77;
st1136:
	if ( ++p == pe )
		goto _test_eof1136;
case 1136:
	switch( (*p) ) {
		case 65: goto st1137;
		case 97: goto st1137;
	}
	goto tr3340;
st1137:
	if ( ++p == pe )
		goto _test_eof1137;
case 1137:
	switch( (*p) ) {
		case 65: goto st1138;
		case 97: goto st1138;
	}
	goto tr3340;
st1138:
	if ( ++p == pe )
		goto _test_eof1138;
case 1138:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr3470;
		case 32: goto tr3470;
		case 40: goto tr3471;
		case 41: goto tr3472;
		case 2058: goto tr3473;
		case 2107: goto tr3474;
	}
	goto tr3340;
st1139:
	if ( ++p == pe )
		goto _test_eof1139;
case 1139:
	switch( (*p) ) {
		case 83: goto st1140;
		case 115: goto st1140;
	}
	goto tr3340;
st1140:
	if ( ++p == pe )
		goto _test_eof1140;
case 1140:
	switch( (*p) ) {
		case 68: goto st1141;
		case 100: goto st1141;
	}
	goto tr3340;
st1141:
	if ( ++p == pe )
		goto _test_eof1141;
case 1141:
	switch( (*p) ) {
		case 66: goto st1142;
		case 98: goto st1142;
	}
	goto tr3340;
st1142:
	if ( ++p == pe )
		goto _test_eof1142;
case 1142:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr3478;
		case 32: goto tr3478;
		case 40: goto tr3479;
		case 41: goto tr3480;
		case 2058: goto tr3481;
		case 2107: goto tr3482;
	}
	goto tr3340;
st1143:
	if ( ++p == pe )
		goto _test_eof1143;
case 1143:
	switch( (*p) ) {
		case 76: goto st1144;
		case 108: goto st1144;
	}
	goto tr3340;
st1144:
	if ( ++p == pe )
		goto _test_eof1144;
case 1144:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr3484;
		case 32: goto tr3484;
		case 40: goto tr3485;
		case 41: goto tr3486;
		case 2058: goto tr3487;
		case 2107: goto tr3488;
	}
	goto tr3340;
st1145:
	if ( ++p == pe )
		goto _test_eof1145;
case 1145:
	switch( (*p) ) {
		case 65: goto st1146;
		case 68: goto st1148;
		case 69: goto st1155;
		case 78: goto st1158;
		case 83: goto st1162;
		case 97: goto st1146;
		case 100: goto st1148;
		case 101: goto st1155;
		case 110: goto st1158;
		case 115: goto st1162;
	}
	goto tr3340;
st1146:
	if ( ++p == pe )
		goto _test_eof1146;
case 1146:
	switch( (*p) ) {
		case 65: goto st1147;
		case 97: goto st1147;
	}
	goto tr3340;
st1147:
	if ( ++p == pe )
		goto _test_eof1147;
case 1147:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr3495;
		case 32: goto tr3495;
		case 40: goto tr3496;
		case 41: goto tr3497;
		case 2058: goto tr3498;
		case 2107: goto tr3499;
	}
	goto tr3340;
st1148:
	if ( ++p == pe )
		goto _test_eof1148;
case 1148:
	switch( (*p) ) {
		case 78: goto st1149;
		case 83: goto st1154;
		case 110: goto st1149;
		case 115: goto st1154;
	}
	goto tr3340;
st1149:
	if ( ++p == pe )
		goto _test_eof1149;
case 1149:
	switch( (*p) ) {
		case 83: goto st1150;
		case 115: goto st1150;
	}
	goto tr3340;
st1150:
	if ( ++p == pe )
		goto _test_eof1150;
case 1150:
	switch( (*p) ) {
		case 75: goto st1151;
		case 107: goto st1151;
	}
	goto tr3340;
st1151:
	if ( ++p == pe )
		goto _test_eof1151;
case 1151:
	switch( (*p) ) {
		case 69: goto st1152;
		case 101: goto st1152;
	}
	goto tr3340;
st1152:
	if ( ++p == pe )
		goto _test_eof1152;
case 1152:
	switch( (*p) ) {
		case 89: goto st1153;
		case 121: goto st1153;
	}
	goto tr3340;
st1153:
	if ( ++p == pe )
		goto _test_eof1153;
case 1153:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr3506;
		case 32: goto tr3506;
		case 40: goto tr3507;
		case 41: goto tr3508;
		case 2058: goto tr3509;
		case 2107: goto tr3510;
	}
	goto tr3340;
st1154:
	if ( ++p == pe )
		goto _test_eof1154;
case 1154:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr3511;
		case 32: goto tr3511;
		case 40: goto tr3512;
		case 41: goto tr3513;
		case 2058: goto tr3514;
		case 2107: goto tr3515;
	}
	goto tr3340;
st1155:
	if ( ++p == pe )
		goto _test_eof1155;
case 1155:
	switch( (*p) ) {
		case 82: goto st1156;
		case 114: goto st1156;
	}
	goto tr3340;
st1156:
	if ( ++p == pe )
		goto _test_eof1156;
case 1156:
	switch( (*p) ) {
		case 84: goto st1157;
		case 116: goto st1157;
	}
	goto tr3340;
st1157:
	if ( ++p == pe )
		goto _test_eof1157;
case 1157:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr3518;
		case 32: goto tr3518;
		case 40: goto tr3519;
		case 41: goto tr3520;
		case 2058: goto tr3521;
		case 2107: goto tr3522;
	}
	goto tr3340;
st1158:
	if ( ++p == pe )
		goto _test_eof1158;
case 1158:
	switch( (*p) ) {
		case 65: goto st1159;
		case 97: goto st1159;
	}
	goto tr3340;
st1159:
	if ( ++p == pe )
		goto _test_eof1159;
case 1159:
	switch( (*p) ) {
		case 77: goto st1160;
		case 109: goto st1160;
	}
	goto tr3340;
st1160:
	if ( ++p == pe )
		goto _test_eof1160;
case 1160:
	switch( (*p) ) {
		case 69: goto st1161;
		case 101: goto st1161;
	}
	goto tr3340;
st1161:
	if ( ++p == pe )
		goto _test_eof1161;
case 1161:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr3526;
		case 32: goto tr3526;
		case 40: goto tr3527;
		case 41: goto tr3528;
		case 2058: goto tr3529;
		case 2107: goto tr3530;
	}
	goto tr3340;
st1162:
	if ( ++p == pe )
		goto _test_eof1162;
case 1162:
	switch( (*p) ) {
		case 89: goto st1163;
		case 121: goto st1163;
	}
	goto tr3340;
st1163:
	if ( ++p == pe )
		goto _test_eof1163;
case 1163:
	switch( (*p) ) {
		case 78: goto st1164;
		case 110: goto st1164;
	}
	goto tr3340;
st1164:
	if ( ++p == pe )
		goto _test_eof1164;
case 1164:
	switch( (*p) ) {
		case 67: goto st1165;
		case 99: goto st1165;
	}
	goto tr3340;
st1165:
	if ( ++p == pe )
		goto _test_eof1165;
case 1165:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr3534;
		case 32: goto tr3534;
		case 40: goto tr3535;
		case 41: goto tr3536;
		case 2058: goto tr3537;
		case 2107: goto tr3538;
	}
	goto tr3340;
st1166:
	if ( ++p == pe )
		goto _test_eof1166;
case 1166:
	switch( (*p) ) {
		case 72: goto st1167;
		case 78: goto st1171;
		case 83: goto st1179;
		case 104: goto st1167;
		case 110: goto st1171;
		case 115: goto st1179;
	}
	goto tr3340;
st1167:
	if ( ++p == pe )
		goto _test_eof1167;
case 1167:
	switch( (*p) ) {
		case 67: goto st1168;
		case 99: goto st1168;
	}
	goto tr3340;
st1168:
	if ( ++p == pe )
		goto _test_eof1168;
case 1168:
	switch( (*p) ) {
		case 73: goto st1169;
		case 105: goto st1169;
	}
	goto tr3340;
st1169:
	if ( ++p == pe )
		goto _test_eof1169;
case 1169:
	switch( (*p) ) {
		case 68: goto st1170;
		case 100: goto st1170;
	}
	goto tr3340;
st1170:
	if ( ++p == pe )
		goto _test_eof1170;
case 1170:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr3545;
		case 32: goto tr3545;
		case 40: goto tr3546;
		case 41: goto tr3547;
		case 2058: goto tr3548;
		case 2107: goto tr3549;
	}
	goto tr3340;
st1171:
	if ( ++p == pe )
		goto _test_eof1171;
case 1171:
	switch( (*p) ) {
		case 65: goto st1172;
		case 83: goto st1175;
		case 97: goto st1172;
		case 115: goto st1175;
	}
	goto tr3340;
st1172:
	if ( ++p == pe )
		goto _test_eof1172;
case 1172:
	switch( (*p) ) {
		case 77: goto st1173;
		case 109: goto st1173;
	}
	goto tr3340;
st1173:
	if ( ++p == pe )
		goto _test_eof1173;
case 1173:
	switch( (*p) ) {
		case 69: goto st1174;
		case 101: goto st1174;
	}
	goto tr3340;
st1174:
	if ( ++p == pe )
		goto _test_eof1174;
case 1174:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr3554;
		case 32: goto tr3554;
		case 40: goto tr3555;
		case 41: goto tr3556;
		case 2058: goto tr3557;
		case 2107: goto tr3558;
	}
	goto tr3340;
st1175:
	if ( ++p == pe )
		goto _test_eof1175;
case 1175:
	switch( (*p) ) {
		case 75: goto st1176;
		case 107: goto st1176;
	}
	goto tr3340;
st1176:
	if ( ++p == pe )
		goto _test_eof1176;
case 1176:
	switch( (*p) ) {
		case 69: goto st1177;
		case 101: goto st1177;
	}
	goto tr3340;
st1177:
	if ( ++p == pe )
		goto _test_eof1177;
case 1177:
	switch( (*p) ) {
		case 89: goto st1178;
		case 121: goto st1178;
	}
	goto tr3340;
st1178:
	if ( ++p == pe )
		goto _test_eof1178;
case 1178:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr3562;
		case 32: goto tr3562;
		case 40: goto tr3563;
		case 41: goto tr3564;
		case 2058: goto tr3565;
		case 2107: goto tr3566;
	}
	goto tr3340;
st1179:
	if ( ++p == pe )
		goto _test_eof1179;
case 1179:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr3567;
		case 32: goto tr3567;
		case 40: goto tr3568;
		case 41: goto tr3569;
		case 2058: goto tr3570;
		case 2107: goto tr3571;
	}
	goto tr3340;
st1180:
	if ( ++p == pe )
		goto _test_eof1180;
case 1180:
	switch( (*p) ) {
		case 85: goto st1181;
		case 117: goto st1181;
	}
	goto tr3340;
st1181:
	if ( ++p == pe )
		goto _test_eof1181;
case 1181:
	switch( (*p) ) {
		case 73: goto st1182;
		case 105: goto st1182;
	}
	goto tr3340;
st1182:
	if ( ++p == pe )
		goto _test_eof1182;
case 1182:
	switch( (*p) ) {
		case 52: goto st1183;
		case 54: goto st1185;
	}
	goto tr3340;
st1183:
	if ( ++p == pe )
		goto _test_eof1183;
case 1183:
	if ( (*p) == 56 )
		goto st1184;
	goto tr3340;
st1184:
	if ( ++p == pe )
		goto _test_eof1184;
case 1184:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr3577;
		case 32: goto tr3577;
		case 40: goto tr3578;
		case 41: goto tr3579;
		case 2058: goto tr3580;
		case 2107: goto tr3581;
	}
	goto tr3340;
st1185:
	if ( ++p == pe )
		goto _test_eof1185;
case 1185:
	if ( (*p) == 52 )
		goto st1186;
	goto tr3340;
st1186:
	if ( ++p == pe )
		goto _test_eof1186;
case 1186:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr3583;
		case 32: goto tr3583;
		case 40: goto tr3584;
		case 41: goto tr3585;
		case 2058: goto tr3586;
		case 2107: goto tr3587;
	}
	goto tr3340;
st1187:
	if ( ++p == pe )
		goto _test_eof1187;
case 1187:
	switch( (*p) ) {
		case 73: goto st1188;
		case 84: goto st1192;
		case 105: goto st1188;
		case 116: goto st1192;
	}
	goto tr3340;
st1188:
	if ( ++p == pe )
		goto _test_eof1188;
case 1188:
	switch( (*p) ) {
		case 78: goto st1189;
		case 110: goto st1189;
	}
	goto tr3340;
st1189:
	if ( ++p == pe )
		goto _test_eof1189;
case 1189:
	switch( (*p) ) {
		case 70: goto st1190;
		case 102: goto st1190;
	}
	goto tr3340;
st1190:
	if ( ++p == pe )
		goto _test_eof1190;
case 1190:
	switch( (*p) ) {
		case 79: goto st1191;
		case 111: goto st1191;
	}
	goto tr3340;
st1191:
	if ( ++p == pe )
		goto _test_eof1191;
case 1191:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr3593;
		case 32: goto tr3593;
		case 40: goto tr3594;
		case 41: goto tr3595;
		case 2058: goto tr3596;
		case 2107: goto tr3597;
	}
	goto tr3340;
st1192:
	if ( ++p == pe )
		goto _test_eof1192;
case 1192:
	switch( (*p) ) {
		case 84: goto st1193;
		case 116: goto st1193;
	}
	goto tr3340;
st1193:
	if ( ++p == pe )
		goto _test_eof1193;
case 1193:
	switch( (*p) ) {
		case 80: goto st1194;
		case 112: goto st1194;
	}
	goto tr3340;
st1194:
	if ( ++p == pe )
		goto _test_eof1194;
case 1194:
	switch( (*p) ) {
		case 83: goto st1195;
		case 115: goto st1195;
	}
	goto tr3340;
st1195:
	if ( ++p == pe )
		goto _test_eof1195;
case 1195:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr3601;
		case 32: goto tr3601;
		case 40: goto tr3602;
		case 41: goto tr3603;
		case 2058: goto tr3604;
		case 2107: goto tr3605;
	}
	goto tr3340;
st1196:
	if ( ++p == pe )
		goto _test_eof1196;
case 1196:
	switch( (*p) ) {
		case 80: goto st1197;
		case 112: goto st1197;
	}
	goto tr3340;
st1197:
	if ( ++p == pe )
		goto _test_eof1197;
case 1197:
	switch( (*p) ) {
		case 83: goto st1198;
		case 115: goto st1198;
	}
	goto tr3340;
st1198:
	if ( ++p == pe )
		goto _test_eof1198;
case 1198:
	switch( (*p) ) {
		case 69: goto st1199;
		case 101: goto st1199;
	}
	goto tr3340;
st1199:
	if ( ++p == pe )
		goto _test_eof1199;
case 1199:
	switch( (*p) ) {
		case 67: goto st1200;
		case 99: goto st1200;
	}
	goto tr3340;
st1200:
	if ( ++p == pe )
		goto _test_eof1200;
case 1200:
	switch( (*p) ) {
		case 75: goto st1201;
		case 107: goto st1201;
	}
	goto tr3340;
st1201:
	if ( ++p == pe )
		goto _test_eof1201;
case 1201:
	switch( (*p) ) {
		case 69: goto st1202;
		case 101: goto st1202;
	}
	goto tr3340;
st1202:
	if ( ++p == pe )
		goto _test_eof1202;
case 1202:
	switch( (*p) ) {
		case 89: goto st1203;
		case 121: goto st1203;
	}
	goto tr3340;
st1203:
	if ( ++p == pe )
		goto _test_eof1203;
case 1203:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr3613;
		case 32: goto tr3613;
		case 40: goto tr3614;
		case 41: goto tr3615;
		case 2058: goto tr3616;
		case 2107: goto tr3617;
	}
	goto tr3340;
st1204:
	if ( ++p == pe )
		goto _test_eof1204;
case 1204:
	switch( (*p) ) {
		case 69: goto st1205;
		case 88: goto st1207;
		case 101: goto st1205;
		case 120: goto st1207;
	}
	goto tr3340;
st1205:
	if ( ++p == pe )
		goto _test_eof1205;
case 1205:
	switch( (*p) ) {
		case 89: goto st1206;
		case 121: goto st1206;
	}
	goto tr3340;
st1206:
	if ( ++p == pe )
		goto _test_eof1206;
case 1206:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr3621;
		case 32: goto tr3621;
		case 40: goto tr3622;
		case 41: goto tr3623;
		case 2058: goto tr3624;
		case 2107: goto tr3625;
	}
	goto tr3340;
st1207:
	if ( ++p == pe )
		goto _test_eof1207;
case 1207:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr3626;
		case 32: goto tr3626;
		case 40: goto tr3627;
		case 41: goto tr3628;
		case 2058: goto tr3629;
		case 2107: goto tr3630;
	}
	goto tr3340;
st1208:
	if ( ++p == pe )
		goto _test_eof1208;
case 1208:
	switch( (*p) ) {
		case 51: goto st1209;
		case 54: goto st1211;
		case 79: goto st1213;
		case 80: goto st1215;
		case 111: goto st1213;
		case 112: goto st1215;
	}
	goto tr3340;
st1209:
	if ( ++p == pe )
		goto _test_eof1209;
case 1209:
	if ( (*p) == 50 )
		goto st1210;
	goto tr3340;
st1210:
	if ( ++p == pe )
		goto _test_eof1210;
case 1210:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr3636;
		case 32: goto tr3636;
		case 40: goto tr3637;
		case 41: goto tr3638;
		case 2058: goto tr3639;
		case 2107: goto tr3640;
	}
	goto tr3340;
st1211:
	if ( ++p == pe )
		goto _test_eof1211;
case 1211:
	if ( (*p) == 52 )
		goto st1212;
	goto tr3340;
st1212:
	if ( ++p == pe )
		goto _test_eof1212;
case 1212:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr3642;
		case 32: goto tr3642;
		case 40: goto tr3643;
		case 41: goto tr3644;
		case 2058: goto tr3645;
		case 2107: goto tr3646;
	}
	goto tr3340;
st1213:
	if ( ++p == pe )
		goto _test_eof1213;
case 1213:
	switch( (*p) ) {
		case 67: goto st1214;
		case 99: goto st1214;
	}
	goto tr3340;
st1214:
	if ( ++p == pe )
		goto _test_eof1214;
case 1214:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr3648;
		case 32: goto tr3648;
		case 40: goto tr3649;
		case 41: goto tr3650;
		case 2058: goto tr3651;
		case 2107: goto tr3652;
	}
	goto tr3340;
st1215:
	if ( ++p == pe )
		goto _test_eof1215;
case 1215:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr3653;
		case 32: goto tr3653;
		case 40: goto tr3654;
		case 41: goto tr3655;
		case 2058: goto tr3656;
		case 2107: goto tr3657;
	}
	goto tr3340;
st1216:
	if ( ++p == pe )
		goto _test_eof1216;
case 1216:
	switch( (*p) ) {
		case 73: goto st1217;
		case 88: goto st1221;
		case 105: goto st1217;
		case 120: goto st1221;
	}
	goto tr3340;
st1217:
	if ( ++p == pe )
		goto _test_eof1217;
case 1217:
	switch( (*p) ) {
		case 78: goto st1218;
		case 110: goto st1218;
	}
	goto tr3340;
st1218:
	if ( ++p == pe )
		goto _test_eof1218;
case 1218:
	switch( (*p) ) {
		case 70: goto st1219;
		case 102: goto st1219;
	}
	goto tr3340;
st1219:
	if ( ++p == pe )
		goto _test_eof1219;
case 1219:
	switch( (*p) ) {
		case 79: goto st1220;
		case 111: goto st1220;
	}
	goto tr3340;
st1220:
	if ( ++p == pe )
		goto _test_eof1220;
case 1220:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr3663;
		case 32: goto tr3663;
		case 40: goto tr3664;
		case 41: goto tr3665;
		case 2058: goto tr3666;
		case 2107: goto tr3667;
	}
	goto tr3340;
st1221:
	if ( ++p == pe )
		goto _test_eof1221;
case 1221:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr3668;
		case 32: goto tr3668;
		case 40: goto tr3669;
		case 41: goto tr3670;
		case 2058: goto tr3671;
		case 2107: goto tr3672;
	}
	goto tr3340;
st1222:
	if ( ++p == pe )
		goto _test_eof1222;
case 1222:
	switch( (*p) ) {
		case 65: goto st1223;
		case 73: goto st1227;
		case 83: goto st1229;
		case 97: goto st1223;
		case 105: goto st1227;
		case 115: goto st1229;
	}
	goto tr3340;
st1223:
	if ( ++p == pe )
		goto _test_eof1223;
case 1223:
	switch( (*p) ) {
		case 80: goto st1224;
		case 112: goto st1224;
	}
	goto tr3340;
st1224:
	if ( ++p == pe )
		goto _test_eof1224;
case 1224:
	switch( (*p) ) {
		case 84: goto st1225;
		case 116: goto st1225;
	}
	goto tr3340;
st1225:
	if ( ++p == pe )
		goto _test_eof1225;
case 1225:
	switch( (*p) ) {
		case 82: goto st1226;
		case 114: goto st1226;
	}
	goto tr3340;
st1226:
	if ( ++p == pe )
		goto _test_eof1226;
case 1226:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr3679;
		case 32: goto tr3679;
		case 40: goto tr3680;
		case 41: goto tr3681;
		case 2058: goto tr3682;
		case 2107: goto tr3683;
	}
	goto tr3340;
st1227:
	if ( ++p == pe )
		goto _test_eof1227;
case 1227:
	switch( (*p) ) {
		case 68: goto st1228;
		case 100: goto st1228;
	}
	goto tr3340;
st1228:
	if ( ++p == pe )
		goto _test_eof1228;
case 1228:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr3685;
		case 32: goto tr3685;
		case 40: goto tr3686;
		case 41: goto tr3687;
		case 2058: goto tr3688;
		case 2107: goto tr3689;
	}
	goto tr3340;
st1229:
	if ( ++p == pe )
		goto _test_eof1229;
case 1229:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr3690;
		case 32: goto tr3690;
		case 40: goto tr3691;
		case 41: goto tr3692;
		case 69: goto st1230;
		case 101: goto st1230;
		case 2058: goto tr3694;
		case 2107: goto tr3695;
	}
	goto tr3340;
st1230:
	if ( ++p == pe )
		goto _test_eof1230;
case 1230:
	switch( (*p) ) {
		case 67: goto st1231;
		case 99: goto st1231;
	}
	goto tr3340;
st1231:
	if ( ++p == pe )
		goto _test_eof1231;
case 1231:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr3697;
		case 32: goto tr3697;
		case 40: goto tr3698;
		case 41: goto tr3699;
		case 51: goto st1232;
		case 2058: goto tr3701;
		case 2107: goto tr3702;
	}
	goto tr3340;
st1232:
	if ( ++p == pe )
		goto _test_eof1232;
case 1232:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr3703;
		case 32: goto tr3703;
		case 40: goto tr3704;
		case 41: goto tr3705;
		case 80: goto st1233;
		case 112: goto st1233;
		case 2058: goto tr3707;
		case 2107: goto tr3708;
	}
	goto tr3340;
st1233:
	if ( ++p == pe )
		goto _test_eof1233;
case 1233:
	switch( (*p) ) {
		case 65: goto st1234;
		case 97: goto st1234;
	}
	goto tr3340;
st1234:
	if ( ++p == pe )
		goto _test_eof1234;
case 1234:
	switch( (*p) ) {
		case 82: goto st1235;
		case 114: goto st1235;
	}
	goto tr3340;
st1235:
	if ( ++p == pe )
		goto _test_eof1235;
case 1235:
	switch( (*p) ) {
		case 65: goto st1236;
		case 97: goto st1236;
	}
	goto tr3340;
st1236:
	if ( ++p == pe )
		goto _test_eof1236;
case 1236:
	switch( (*p) ) {
		case 77: goto st1237;
		case 109: goto st1237;
	}
	goto tr3340;
st1237:
	if ( ++p == pe )
		goto _test_eof1237;
case 1237:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr3713;
		case 32: goto tr3713;
		case 40: goto tr3714;
		case 41: goto tr3715;
		case 2058: goto tr3716;
		case 2107: goto tr3717;
	}
	goto tr3340;
st1238:
	if ( ++p == pe )
		goto _test_eof1238;
case 1238:
	switch( (*p) ) {
		case 80: goto st1239;
		case 112: goto st1239;
	}
	goto tr3340;
st1239:
	if ( ++p == pe )
		goto _test_eof1239;
case 1239:
	switch( (*p) ) {
		case 69: goto st1240;
		case 101: goto st1240;
	}
	goto tr3340;
st1240:
	if ( ++p == pe )
		goto _test_eof1240;
case 1240:
	switch( (*p) ) {
		case 78: goto st1241;
		case 110: goto st1241;
	}
	goto tr3340;
st1241:
	if ( ++p == pe )
		goto _test_eof1241;
case 1241:
	switch( (*p) ) {
		case 80: goto st1242;
		case 112: goto st1242;
	}
	goto tr3340;
st1242:
	if ( ++p == pe )
		goto _test_eof1242;
case 1242:
	switch( (*p) ) {
		case 71: goto st1243;
		case 103: goto st1243;
	}
	goto tr3340;
st1243:
	if ( ++p == pe )
		goto _test_eof1243;
case 1243:
	switch( (*p) ) {
		case 80: goto st1244;
		case 112: goto st1244;
	}
	goto tr3340;
st1244:
	if ( ++p == pe )
		goto _test_eof1244;
case 1244:
	switch( (*p) ) {
		case 75: goto st1245;
		case 107: goto st1245;
	}
	goto tr3340;
st1245:
	if ( ++p == pe )
		goto _test_eof1245;
case 1245:
	switch( (*p) ) {
		case 69: goto st1246;
		case 101: goto st1246;
	}
	goto tr3340;
st1246:
	if ( ++p == pe )
		goto _test_eof1246;
case 1246:
	switch( (*p) ) {
		case 89: goto st1247;
		case 121: goto st1247;
	}
	goto tr3340;
st1247:
	if ( ++p == pe )
		goto _test_eof1247;
case 1247:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr3727;
		case 32: goto tr3727;
		case 40: goto tr3728;
		case 41: goto tr3729;
		case 2058: goto tr3730;
		case 2107: goto tr3731;
	}
	goto tr3340;
st1248:
	if ( ++p == pe )
		goto _test_eof1248;
case 1248:
	switch( (*p) ) {
		case 84: goto st1249;
		case 116: goto st1249;
	}
	goto tr3340;
st1249:
	if ( ++p == pe )
		goto _test_eof1249;
case 1249:
	switch( (*p) ) {
		case 82: goto st1250;
		case 114: goto st1250;
	}
	goto tr3340;
st1250:
	if ( ++p == pe )
		goto _test_eof1250;
case 1250:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr3734;
		case 32: goto tr3734;
		case 40: goto tr3735;
		case 41: goto tr3736;
		case 2058: goto tr3737;
		case 2107: goto tr3738;
	}
	goto tr3340;
st1251:
	if ( ++p == pe )
		goto _test_eof1251;
case 1251:
	switch( (*p) ) {
		case 80: goto st1252;
		case 82: goto st1253;
		case 84: goto st1257;
		case 112: goto st1252;
		case 114: goto st1253;
		case 116: goto st1257;
	}
	goto tr3340;
st1252:
	if ( ++p == pe )
		goto _test_eof1252;
case 1252:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr3742;
		case 32: goto tr3742;
		case 40: goto tr3743;
		case 41: goto tr3744;
		case 2058: goto tr3745;
		case 2107: goto tr3746;
	}
	goto tr3340;
st1253:
	if ( ++p == pe )
		goto _test_eof1253;
case 1253:
	switch( (*p) ) {
		case 83: goto st1254;
		case 115: goto st1254;
	}
	goto tr3340;
st1254:
	if ( ++p == pe )
		goto _test_eof1254;
case 1254:
	switch( (*p) ) {
		case 73: goto st1255;
		case 105: goto st1255;
	}
	goto tr3340;
st1255:
	if ( ++p == pe )
		goto _test_eof1255;
case 1255:
	switch( (*p) ) {
		case 71: goto st1256;
		case 103: goto st1256;
	}
	goto tr3340;
st1256:
	if ( ++p == pe )
		goto _test_eof1256;
case 1256:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr3750;
		case 32: goto tr3750;
		case 40: goto tr3751;
		case 41: goto tr3752;
		case 2058: goto tr3753;
		case 2107: goto tr3754;
	}
	goto tr3340;
st1257:
	if ( ++p == pe )
		goto _test_eof1257;
case 1257:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr3755;
		case 32: goto tr3755;
		case 40: goto tr3756;
		case 41: goto tr3757;
		case 2058: goto tr3758;
		case 2107: goto tr3759;
	}
	goto tr3340;
st1258:
	if ( ++p == pe )
		goto _test_eof1258;
case 1258:
	switch( (*p) ) {
		case 77: goto st1259;
		case 79: goto st1264;
		case 80: goto st1266;
		case 82: goto st1268;
		case 83: goto st1270;
		case 86: goto st1274;
		case 109: goto st1259;
		case 111: goto st1264;
		case 112: goto st1266;
		case 114: goto st1268;
		case 115: goto st1270;
		case 118: goto st1274;
	}
	goto tr3340;
st1259:
	if ( ++p == pe )
		goto _test_eof1259;
case 1259:
	switch( (*p) ) {
		case 73: goto st1260;
		case 105: goto st1260;
	}
	goto tr3340;
st1260:
	if ( ++p == pe )
		goto _test_eof1260;
case 1260:
	switch( (*p) ) {
		case 77: goto st1261;
		case 109: goto st1261;
	}
	goto tr3340;
st1261:
	if ( ++p == pe )
		goto _test_eof1261;
case 1261:
	switch( (*p) ) {
		case 69: goto st1262;
		case 101: goto st1262;
	}
	goto tr3340;
st1262:
	if ( ++p == pe )
		goto _test_eof1262;
case 1262:
	switch( (*p) ) {
		case 65: goto st1263;
		case 97: goto st1263;
	}
	goto tr3340;
st1263:
	if ( ++p == pe )
		goto _test_eof1263;
case 1263:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr3770;
		case 32: goto tr3770;
		case 40: goto tr3771;
		case 41: goto tr3772;
		case 2058: goto tr3773;
		case 2107: goto tr3774;
	}
	goto tr3340;
st1264:
	if ( ++p == pe )
		goto _test_eof1264;
case 1264:
	switch( (*p) ) {
		case 65: goto st1265;
		case 97: goto st1265;
	}
	goto tr3340;
st1265:
	if ( ++p == pe )
		goto _test_eof1265;
case 1265:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr3776;
		case 32: goto tr3776;
		case 40: goto tr3777;
		case 41: goto tr3778;
		case 2058: goto tr3779;
		case 2107: goto tr3780;
	}
	goto tr3340;
st1266:
	if ( ++p == pe )
		goto _test_eof1266;
case 1266:
	switch( (*p) ) {
		case 70: goto st1267;
		case 102: goto st1267;
	}
	goto tr3340;
st1267:
	if ( ++p == pe )
		goto _test_eof1267;
case 1267:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr3782;
		case 32: goto tr3782;
		case 40: goto tr3783;
		case 41: goto tr3784;
		case 2058: goto tr3785;
		case 2107: goto tr3786;
	}
	goto tr3340;
st1268:
	if ( ++p == pe )
		goto _test_eof1268;
case 1268:
	switch( (*p) ) {
		case 86: goto st1269;
		case 118: goto st1269;
	}
	goto tr3340;
st1269:
	if ( ++p == pe )
		goto _test_eof1269;
case 1269:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr3788;
		case 32: goto tr3788;
		case 40: goto tr3789;
		case 41: goto tr3790;
		case 2058: goto tr3791;
		case 2107: goto tr3792;
	}
	goto tr3340;
st1270:
	if ( ++p == pe )
		goto _test_eof1270;
case 1270:
	switch( (*p) ) {
		case 72: goto st1271;
		case 104: goto st1271;
	}
	goto tr3340;
st1271:
	if ( ++p == pe )
		goto _test_eof1271;
case 1271:
	switch( (*p) ) {
		case 70: goto st1272;
		case 102: goto st1272;
	}
	goto tr3340;
st1272:
	if ( ++p == pe )
		goto _test_eof1272;
case 1272:
	switch( (*p) ) {
		case 80: goto st1273;
		case 112: goto st1273;
	}
	goto tr3340;
st1273:
	if ( ++p == pe )
		goto _test_eof1273;
case 1273:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr3796;
		case 32: goto tr3796;
		case 40: goto tr3797;
		case 41: goto tr3798;
		case 2058: goto tr3799;
		case 2107: goto tr3800;
	}
	goto tr3340;
st1274:
	if ( ++p == pe )
		goto _test_eof1274;
case 1274:
	switch( (*p) ) {
		case 67: goto st1275;
		case 99: goto st1275;
	}
	goto tr3340;
st1275:
	if ( ++p == pe )
		goto _test_eof1275;
case 1275:
	switch( (*p) ) {
		case 66: goto st1276;
		case 98: goto st1276;
	}
	goto tr3340;
st1276:
	if ( ++p == pe )
		goto _test_eof1276;
case 1276:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr3803;
		case 32: goto tr3803;
		case 40: goto tr3804;
		case 41: goto tr3805;
		case 2058: goto tr3806;
		case 2107: goto tr3807;
	}
	goto tr3340;
st1277:
	if ( ++p == pe )
		goto _test_eof1277;
case 1277:
	switch( (*p) ) {
		case 76: goto st1278;
		case 88: goto st1281;
		case 89: goto st1283;
		case 108: goto st1278;
		case 120: goto st1281;
		case 121: goto st1283;
	}
	goto tr3340;
st1278:
	if ( ++p == pe )
		goto _test_eof1278;
case 1278:
	switch( (*p) ) {
		case 83: goto st1279;
		case 115: goto st1279;
	}
	goto tr3340;
st1279:
	if ( ++p == pe )
		goto _test_eof1279;
case 1279:
	switch( (*p) ) {
		case 65: goto st1280;
		case 97: goto st1280;
	}
	goto tr3340;
st1280:
	if ( ++p == pe )
		goto _test_eof1280;
case 1280:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr3813;
		case 32: goto tr3813;
		case 40: goto tr3814;
		case 41: goto tr3815;
		case 2058: goto tr3816;
		case 2107: goto tr3817;
	}
	goto tr3340;
st1281:
	if ( ++p == pe )
		goto _test_eof1281;
case 1281:
	switch( (*p) ) {
		case 84: goto st1282;
		case 116: goto st1282;
	}
	goto tr3340;
st1282:
	if ( ++p == pe )
		goto _test_eof1282;
case 1282:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr3819;
		case 32: goto tr3819;
		case 40: goto tr3820;
		case 41: goto tr3821;
		case 2058: goto tr3822;
		case 2107: goto tr3823;
	}
	goto tr3340;
st1283:
	if ( ++p == pe )
		goto _test_eof1283;
case 1283:
	switch( (*p) ) {
		case 80: goto st1284;
		case 112: goto st1284;
	}
	goto tr3340;
st1284:
	if ( ++p == pe )
		goto _test_eof1284;
case 1284:
	switch( (*p) ) {
		case 69: goto st1285;
		case 101: goto st1285;
	}
	goto tr3340;
st1285:
	if ( ++p == pe )
		goto _test_eof1285;
case 1285:
	if ( 48 <= (*p) && (*p) <= 57 )
		goto tr3827;
	goto tr3826;
tr3827:
	{
		s->number64 = 0;
	}
	{
		// Overflow check: 10*(s->number64) + fc - '0' <= UINT64_MAX
		if ((s->number64 < (UINT64_MAX / 10)) ||   // Dominant fast check.
			((s->number64 == (UINT64_MAX / 10)) && // Marginal case.
			 ((uint8_t)(*p) <= (UINT64_MAX % 10) + '0')
			)
		   ) {
			s->number64 *= 10;
			s->number64 += digit_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_NUMBER64_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st1286;
tr3831:
	{
		// Overflow check: 10*(s->number64) + fc - '0' <= UINT64_MAX
		if ((s->number64 < (UINT64_MAX / 10)) ||   // Dominant fast check.
			((s->number64 == (UINT64_MAX / 10)) && // Marginal case.
			 ((uint8_t)(*p) <= (UINT64_MAX % 10) + '0')
			)
		   ) {
			s->number64 *= 10;
			s->number64 += digit_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_NUMBER64_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st1286;
st1286:
	if ( ++p == pe )
		goto _test_eof1286;
case 1286:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr3828;
		case 32: goto tr3828;
		case 40: goto tr3829;
		case 41: goto tr3830;
		case 2058: goto tr3832;
		case 2107: goto tr3833;
	}
	if ( 48 <= _widec && _widec <= 57 )
		goto tr3831;
	goto tr3826;
st1287:
	if ( ++p == pe )
		goto _test_eof1287;
case 1287:
	switch( (*p) ) {
		case 82: goto st1288;
		case 114: goto st1288;
	}
	goto tr3340;
st1288:
	if ( ++p == pe )
		goto _test_eof1288;
case 1288:
	switch( (*p) ) {
		case 73: goto st1289;
		case 105: goto st1289;
	}
	goto tr3340;
st1289:
	if ( ++p == pe )
		goto _test_eof1289;
case 1289:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr3836;
		case 32: goto tr3836;
		case 40: goto tr3837;
		case 41: goto tr3838;
		case 2058: goto tr3839;
		case 2107: goto tr3840;
	}
	goto tr3340;
st1290:
	if ( ++p == pe )
		goto _test_eof1290;
case 1290:
	switch( (*p) ) {
		case 65: goto st1291;
		case 97: goto st1291;
	}
	goto tr3340;
st1291:
	if ( ++p == pe )
		goto _test_eof1291;
case 1291:
	switch( (*p) ) {
		case 76: goto st1292;
		case 108: goto st1292;
	}
	goto tr3340;
st1292:
	if ( ++p == pe )
		goto _test_eof1292;
case 1292:
	switch( (*p) ) {
		case 76: goto st1293;
		case 108: goto st1293;
	}
	goto tr3340;
st1293:
	if ( ++p == pe )
		goto _test_eof1293;
case 1293:
	switch( (*p) ) {
		case 69: goto st1294;
		case 101: goto st1294;
	}
	goto tr3340;
st1294:
	if ( ++p == pe )
		goto _test_eof1294;
case 1294:
	switch( (*p) ) {
		case 84: goto st1295;
		case 116: goto st1295;
	}
	goto tr3340;
st1295:
	if ( ++p == pe )
		goto _test_eof1295;
case 1295:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr3846;
		case 32: goto tr3846;
		case 40: goto tr3847;
		case 41: goto tr3848;
		case 2058: goto tr3849;
		case 2107: goto tr3850;
	}
	goto tr3340;
st1296:
	if ( ++p == pe )
		goto _test_eof1296;
case 1296:
	switch( (*p) ) {
		case 79: goto st1297;
		case 111: goto st1297;
	}
	goto tr3340;
st1297:
	if ( ++p == pe )
		goto _test_eof1297;
case 1297:
	switch( (*p) ) {
		case 78: goto st1298;
		case 110: goto st1298;
	}
	goto tr3340;
st1298:
	if ( ++p == pe )
		goto _test_eof1298;
case 1298:
	switch( (*p) ) {
		case 69: goto st1299;
		case 101: goto st1299;
	}
	goto tr3340;
st1299:
	if ( ++p == pe )
		goto _test_eof1299;
case 1299:
	switch( (*p) ) {
		case 77: goto st1300;
		case 109: goto st1300;
	}
	goto tr3340;
st1300:
	if ( ++p == pe )
		goto _test_eof1300;
case 1300:
	switch( (*p) ) {
		case 68: goto st1301;
		case 100: goto st1301;
	}
	goto tr3340;
st1301:
	if ( ++p == pe )
		goto _test_eof1301;
case 1301:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr3856;
		case 32: goto tr3856;
		case 40: goto tr3857;
		case 41: goto tr3858;
		case 2058: goto tr3859;
		case 2107: goto tr3860;
	}
	goto tr3340;
st1302:
	if ( ++p == pe )
		goto _test_eof1302;
case 1302:
	switch( (*p) ) {
		case 42: goto tr3861;
		case 92: goto tr3861;
		case 95: goto tr3861;
	}
	if ( (*p) < 64 ) {
		if ( 45 <= (*p) && (*p) <= 57 )
			goto tr3861;
	} else if ( (*p) > 90 ) {
		if ( 97 <= (*p) && (*p) <= 122 )
			goto tr3861;
	} else
		goto tr3861;
	goto tr77;
tr3861:
	{
		s->dname = rdata_tail;
	}
	{ p--; {stack[top++] = 1303;goto st318;} }
	goto st1303;
st1303:
	if ( ++p == pe )
		goto _test_eof1303;
case 1303:
	switch( (*p) ) {
		case 32: goto tr3862;
		case 59: goto tr3862;
	}
	if ( (*p) > 10 ) {
		if ( 40 <= (*p) && (*p) <= 41 )
			goto tr3862;
	} else if ( (*p) >= 9 )
		goto tr3862;
	goto tr77;
tr3862:
	{
		rdata_tail += s->dname_tmp_length;
	}
	{ p--; {stack[top++] = 1304;goto st385;} }
	goto st1304;
st1304:
	if ( ++p == pe )
		goto _test_eof1304;
case 1304:
	switch( (*p) ) {
		case 32: goto tr3863;
		case 59: goto tr3863;
	}
	if ( (*p) > 10 ) {
		if ( 40 <= (*p) && (*p) <= 41 )
			goto tr3863;
	} else if ( (*p) >= 9 )
		goto tr3863;
	goto tr77;
tr3863:
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1522;
st1522:
	if ( ++p == pe )
		goto _test_eof1522;
case 1522:
	goto st0;
st1305:
	if ( ++p == pe )
		goto _test_eof1305;
case 1305:
	if ( 48 <= (*p) && (*p) <= 57 )
		goto tr3864;
	goto tr2396;
tr3864:
	{
		s->number64 = 0;
	}
	{
		// Overflow check: 10*(s->number64) + fc - '0' <= UINT64_MAX
		if ((s->number64 < (UINT64_MAX / 10)) ||   // Dominant fast check.
			((s->number64 == (UINT64_MAX / 10)) && // Marginal case.
			 ((uint8_t)(*p) <= (UINT64_MAX % 10) + '0')
			)
		   ) {
			s->number64 *= 10;
			s->number64 += digit_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_NUMBER64_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st1306;
tr3868:
	{
		// Overflow check: 10*(s->number64) + fc - '0' <= UINT64_MAX
		if ((s->number64 < (UINT64_MAX / 10)) ||   // Dominant fast check.
			((s->number64 == (UINT64_MAX / 10)) && // Marginal case.
			 ((uint8_t)(*p) <= (UINT64_MAX % 10) + '0')
			)
		   ) {
			s->number64 *= 10;
			s->number64 += digit_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_NUMBER64_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st1306;
st1306:
	if ( ++p == pe )
		goto _test_eof1306;
case 1306:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr3865;
		case 32: goto tr3865;
		case 40: goto tr3866;
		case 41: goto tr3867;
		case 2058: goto tr3869;
		case 2107: goto tr3870;
	}
	if ( 48 <= _widec && _widec <= 57 )
		goto tr3868;
	goto tr2396;
tr3872:
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st1307;
tr3873:
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st1307;
tr3875:
	{
		s->line_counter++;
	}
	goto st1307;
tr3901:
	{
		s->buffer[s->buffer_length++] = 0;

		// Execute the comment callback.
		if (s->process.automatic && s->process.comment != NULL) {
			s->process.comment(s);

			// Stop if required from the callback.
			if (s->state == ZS_STATE_STOP) {
				{p++; cs = 1307; goto _out;}
			}
		}
	}
	{
		s->line_counter++;
	}
	goto st1307;
tr3865:
	{
		if (s->number64 <= UINT16_MAX) {
			uint16_t num16 = htons((uint16_t)s->number64);
			memcpy(rdata_tail, &num16, 2);
			rdata_tail += 2;
		} else {
			WARN(ZS_NUMBER16_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st1307;
tr3866:
	{
		if (s->number64 <= UINT16_MAX) {
			uint16_t num16 = htons((uint16_t)s->number64);
			memcpy(rdata_tail, &num16, 2);
			rdata_tail += 2;
		} else {
			WARN(ZS_NUMBER16_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st1307;
tr3867:
	{
		if (s->number64 <= UINT16_MAX) {
			uint16_t num16 = htons((uint16_t)s->number64);
			memcpy(rdata_tail, &num16, 2);
			rdata_tail += 2;
		} else {
			WARN(ZS_NUMBER16_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st1307;
tr3869:
	{
		if (s->number64 <= UINT16_MAX) {
			uint16_t num16 = htons((uint16_t)s->number64);
			memcpy(rdata_tail, &num16, 2);
			rdata_tail += 2;
		} else {
			WARN(ZS_NUMBER16_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		s->line_counter++;
	}
	goto st1307;
st1307:
	if ( ++p == pe )
		goto _test_eof1307;
case 1307:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto st1307;
		case 32: goto st1307;
		case 40: goto tr3872;
		case 41: goto tr3873;
		case 2058: goto tr3875;
		case 2107: goto tr3876;
	}
	if ( 48 <= _widec && _widec <= 57 )
		goto tr3874;
	goto tr2396;
tr3874:
	{
		s->number64 = 0;
	}
	{
		// Overflow check: 10*(s->number64) + fc - '0' <= UINT64_MAX
		if ((s->number64 < (UINT64_MAX / 10)) ||   // Dominant fast check.
			((s->number64 == (UINT64_MAX / 10)) && // Marginal case.
			 ((uint8_t)(*p) <= (UINT64_MAX % 10) + '0')
			)
		   ) {
			s->number64 *= 10;
			s->number64 += digit_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_NUMBER64_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st1308;
tr3880:
	{
		// Overflow check: 10*(s->number64) + fc - '0' <= UINT64_MAX
		if ((s->number64 < (UINT64_MAX / 10)) ||   // Dominant fast check.
			((s->number64 == (UINT64_MAX / 10)) && // Marginal case.
			 ((uint8_t)(*p) <= (UINT64_MAX % 10) + '0')
			)
		   ) {
			s->number64 *= 10;
			s->number64 += digit_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_NUMBER64_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st1308;
st1308:
	if ( ++p == pe )
		goto _test_eof1308;
case 1308:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr3877;
		case 32: goto tr3877;
		case 40: goto tr3878;
		case 41: goto tr3879;
		case 2058: goto tr3881;
		case 2107: goto tr3882;
	}
	if ( 48 <= _widec && _widec <= 57 )
		goto tr3880;
	goto tr2396;
tr3884:
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st1309;
tr3885:
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st1309;
tr3887:
	{
		s->line_counter++;
	}
	goto st1309;
tr3899:
	{
		s->buffer[s->buffer_length++] = 0;

		// Execute the comment callback.
		if (s->process.automatic && s->process.comment != NULL) {
			s->process.comment(s);

			// Stop if required from the callback.
			if (s->state == ZS_STATE_STOP) {
				{p++; cs = 1309; goto _out;}
			}
		}
	}
	{
		s->line_counter++;
	}
	goto st1309;
tr3877:
	{
		if (s->number64 <= UINT8_MAX) {
			*rdata_tail = (uint8_t)(s->number64);
			rdata_tail += 1;
		} else {
			WARN(ZS_NUMBER8_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st1309;
tr3878:
	{
		if (s->number64 <= UINT8_MAX) {
			*rdata_tail = (uint8_t)(s->number64);
			rdata_tail += 1;
		} else {
			WARN(ZS_NUMBER8_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st1309;
tr3879:
	{
		if (s->number64 <= UINT8_MAX) {
			*rdata_tail = (uint8_t)(s->number64);
			rdata_tail += 1;
		} else {
			WARN(ZS_NUMBER8_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st1309;
tr3881:
	{
		if (s->number64 <= UINT8_MAX) {
			*rdata_tail = (uint8_t)(s->number64);
			rdata_tail += 1;
		} else {
			WARN(ZS_NUMBER8_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		s->line_counter++;
	}
	goto st1309;
st1309:
	if ( ++p == pe )
		goto _test_eof1309;
case 1309:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto st1309;
		case 32: goto st1309;
		case 40: goto tr3884;
		case 41: goto tr3885;
		case 2058: goto tr3887;
		case 2107: goto tr3888;
	}
	if ( _widec < 65 ) {
		if ( 48 <= _widec && _widec <= 57 )
			goto tr3886;
	} else if ( _widec > 90 ) {
		if ( 97 <= _widec && _widec <= 122 )
			goto tr3886;
	} else
		goto tr3886;
	goto tr77;
tr3886:
	{ p--; {stack[top++] = 1310;goto st741;} }
	goto st1310;
st1310:
	if ( ++p == pe )
		goto _test_eof1310;
case 1310:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto st1311;
		case 32: goto st1311;
		case 40: goto tr3890;
		case 41: goto tr3891;
		case 2058: goto tr3892;
		case 2107: goto tr3893;
	}
	goto tr77;
tr3890:
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st1311;
tr3891:
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st1311;
tr3892:
	{
		s->line_counter++;
	}
	goto st1311;
tr3897:
	{
		s->buffer[s->buffer_length++] = 0;

		// Execute the comment callback.
		if (s->process.automatic && s->process.comment != NULL) {
			s->process.comment(s);

			// Stop if required from the callback.
			if (s->state == ZS_STATE_STOP) {
				{p++; cs = 1311; goto _out;}
			}
		}
	}
	{
		s->line_counter++;
	}
	goto st1311;
st1311:
	if ( ++p == pe )
		goto _test_eof1311;
case 1311:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto st1311;
		case 32: goto st1311;
		case 40: goto tr3890;
		case 41: goto tr3891;
		case 43: goto tr3894;
		case 2058: goto tr3892;
		case 2107: goto tr3893;
	}
	if ( _widec < 65 ) {
		if ( 47 <= _widec && _widec <= 57 )
			goto tr3894;
	} else if ( _widec > 90 ) {
		if ( 97 <= _widec && _widec <= 122 )
			goto tr3894;
	} else
		goto tr3894;
	goto tr77;
tr3894:
	{ p--; {stack[top++] = 1312;goto st378;} }
	goto st1312;
st1312:
	if ( ++p == pe )
		goto _test_eof1312;
case 1312:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(2176 + ((*p) - -128));
			if (
 !s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(2176 + ((*p) - -128));
		if (
 !s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 2570: goto tr3895;
		case 2619: goto tr3895;
	}
	goto tr77;
tr3895:
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1523;
st1523:
	if ( ++p == pe )
		goto _test_eof1523;
case 1523:
	goto st0;
tr3893:
	{
		s->buffer_length = 0;
	}
	goto st1313;
tr3896:
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		}
	}
	goto st1313;
st1313:
	if ( ++p == pe )
		goto _test_eof1313;
case 1313:
	_widec = (*p);
	if ( (*p) < 10 ) {
		if ( (*p) <= 9 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) > 10 ) {
		if ( 11 <= (*p) )
 {			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	if ( _widec == 2058 )
		goto tr3897;
	if ( 1920 <= _widec && _widec <= 2175 )
		goto tr3896;
	goto tr77;
tr3888:
	{
		s->buffer_length = 0;
	}
	goto st1314;
tr3898:
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		}
	}
	goto st1314;
tr3882:
	{
		if (s->number64 <= UINT8_MAX) {
			*rdata_tail = (uint8_t)(s->number64);
			rdata_tail += 1;
		} else {
			WARN(ZS_NUMBER8_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		s->buffer_length = 0;
	}
	goto st1314;
st1314:
	if ( ++p == pe )
		goto _test_eof1314;
case 1314:
	_widec = (*p);
	if ( (*p) < 10 ) {
		if ( (*p) <= 9 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) > 10 ) {
		if ( 11 <= (*p) )
 {			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	if ( _widec == 2058 )
		goto tr3899;
	if ( 1920 <= _widec && _widec <= 2175 )
		goto tr3898;
	goto tr77;
tr3876:
	{
		s->buffer_length = 0;
	}
	goto st1315;
tr3900:
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		}
	}
	goto st1315;
tr3870:
	{
		if (s->number64 <= UINT16_MAX) {
			uint16_t num16 = htons((uint16_t)s->number64);
			memcpy(rdata_tail, &num16, 2);
			rdata_tail += 2;
		} else {
			WARN(ZS_NUMBER16_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		s->buffer_length = 0;
	}
	goto st1315;
st1315:
	if ( ++p == pe )
		goto _test_eof1315;
case 1315:
	_widec = (*p);
	if ( (*p) < 10 ) {
		if ( (*p) <= 9 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) > 10 ) {
		if ( 11 <= (*p) )
 {			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	if ( _widec == 2058 )
		goto tr3901;
	if ( 1920 <= _widec && _widec <= 2175 )
		goto tr3900;
	goto tr77;
st1316:
	if ( ++p == pe )
		goto _test_eof1316;
case 1316:
	if ( (*p) == 43 )
		goto tr3902;
	if ( (*p) < 65 ) {
		if ( 47 <= (*p) && (*p) <= 57 )
			goto tr3902;
	} else if ( (*p) > 90 ) {
		if ( 97 <= (*p) && (*p) <= 122 )
			goto tr3902;
	} else
		goto tr3902;
	goto tr77;
tr3902:
	{ p--; {stack[top++] = 1317;goto st378;} }
	goto st1317;
st1317:
	if ( ++p == pe )
		goto _test_eof1317;
case 1317:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(2176 + ((*p) - -128));
			if (
 !s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(2176 + ((*p) - -128));
		if (
 !s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 2570: goto tr3903;
		case 2619: goto tr3903;
	}
	goto tr77;
tr3903:
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1524;
st1524:
	if ( ++p == pe )
		goto _test_eof1524;
case 1524:
	goto st0;
st1318:
	if ( ++p == pe )
		goto _test_eof1318;
case 1318:
	if ( 48 <= (*p) && (*p) <= 57 )
		goto tr3904;
	goto tr2396;
tr3904:
	{
		s->number64 = 0;
	}
	{
		// Overflow check: 10*(s->number64) + fc - '0' <= UINT64_MAX
		if ((s->number64 < (UINT64_MAX / 10)) ||   // Dominant fast check.
			((s->number64 == (UINT64_MAX / 10)) && // Marginal case.
			 ((uint8_t)(*p) <= (UINT64_MAX % 10) + '0')
			)
		   ) {
			s->number64 *= 10;
			s->number64 += digit_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_NUMBER64_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st1319;
tr3908:
	{
		// Overflow check: 10*(s->number64) + fc - '0' <= UINT64_MAX
		if ((s->number64 < (UINT64_MAX / 10)) ||   // Dominant fast check.
			((s->number64 == (UINT64_MAX / 10)) && // Marginal case.
			 ((uint8_t)(*p) <= (UINT64_MAX % 10) + '0')
			)
		   ) {
			s->number64 *= 10;
			s->number64 += digit_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_NUMBER64_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st1319;
st1319:
	if ( ++p == pe )
		goto _test_eof1319;
case 1319:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr3905;
		case 32: goto tr3905;
		case 40: goto tr3906;
		case 41: goto tr3907;
		case 2058: goto tr3909;
		case 2107: goto tr3910;
	}
	if ( 48 <= _widec && _widec <= 57 )
		goto tr3908;
	goto tr2396;
tr3912:
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st1320;
tr3913:
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st1320;
tr3915:
	{
		s->line_counter++;
	}
	goto st1320;
tr3979:
	{
		s->buffer[s->buffer_length++] = 0;

		// Execute the comment callback.
		if (s->process.automatic && s->process.comment != NULL) {
			s->process.comment(s);

			// Stop if required from the callback.
			if (s->state == ZS_STATE_STOP) {
				{p++; cs = 1320; goto _out;}
			}
		}
	}
	{
		s->line_counter++;
	}
	goto st1320;
tr3905:
	{
		if (s->number64 <= UINT8_MAX) {
			*rdata_tail = (uint8_t)(s->number64);
			rdata_tail += 1;
		} else {
			WARN(ZS_NUMBER8_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st1320;
tr3906:
	{
		if (s->number64 <= UINT8_MAX) {
			*rdata_tail = (uint8_t)(s->number64);
			rdata_tail += 1;
		} else {
			WARN(ZS_NUMBER8_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st1320;
tr3907:
	{
		if (s->number64 <= UINT8_MAX) {
			*rdata_tail = (uint8_t)(s->number64);
			rdata_tail += 1;
		} else {
			WARN(ZS_NUMBER8_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st1320;
tr3909:
	{
		if (s->number64 <= UINT8_MAX) {
			*rdata_tail = (uint8_t)(s->number64);
			rdata_tail += 1;
		} else {
			WARN(ZS_NUMBER8_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		s->line_counter++;
	}
	goto st1320;
st1320:
	if ( ++p == pe )
		goto _test_eof1320;
case 1320:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto st1320;
		case 32: goto st1320;
		case 40: goto tr3912;
		case 41: goto tr3913;
		case 2058: goto tr3915;
		case 2107: goto tr3916;
	}
	if ( 48 <= _widec && _widec <= 57 )
		goto tr3914;
	goto tr2396;
tr3914:
	{
		s->number64 = 0;
	}
	{
		// Overflow check: 10*(s->number64) + fc - '0' <= UINT64_MAX
		if ((s->number64 < (UINT64_MAX / 10)) ||   // Dominant fast check.
			((s->number64 == (UINT64_MAX / 10)) && // Marginal case.
			 ((uint8_t)(*p) <= (UINT64_MAX % 10) + '0')
			)
		   ) {
			s->number64 *= 10;
			s->number64 += digit_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_NUMBER64_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st1321;
tr3920:
	{
		// Overflow check: 10*(s->number64) + fc - '0' <= UINT64_MAX
		if ((s->number64 < (UINT64_MAX / 10)) ||   // Dominant fast check.
			((s->number64 == (UINT64_MAX / 10)) && // Marginal case.
			 ((uint8_t)(*p) <= (UINT64_MAX % 10) + '0')
			)
		   ) {
			s->number64 *= 10;
			s->number64 += digit_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_NUMBER64_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st1321;
st1321:
	if ( ++p == pe )
		goto _test_eof1321;
case 1321:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr3917;
		case 32: goto tr3917;
		case 40: goto tr3918;
		case 41: goto tr3919;
		case 2058: goto tr3921;
		case 2107: goto tr3922;
	}
	if ( 48 <= _widec && _widec <= 57 )
		goto tr3920;
	goto tr2396;
tr3924:
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st1322;
tr3925:
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st1322;
tr3927:
	{
		s->line_counter++;
	}
	goto st1322;
tr3977:
	{
		s->buffer[s->buffer_length++] = 0;

		// Execute the comment callback.
		if (s->process.automatic && s->process.comment != NULL) {
			s->process.comment(s);

			// Stop if required from the callback.
			if (s->state == ZS_STATE_STOP) {
				{p++; cs = 1322; goto _out;}
			}
		}
	}
	{
		s->line_counter++;
	}
	goto st1322;
tr3917:
	{
		if (s->number64 <= UINT8_MAX) {
			*rdata_tail = (uint8_t)(s->number64);
			rdata_tail += 1;
		} else {
			WARN(ZS_NUMBER8_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st1322;
tr3918:
	{
		if (s->number64 <= UINT8_MAX) {
			*rdata_tail = (uint8_t)(s->number64);
			rdata_tail += 1;
		} else {
			WARN(ZS_NUMBER8_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st1322;
tr3919:
	{
		if (s->number64 <= UINT8_MAX) {
			*rdata_tail = (uint8_t)(s->number64);
			rdata_tail += 1;
		} else {
			WARN(ZS_NUMBER8_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st1322;
tr3921:
	{
		if (s->number64 <= UINT8_MAX) {
			*rdata_tail = (uint8_t)(s->number64);
			rdata_tail += 1;
		} else {
			WARN(ZS_NUMBER8_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		s->line_counter++;
	}
	goto st1322;
st1322:
	if ( ++p == pe )
		goto _test_eof1322;
case 1322:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto st1322;
		case 32: goto st1322;
		case 40: goto tr3924;
		case 41: goto tr3925;
		case 2058: goto tr3927;
		case 2107: goto tr3928;
	}
	if ( 48 <= _widec && _widec <= 57 )
		goto tr3926;
	goto tr2396;
tr3926:
	{
		s->number64 = 0;
	}
	{
		// Overflow check: 10*(s->number64) + fc - '0' <= UINT64_MAX
		if ((s->number64 < (UINT64_MAX / 10)) ||   // Dominant fast check.
			((s->number64 == (UINT64_MAX / 10)) && // Marginal case.
			 ((uint8_t)(*p) <= (UINT64_MAX % 10) + '0')
			)
		   ) {
			s->number64 *= 10;
			s->number64 += digit_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_NUMBER64_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st1323;
tr3932:
	{
		// Overflow check: 10*(s->number64) + fc - '0' <= UINT64_MAX
		if ((s->number64 < (UINT64_MAX / 10)) ||   // Dominant fast check.
			((s->number64 == (UINT64_MAX / 10)) && // Marginal case.
			 ((uint8_t)(*p) <= (UINT64_MAX % 10) + '0')
			)
		   ) {
			s->number64 *= 10;
			s->number64 += digit_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_NUMBER64_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st1323;
st1323:
	if ( ++p == pe )
		goto _test_eof1323;
case 1323:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr3929;
		case 32: goto tr3929;
		case 40: goto tr3930;
		case 41: goto tr3931;
		case 2058: goto tr3933;
		case 2107: goto tr3934;
	}
	if ( 48 <= _widec && _widec <= 57 )
		goto tr3932;
	goto tr2396;
tr3936:
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st1324;
tr3937:
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st1324;
tr3940:
	{
		s->line_counter++;
	}
	goto st1324;
tr3975:
	{
		s->buffer[s->buffer_length++] = 0;

		// Execute the comment callback.
		if (s->process.automatic && s->process.comment != NULL) {
			s->process.comment(s);

			// Stop if required from the callback.
			if (s->state == ZS_STATE_STOP) {
				{p++; cs = 1324; goto _out;}
			}
		}
	}
	{
		s->line_counter++;
	}
	goto st1324;
tr3929:
	{
		if (s->number64 <= UINT16_MAX) {
			uint16_t num16 = htons((uint16_t)s->number64);
			memcpy(rdata_tail, &num16, 2);
			rdata_tail += 2;
		} else {
			WARN(ZS_NUMBER16_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st1324;
tr3930:
	{
		if (s->number64 <= UINT16_MAX) {
			uint16_t num16 = htons((uint16_t)s->number64);
			memcpy(rdata_tail, &num16, 2);
			rdata_tail += 2;
		} else {
			WARN(ZS_NUMBER16_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st1324;
tr3931:
	{
		if (s->number64 <= UINT16_MAX) {
			uint16_t num16 = htons((uint16_t)s->number64);
			memcpy(rdata_tail, &num16, 2);
			rdata_tail += 2;
		} else {
			WARN(ZS_NUMBER16_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st1324;
tr3933:
	{
		if (s->number64 <= UINT16_MAX) {
			uint16_t num16 = htons((uint16_t)s->number64);
			memcpy(rdata_tail, &num16, 2);
			rdata_tail += 2;
		} else {
			WARN(ZS_NUMBER16_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		s->line_counter++;
	}
	goto st1324;
st1324:
	if ( ++p == pe )
		goto _test_eof1324;
case 1324:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto st1324;
		case 32: goto st1324;
		case 40: goto tr3936;
		case 41: goto tr3937;
		case 45: goto tr3938;
		case 2058: goto tr3940;
		case 2107: goto tr3941;
	}
	if ( _widec < 65 ) {
		if ( 48 <= _widec && _widec <= 57 )
			goto tr3939;
	} else if ( _widec > 70 ) {
		if ( 97 <= _widec && _widec <= 102 )
			goto tr3939;
	} else
		goto tr3939;
	goto tr3067;
tr3938:
	{
		if (rdata_tail <= rdata_stop) {
			s->item_length_location = rdata_tail++;
		} else {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st1325;
st1325:
	if ( ++p == pe )
		goto _test_eof1325;
case 1325:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr3942;
		case 32: goto tr3942;
		case 40: goto tr3943;
		case 41: goto tr3944;
		case 2058: goto tr3945;
		case 2107: goto tr3946;
	}
	goto tr3067;
tr3949:
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st1326;
tr3950:
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st1326;
tr3952:
	{
		s->line_counter++;
	}
	goto st1326;
tr3971:
	{
		s->buffer[s->buffer_length++] = 0;

		// Execute the comment callback.
		if (s->process.automatic && s->process.comment != NULL) {
			s->process.comment(s);

			// Stop if required from the callback.
			if (s->state == ZS_STATE_STOP) {
				{p++; cs = 1326; goto _out;}
			}
		}
	}
	{
		s->line_counter++;
	}
	goto st1326;
tr3942:
	{
		s->item_length = rdata_tail - s->item_length_location - 1;
		if (s->comma_list && s->item_length == 0) {
			WARN(ZS_EMPTY_LIST_ITEM);
			p--; {goto st316;}
		}
		if (s->item_length <= MAX_ITEM_LENGTH) {
			*(s->item_length_location) = (uint8_t)(s->item_length);
		} else {
			WARN(ZS_ITEM_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st1326;
tr3943:
	{
		s->item_length = rdata_tail - s->item_length_location - 1;
		if (s->comma_list && s->item_length == 0) {
			WARN(ZS_EMPTY_LIST_ITEM);
			p--; {goto st316;}
		}
		if (s->item_length <= MAX_ITEM_LENGTH) {
			*(s->item_length_location) = (uint8_t)(s->item_length);
		} else {
			WARN(ZS_ITEM_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st1326;
tr3944:
	{
		s->item_length = rdata_tail - s->item_length_location - 1;
		if (s->comma_list && s->item_length == 0) {
			WARN(ZS_EMPTY_LIST_ITEM);
			p--; {goto st316;}
		}
		if (s->item_length <= MAX_ITEM_LENGTH) {
			*(s->item_length_location) = (uint8_t)(s->item_length);
		} else {
			WARN(ZS_ITEM_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st1326;
tr3945:
	{
		s->item_length = rdata_tail - s->item_length_location - 1;
		if (s->comma_list && s->item_length == 0) {
			WARN(ZS_EMPTY_LIST_ITEM);
			p--; {goto st316;}
		}
		if (s->item_length <= MAX_ITEM_LENGTH) {
			*(s->item_length_location) = (uint8_t)(s->item_length);
		} else {
			WARN(ZS_ITEM_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		s->line_counter++;
	}
	goto st1326;
st1326:
	if ( ++p == pe )
		goto _test_eof1326;
case 1326:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto st1326;
		case 32: goto st1326;
		case 40: goto tr3949;
		case 41: goto tr3950;
		case 2058: goto tr3952;
		case 2107: goto tr3953;
	}
	if ( _widec < 65 ) {
		if ( 48 <= _widec && _widec <= 57 )
			goto tr3951;
	} else if ( _widec > 86 ) {
		if ( 97 <= _widec && _widec <= 118 )
			goto tr3951;
	} else
		goto tr3951;
	goto tr3947;
tr3951:
	{
		if (rdata_tail <= rdata_stop) {
			s->item_length_location = rdata_tail++;
		} else {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (rdata_tail <= rdata_stop) {
			*rdata_tail = first_base32hex_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st1327;
tr3966:
	{
		if (rdata_tail <= rdata_stop) {
			*rdata_tail = first_base32hex_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st1327;
st1327:
	if ( ++p == pe )
		goto _test_eof1327;
case 1327:
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr3954;
	} else if ( (*p) > 86 ) {
		if ( 97 <= (*p) && (*p) <= 118 )
			goto tr3954;
	} else
		goto tr3954;
	goto tr3947;
tr3954:
	{
		*(rdata_tail++) += second_left_base32hex_to_num[(uint8_t)(*p)];

		if (rdata_tail <= rdata_stop) {
			*rdata_tail = second_right_base32hex_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st1328;
st1328:
	if ( ++p == pe )
		goto _test_eof1328;
case 1328:
	if ( (*p) == 61 )
		goto st1339;
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr3955;
	} else if ( (*p) > 86 ) {
		if ( 97 <= (*p) && (*p) <= 118 )
			goto tr3955;
	} else
		goto tr3955;
	goto tr3947;
tr3955:
	{
		*rdata_tail += third_base32hex_to_num[(uint8_t)(*p)];
	}
	goto st1329;
st1329:
	if ( ++p == pe )
		goto _test_eof1329;
case 1329:
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr3957;
	} else if ( (*p) > 86 ) {
		if ( 97 <= (*p) && (*p) <= 118 )
			goto tr3957;
	} else
		goto tr3957;
	goto tr3947;
tr3957:
	{
		*(rdata_tail++) += fourth_left_base32hex_to_num[(uint8_t)(*p)];

		if (rdata_tail <= rdata_stop) {
			*rdata_tail = fourth_right_base32hex_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st1330;
st1330:
	if ( ++p == pe )
		goto _test_eof1330;
case 1330:
	if ( (*p) == 61 )
		goto st1338;
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr3958;
	} else if ( (*p) > 86 ) {
		if ( 97 <= (*p) && (*p) <= 118 )
			goto tr3958;
	} else
		goto tr3958;
	goto tr3947;
tr3958:
	{
		*(rdata_tail++) += fifth_left_base32hex_to_num[(uint8_t)(*p)];

		if (rdata_tail <= rdata_stop) {
			*rdata_tail = fifth_right_base32hex_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st1331;
st1331:
	if ( ++p == pe )
		goto _test_eof1331;
case 1331:
	if ( (*p) == 61 )
		goto st1336;
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr3960;
	} else if ( (*p) > 86 ) {
		if ( 97 <= (*p) && (*p) <= 118 )
			goto tr3960;
	} else
		goto tr3960;
	goto tr3947;
tr3960:
	{
		*rdata_tail += sixth_base32hex_to_num[(uint8_t)(*p)];
	}
	goto st1332;
st1332:
	if ( ++p == pe )
		goto _test_eof1332;
case 1332:
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr3962;
	} else if ( (*p) > 86 ) {
		if ( 97 <= (*p) && (*p) <= 118 )
			goto tr3962;
	} else
		goto tr3962;
	goto tr3947;
tr3962:
	{
		*(rdata_tail++) += seventh_left_base32hex_to_num[(uint8_t)(*p)];

		if (rdata_tail <= rdata_stop) {
			*rdata_tail = seventh_right_base32hex_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st1333;
st1333:
	if ( ++p == pe )
		goto _test_eof1333;
case 1333:
	if ( (*p) == 61 )
		goto st1334;
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr3963;
	} else if ( (*p) > 86 ) {
		if ( 97 <= (*p) && (*p) <= 118 )
			goto tr3963;
	} else
		goto tr3963;
	goto tr3947;
tr3963:
	{
		*(rdata_tail++) += eighth_base32hex_to_num[(uint8_t)(*p)];
	}
	goto st1334;
st1334:
	if ( ++p == pe )
		goto _test_eof1334;
case 1334:
	switch( (*p) ) {
		case 32: goto tr3965;
		case 59: goto tr3965;
	}
	if ( (*p) < 48 ) {
		if ( (*p) > 10 ) {
			if ( 40 <= (*p) && (*p) <= 41 )
				goto tr3965;
		} else if ( (*p) >= 9 )
			goto tr3965;
	} else if ( (*p) > 57 ) {
		if ( (*p) > 86 ) {
			if ( 97 <= (*p) && (*p) <= 118 )
				goto tr3966;
		} else if ( (*p) >= 65 )
			goto tr3966;
	} else
		goto tr3966;
	goto tr3947;
tr3965:
	{
		s->item_length = rdata_tail - s->item_length_location - 1;
		if (s->comma_list && s->item_length == 0) {
			WARN(ZS_EMPTY_LIST_ITEM);
			p--; {goto st316;}
		}
		if (s->item_length <= MAX_ITEM_LENGTH) {
			*(s->item_length_location) = (uint8_t)(s->item_length);
		} else {
			WARN(ZS_ITEM_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{ p--; {stack[top++] = 1335;goto st385;} }
	goto st1335;
st1335:
	if ( ++p == pe )
		goto _test_eof1335;
case 1335:
	switch( (*p) ) {
		case 32: goto tr3967;
		case 59: goto tr3967;
	}
	if ( (*p) > 10 ) {
		if ( 40 <= (*p) && (*p) <= 41 )
			goto tr3967;
	} else if ( (*p) >= 9 )
		goto tr3967;
	goto tr77;
tr3967:
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1525;
st1525:
	if ( ++p == pe )
		goto _test_eof1525;
case 1525:
	goto st0;
st1336:
	if ( ++p == pe )
		goto _test_eof1336;
case 1336:
	if ( (*p) == 61 )
		goto st1337;
	goto tr3947;
st1337:
	if ( ++p == pe )
		goto _test_eof1337;
case 1337:
	if ( (*p) == 61 )
		goto st1334;
	goto tr3947;
st1338:
	if ( ++p == pe )
		goto _test_eof1338;
case 1338:
	if ( (*p) == 61 )
		goto st1336;
	goto tr3947;
st1339:
	if ( ++p == pe )
		goto _test_eof1339;
case 1339:
	if ( (*p) == 61 )
		goto st1340;
	goto tr3947;
st1340:
	if ( ++p == pe )
		goto _test_eof1340;
case 1340:
	if ( (*p) == 61 )
		goto st1338;
	goto tr3947;
tr3953:
	{
		s->buffer_length = 0;
	}
	goto st1341;
tr3970:
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		}
	}
	goto st1341;
tr3946:
	{
		s->item_length = rdata_tail - s->item_length_location - 1;
		if (s->comma_list && s->item_length == 0) {
			WARN(ZS_EMPTY_LIST_ITEM);
			p--; {goto st316;}
		}
		if (s->item_length <= MAX_ITEM_LENGTH) {
			*(s->item_length_location) = (uint8_t)(s->item_length);
		} else {
			WARN(ZS_ITEM_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		s->buffer_length = 0;
	}
	goto st1341;
st1341:
	if ( ++p == pe )
		goto _test_eof1341;
case 1341:
	_widec = (*p);
	if ( (*p) < 10 ) {
		if ( (*p) <= 9 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) > 10 ) {
		if ( 11 <= (*p) )
 {			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	if ( _widec == 2058 )
		goto tr3971;
	if ( 1920 <= _widec && _widec <= 2175 )
		goto tr3970;
	goto tr77;
tr3973:
	{
		if (rdata_tail <= rdata_stop) {
			*rdata_tail = first_hex_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st1342;
tr3939:
	{
		if (rdata_tail <= rdata_stop) {
			s->item_length_location = rdata_tail++;
		} else {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (rdata_tail <= rdata_stop) {
			*rdata_tail = first_hex_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st1342;
st1342:
	if ( ++p == pe )
		goto _test_eof1342;
case 1342:
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr3972;
	} else if ( (*p) > 70 ) {
		if ( 97 <= (*p) && (*p) <= 102 )
			goto tr3972;
	} else
		goto tr3972;
	goto tr3067;
tr3972:
	{
		*rdata_tail += second_hex_to_num[(uint8_t)(*p)];
		rdata_tail++;
	}
	goto st1343;
st1343:
	if ( ++p == pe )
		goto _test_eof1343;
case 1343:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr3942;
		case 32: goto tr3942;
		case 40: goto tr3943;
		case 41: goto tr3944;
		case 2058: goto tr3945;
		case 2107: goto tr3946;
	}
	if ( _widec < 65 ) {
		if ( 48 <= _widec && _widec <= 57 )
			goto tr3973;
	} else if ( _widec > 70 ) {
		if ( 97 <= _widec && _widec <= 102 )
			goto tr3973;
	} else
		goto tr3973;
	goto tr3067;
tr3941:
	{
		s->buffer_length = 0;
	}
	goto st1344;
tr3974:
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		}
	}
	goto st1344;
tr3934:
	{
		if (s->number64 <= UINT16_MAX) {
			uint16_t num16 = htons((uint16_t)s->number64);
			memcpy(rdata_tail, &num16, 2);
			rdata_tail += 2;
		} else {
			WARN(ZS_NUMBER16_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		s->buffer_length = 0;
	}
	goto st1344;
st1344:
	if ( ++p == pe )
		goto _test_eof1344;
case 1344:
	_widec = (*p);
	if ( (*p) < 10 ) {
		if ( (*p) <= 9 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) > 10 ) {
		if ( 11 <= (*p) )
 {			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	if ( _widec == 2058 )
		goto tr3975;
	if ( 1920 <= _widec && _widec <= 2175 )
		goto tr3974;
	goto tr77;
tr3928:
	{
		s->buffer_length = 0;
	}
	goto st1345;
tr3976:
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		}
	}
	goto st1345;
tr3922:
	{
		if (s->number64 <= UINT8_MAX) {
			*rdata_tail = (uint8_t)(s->number64);
			rdata_tail += 1;
		} else {
			WARN(ZS_NUMBER8_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		s->buffer_length = 0;
	}
	goto st1345;
st1345:
	if ( ++p == pe )
		goto _test_eof1345;
case 1345:
	_widec = (*p);
	if ( (*p) < 10 ) {
		if ( (*p) <= 9 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) > 10 ) {
		if ( 11 <= (*p) )
 {			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	if ( _widec == 2058 )
		goto tr3977;
	if ( 1920 <= _widec && _widec <= 2175 )
		goto tr3976;
	goto tr77;
tr3916:
	{
		s->buffer_length = 0;
	}
	goto st1346;
tr3978:
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		}
	}
	goto st1346;
tr3910:
	{
		if (s->number64 <= UINT8_MAX) {
			*rdata_tail = (uint8_t)(s->number64);
			rdata_tail += 1;
		} else {
			WARN(ZS_NUMBER8_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		s->buffer_length = 0;
	}
	goto st1346;
st1346:
	if ( ++p == pe )
		goto _test_eof1346;
case 1346:
	_widec = (*p);
	if ( (*p) < 10 ) {
		if ( (*p) <= 9 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) > 10 ) {
		if ( 11 <= (*p) )
 {			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	if ( _widec == 2058 )
		goto tr3979;
	if ( 1920 <= _widec && _widec <= 2175 )
		goto tr3978;
	goto tr77;
st1347:
	if ( ++p == pe )
		goto _test_eof1347;
case 1347:
	if ( 48 <= (*p) && (*p) <= 57 )
		goto tr3980;
	goto tr2396;
tr3980:
	{
		s->number64 = 0;
	}
	{
		// Overflow check: 10*(s->number64) + fc - '0' <= UINT64_MAX
		if ((s->number64 < (UINT64_MAX / 10)) ||   // Dominant fast check.
			((s->number64 == (UINT64_MAX / 10)) && // Marginal case.
			 ((uint8_t)(*p) <= (UINT64_MAX % 10) + '0')
			)
		   ) {
			s->number64 *= 10;
			s->number64 += digit_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_NUMBER64_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st1348;
tr3984:
	{
		// Overflow check: 10*(s->number64) + fc - '0' <= UINT64_MAX
		if ((s->number64 < (UINT64_MAX / 10)) ||   // Dominant fast check.
			((s->number64 == (UINT64_MAX / 10)) && // Marginal case.
			 ((uint8_t)(*p) <= (UINT64_MAX % 10) + '0')
			)
		   ) {
			s->number64 *= 10;
			s->number64 += digit_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_NUMBER64_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st1348;
st1348:
	if ( ++p == pe )
		goto _test_eof1348;
case 1348:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr3981;
		case 32: goto tr3981;
		case 40: goto tr3982;
		case 41: goto tr3983;
		case 2058: goto tr3985;
		case 2107: goto tr3986;
	}
	if ( 48 <= _widec && _widec <= 57 )
		goto tr3984;
	goto tr2396;
tr3988:
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st1349;
tr3989:
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st1349;
tr3991:
	{
		s->line_counter++;
	}
	goto st1349;
tr4026:
	{
		s->buffer[s->buffer_length++] = 0;

		// Execute the comment callback.
		if (s->process.automatic && s->process.comment != NULL) {
			s->process.comment(s);

			// Stop if required from the callback.
			if (s->state == ZS_STATE_STOP) {
				{p++; cs = 1349; goto _out;}
			}
		}
	}
	{
		s->line_counter++;
	}
	goto st1349;
tr3981:
	{
		if (s->number64 <= UINT8_MAX) {
			*rdata_tail = (uint8_t)(s->number64);
			rdata_tail += 1;
		} else {
			WARN(ZS_NUMBER8_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st1349;
tr3982:
	{
		if (s->number64 <= UINT8_MAX) {
			*rdata_tail = (uint8_t)(s->number64);
			rdata_tail += 1;
		} else {
			WARN(ZS_NUMBER8_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st1349;
tr3983:
	{
		if (s->number64 <= UINT8_MAX) {
			*rdata_tail = (uint8_t)(s->number64);
			rdata_tail += 1;
		} else {
			WARN(ZS_NUMBER8_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st1349;
tr3985:
	{
		if (s->number64 <= UINT8_MAX) {
			*rdata_tail = (uint8_t)(s->number64);
			rdata_tail += 1;
		} else {
			WARN(ZS_NUMBER8_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		s->line_counter++;
	}
	goto st1349;
st1349:
	if ( ++p == pe )
		goto _test_eof1349;
case 1349:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto st1349;
		case 32: goto st1349;
		case 40: goto tr3988;
		case 41: goto tr3989;
		case 2058: goto tr3991;
		case 2107: goto tr3992;
	}
	if ( 48 <= _widec && _widec <= 57 )
		goto tr3990;
	goto tr2396;
tr3990:
	{
		s->number64 = 0;
	}
	{
		// Overflow check: 10*(s->number64) + fc - '0' <= UINT64_MAX
		if ((s->number64 < (UINT64_MAX / 10)) ||   // Dominant fast check.
			((s->number64 == (UINT64_MAX / 10)) && // Marginal case.
			 ((uint8_t)(*p) <= (UINT64_MAX % 10) + '0')
			)
		   ) {
			s->number64 *= 10;
			s->number64 += digit_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_NUMBER64_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st1350;
tr3996:
	{
		// Overflow check: 10*(s->number64) + fc - '0' <= UINT64_MAX
		if ((s->number64 < (UINT64_MAX / 10)) ||   // Dominant fast check.
			((s->number64 == (UINT64_MAX / 10)) && // Marginal case.
			 ((uint8_t)(*p) <= (UINT64_MAX % 10) + '0')
			)
		   ) {
			s->number64 *= 10;
			s->number64 += digit_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_NUMBER64_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st1350;
st1350:
	if ( ++p == pe )
		goto _test_eof1350;
case 1350:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr3993;
		case 32: goto tr3993;
		case 40: goto tr3994;
		case 41: goto tr3995;
		case 2058: goto tr3997;
		case 2107: goto tr3998;
	}
	if ( 48 <= _widec && _widec <= 57 )
		goto tr3996;
	goto tr2396;
tr4000:
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st1351;
tr4001:
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st1351;
tr4003:
	{
		s->line_counter++;
	}
	goto st1351;
tr4024:
	{
		s->buffer[s->buffer_length++] = 0;

		// Execute the comment callback.
		if (s->process.automatic && s->process.comment != NULL) {
			s->process.comment(s);

			// Stop if required from the callback.
			if (s->state == ZS_STATE_STOP) {
				{p++; cs = 1351; goto _out;}
			}
		}
	}
	{
		s->line_counter++;
	}
	goto st1351;
tr3993:
	{
		if (s->number64 <= UINT8_MAX) {
			*rdata_tail = (uint8_t)(s->number64);
			rdata_tail += 1;
		} else {
			WARN(ZS_NUMBER8_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st1351;
tr3994:
	{
		if (s->number64 <= UINT8_MAX) {
			*rdata_tail = (uint8_t)(s->number64);
			rdata_tail += 1;
		} else {
			WARN(ZS_NUMBER8_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st1351;
tr3995:
	{
		if (s->number64 <= UINT8_MAX) {
			*rdata_tail = (uint8_t)(s->number64);
			rdata_tail += 1;
		} else {
			WARN(ZS_NUMBER8_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st1351;
tr3997:
	{
		if (s->number64 <= UINT8_MAX) {
			*rdata_tail = (uint8_t)(s->number64);
			rdata_tail += 1;
		} else {
			WARN(ZS_NUMBER8_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		s->line_counter++;
	}
	goto st1351;
st1351:
	if ( ++p == pe )
		goto _test_eof1351;
case 1351:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto st1351;
		case 32: goto st1351;
		case 40: goto tr4000;
		case 41: goto tr4001;
		case 2058: goto tr4003;
		case 2107: goto tr4004;
	}
	if ( 48 <= _widec && _widec <= 57 )
		goto tr4002;
	goto tr2396;
tr4002:
	{
		s->number64 = 0;
	}
	{
		// Overflow check: 10*(s->number64) + fc - '0' <= UINT64_MAX
		if ((s->number64 < (UINT64_MAX / 10)) ||   // Dominant fast check.
			((s->number64 == (UINT64_MAX / 10)) && // Marginal case.
			 ((uint8_t)(*p) <= (UINT64_MAX % 10) + '0')
			)
		   ) {
			s->number64 *= 10;
			s->number64 += digit_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_NUMBER64_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st1352;
tr4008:
	{
		// Overflow check: 10*(s->number64) + fc - '0' <= UINT64_MAX
		if ((s->number64 < (UINT64_MAX / 10)) ||   // Dominant fast check.
			((s->number64 == (UINT64_MAX / 10)) && // Marginal case.
			 ((uint8_t)(*p) <= (UINT64_MAX % 10) + '0')
			)
		   ) {
			s->number64 *= 10;
			s->number64 += digit_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_NUMBER64_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st1352;
st1352:
	if ( ++p == pe )
		goto _test_eof1352;
case 1352:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr4005;
		case 32: goto tr4005;
		case 40: goto tr4006;
		case 41: goto tr4007;
		case 2058: goto tr4009;
		case 2107: goto tr4010;
	}
	if ( 48 <= _widec && _widec <= 57 )
		goto tr4008;
	goto tr2396;
tr4012:
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st1353;
tr4013:
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st1353;
tr4016:
	{
		s->line_counter++;
	}
	goto st1353;
tr4022:
	{
		s->buffer[s->buffer_length++] = 0;

		// Execute the comment callback.
		if (s->process.automatic && s->process.comment != NULL) {
			s->process.comment(s);

			// Stop if required from the callback.
			if (s->state == ZS_STATE_STOP) {
				{p++; cs = 1353; goto _out;}
			}
		}
	}
	{
		s->line_counter++;
	}
	goto st1353;
tr4005:
	{
		if (s->number64 <= UINT16_MAX) {
			uint16_t num16 = htons((uint16_t)s->number64);
			memcpy(rdata_tail, &num16, 2);
			rdata_tail += 2;
		} else {
			WARN(ZS_NUMBER16_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st1353;
tr4006:
	{
		if (s->number64 <= UINT16_MAX) {
			uint16_t num16 = htons((uint16_t)s->number64);
			memcpy(rdata_tail, &num16, 2);
			rdata_tail += 2;
		} else {
			WARN(ZS_NUMBER16_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st1353;
tr4007:
	{
		if (s->number64 <= UINT16_MAX) {
			uint16_t num16 = htons((uint16_t)s->number64);
			memcpy(rdata_tail, &num16, 2);
			rdata_tail += 2;
		} else {
			WARN(ZS_NUMBER16_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st1353;
tr4009:
	{
		if (s->number64 <= UINT16_MAX) {
			uint16_t num16 = htons((uint16_t)s->number64);
			memcpy(rdata_tail, &num16, 2);
			rdata_tail += 2;
		} else {
			WARN(ZS_NUMBER16_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		s->line_counter++;
	}
	goto st1353;
st1353:
	if ( ++p == pe )
		goto _test_eof1353;
case 1353:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto st1353;
		case 32: goto st1353;
		case 40: goto tr4012;
		case 41: goto tr4013;
		case 45: goto tr4014;
		case 2058: goto tr4016;
		case 2107: goto tr4017;
	}
	if ( _widec < 65 ) {
		if ( 48 <= _widec && _widec <= 57 )
			goto tr4015;
	} else if ( _widec > 70 ) {
		if ( 97 <= _widec && _widec <= 102 )
			goto tr4015;
	} else
		goto tr4015;
	goto tr3067;
tr4014:
	{
		if (rdata_tail <= rdata_stop) {
			s->item_length_location = rdata_tail++;
		} else {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st1354;
st1354:
	if ( ++p == pe )
		goto _test_eof1354;
case 1354:
	switch( (*p) ) {
		case 32: goto tr4018;
		case 59: goto tr4018;
	}
	if ( (*p) > 10 ) {
		if ( 40 <= (*p) && (*p) <= 41 )
			goto tr4018;
	} else if ( (*p) >= 9 )
		goto tr4018;
	goto tr3067;
tr4018:
	{
		s->item_length = rdata_tail - s->item_length_location - 1;
		if (s->comma_list && s->item_length == 0) {
			WARN(ZS_EMPTY_LIST_ITEM);
			p--; {goto st316;}
		}
		if (s->item_length <= MAX_ITEM_LENGTH) {
			*(s->item_length_location) = (uint8_t)(s->item_length);
		} else {
			WARN(ZS_ITEM_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1526;
st1526:
	if ( ++p == pe )
		goto _test_eof1526;
case 1526:
	goto st0;
tr4020:
	{
		if (rdata_tail <= rdata_stop) {
			*rdata_tail = first_hex_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st1355;
tr4015:
	{
		if (rdata_tail <= rdata_stop) {
			s->item_length_location = rdata_tail++;
		} else {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (rdata_tail <= rdata_stop) {
			*rdata_tail = first_hex_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st1355;
st1355:
	if ( ++p == pe )
		goto _test_eof1355;
case 1355:
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr4019;
	} else if ( (*p) > 70 ) {
		if ( 97 <= (*p) && (*p) <= 102 )
			goto tr4019;
	} else
		goto tr4019;
	goto tr3067;
tr4019:
	{
		*rdata_tail += second_hex_to_num[(uint8_t)(*p)];
		rdata_tail++;
	}
	goto st1356;
st1356:
	if ( ++p == pe )
		goto _test_eof1356;
case 1356:
	switch( (*p) ) {
		case 32: goto tr4018;
		case 59: goto tr4018;
	}
	if ( (*p) < 48 ) {
		if ( (*p) > 10 ) {
			if ( 40 <= (*p) && (*p) <= 41 )
				goto tr4018;
		} else if ( (*p) >= 9 )
			goto tr4018;
	} else if ( (*p) > 57 ) {
		if ( (*p) > 70 ) {
			if ( 97 <= (*p) && (*p) <= 102 )
				goto tr4020;
		} else if ( (*p) >= 65 )
			goto tr4020;
	} else
		goto tr4020;
	goto tr3067;
tr4017:
	{
		s->buffer_length = 0;
	}
	goto st1357;
tr4021:
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		}
	}
	goto st1357;
tr4010:
	{
		if (s->number64 <= UINT16_MAX) {
			uint16_t num16 = htons((uint16_t)s->number64);
			memcpy(rdata_tail, &num16, 2);
			rdata_tail += 2;
		} else {
			WARN(ZS_NUMBER16_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		s->buffer_length = 0;
	}
	goto st1357;
st1357:
	if ( ++p == pe )
		goto _test_eof1357;
case 1357:
	_widec = (*p);
	if ( (*p) < 10 ) {
		if ( (*p) <= 9 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) > 10 ) {
		if ( 11 <= (*p) )
 {			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	if ( _widec == 2058 )
		goto tr4022;
	if ( 1920 <= _widec && _widec <= 2175 )
		goto tr4021;
	goto tr77;
tr4004:
	{
		s->buffer_length = 0;
	}
	goto st1358;
tr4023:
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		}
	}
	goto st1358;
tr3998:
	{
		if (s->number64 <= UINT8_MAX) {
			*rdata_tail = (uint8_t)(s->number64);
			rdata_tail += 1;
		} else {
			WARN(ZS_NUMBER8_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		s->buffer_length = 0;
	}
	goto st1358;
st1358:
	if ( ++p == pe )
		goto _test_eof1358;
case 1358:
	_widec = (*p);
	if ( (*p) < 10 ) {
		if ( (*p) <= 9 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) > 10 ) {
		if ( 11 <= (*p) )
 {			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	if ( _widec == 2058 )
		goto tr4024;
	if ( 1920 <= _widec && _widec <= 2175 )
		goto tr4023;
	goto tr77;
tr3992:
	{
		s->buffer_length = 0;
	}
	goto st1359;
tr4025:
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		}
	}
	goto st1359;
tr3986:
	{
		if (s->number64 <= UINT8_MAX) {
			*rdata_tail = (uint8_t)(s->number64);
			rdata_tail += 1;
		} else {
			WARN(ZS_NUMBER8_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		s->buffer_length = 0;
	}
	goto st1359;
st1359:
	if ( ++p == pe )
		goto _test_eof1359;
case 1359:
	_widec = (*p);
	if ( (*p) < 10 ) {
		if ( (*p) <= 9 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) > 10 ) {
		if ( 11 <= (*p) )
 {			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	if ( _widec == 2058 )
		goto tr4026;
	if ( 1920 <= _widec && _widec <= 2175 )
		goto tr4025;
	goto tr77;
st1360:
	if ( ++p == pe )
		goto _test_eof1360;
case 1360:
	if ( 48 <= (*p) && (*p) <= 57 )
		goto tr4027;
	goto tr2396;
tr4027:
	{
		s->number64 = 0;
	}
	{
		// Overflow check: 10*(s->number64) + fc - '0' <= UINT64_MAX
		if ((s->number64 < (UINT64_MAX / 10)) ||   // Dominant fast check.
			((s->number64 == (UINT64_MAX / 10)) && // Marginal case.
			 ((uint8_t)(*p) <= (UINT64_MAX % 10) + '0')
			)
		   ) {
			s->number64 *= 10;
			s->number64 += digit_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_NUMBER64_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st1361;
tr4031:
	{
		// Overflow check: 10*(s->number64) + fc - '0' <= UINT64_MAX
		if ((s->number64 < (UINT64_MAX / 10)) ||   // Dominant fast check.
			((s->number64 == (UINT64_MAX / 10)) && // Marginal case.
			 ((uint8_t)(*p) <= (UINT64_MAX % 10) + '0')
			)
		   ) {
			s->number64 *= 10;
			s->number64 += digit_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_NUMBER64_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st1361;
st1361:
	if ( ++p == pe )
		goto _test_eof1361;
case 1361:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr4028;
		case 32: goto tr4028;
		case 40: goto tr4029;
		case 41: goto tr4030;
		case 2058: goto tr4032;
		case 2107: goto tr4033;
	}
	if ( 48 <= _widec && _widec <= 57 )
		goto tr4031;
	goto tr2396;
tr4035:
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st1362;
tr4036:
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st1362;
tr4038:
	{
		s->line_counter++;
	}
	goto st1362;
tr4080:
	{
		s->buffer[s->buffer_length++] = 0;

		// Execute the comment callback.
		if (s->process.automatic && s->process.comment != NULL) {
			s->process.comment(s);

			// Stop if required from the callback.
			if (s->state == ZS_STATE_STOP) {
				{p++; cs = 1362; goto _out;}
			}
		}
	}
	{
		s->line_counter++;
	}
	goto st1362;
tr4028:
	{
		if (s->number64 <= UINT8_MAX) {
			*rdata_tail = (uint8_t)(s->number64);
			rdata_tail += 1;
		} else {
			WARN(ZS_NUMBER8_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st1362;
tr4029:
	{
		if (s->number64 <= UINT8_MAX) {
			*rdata_tail = (uint8_t)(s->number64);
			rdata_tail += 1;
		} else {
			WARN(ZS_NUMBER8_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st1362;
tr4030:
	{
		if (s->number64 <= UINT8_MAX) {
			*rdata_tail = (uint8_t)(s->number64);
			rdata_tail += 1;
		} else {
			WARN(ZS_NUMBER8_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st1362;
tr4032:
	{
		if (s->number64 <= UINT8_MAX) {
			*rdata_tail = (uint8_t)(s->number64);
			rdata_tail += 1;
		} else {
			WARN(ZS_NUMBER8_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		s->line_counter++;
	}
	goto st1362;
st1362:
	if ( ++p == pe )
		goto _test_eof1362;
case 1362:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto st1362;
		case 32: goto st1362;
		case 40: goto tr4035;
		case 41: goto tr4036;
		case 2058: goto tr4038;
		case 2107: goto tr4039;
	}
	if ( 48 <= _widec && _widec <= 57 )
		goto tr4037;
	goto tr2396;
tr4037:
	{
		s->number64 = 0;
	}
	{
		// Overflow check: 10*(s->number64) + fc - '0' <= UINT64_MAX
		if ((s->number64 < (UINT64_MAX / 10)) ||   // Dominant fast check.
			((s->number64 == (UINT64_MAX / 10)) && // Marginal case.
			 ((uint8_t)(*p) <= (UINT64_MAX % 10) + '0')
			)
		   ) {
			s->number64 *= 10;
			s->number64 += digit_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_NUMBER64_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st1363;
tr4043:
	{
		// Overflow check: 10*(s->number64) + fc - '0' <= UINT64_MAX
		if ((s->number64 < (UINT64_MAX / 10)) ||   // Dominant fast check.
			((s->number64 == (UINT64_MAX / 10)) && // Marginal case.
			 ((uint8_t)(*p) <= (UINT64_MAX % 10) + '0')
			)
		   ) {
			s->number64 *= 10;
			s->number64 += digit_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_NUMBER64_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st1363;
st1363:
	if ( ++p == pe )
		goto _test_eof1363;
case 1363:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr4040;
		case 32: goto tr4040;
		case 40: goto tr4041;
		case 41: goto tr4042;
		case 2058: goto tr4044;
		case 2107: goto tr4045;
	}
	if ( 48 <= _widec && _widec <= 57 )
		goto tr4043;
	goto tr2396;
tr4047:
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st1364;
tr4048:
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st1364;
tr4050:
	{
		s->line_counter++;
	}
	goto st1364;
tr4078:
	{
		s->buffer[s->buffer_length++] = 0;

		// Execute the comment callback.
		if (s->process.automatic && s->process.comment != NULL) {
			s->process.comment(s);

			// Stop if required from the callback.
			if (s->state == ZS_STATE_STOP) {
				{p++; cs = 1364; goto _out;}
			}
		}
	}
	{
		s->line_counter++;
	}
	goto st1364;
tr4040:
	{
		if (s->number64 <= UINT8_MAX) {
			*rdata_tail = (uint8_t)(s->number64);
			rdata_tail += 1;
		} else {
			WARN(ZS_NUMBER8_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st1364;
tr4041:
	{
		if (s->number64 <= UINT8_MAX) {
			*rdata_tail = (uint8_t)(s->number64);
			rdata_tail += 1;
		} else {
			WARN(ZS_NUMBER8_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st1364;
tr4042:
	{
		if (s->number64 <= UINT8_MAX) {
			*rdata_tail = (uint8_t)(s->number64);
			rdata_tail += 1;
		} else {
			WARN(ZS_NUMBER8_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st1364;
tr4044:
	{
		if (s->number64 <= UINT8_MAX) {
			*rdata_tail = (uint8_t)(s->number64);
			rdata_tail += 1;
		} else {
			WARN(ZS_NUMBER8_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		s->line_counter++;
	}
	goto st1364;
st1364:
	if ( ++p == pe )
		goto _test_eof1364;
case 1364:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto st1364;
		case 32: goto st1364;
		case 40: goto tr4047;
		case 41: goto tr4048;
		case 2058: goto tr4050;
		case 2107: goto tr4051;
	}
	if ( 48 <= _widec && _widec <= 57 )
		goto tr4049;
	goto tr2396;
tr4049:
	{
		s->number64 = 0;
	}
	{
		// Overflow check: 10*(s->number64) + fc - '0' <= UINT64_MAX
		if ((s->number64 < (UINT64_MAX / 10)) ||   // Dominant fast check.
			((s->number64 == (UINT64_MAX / 10)) && // Marginal case.
			 ((uint8_t)(*p) <= (UINT64_MAX % 10) + '0')
			)
		   ) {
			s->number64 *= 10;
			s->number64 += digit_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_NUMBER64_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st1365;
tr4055:
	{
		// Overflow check: 10*(s->number64) + fc - '0' <= UINT64_MAX
		if ((s->number64 < (UINT64_MAX / 10)) ||   // Dominant fast check.
			((s->number64 == (UINT64_MAX / 10)) && // Marginal case.
			 ((uint8_t)(*p) <= (UINT64_MAX % 10) + '0')
			)
		   ) {
			s->number64 *= 10;
			s->number64 += digit_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_NUMBER64_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st1365;
st1365:
	if ( ++p == pe )
		goto _test_eof1365;
case 1365:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr4052;
		case 32: goto tr4052;
		case 40: goto tr4053;
		case 41: goto tr4054;
		case 2058: goto tr4056;
		case 2107: goto tr4057;
	}
	if ( 48 <= _widec && _widec <= 57 )
		goto tr4055;
	goto tr2396;
tr4059:
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st1366;
tr4060:
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st1366;
tr4062:
	{
		s->line_counter++;
	}
	goto st1366;
tr4076:
	{
		s->buffer[s->buffer_length++] = 0;

		// Execute the comment callback.
		if (s->process.automatic && s->process.comment != NULL) {
			s->process.comment(s);

			// Stop if required from the callback.
			if (s->state == ZS_STATE_STOP) {
				{p++; cs = 1366; goto _out;}
			}
		}
	}
	{
		s->line_counter++;
	}
	goto st1366;
tr4052:
	{
		if (s->number64 <= UINT8_MAX) {
			*rdata_tail = (uint8_t)(s->number64);
			rdata_tail += 1;
		} else {
			WARN(ZS_NUMBER8_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st1366;
tr4053:
	{
		if (s->number64 <= UINT8_MAX) {
			*rdata_tail = (uint8_t)(s->number64);
			rdata_tail += 1;
		} else {
			WARN(ZS_NUMBER8_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st1366;
tr4054:
	{
		if (s->number64 <= UINT8_MAX) {
			*rdata_tail = (uint8_t)(s->number64);
			rdata_tail += 1;
		} else {
			WARN(ZS_NUMBER8_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st1366;
tr4056:
	{
		if (s->number64 <= UINT8_MAX) {
			*rdata_tail = (uint8_t)(s->number64);
			rdata_tail += 1;
		} else {
			WARN(ZS_NUMBER8_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		s->line_counter++;
	}
	goto st1366;
st1366:
	if ( ++p == pe )
		goto _test_eof1366;
case 1366:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto st1366;
		case 32: goto st1366;
		case 40: goto tr4059;
		case 41: goto tr4060;
		case 2058: goto tr4062;
		case 2107: goto tr4063;
	}
	if ( _widec < 65 ) {
		if ( 48 <= _widec && _widec <= 57 )
			goto tr4061;
	} else if ( _widec > 70 ) {
		if ( 97 <= _widec && _widec <= 102 )
			goto tr4061;
	} else
		goto tr4061;
	goto tr3067;
tr4061:
	{
		if (rdata_tail <= rdata_stop) {
			*rdata_tail = first_hex_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st1367;
st1367:
	if ( ++p == pe )
		goto _test_eof1367;
case 1367:
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr4064;
	} else if ( (*p) > 70 ) {
		if ( 97 <= (*p) && (*p) <= 102 )
			goto tr4064;
	} else
		goto tr4064;
	goto tr3067;
tr4066:
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st1368;
tr4067:
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st1368;
tr4068:
	{
		s->line_counter++;
	}
	goto st1368;
tr4074:
	{
		s->buffer[s->buffer_length++] = 0;

		// Execute the comment callback.
		if (s->process.automatic && s->process.comment != NULL) {
			s->process.comment(s);

			// Stop if required from the callback.
			if (s->state == ZS_STATE_STOP) {
				{p++; cs = 1368; goto _out;}
			}
		}
	}
	{
		s->line_counter++;
	}
	goto st1368;
tr4064:
	{
		*rdata_tail += second_hex_to_num[(uint8_t)(*p)];
		rdata_tail++;
	}
	goto st1368;
st1368:
	if ( ++p == pe )
		goto _test_eof1368;
case 1368:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(2688 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 !s->multiline  ) _widec += 512;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(2688 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		if (
 !s->multiline  ) _widec += 512;
	}
	switch( _widec ) {
		case 9: goto st1368;
		case 32: goto st1368;
		case 40: goto tr4066;
		case 41: goto tr4067;
		case 3082: goto tr4068;
		case 3131: goto tr4069;
		case 3338: goto tr4070;
		case 3387: goto tr4070;
		case 3594: goto tr4071;
		case 3643: goto tr4072;
	}
	if ( _widec < 65 ) {
		if ( 48 <= _widec && _widec <= 57 )
			goto tr4061;
	} else if ( _widec > 70 ) {
		if ( 97 <= _widec && _widec <= 102 )
			goto tr4061;
	} else
		goto tr4061;
	goto tr3067;
tr4069:
	{
		s->buffer_length = 0;
	}
	goto st1369;
tr4073:
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		}
	}
	goto st1369;
st1369:
	if ( ++p == pe )
		goto _test_eof1369;
case 1369:
	_widec = (*p);
	if ( (*p) < 10 ) {
		if ( (*p) <= 9 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) > 10 ) {
		if ( 11 <= (*p) )
 {			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	if ( _widec == 2058 )
		goto tr4074;
	if ( 1920 <= _widec && _widec <= 2175 )
		goto tr4073;
	goto tr3067;
tr4070:
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1527;
st1527:
	if ( ++p == pe )
		goto _test_eof1527;
case 1527:
	goto st0;
tr4071:
	{
		s->line_counter++;
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1528;
st1528:
	if ( ++p == pe )
		goto _test_eof1528;
case 1528:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(2688 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 !s->multiline  ) _widec += 512;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(2688 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		if (
 !s->multiline  ) _widec += 512;
	}
	switch( _widec ) {
		case 9: goto st1368;
		case 32: goto st1368;
		case 40: goto tr4066;
		case 41: goto tr4067;
		case 3082: goto tr4068;
		case 3131: goto tr4069;
		case 3338: goto tr4070;
		case 3387: goto tr4070;
		case 3594: goto tr4071;
		case 3643: goto tr4072;
	}
	if ( _widec < 65 ) {
		if ( 48 <= _widec && _widec <= 57 )
			goto tr4061;
	} else if ( _widec > 70 ) {
		if ( 97 <= _widec && _widec <= 102 )
			goto tr4061;
	} else
		goto tr4061;
	goto tr3067;
tr4072:
	{
		s->buffer_length = 0;
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1529;
st1529:
	if ( ++p == pe )
		goto _test_eof1529;
case 1529:
	_widec = (*p);
	if ( (*p) < 10 ) {
		if ( (*p) <= 9 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) > 10 ) {
		if ( 11 <= (*p) )
 {			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	if ( _widec == 2058 )
		goto tr4074;
	if ( 1920 <= _widec && _widec <= 2175 )
		goto tr4073;
	goto tr3067;
tr4063:
	{
		s->buffer_length = 0;
	}
	goto st1370;
tr4075:
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		}
	}
	goto st1370;
tr4057:
	{
		if (s->number64 <= UINT8_MAX) {
			*rdata_tail = (uint8_t)(s->number64);
			rdata_tail += 1;
		} else {
			WARN(ZS_NUMBER8_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		s->buffer_length = 0;
	}
	goto st1370;
st1370:
	if ( ++p == pe )
		goto _test_eof1370;
case 1370:
	_widec = (*p);
	if ( (*p) < 10 ) {
		if ( (*p) <= 9 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) > 10 ) {
		if ( 11 <= (*p) )
 {			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	if ( _widec == 2058 )
		goto tr4076;
	if ( 1920 <= _widec && _widec <= 2175 )
		goto tr4075;
	goto tr77;
tr4051:
	{
		s->buffer_length = 0;
	}
	goto st1371;
tr4077:
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		}
	}
	goto st1371;
tr4045:
	{
		if (s->number64 <= UINT8_MAX) {
			*rdata_tail = (uint8_t)(s->number64);
			rdata_tail += 1;
		} else {
			WARN(ZS_NUMBER8_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		s->buffer_length = 0;
	}
	goto st1371;
st1371:
	if ( ++p == pe )
		goto _test_eof1371;
case 1371:
	_widec = (*p);
	if ( (*p) < 10 ) {
		if ( (*p) <= 9 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) > 10 ) {
		if ( 11 <= (*p) )
 {			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	if ( _widec == 2058 )
		goto tr4078;
	if ( 1920 <= _widec && _widec <= 2175 )
		goto tr4077;
	goto tr77;
tr4039:
	{
		s->buffer_length = 0;
	}
	goto st1372;
tr4079:
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		}
	}
	goto st1372;
tr4033:
	{
		if (s->number64 <= UINT8_MAX) {
			*rdata_tail = (uint8_t)(s->number64);
			rdata_tail += 1;
		} else {
			WARN(ZS_NUMBER8_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		s->buffer_length = 0;
	}
	goto st1372;
st1372:
	if ( ++p == pe )
		goto _test_eof1372;
case 1372:
	_widec = (*p);
	if ( (*p) < 10 ) {
		if ( (*p) <= 9 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) > 10 ) {
		if ( 11 <= (*p) )
 {			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	if ( _widec == 2058 )
		goto tr4080;
	if ( 1920 <= _widec && _widec <= 2175 )
		goto tr4079;
	goto tr77;
st1373:
	if ( ++p == pe )
		goto _test_eof1373;
case 1373:
	if ( 48 <= (*p) && (*p) <= 57 )
		goto tr4081;
	goto tr2396;
tr4081:
	{
		s->number64 = 0;
	}
	{
		// Overflow check: 10*(s->number64) + fc - '0' <= UINT64_MAX
		if ((s->number64 < (UINT64_MAX / 10)) ||   // Dominant fast check.
			((s->number64 == (UINT64_MAX / 10)) && // Marginal case.
			 ((uint8_t)(*p) <= (UINT64_MAX % 10) + '0')
			)
		   ) {
			s->number64 *= 10;
			s->number64 += digit_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_NUMBER64_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st1374;
tr4085:
	{
		// Overflow check: 10*(s->number64) + fc - '0' <= UINT64_MAX
		if ((s->number64 < (UINT64_MAX / 10)) ||   // Dominant fast check.
			((s->number64 == (UINT64_MAX / 10)) && // Marginal case.
			 ((uint8_t)(*p) <= (UINT64_MAX % 10) + '0')
			)
		   ) {
			s->number64 *= 10;
			s->number64 += digit_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_NUMBER64_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st1374;
st1374:
	if ( ++p == pe )
		goto _test_eof1374;
case 1374:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr4082;
		case 32: goto tr4082;
		case 40: goto tr4083;
		case 41: goto tr4084;
		case 2058: goto tr4086;
		case 2107: goto tr4087;
	}
	if ( 48 <= _widec && _widec <= 57 )
		goto tr4085;
	goto tr2396;
tr4089:
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st1375;
tr4090:
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st1375;
tr4092:
	{
		s->line_counter++;
	}
	goto st1375;
tr4098:
	{
		s->buffer[s->buffer_length++] = 0;

		// Execute the comment callback.
		if (s->process.automatic && s->process.comment != NULL) {
			s->process.comment(s);

			// Stop if required from the callback.
			if (s->state == ZS_STATE_STOP) {
				{p++; cs = 1375; goto _out;}
			}
		}
	}
	{
		s->line_counter++;
	}
	goto st1375;
tr4082:
	{
		if (s->number64 <= UINT32_MAX) {
			uint32_t num32 = htonl((uint32_t)s->number64);
			memcpy(rdata_tail, &num32, 4);
			rdata_tail += 4;
		} else {
			WARN(ZS_NUMBER32_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st1375;
tr4083:
	{
		if (s->number64 <= UINT32_MAX) {
			uint32_t num32 = htonl((uint32_t)s->number64);
			memcpy(rdata_tail, &num32, 4);
			rdata_tail += 4;
		} else {
			WARN(ZS_NUMBER32_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st1375;
tr4084:
	{
		if (s->number64 <= UINT32_MAX) {
			uint32_t num32 = htonl((uint32_t)s->number64);
			memcpy(rdata_tail, &num32, 4);
			rdata_tail += 4;
		} else {
			WARN(ZS_NUMBER32_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st1375;
tr4086:
	{
		if (s->number64 <= UINT32_MAX) {
			uint32_t num32 = htonl((uint32_t)s->number64);
			memcpy(rdata_tail, &num32, 4);
			rdata_tail += 4;
		} else {
			WARN(ZS_NUMBER32_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		s->line_counter++;
	}
	goto st1375;
st1375:
	if ( ++p == pe )
		goto _test_eof1375;
case 1375:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto st1375;
		case 32: goto st1375;
		case 40: goto tr4089;
		case 41: goto tr4090;
		case 2058: goto tr4092;
		case 2107: goto tr4093;
	}
	if ( 48 <= _widec && _widec <= 57 )
		goto tr4091;
	goto tr2396;
tr4091:
	{
		s->number64 = 0;
	}
	{
		// Overflow check: 10*(s->number64) + fc - '0' <= UINT64_MAX
		if ((s->number64 < (UINT64_MAX / 10)) ||   // Dominant fast check.
			((s->number64 == (UINT64_MAX / 10)) && // Marginal case.
			 ((uint8_t)(*p) <= (UINT64_MAX % 10) + '0')
			)
		   ) {
			s->number64 *= 10;
			s->number64 += digit_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_NUMBER64_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st1376;
tr4095:
	{
		// Overflow check: 10*(s->number64) + fc - '0' <= UINT64_MAX
		if ((s->number64 < (UINT64_MAX / 10)) ||   // Dominant fast check.
			((s->number64 == (UINT64_MAX / 10)) && // Marginal case.
			 ((uint8_t)(*p) <= (UINT64_MAX % 10) + '0')
			)
		   ) {
			s->number64 *= 10;
			s->number64 += digit_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_NUMBER64_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st1376;
st1376:
	if ( ++p == pe )
		goto _test_eof1376;
case 1376:
	switch( (*p) ) {
		case 32: goto tr4094;
		case 59: goto tr4094;
	}
	if ( (*p) < 40 ) {
		if ( 9 <= (*p) && (*p) <= 10 )
			goto tr4094;
	} else if ( (*p) > 41 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr4095;
	} else
		goto tr4094;
	goto tr2396;
tr4094:
	{
		if (s->number64 <= UINT16_MAX) {
			uint16_t num16 = htons((uint16_t)s->number64);
			memcpy(rdata_tail, &num16, 2);
			rdata_tail += 2;
		} else {
			WARN(ZS_NUMBER16_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{ p--; {stack[top++] = 1377;goto st385;} }
	goto st1377;
st1377:
	if ( ++p == pe )
		goto _test_eof1377;
case 1377:
	switch( (*p) ) {
		case 32: goto tr4096;
		case 59: goto tr4096;
	}
	if ( (*p) > 10 ) {
		if ( 40 <= (*p) && (*p) <= 41 )
			goto tr4096;
	} else if ( (*p) >= 9 )
		goto tr4096;
	goto tr77;
tr4096:
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1530;
st1530:
	if ( ++p == pe )
		goto _test_eof1530;
case 1530:
	goto st0;
tr4093:
	{
		s->buffer_length = 0;
	}
	goto st1378;
tr4097:
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		}
	}
	goto st1378;
tr4087:
	{
		if (s->number64 <= UINT32_MAX) {
			uint32_t num32 = htonl((uint32_t)s->number64);
			memcpy(rdata_tail, &num32, 4);
			rdata_tail += 4;
		} else {
			WARN(ZS_NUMBER32_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		s->buffer_length = 0;
	}
	goto st1378;
st1378:
	if ( ++p == pe )
		goto _test_eof1378;
case 1378:
	_widec = (*p);
	if ( (*p) < 10 ) {
		if ( (*p) <= 9 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) > 10 ) {
		if ( 11 <= (*p) )
 {			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	if ( _widec == 2058 )
		goto tr4098;
	if ( 1920 <= _widec && _widec <= 2175 )
		goto tr4097;
	goto tr77;
st1379:
	if ( ++p == pe )
		goto _test_eof1379;
case 1379:
	if ( 48 <= (*p) && (*p) <= 57 )
		goto tr4099;
	goto tr2396;
tr4099:
	{
		s->number64 = 0;
	}
	{
		// Overflow check: 10*(s->number64) + fc - '0' <= UINT64_MAX
		if ((s->number64 < (UINT64_MAX / 10)) ||   // Dominant fast check.
			((s->number64 == (UINT64_MAX / 10)) && // Marginal case.
			 ((uint8_t)(*p) <= (UINT64_MAX % 10) + '0')
			)
		   ) {
			s->number64 *= 10;
			s->number64 += digit_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_NUMBER64_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st1380;
tr4103:
	{
		// Overflow check: 10*(s->number64) + fc - '0' <= UINT64_MAX
		if ((s->number64 < (UINT64_MAX / 10)) ||   // Dominant fast check.
			((s->number64 == (UINT64_MAX / 10)) && // Marginal case.
			 ((uint8_t)(*p) <= (UINT64_MAX % 10) + '0')
			)
		   ) {
			s->number64 *= 10;
			s->number64 += digit_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_NUMBER64_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st1380;
st1380:
	if ( ++p == pe )
		goto _test_eof1380;
case 1380:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr4100;
		case 32: goto tr4100;
		case 40: goto tr4101;
		case 41: goto tr4102;
		case 2058: goto tr4104;
		case 2107: goto tr4105;
	}
	if ( 48 <= _widec && _widec <= 57 )
		goto tr4103;
	goto tr2396;
tr4107:
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st1381;
tr4108:
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st1381;
tr4110:
	{
		s->line_counter++;
	}
	goto st1381;
tr4152:
	{
		s->buffer[s->buffer_length++] = 0;

		// Execute the comment callback.
		if (s->process.automatic && s->process.comment != NULL) {
			s->process.comment(s);

			// Stop if required from the callback.
			if (s->state == ZS_STATE_STOP) {
				{p++; cs = 1381; goto _out;}
			}
		}
	}
	{
		s->line_counter++;
	}
	goto st1381;
tr4100:
	{
		if (s->number64 <= UINT32_MAX) {
			uint32_t num32 = htonl((uint32_t)s->number64);
			memcpy(rdata_tail, &num32, 4);
			rdata_tail += 4;
		} else {
			WARN(ZS_NUMBER32_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st1381;
tr4101:
	{
		if (s->number64 <= UINT32_MAX) {
			uint32_t num32 = htonl((uint32_t)s->number64);
			memcpy(rdata_tail, &num32, 4);
			rdata_tail += 4;
		} else {
			WARN(ZS_NUMBER32_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st1381;
tr4102:
	{
		if (s->number64 <= UINT32_MAX) {
			uint32_t num32 = htonl((uint32_t)s->number64);
			memcpy(rdata_tail, &num32, 4);
			rdata_tail += 4;
		} else {
			WARN(ZS_NUMBER32_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st1381;
tr4104:
	{
		if (s->number64 <= UINT32_MAX) {
			uint32_t num32 = htonl((uint32_t)s->number64);
			memcpy(rdata_tail, &num32, 4);
			rdata_tail += 4;
		} else {
			WARN(ZS_NUMBER32_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		s->line_counter++;
	}
	goto st1381;
st1381:
	if ( ++p == pe )
		goto _test_eof1381;
case 1381:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto st1381;
		case 32: goto st1381;
		case 40: goto tr4107;
		case 41: goto tr4108;
		case 2058: goto tr4110;
		case 2107: goto tr4111;
	}
	if ( 48 <= _widec && _widec <= 57 )
		goto tr4109;
	goto tr2396;
tr4109:
	{
		s->number64 = 0;
	}
	{
		// Overflow check: 10*(s->number64) + fc - '0' <= UINT64_MAX
		if ((s->number64 < (UINT64_MAX / 10)) ||   // Dominant fast check.
			((s->number64 == (UINT64_MAX / 10)) && // Marginal case.
			 ((uint8_t)(*p) <= (UINT64_MAX % 10) + '0')
			)
		   ) {
			s->number64 *= 10;
			s->number64 += digit_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_NUMBER64_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st1382;
tr4115:
	{
		// Overflow check: 10*(s->number64) + fc - '0' <= UINT64_MAX
		if ((s->number64 < (UINT64_MAX / 10)) ||   // Dominant fast check.
			((s->number64 == (UINT64_MAX / 10)) && // Marginal case.
			 ((uint8_t)(*p) <= (UINT64_MAX % 10) + '0')
			)
		   ) {
			s->number64 *= 10;
			s->number64 += digit_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_NUMBER64_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st1382;
st1382:
	if ( ++p == pe )
		goto _test_eof1382;
case 1382:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr4112;
		case 32: goto tr4112;
		case 40: goto tr4113;
		case 41: goto tr4114;
		case 2058: goto tr4116;
		case 2107: goto tr4117;
	}
	if ( 48 <= _widec && _widec <= 57 )
		goto tr4115;
	goto tr2396;
tr4119:
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st1383;
tr4120:
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st1383;
tr4122:
	{
		s->line_counter++;
	}
	goto st1383;
tr4150:
	{
		s->buffer[s->buffer_length++] = 0;

		// Execute the comment callback.
		if (s->process.automatic && s->process.comment != NULL) {
			s->process.comment(s);

			// Stop if required from the callback.
			if (s->state == ZS_STATE_STOP) {
				{p++; cs = 1383; goto _out;}
			}
		}
	}
	{
		s->line_counter++;
	}
	goto st1383;
tr4112:
	{
		if (s->number64 <= UINT8_MAX) {
			*rdata_tail = (uint8_t)(s->number64);
			rdata_tail += 1;
		} else {
			WARN(ZS_NUMBER8_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st1383;
tr4113:
	{
		if (s->number64 <= UINT8_MAX) {
			*rdata_tail = (uint8_t)(s->number64);
			rdata_tail += 1;
		} else {
			WARN(ZS_NUMBER8_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st1383;
tr4114:
	{
		if (s->number64 <= UINT8_MAX) {
			*rdata_tail = (uint8_t)(s->number64);
			rdata_tail += 1;
		} else {
			WARN(ZS_NUMBER8_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st1383;
tr4116:
	{
		if (s->number64 <= UINT8_MAX) {
			*rdata_tail = (uint8_t)(s->number64);
			rdata_tail += 1;
		} else {
			WARN(ZS_NUMBER8_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		s->line_counter++;
	}
	goto st1383;
st1383:
	if ( ++p == pe )
		goto _test_eof1383;
case 1383:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto st1383;
		case 32: goto st1383;
		case 40: goto tr4119;
		case 41: goto tr4120;
		case 2058: goto tr4122;
		case 2107: goto tr4123;
	}
	if ( 48 <= _widec && _widec <= 57 )
		goto tr4121;
	goto tr2396;
tr4121:
	{
		s->number64 = 0;
	}
	{
		// Overflow check: 10*(s->number64) + fc - '0' <= UINT64_MAX
		if ((s->number64 < (UINT64_MAX / 10)) ||   // Dominant fast check.
			((s->number64 == (UINT64_MAX / 10)) && // Marginal case.
			 ((uint8_t)(*p) <= (UINT64_MAX % 10) + '0')
			)
		   ) {
			s->number64 *= 10;
			s->number64 += digit_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_NUMBER64_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st1384;
tr4127:
	{
		// Overflow check: 10*(s->number64) + fc - '0' <= UINT64_MAX
		if ((s->number64 < (UINT64_MAX / 10)) ||   // Dominant fast check.
			((s->number64 == (UINT64_MAX / 10)) && // Marginal case.
			 ((uint8_t)(*p) <= (UINT64_MAX % 10) + '0')
			)
		   ) {
			s->number64 *= 10;
			s->number64 += digit_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_NUMBER64_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st1384;
st1384:
	if ( ++p == pe )
		goto _test_eof1384;
case 1384:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr4124;
		case 32: goto tr4124;
		case 40: goto tr4125;
		case 41: goto tr4126;
		case 2058: goto tr4128;
		case 2107: goto tr4129;
	}
	if ( 48 <= _widec && _widec <= 57 )
		goto tr4127;
	goto tr2396;
tr4131:
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st1385;
tr4132:
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st1385;
tr4134:
	{
		s->line_counter++;
	}
	goto st1385;
tr4148:
	{
		s->buffer[s->buffer_length++] = 0;

		// Execute the comment callback.
		if (s->process.automatic && s->process.comment != NULL) {
			s->process.comment(s);

			// Stop if required from the callback.
			if (s->state == ZS_STATE_STOP) {
				{p++; cs = 1385; goto _out;}
			}
		}
	}
	{
		s->line_counter++;
	}
	goto st1385;
tr4124:
	{
		if (s->number64 <= UINT8_MAX) {
			*rdata_tail = (uint8_t)(s->number64);
			rdata_tail += 1;
		} else {
			WARN(ZS_NUMBER8_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st1385;
tr4125:
	{
		if (s->number64 <= UINT8_MAX) {
			*rdata_tail = (uint8_t)(s->number64);
			rdata_tail += 1;
		} else {
			WARN(ZS_NUMBER8_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st1385;
tr4126:
	{
		if (s->number64 <= UINT8_MAX) {
			*rdata_tail = (uint8_t)(s->number64);
			rdata_tail += 1;
		} else {
			WARN(ZS_NUMBER8_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st1385;
tr4128:
	{
		if (s->number64 <= UINT8_MAX) {
			*rdata_tail = (uint8_t)(s->number64);
			rdata_tail += 1;
		} else {
			WARN(ZS_NUMBER8_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		s->line_counter++;
	}
	goto st1385;
st1385:
	if ( ++p == pe )
		goto _test_eof1385;
case 1385:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto st1385;
		case 32: goto st1385;
		case 40: goto tr4131;
		case 41: goto tr4132;
		case 2058: goto tr4134;
		case 2107: goto tr4135;
	}
	if ( _widec < 65 ) {
		if ( 48 <= _widec && _widec <= 57 )
			goto tr4133;
	} else if ( _widec > 70 ) {
		if ( 97 <= _widec && _widec <= 102 )
			goto tr4133;
	} else
		goto tr4133;
	goto tr3067;
tr4133:
	{
		if (rdata_tail <= rdata_stop) {
			*rdata_tail = first_hex_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st1386;
st1386:
	if ( ++p == pe )
		goto _test_eof1386;
case 1386:
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr4136;
	} else if ( (*p) > 70 ) {
		if ( 97 <= (*p) && (*p) <= 102 )
			goto tr4136;
	} else
		goto tr4136;
	goto tr3067;
tr4138:
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st1387;
tr4139:
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st1387;
tr4140:
	{
		s->line_counter++;
	}
	goto st1387;
tr4146:
	{
		s->buffer[s->buffer_length++] = 0;

		// Execute the comment callback.
		if (s->process.automatic && s->process.comment != NULL) {
			s->process.comment(s);

			// Stop if required from the callback.
			if (s->state == ZS_STATE_STOP) {
				{p++; cs = 1387; goto _out;}
			}
		}
	}
	{
		s->line_counter++;
	}
	goto st1387;
tr4136:
	{
		*rdata_tail += second_hex_to_num[(uint8_t)(*p)];
		rdata_tail++;
	}
	goto st1387;
st1387:
	if ( ++p == pe )
		goto _test_eof1387;
case 1387:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(2688 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 !s->multiline  ) _widec += 512;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(2688 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		if (
 !s->multiline  ) _widec += 512;
	}
	switch( _widec ) {
		case 9: goto st1387;
		case 32: goto st1387;
		case 40: goto tr4138;
		case 41: goto tr4139;
		case 3082: goto tr4140;
		case 3131: goto tr4141;
		case 3338: goto tr4142;
		case 3387: goto tr4142;
		case 3594: goto tr4143;
		case 3643: goto tr4144;
	}
	if ( _widec < 65 ) {
		if ( 48 <= _widec && _widec <= 57 )
			goto tr4133;
	} else if ( _widec > 70 ) {
		if ( 97 <= _widec && _widec <= 102 )
			goto tr4133;
	} else
		goto tr4133;
	goto tr3067;
tr4141:
	{
		s->buffer_length = 0;
	}
	goto st1388;
tr4145:
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		}
	}
	goto st1388;
st1388:
	if ( ++p == pe )
		goto _test_eof1388;
case 1388:
	_widec = (*p);
	if ( (*p) < 10 ) {
		if ( (*p) <= 9 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) > 10 ) {
		if ( 11 <= (*p) )
 {			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	if ( _widec == 2058 )
		goto tr4146;
	if ( 1920 <= _widec && _widec <= 2175 )
		goto tr4145;
	goto tr3067;
tr4142:
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1531;
st1531:
	if ( ++p == pe )
		goto _test_eof1531;
case 1531:
	goto st0;
tr4143:
	{
		s->line_counter++;
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1532;
st1532:
	if ( ++p == pe )
		goto _test_eof1532;
case 1532:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(2688 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
			if (
 !s->multiline  ) _widec += 512;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(2688 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		if (
 !s->multiline  ) _widec += 512;
	}
	switch( _widec ) {
		case 9: goto st1387;
		case 32: goto st1387;
		case 40: goto tr4138;
		case 41: goto tr4139;
		case 3082: goto tr4140;
		case 3131: goto tr4141;
		case 3338: goto tr4142;
		case 3387: goto tr4142;
		case 3594: goto tr4143;
		case 3643: goto tr4144;
	}
	if ( _widec < 65 ) {
		if ( 48 <= _widec && _widec <= 57 )
			goto tr4133;
	} else if ( _widec > 70 ) {
		if ( 97 <= _widec && _widec <= 102 )
			goto tr4133;
	} else
		goto tr4133;
	goto tr3067;
tr4144:
	{
		s->buffer_length = 0;
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1533;
st1533:
	if ( ++p == pe )
		goto _test_eof1533;
case 1533:
	_widec = (*p);
	if ( (*p) < 10 ) {
		if ( (*p) <= 9 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) > 10 ) {
		if ( 11 <= (*p) )
 {			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	if ( _widec == 2058 )
		goto tr4146;
	if ( 1920 <= _widec && _widec <= 2175 )
		goto tr4145;
	goto tr3067;
tr4135:
	{
		s->buffer_length = 0;
	}
	goto st1389;
tr4147:
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		}
	}
	goto st1389;
tr4129:
	{
		if (s->number64 <= UINT8_MAX) {
			*rdata_tail = (uint8_t)(s->number64);
			rdata_tail += 1;
		} else {
			WARN(ZS_NUMBER8_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		s->buffer_length = 0;
	}
	goto st1389;
st1389:
	if ( ++p == pe )
		goto _test_eof1389;
case 1389:
	_widec = (*p);
	if ( (*p) < 10 ) {
		if ( (*p) <= 9 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) > 10 ) {
		if ( 11 <= (*p) )
 {			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	if ( _widec == 2058 )
		goto tr4148;
	if ( 1920 <= _widec && _widec <= 2175 )
		goto tr4147;
	goto tr77;
tr4123:
	{
		s->buffer_length = 0;
	}
	goto st1390;
tr4149:
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		}
	}
	goto st1390;
tr4117:
	{
		if (s->number64 <= UINT8_MAX) {
			*rdata_tail = (uint8_t)(s->number64);
			rdata_tail += 1;
		} else {
			WARN(ZS_NUMBER8_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		s->buffer_length = 0;
	}
	goto st1390;
st1390:
	if ( ++p == pe )
		goto _test_eof1390;
case 1390:
	_widec = (*p);
	if ( (*p) < 10 ) {
		if ( (*p) <= 9 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) > 10 ) {
		if ( 11 <= (*p) )
 {			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	if ( _widec == 2058 )
		goto tr4150;
	if ( 1920 <= _widec && _widec <= 2175 )
		goto tr4149;
	goto tr77;
tr4111:
	{
		s->buffer_length = 0;
	}
	goto st1391;
tr4151:
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		}
	}
	goto st1391;
tr4105:
	{
		if (s->number64 <= UINT32_MAX) {
			uint32_t num32 = htonl((uint32_t)s->number64);
			memcpy(rdata_tail, &num32, 4);
			rdata_tail += 4;
		} else {
			WARN(ZS_NUMBER32_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		s->buffer_length = 0;
	}
	goto st1391;
st1391:
	if ( ++p == pe )
		goto _test_eof1391;
case 1391:
	_widec = (*p);
	if ( (*p) < 10 ) {
		if ( (*p) <= 9 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) > 10 ) {
		if ( 11 <= (*p) )
 {			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	if ( _widec == 2058 )
		goto tr4152;
	if ( 1920 <= _widec && _widec <= 2175 )
		goto tr4151;
	goto tr77;
st1392:
	if ( ++p == pe )
		goto _test_eof1392;
case 1392:
	if ( 48 <= (*p) && (*p) <= 57 )
		goto tr4153;
	goto tr2396;
tr4153:
	{
		s->number64 = 0;
	}
	{
		// Overflow check: 10*(s->number64) + fc - '0' <= UINT64_MAX
		if ((s->number64 < (UINT64_MAX / 10)) ||   // Dominant fast check.
			((s->number64 == (UINT64_MAX / 10)) && // Marginal case.
			 ((uint8_t)(*p) <= (UINT64_MAX % 10) + '0')
			)
		   ) {
			s->number64 *= 10;
			s->number64 += digit_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_NUMBER64_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st1393;
tr4157:
	{
		// Overflow check: 10*(s->number64) + fc - '0' <= UINT64_MAX
		if ((s->number64 < (UINT64_MAX / 10)) ||   // Dominant fast check.
			((s->number64 == (UINT64_MAX / 10)) && // Marginal case.
			 ((uint8_t)(*p) <= (UINT64_MAX % 10) + '0')
			)
		   ) {
			s->number64 *= 10;
			s->number64 += digit_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_NUMBER64_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st1393;
st1393:
	if ( ++p == pe )
		goto _test_eof1393;
case 1393:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr4154;
		case 32: goto tr4154;
		case 40: goto tr4155;
		case 41: goto tr4156;
		case 2058: goto tr4158;
		case 2107: goto tr4159;
	}
	if ( 48 <= _widec && _widec <= 57 )
		goto tr4157;
	goto tr2396;
tr4161:
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st1394;
tr4162:
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st1394;
tr4164:
	{
		s->line_counter++;
	}
	goto st1394;
tr4169:
	{
		s->buffer[s->buffer_length++] = 0;

		// Execute the comment callback.
		if (s->process.automatic && s->process.comment != NULL) {
			s->process.comment(s);

			// Stop if required from the callback.
			if (s->state == ZS_STATE_STOP) {
				{p++; cs = 1394; goto _out;}
			}
		}
	}
	{
		s->line_counter++;
	}
	goto st1394;
tr4154:
	{
		if (s->number64 <= UINT16_MAX) {
			uint16_t num16 = htons((uint16_t)s->number64);
			memcpy(rdata_tail, &num16, 2);
			rdata_tail += 2;
		} else {
			WARN(ZS_NUMBER16_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st1394;
tr4155:
	{
		if (s->number64 <= UINT16_MAX) {
			uint16_t num16 = htons((uint16_t)s->number64);
			memcpy(rdata_tail, &num16, 2);
			rdata_tail += 2;
		} else {
			WARN(ZS_NUMBER16_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st1394;
tr4156:
	{
		if (s->number64 <= UINT16_MAX) {
			uint16_t num16 = htons((uint16_t)s->number64);
			memcpy(rdata_tail, &num16, 2);
			rdata_tail += 2;
		} else {
			WARN(ZS_NUMBER16_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st1394;
tr4158:
	{
		if (s->number64 <= UINT16_MAX) {
			uint16_t num16 = htons((uint16_t)s->number64);
			memcpy(rdata_tail, &num16, 2);
			rdata_tail += 2;
		} else {
			WARN(ZS_NUMBER16_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		s->line_counter++;
	}
	goto st1394;
st1394:
	if ( ++p == pe )
		goto _test_eof1394;
case 1394:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto st1394;
		case 32: goto st1394;
		case 40: goto tr4161;
		case 41: goto tr4162;
		case 46: goto tr4163;
		case 2058: goto tr4164;
		case 2107: goto tr4165;
	}
	if ( 48 <= _widec && _widec <= 57 )
		goto tr4163;
	goto tr2373;
tr4167:
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		} else {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st1395;
tr4163:
	{
		s->buffer_length = 0;
	}
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		} else {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st1395;
st1395:
	if ( ++p == pe )
		goto _test_eof1395;
case 1395:
	switch( (*p) ) {
		case 32: goto tr4166;
		case 46: goto tr4167;
		case 59: goto tr4166;
	}
	if ( (*p) < 40 ) {
		if ( 9 <= (*p) && (*p) <= 10 )
			goto tr4166;
	} else if ( (*p) > 41 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr4167;
	} else
		goto tr4166;
	goto tr2373;
tr4166:
	{
		s->buffer[s->buffer_length] = 0;

		if (inet_pton(AF_INET, (char *)s->buffer, s->addr) <= 0) {
			WARN(ZS_BAD_IPV4);
			p--; {goto st316;}
		}
	}
	{
		if (rdata_tail + ZS_INET4_ADDR_LENGTH > rdata_stop + 1) {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
		memcpy(rdata_tail, s->addr, ZS_INET4_ADDR_LENGTH);
		rdata_tail += ZS_INET4_ADDR_LENGTH;
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1534;
st1534:
	if ( ++p == pe )
		goto _test_eof1534;
case 1534:
	goto st0;
tr4165:
	{
		s->buffer_length = 0;
	}
	goto st1396;
tr4168:
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		}
	}
	goto st1396;
tr4159:
	{
		if (s->number64 <= UINT16_MAX) {
			uint16_t num16 = htons((uint16_t)s->number64);
			memcpy(rdata_tail, &num16, 2);
			rdata_tail += 2;
		} else {
			WARN(ZS_NUMBER16_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		s->buffer_length = 0;
	}
	goto st1396;
st1396:
	if ( ++p == pe )
		goto _test_eof1396;
case 1396:
	_widec = (*p);
	if ( (*p) < 10 ) {
		if ( (*p) <= 9 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) > 10 ) {
		if ( 11 <= (*p) )
 {			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	if ( _widec == 2058 )
		goto tr4169;
	if ( 1920 <= _widec && _widec <= 2175 )
		goto tr4168;
	goto tr77;
st1397:
	if ( ++p == pe )
		goto _test_eof1397;
case 1397:
	if ( 48 <= (*p) && (*p) <= 57 )
		goto tr4170;
	goto tr2396;
tr4170:
	{
		s->number64 = 0;
	}
	{
		// Overflow check: 10*(s->number64) + fc - '0' <= UINT64_MAX
		if ((s->number64 < (UINT64_MAX / 10)) ||   // Dominant fast check.
			((s->number64 == (UINT64_MAX / 10)) && // Marginal case.
			 ((uint8_t)(*p) <= (UINT64_MAX % 10) + '0')
			)
		   ) {
			s->number64 *= 10;
			s->number64 += digit_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_NUMBER64_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st1398;
tr4174:
	{
		// Overflow check: 10*(s->number64) + fc - '0' <= UINT64_MAX
		if ((s->number64 < (UINT64_MAX / 10)) ||   // Dominant fast check.
			((s->number64 == (UINT64_MAX / 10)) && // Marginal case.
			 ((uint8_t)(*p) <= (UINT64_MAX % 10) + '0')
			)
		   ) {
			s->number64 *= 10;
			s->number64 += digit_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_NUMBER64_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st1398;
st1398:
	if ( ++p == pe )
		goto _test_eof1398;
case 1398:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr4171;
		case 32: goto tr4171;
		case 40: goto tr4172;
		case 41: goto tr4173;
		case 2058: goto tr4175;
		case 2107: goto tr4176;
	}
	if ( 48 <= _widec && _widec <= 57 )
		goto tr4174;
	goto tr2396;
tr4178:
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st1399;
tr4179:
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st1399;
tr4181:
	{
		s->line_counter++;
	}
	goto st1399;
tr4195:
	{
		s->buffer[s->buffer_length++] = 0;

		// Execute the comment callback.
		if (s->process.automatic && s->process.comment != NULL) {
			s->process.comment(s);

			// Stop if required from the callback.
			if (s->state == ZS_STATE_STOP) {
				{p++; cs = 1399; goto _out;}
			}
		}
	}
	{
		s->line_counter++;
	}
	goto st1399;
tr4171:
	{
		if (s->number64 <= UINT16_MAX) {
			uint16_t num16 = htons((uint16_t)s->number64);
			memcpy(rdata_tail, &num16, 2);
			rdata_tail += 2;
		} else {
			WARN(ZS_NUMBER16_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st1399;
tr4172:
	{
		if (s->number64 <= UINT16_MAX) {
			uint16_t num16 = htons((uint16_t)s->number64);
			memcpy(rdata_tail, &num16, 2);
			rdata_tail += 2;
		} else {
			WARN(ZS_NUMBER16_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st1399;
tr4173:
	{
		if (s->number64 <= UINT16_MAX) {
			uint16_t num16 = htons((uint16_t)s->number64);
			memcpy(rdata_tail, &num16, 2);
			rdata_tail += 2;
		} else {
			WARN(ZS_NUMBER16_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st1399;
tr4175:
	{
		if (s->number64 <= UINT16_MAX) {
			uint16_t num16 = htons((uint16_t)s->number64);
			memcpy(rdata_tail, &num16, 2);
			rdata_tail += 2;
		} else {
			WARN(ZS_NUMBER16_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		s->line_counter++;
	}
	goto st1399;
st1399:
	if ( ++p == pe )
		goto _test_eof1399;
case 1399:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto st1399;
		case 32: goto st1399;
		case 40: goto tr4178;
		case 41: goto tr4179;
		case 2058: goto tr4181;
		case 2107: goto tr4182;
	}
	if ( _widec < 65 ) {
		if ( 48 <= _widec && _widec <= 57 )
			goto tr4180;
	} else if ( _widec > 70 ) {
		if ( 97 <= _widec && _widec <= 102 )
			goto tr4180;
	} else
		goto tr4180;
	goto tr3067;
tr4180:
	{
		s->item_length = 0;
	}
	{
		if (rdata_tail <= rdata_stop) {
			*rdata_tail = first_hex_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st1400;
st1400:
	if ( ++p == pe )
		goto _test_eof1400;
case 1400:
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr4183;
	} else if ( (*p) > 70 ) {
		if ( 97 <= (*p) && (*p) <= 102 )
			goto tr4183;
	} else
		goto tr4183;
	goto tr3067;
tr4183:
	{
		*rdata_tail += second_hex_to_num[(uint8_t)(*p)];
		rdata_tail++;
	}
	goto st1401;
st1401:
	if ( ++p == pe )
		goto _test_eof1401;
case 1401:
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr4184;
	} else if ( (*p) > 70 ) {
		if ( 97 <= (*p) && (*p) <= 102 )
			goto tr4184;
	} else
		goto tr4184;
	goto tr3067;
tr4184:
	{
		if (rdata_tail <= rdata_stop) {
			*rdata_tail = first_hex_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st1402;
st1402:
	if ( ++p == pe )
		goto _test_eof1402;
case 1402:
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr4185;
	} else if ( (*p) > 70 ) {
		if ( 97 <= (*p) && (*p) <= 102 )
			goto tr4185;
	} else
		goto tr4185;
	goto tr3067;
tr4185:
	{
		*rdata_tail += second_hex_to_num[(uint8_t)(*p)];
		rdata_tail++;
	}
	goto st1403;
st1403:
	if ( ++p == pe )
		goto _test_eof1403;
case 1403:
	if ( (*p) == 58 )
		goto tr4187;
	goto tr4186;
tr4187:
	{
		s->item_length++;
	}
	goto st1404;
st1404:
	if ( ++p == pe )
		goto _test_eof1404;
case 1404:
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr4188;
	} else if ( (*p) > 70 ) {
		if ( 97 <= (*p) && (*p) <= 102 )
			goto tr4188;
	} else
		goto tr4188;
	goto tr3067;
tr4188:
	{
		if (rdata_tail <= rdata_stop) {
			*rdata_tail = first_hex_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st1405;
st1405:
	if ( ++p == pe )
		goto _test_eof1405;
case 1405:
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr4189;
	} else if ( (*p) > 70 ) {
		if ( 97 <= (*p) && (*p) <= 102 )
			goto tr4189;
	} else
		goto tr4189;
	goto tr3067;
tr4189:
	{
		*rdata_tail += second_hex_to_num[(uint8_t)(*p)];
		rdata_tail++;
	}
	goto st1406;
st1406:
	if ( ++p == pe )
		goto _test_eof1406;
case 1406:
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr4190;
	} else if ( (*p) > 70 ) {
		if ( 97 <= (*p) && (*p) <= 102 )
			goto tr4190;
	} else
		goto tr4190;
	goto tr3067;
tr4190:
	{
		if (rdata_tail <= rdata_stop) {
			*rdata_tail = first_hex_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st1407;
st1407:
	if ( ++p == pe )
		goto _test_eof1407;
case 1407:
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr4191;
	} else if ( (*p) > 70 ) {
		if ( 97 <= (*p) && (*p) <= 102 )
			goto tr4191;
	} else
		goto tr4191;
	goto tr3067;
tr4191:
	{
		*rdata_tail += second_hex_to_num[(uint8_t)(*p)];
		rdata_tail++;
	}
	goto st1408;
st1408:
	if ( ++p == pe )
		goto _test_eof1408;
case 1408:
	switch( (*p) ) {
		case 32: goto tr4193;
		case 58: goto tr4187;
		case 59: goto tr4193;
	}
	if ( (*p) > 10 ) {
		if ( 40 <= (*p) && (*p) <= 41 )
			goto tr4193;
	} else if ( (*p) >= 9 )
		goto tr4193;
	goto tr4192;
tr4193:
	{
		s->item_length++;
	}
	{
		if (s->item_length != 4) {
			WARN(ZS_BAD_L64_LENGTH);
			p--; {goto st316;}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1535;
st1535:
	if ( ++p == pe )
		goto _test_eof1535;
case 1535:
	goto st0;
tr4182:
	{
		s->buffer_length = 0;
	}
	goto st1409;
tr4194:
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		}
	}
	goto st1409;
tr4176:
	{
		if (s->number64 <= UINT16_MAX) {
			uint16_t num16 = htons((uint16_t)s->number64);
			memcpy(rdata_tail, &num16, 2);
			rdata_tail += 2;
		} else {
			WARN(ZS_NUMBER16_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		s->buffer_length = 0;
	}
	goto st1409;
st1409:
	if ( ++p == pe )
		goto _test_eof1409;
case 1409:
	_widec = (*p);
	if ( (*p) < 10 ) {
		if ( (*p) <= 9 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) > 10 ) {
		if ( 11 <= (*p) )
 {			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	if ( _widec == 2058 )
		goto tr4195;
	if ( 1920 <= _widec && _widec <= 2175 )
		goto tr4194;
	goto tr77;
st1410:
	if ( ++p == pe )
		goto _test_eof1410;
case 1410:
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr4196;
	} else if ( (*p) > 70 ) {
		if ( 97 <= (*p) && (*p) <= 102 )
			goto tr4196;
	} else
		goto tr4196;
	goto tr3067;
tr4196:
	{
		s->item_length = 0;
	}
	{
		if (rdata_tail <= rdata_stop) {
			*rdata_tail = first_hex_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st1411;
st1411:
	if ( ++p == pe )
		goto _test_eof1411;
case 1411:
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr4197;
	} else if ( (*p) > 70 ) {
		if ( 97 <= (*p) && (*p) <= 102 )
			goto tr4197;
	} else
		goto tr4197;
	goto tr3067;
tr4197:
	{
		*rdata_tail += second_hex_to_num[(uint8_t)(*p)];
		rdata_tail++;
	}
	goto st1412;
st1412:
	if ( ++p == pe )
		goto _test_eof1412;
case 1412:
	if ( (*p) == 45 )
		goto tr4199;
	goto tr4198;
tr4199:
	{
		s->item_length++;
	}
	goto st1413;
st1413:
	if ( ++p == pe )
		goto _test_eof1413;
case 1413:
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr4200;
	} else if ( (*p) > 70 ) {
		if ( 97 <= (*p) && (*p) <= 102 )
			goto tr4200;
	} else
		goto tr4200;
	goto tr3067;
tr4200:
	{
		if (rdata_tail <= rdata_stop) {
			*rdata_tail = first_hex_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st1414;
st1414:
	if ( ++p == pe )
		goto _test_eof1414;
case 1414:
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr4201;
	} else if ( (*p) > 70 ) {
		if ( 97 <= (*p) && (*p) <= 102 )
			goto tr4201;
	} else
		goto tr4201;
	goto tr3067;
tr4201:
	{
		*rdata_tail += second_hex_to_num[(uint8_t)(*p)];
		rdata_tail++;
	}
	goto st1415;
st1415:
	if ( ++p == pe )
		goto _test_eof1415;
case 1415:
	switch( (*p) ) {
		case 32: goto tr4202;
		case 45: goto tr4199;
		case 59: goto tr4202;
	}
	if ( (*p) > 10 ) {
		if ( 40 <= (*p) && (*p) <= 41 )
			goto tr4202;
	} else if ( (*p) >= 9 )
		goto tr4202;
	goto tr4198;
tr4202:
	{
		s->item_length++;
	}
	{
		if (s->item_length != 6) {
			WARN(ZS_BAD_EUI_LENGTH);
			p--; {goto st316;}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1536;
st1536:
	if ( ++p == pe )
		goto _test_eof1536;
case 1536:
	goto st0;
st1416:
	if ( ++p == pe )
		goto _test_eof1416;
case 1416:
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr4203;
	} else if ( (*p) > 70 ) {
		if ( 97 <= (*p) && (*p) <= 102 )
			goto tr4203;
	} else
		goto tr4203;
	goto tr3067;
tr4203:
	{
		s->item_length = 0;
	}
	{
		if (rdata_tail <= rdata_stop) {
			*rdata_tail = first_hex_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st1417;
st1417:
	if ( ++p == pe )
		goto _test_eof1417;
case 1417:
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr4204;
	} else if ( (*p) > 70 ) {
		if ( 97 <= (*p) && (*p) <= 102 )
			goto tr4204;
	} else
		goto tr4204;
	goto tr3067;
tr4204:
	{
		*rdata_tail += second_hex_to_num[(uint8_t)(*p)];
		rdata_tail++;
	}
	goto st1418;
st1418:
	if ( ++p == pe )
		goto _test_eof1418;
case 1418:
	if ( (*p) == 45 )
		goto tr4205;
	goto tr4198;
tr4205:
	{
		s->item_length++;
	}
	goto st1419;
st1419:
	if ( ++p == pe )
		goto _test_eof1419;
case 1419:
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr4206;
	} else if ( (*p) > 70 ) {
		if ( 97 <= (*p) && (*p) <= 102 )
			goto tr4206;
	} else
		goto tr4206;
	goto tr3067;
tr4206:
	{
		if (rdata_tail <= rdata_stop) {
			*rdata_tail = first_hex_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st1420;
st1420:
	if ( ++p == pe )
		goto _test_eof1420;
case 1420:
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr4207;
	} else if ( (*p) > 70 ) {
		if ( 97 <= (*p) && (*p) <= 102 )
			goto tr4207;
	} else
		goto tr4207;
	goto tr3067;
tr4207:
	{
		*rdata_tail += second_hex_to_num[(uint8_t)(*p)];
		rdata_tail++;
	}
	goto st1421;
st1421:
	if ( ++p == pe )
		goto _test_eof1421;
case 1421:
	switch( (*p) ) {
		case 32: goto tr4208;
		case 45: goto tr4205;
		case 59: goto tr4208;
	}
	if ( (*p) > 10 ) {
		if ( 40 <= (*p) && (*p) <= 41 )
			goto tr4208;
	} else if ( (*p) >= 9 )
		goto tr4208;
	goto tr4198;
tr4208:
	{
		s->item_length++;
	}
	{
		if (s->item_length != 8) {
			WARN(ZS_BAD_EUI_LENGTH);
			p--; {goto st316;}
		}
	}
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1537;
st1537:
	if ( ++p == pe )
		goto _test_eof1537;
case 1537:
	goto st0;
st1422:
	if ( ++p == pe )
		goto _test_eof1422;
case 1422:
	if ( 48 <= (*p) && (*p) <= 57 )
		goto tr4209;
	goto tr2396;
tr4209:
	{
		s->number64 = 0;
	}
	{
		// Overflow check: 10*(s->number64) + fc - '0' <= UINT64_MAX
		if ((s->number64 < (UINT64_MAX / 10)) ||   // Dominant fast check.
			((s->number64 == (UINT64_MAX / 10)) && // Marginal case.
			 ((uint8_t)(*p) <= (UINT64_MAX % 10) + '0')
			)
		   ) {
			s->number64 *= 10;
			s->number64 += digit_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_NUMBER64_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st1423;
tr4213:
	{
		// Overflow check: 10*(s->number64) + fc - '0' <= UINT64_MAX
		if ((s->number64 < (UINT64_MAX / 10)) ||   // Dominant fast check.
			((s->number64 == (UINT64_MAX / 10)) && // Marginal case.
			 ((uint8_t)(*p) <= (UINT64_MAX % 10) + '0')
			)
		   ) {
			s->number64 *= 10;
			s->number64 += digit_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_NUMBER64_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st1423;
st1423:
	if ( ++p == pe )
		goto _test_eof1423;
case 1423:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr4210;
		case 32: goto tr4210;
		case 40: goto tr4211;
		case 41: goto tr4212;
		case 2058: goto tr4214;
		case 2107: goto tr4215;
	}
	if ( 48 <= _widec && _widec <= 57 )
		goto tr4213;
	goto tr2396;
tr4217:
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st1424;
tr4218:
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st1424;
tr4220:
	{
		s->line_counter++;
	}
	goto st1424;
tr4238:
	{
		s->buffer[s->buffer_length++] = 0;

		// Execute the comment callback.
		if (s->process.automatic && s->process.comment != NULL) {
			s->process.comment(s);

			// Stop if required from the callback.
			if (s->state == ZS_STATE_STOP) {
				{p++; cs = 1424; goto _out;}
			}
		}
	}
	{
		s->line_counter++;
	}
	goto st1424;
tr4210:
	{
		if (s->number64 <= UINT16_MAX) {
			uint16_t num16 = htons((uint16_t)s->number64);
			memcpy(rdata_tail, &num16, 2);
			rdata_tail += 2;
		} else {
			WARN(ZS_NUMBER16_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st1424;
tr4211:
	{
		if (s->number64 <= UINT16_MAX) {
			uint16_t num16 = htons((uint16_t)s->number64);
			memcpy(rdata_tail, &num16, 2);
			rdata_tail += 2;
		} else {
			WARN(ZS_NUMBER16_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st1424;
tr4212:
	{
		if (s->number64 <= UINT16_MAX) {
			uint16_t num16 = htons((uint16_t)s->number64);
			memcpy(rdata_tail, &num16, 2);
			rdata_tail += 2;
		} else {
			WARN(ZS_NUMBER16_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st1424;
tr4214:
	{
		if (s->number64 <= UINT16_MAX) {
			uint16_t num16 = htons((uint16_t)s->number64);
			memcpy(rdata_tail, &num16, 2);
			rdata_tail += 2;
		} else {
			WARN(ZS_NUMBER16_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		s->line_counter++;
	}
	goto st1424;
st1424:
	if ( ++p == pe )
		goto _test_eof1424;
case 1424:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto st1424;
		case 32: goto st1424;
		case 40: goto tr4217;
		case 41: goto tr4218;
		case 2058: goto tr4220;
		case 2107: goto tr4221;
	}
	if ( 48 <= _widec && _widec <= 57 )
		goto tr4219;
	goto tr2396;
tr4219:
	{
		s->number64 = 0;
	}
	{
		// Overflow check: 10*(s->number64) + fc - '0' <= UINT64_MAX
		if ((s->number64 < (UINT64_MAX / 10)) ||   // Dominant fast check.
			((s->number64 == (UINT64_MAX / 10)) && // Marginal case.
			 ((uint8_t)(*p) <= (UINT64_MAX % 10) + '0')
			)
		   ) {
			s->number64 *= 10;
			s->number64 += digit_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_NUMBER64_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st1425;
tr4225:
	{
		// Overflow check: 10*(s->number64) + fc - '0' <= UINT64_MAX
		if ((s->number64 < (UINT64_MAX / 10)) ||   // Dominant fast check.
			((s->number64 == (UINT64_MAX / 10)) && // Marginal case.
			 ((uint8_t)(*p) <= (UINT64_MAX % 10) + '0')
			)
		   ) {
			s->number64 *= 10;
			s->number64 += digit_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_NUMBER64_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st1425;
st1425:
	if ( ++p == pe )
		goto _test_eof1425;
case 1425:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr4222;
		case 32: goto tr4222;
		case 40: goto tr4223;
		case 41: goto tr4224;
		case 2058: goto tr4226;
		case 2107: goto tr4227;
	}
	if ( 48 <= _widec && _widec <= 57 )
		goto tr4225;
	goto tr2396;
tr4230:
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st1426;
tr4231:
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st1426;
tr4232:
	{
		s->line_counter++;
	}
	goto st1426;
tr4236:
	{
		s->buffer[s->buffer_length++] = 0;

		// Execute the comment callback.
		if (s->process.automatic && s->process.comment != NULL) {
			s->process.comment(s);

			// Stop if required from the callback.
			if (s->state == ZS_STATE_STOP) {
				{p++; cs = 1426; goto _out;}
			}
		}
	}
	{
		s->line_counter++;
	}
	goto st1426;
tr4222:
	{
		if (s->number64 <= UINT16_MAX) {
			uint16_t num16 = htons((uint16_t)s->number64);
			memcpy(rdata_tail, &num16, 2);
			rdata_tail += 2;
		} else {
			WARN(ZS_NUMBER16_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st1426;
tr4223:
	{
		if (s->number64 <= UINT16_MAX) {
			uint16_t num16 = htons((uint16_t)s->number64);
			memcpy(rdata_tail, &num16, 2);
			rdata_tail += 2;
		} else {
			WARN(ZS_NUMBER16_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st1426;
tr4224:
	{
		if (s->number64 <= UINT16_MAX) {
			uint16_t num16 = htons((uint16_t)s->number64);
			memcpy(rdata_tail, &num16, 2);
			rdata_tail += 2;
		} else {
			WARN(ZS_NUMBER16_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st1426;
tr4226:
	{
		if (s->number64 <= UINT16_MAX) {
			uint16_t num16 = htons((uint16_t)s->number64);
			memcpy(rdata_tail, &num16, 2);
			rdata_tail += 2;
		} else {
			WARN(ZS_NUMBER16_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		s->line_counter++;
	}
	goto st1426;
st1426:
	if ( ++p == pe )
		goto _test_eof1426;
case 1426:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto st1426;
		case 32: goto st1426;
		case 40: goto tr4230;
		case 41: goto tr4231;
		case 2058: goto tr4232;
		case 2107: goto tr4233;
	}
	if ( _widec < 11 ) {
		if ( _widec <= 8 )
			goto tr4228;
	} else if ( _widec > 58 ) {
		if ( 60 <= _widec )
			goto tr4228;
	} else
		goto tr4228;
	goto tr77;
tr4228:
	{ p--; {stack[top++] = 1427;goto st327;} }
	goto st1427;
st1427:
	if ( ++p == pe )
		goto _test_eof1427;
case 1427:
	switch( (*p) ) {
		case 32: goto tr4234;
		case 59: goto tr4234;
	}
	if ( (*p) > 10 ) {
		if ( 40 <= (*p) && (*p) <= 41 )
			goto tr4234;
	} else if ( (*p) >= 9 )
		goto tr4234;
	goto tr77;
tr4234:
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1538;
st1538:
	if ( ++p == pe )
		goto _test_eof1538;
case 1538:
	goto st0;
tr4233:
	{
		s->buffer_length = 0;
	}
	goto st1428;
tr4235:
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		}
	}
	goto st1428;
tr4227:
	{
		if (s->number64 <= UINT16_MAX) {
			uint16_t num16 = htons((uint16_t)s->number64);
			memcpy(rdata_tail, &num16, 2);
			rdata_tail += 2;
		} else {
			WARN(ZS_NUMBER16_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		s->buffer_length = 0;
	}
	goto st1428;
st1428:
	if ( ++p == pe )
		goto _test_eof1428;
case 1428:
	_widec = (*p);
	if ( (*p) < 10 ) {
		if ( (*p) <= 9 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) > 10 ) {
		if ( 11 <= (*p) )
 {			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	if ( _widec == 2058 )
		goto tr4236;
	if ( 1920 <= _widec && _widec <= 2175 )
		goto tr4235;
	goto tr77;
tr4221:
	{
		s->buffer_length = 0;
	}
	goto st1429;
tr4237:
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		}
	}
	goto st1429;
tr4215:
	{
		if (s->number64 <= UINT16_MAX) {
			uint16_t num16 = htons((uint16_t)s->number64);
			memcpy(rdata_tail, &num16, 2);
			rdata_tail += 2;
		} else {
			WARN(ZS_NUMBER16_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		s->buffer_length = 0;
	}
	goto st1429;
st1429:
	if ( ++p == pe )
		goto _test_eof1429;
case 1429:
	_widec = (*p);
	if ( (*p) < 10 ) {
		if ( (*p) <= 9 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) > 10 ) {
		if ( 11 <= (*p) )
 {			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	if ( _widec == 2058 )
		goto tr4238;
	if ( 1920 <= _widec && _widec <= 2175 )
		goto tr4237;
	goto tr77;
st1430:
	if ( ++p == pe )
		goto _test_eof1430;
case 1430:
	if ( 48 <= (*p) && (*p) <= 57 )
		goto tr4239;
	goto tr2396;
tr4239:
	{
		s->number64 = 0;
	}
	{
		// Overflow check: 10*(s->number64) + fc - '0' <= UINT64_MAX
		if ((s->number64 < (UINT64_MAX / 10)) ||   // Dominant fast check.
			((s->number64 == (UINT64_MAX / 10)) && // Marginal case.
			 ((uint8_t)(*p) <= (UINT64_MAX % 10) + '0')
			)
		   ) {
			s->number64 *= 10;
			s->number64 += digit_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_NUMBER64_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st1431;
tr4243:
	{
		// Overflow check: 10*(s->number64) + fc - '0' <= UINT64_MAX
		if ((s->number64 < (UINT64_MAX / 10)) ||   // Dominant fast check.
			((s->number64 == (UINT64_MAX / 10)) && // Marginal case.
			 ((uint8_t)(*p) <= (UINT64_MAX % 10) + '0')
			)
		   ) {
			s->number64 *= 10;
			s->number64 += digit_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_NUMBER64_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st1431;
st1431:
	if ( ++p == pe )
		goto _test_eof1431;
case 1431:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr4240;
		case 32: goto tr4240;
		case 40: goto tr4241;
		case 41: goto tr4242;
		case 2058: goto tr4244;
		case 2107: goto tr4245;
	}
	if ( 48 <= _widec && _widec <= 57 )
		goto tr4243;
	goto tr2396;
tr4248:
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st1432;
tr4249:
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st1432;
tr4250:
	{
		s->line_counter++;
	}
	goto st1432;
tr4267:
	{
		s->buffer[s->buffer_length++] = 0;

		// Execute the comment callback.
		if (s->process.automatic && s->process.comment != NULL) {
			s->process.comment(s);

			// Stop if required from the callback.
			if (s->state == ZS_STATE_STOP) {
				{p++; cs = 1432; goto _out;}
			}
		}
	}
	{
		s->line_counter++;
	}
	goto st1432;
tr4240:
	{
		if (s->number64 <= UINT8_MAX) {
			*rdata_tail = (uint8_t)(s->number64);
			rdata_tail += 1;
		} else {
			WARN(ZS_NUMBER8_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st1432;
tr4241:
	{
		if (s->number64 <= UINT8_MAX) {
			*rdata_tail = (uint8_t)(s->number64);
			rdata_tail += 1;
		} else {
			WARN(ZS_NUMBER8_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st1432;
tr4242:
	{
		if (s->number64 <= UINT8_MAX) {
			*rdata_tail = (uint8_t)(s->number64);
			rdata_tail += 1;
		} else {
			WARN(ZS_NUMBER8_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st1432;
tr4244:
	{
		if (s->number64 <= UINT8_MAX) {
			*rdata_tail = (uint8_t)(s->number64);
			rdata_tail += 1;
		} else {
			WARN(ZS_NUMBER8_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		s->line_counter++;
	}
	goto st1432;
st1432:
	if ( ++p == pe )
		goto _test_eof1432;
case 1432:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto st1432;
		case 32: goto st1432;
		case 40: goto tr4248;
		case 41: goto tr4249;
		case 2058: goto tr4250;
		case 2107: goto tr4251;
	}
	if ( _widec < 11 ) {
		if ( _widec <= 8 )
			goto tr4246;
	} else if ( _widec > 58 ) {
		if ( 60 <= _widec )
			goto tr4246;
	} else
		goto tr4246;
	goto tr77;
tr4246:
	{
		if (rdata_tail <= rdata_stop) {
			s->item_length_location = rdata_tail++;
		} else {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{ p--; {stack[top++] = 1433;goto st327;} }
	goto st1433;
st1433:
	if ( ++p == pe )
		goto _test_eof1433;
case 1433:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr4252;
		case 32: goto tr4252;
		case 40: goto tr4253;
		case 41: goto tr4254;
		case 2058: goto tr4255;
		case 2107: goto tr4256;
	}
	goto tr77;
tr4259:
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st1434;
tr4260:
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st1434;
tr4261:
	{
		s->line_counter++;
	}
	goto st1434;
tr4265:
	{
		s->buffer[s->buffer_length++] = 0;

		// Execute the comment callback.
		if (s->process.automatic && s->process.comment != NULL) {
			s->process.comment(s);

			// Stop if required from the callback.
			if (s->state == ZS_STATE_STOP) {
				{p++; cs = 1434; goto _out;}
			}
		}
	}
	{
		s->line_counter++;
	}
	goto st1434;
tr4252:
	{
		s->item_length = rdata_tail - s->item_length_location - 1;
		if (s->comma_list && s->item_length == 0) {
			WARN(ZS_EMPTY_LIST_ITEM);
			p--; {goto st316;}
		}
		if (s->item_length <= MAX_ITEM_LENGTH) {
			*(s->item_length_location) = (uint8_t)(s->item_length);
		} else {
			WARN(ZS_ITEM_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st1434;
tr4253:
	{
		s->item_length = rdata_tail - s->item_length_location - 1;
		if (s->comma_list && s->item_length == 0) {
			WARN(ZS_EMPTY_LIST_ITEM);
			p--; {goto st316;}
		}
		if (s->item_length <= MAX_ITEM_LENGTH) {
			*(s->item_length_location) = (uint8_t)(s->item_length);
		} else {
			WARN(ZS_ITEM_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st1434;
tr4254:
	{
		s->item_length = rdata_tail - s->item_length_location - 1;
		if (s->comma_list && s->item_length == 0) {
			WARN(ZS_EMPTY_LIST_ITEM);
			p--; {goto st316;}
		}
		if (s->item_length <= MAX_ITEM_LENGTH) {
			*(s->item_length_location) = (uint8_t)(s->item_length);
		} else {
			WARN(ZS_ITEM_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st1434;
tr4255:
	{
		s->item_length = rdata_tail - s->item_length_location - 1;
		if (s->comma_list && s->item_length == 0) {
			WARN(ZS_EMPTY_LIST_ITEM);
			p--; {goto st316;}
		}
		if (s->item_length <= MAX_ITEM_LENGTH) {
			*(s->item_length_location) = (uint8_t)(s->item_length);
		} else {
			WARN(ZS_ITEM_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		s->line_counter++;
	}
	goto st1434;
st1434:
	if ( ++p == pe )
		goto _test_eof1434;
case 1434:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto st1434;
		case 32: goto st1434;
		case 40: goto tr4259;
		case 41: goto tr4260;
		case 2058: goto tr4261;
		case 2107: goto tr4262;
	}
	if ( _widec < 11 ) {
		if ( _widec <= 8 )
			goto tr4257;
	} else if ( _widec > 58 ) {
		if ( 60 <= _widec )
			goto tr4257;
	} else
		goto tr4257;
	goto tr77;
tr4257:
	{ p--; {stack[top++] = 1435;goto st327;} }
	goto st1435;
st1435:
	if ( ++p == pe )
		goto _test_eof1435;
case 1435:
	switch( (*p) ) {
		case 32: goto tr4263;
		case 59: goto tr4263;
	}
	if ( (*p) > 10 ) {
		if ( 40 <= (*p) && (*p) <= 41 )
			goto tr4263;
	} else if ( (*p) >= 9 )
		goto tr4263;
	goto tr77;
tr4263:
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1539;
st1539:
	if ( ++p == pe )
		goto _test_eof1539;
case 1539:
	goto st0;
tr4262:
	{
		s->buffer_length = 0;
	}
	goto st1436;
tr4264:
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		}
	}
	goto st1436;
tr4256:
	{
		s->item_length = rdata_tail - s->item_length_location - 1;
		if (s->comma_list && s->item_length == 0) {
			WARN(ZS_EMPTY_LIST_ITEM);
			p--; {goto st316;}
		}
		if (s->item_length <= MAX_ITEM_LENGTH) {
			*(s->item_length_location) = (uint8_t)(s->item_length);
		} else {
			WARN(ZS_ITEM_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		s->buffer_length = 0;
	}
	goto st1436;
st1436:
	if ( ++p == pe )
		goto _test_eof1436;
case 1436:
	_widec = (*p);
	if ( (*p) < 10 ) {
		if ( (*p) <= 9 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) > 10 ) {
		if ( 11 <= (*p) )
 {			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	if ( _widec == 2058 )
		goto tr4265;
	if ( 1920 <= _widec && _widec <= 2175 )
		goto tr4264;
	goto tr77;
tr4251:
	{
		s->buffer_length = 0;
	}
	goto st1437;
tr4266:
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		}
	}
	goto st1437;
tr4245:
	{
		if (s->number64 <= UINT8_MAX) {
			*rdata_tail = (uint8_t)(s->number64);
			rdata_tail += 1;
		} else {
			WARN(ZS_NUMBER8_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		s->buffer_length = 0;
	}
	goto st1437;
st1437:
	if ( ++p == pe )
		goto _test_eof1437;
case 1437:
	_widec = (*p);
	if ( (*p) < 10 ) {
		if ( (*p) <= 9 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) > 10 ) {
		if ( 11 <= (*p) )
 {			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	if ( _widec == 2058 )
		goto tr4267;
	if ( 1920 <= _widec && _widec <= 2175 )
		goto tr4266;
	goto tr77;
st1438:
	if ( ++p == pe )
		goto _test_eof1438;
case 1438:
	if ( 48 <= (*p) && (*p) <= 57 )
		goto tr4268;
	goto tr2396;
tr4268:
	{
		s->number64 = 0;
	}
	{
		// Overflow check: 10*(s->number64) + fc - '0' <= UINT64_MAX
		if ((s->number64 < (UINT64_MAX / 10)) ||   // Dominant fast check.
			((s->number64 == (UINT64_MAX / 10)) && // Marginal case.
			 ((uint8_t)(*p) <= (UINT64_MAX % 10) + '0')
			)
		   ) {
			s->number64 *= 10;
			s->number64 += digit_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_NUMBER64_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st1439;
tr4272:
	{
		// Overflow check: 10*(s->number64) + fc - '0' <= UINT64_MAX
		if ((s->number64 < (UINT64_MAX / 10)) ||   // Dominant fast check.
			((s->number64 == (UINT64_MAX / 10)) && // Marginal case.
			 ((uint8_t)(*p) <= (UINT64_MAX % 10) + '0')
			)
		   ) {
			s->number64 *= 10;
			s->number64 += digit_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_NUMBER64_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st1439;
st1439:
	if ( ++p == pe )
		goto _test_eof1439;
case 1439:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto tr4269;
		case 32: goto tr4269;
		case 40: goto tr4270;
		case 41: goto tr4271;
		case 2058: goto tr4273;
		case 2107: goto tr4274;
	}
	if ( 48 <= _widec && _widec <= 57 )
		goto tr4272;
	goto tr2396;
tr4276:
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st1440;
tr4277:
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st1440;
tr4279:
	{
		s->line_counter++;
	}
	goto st1440;
tr4284:
	{
		s->buffer[s->buffer_length++] = 0;

		// Execute the comment callback.
		if (s->process.automatic && s->process.comment != NULL) {
			s->process.comment(s);

			// Stop if required from the callback.
			if (s->state == ZS_STATE_STOP) {
				{p++; cs = 1440; goto _out;}
			}
		}
	}
	{
		s->line_counter++;
	}
	goto st1440;
tr4269:
	{
		if (s->number64 <= UINT16_MAX) {
			uint16_t num16 = htons((uint16_t)s->number64);
			memcpy(rdata_tail, &num16, 2);
			rdata_tail += 2;
		} else {
			WARN(ZS_NUMBER16_OVERFLOW);
			p--; {goto st316;}
		}
	}
	goto st1440;
tr4270:
	{
		if (s->number64 <= UINT16_MAX) {
			uint16_t num16 = htons((uint16_t)s->number64);
			memcpy(rdata_tail, &num16, 2);
			rdata_tail += 2;
		} else {
			WARN(ZS_NUMBER16_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = true;
	}
	goto st1440;
tr4271:
	{
		if (s->number64 <= UINT16_MAX) {
			uint16_t num16 = htons((uint16_t)s->number64);
			memcpy(rdata_tail, &num16, 2);
			rdata_tail += 2;
		} else {
			WARN(ZS_NUMBER16_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {goto st316;}
		}
		s->multiline = false;
	}
	goto st1440;
tr4273:
	{
		if (s->number64 <= UINT16_MAX) {
			uint16_t num16 = htons((uint16_t)s->number64);
			memcpy(rdata_tail, &num16, 2);
			rdata_tail += 2;
		} else {
			WARN(ZS_NUMBER16_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		s->line_counter++;
	}
	goto st1440;
st1440:
	if ( ++p == pe )
		goto _test_eof1440;
case 1440:
	_widec = (*p);
	if ( (*p) > 10 ) {
		if ( 59 <= (*p) && (*p) <= 59 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) >= 10 ) {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	switch( _widec ) {
		case 9: goto st1440;
		case 32: goto st1440;
		case 40: goto tr4276;
		case 41: goto tr4277;
		case 42: goto tr4278;
		case 92: goto tr4278;
		case 95: goto tr4278;
		case 2058: goto tr4279;
		case 2107: goto tr4280;
	}
	if ( _widec < 64 ) {
		if ( 45 <= _widec && _widec <= 57 )
			goto tr4278;
	} else if ( _widec > 90 ) {
		if ( 97 <= _widec && _widec <= 122 )
			goto tr4278;
	} else
		goto tr4278;
	goto tr77;
tr4278:
	{
		s->dname = rdata_tail;
	}
	{ p--; {stack[top++] = 1441;goto st318;} }
	goto st1441;
st1441:
	if ( ++p == pe )
		goto _test_eof1441;
case 1441:
	switch( (*p) ) {
		case 32: goto tr4281;
		case 59: goto tr4281;
	}
	if ( (*p) > 10 ) {
		if ( 40 <= (*p) && (*p) <= 41 )
			goto tr4281;
	} else if ( (*p) >= 9 )
		goto tr4281;
	goto tr77;
tr4281:
	{
		rdata_tail += s->dname_tmp_length;
	}
	{ p--; {stack[top++] = 1442;goto st630;} }
	goto st1442;
st1442:
	if ( ++p == pe )
		goto _test_eof1442;
case 1442:
	switch( (*p) ) {
		case 32: goto tr4282;
		case 59: goto tr4282;
	}
	if ( (*p) > 10 ) {
		if ( 40 <= (*p) && (*p) <= 41 )
			goto tr4282;
	} else if ( (*p) >= 9 )
		goto tr4282;
	goto tr77;
tr4282:
	{
		p--; {cs = stack[--top];goto _again;}
	}
	goto st1540;
st1540:
	if ( ++p == pe )
		goto _test_eof1540;
case 1540:
	goto st0;
tr4280:
	{
		s->buffer_length = 0;
	}
	goto st1443;
tr4283:
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		}
	}
	goto st1443;
tr4274:
	{
		if (s->number64 <= UINT16_MAX) {
			uint16_t num16 = htons((uint16_t)s->number64);
			memcpy(rdata_tail, &num16, 2);
			rdata_tail += 2;
		} else {
			WARN(ZS_NUMBER16_OVERFLOW);
			p--; {goto st316;}
		}
	}
	{
		s->buffer_length = 0;
	}
	goto st1443;
st1443:
	if ( ++p == pe )
		goto _test_eof1443;
case 1443:
	_widec = (*p);
	if ( (*p) < 10 ) {
		if ( (*p) <= 9 ) {
			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else if ( (*p) > 10 ) {
		if ( 11 <= (*p) )
 {			_widec = (short)(1664 + ((*p) - -128));
			if (
 s->multiline  ) _widec += 256;
		}
	} else {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
	}
	if ( _widec == 2058 )
		goto tr4284;
	if ( 1920 <= _widec && _widec <= 2175 )
		goto tr4283;
	goto tr77;
	}
	_test_eof1444: cs = 1444; goto _test_eof;
	_test_eof1: cs = 1; goto _test_eof;
	_test_eof2: cs = 2; goto _test_eof;
	_test_eof3: cs = 3; goto _test_eof;
	_test_eof4: cs = 4; goto _test_eof;
	_test_eof5: cs = 5; goto _test_eof;
	_test_eof6: cs = 6; goto _test_eof;
	_test_eof7: cs = 7; goto _test_eof;
	_test_eof8: cs = 8; goto _test_eof;
	_test_eof9: cs = 9; goto _test_eof;
	_test_eof10: cs = 10; goto _test_eof;
	_test_eof11: cs = 11; goto _test_eof;
	_test_eof12: cs = 12; goto _test_eof;
	_test_eof13: cs = 13; goto _test_eof;
	_test_eof1445: cs = 1445; goto _test_eof;
	_test_eof14: cs = 14; goto _test_eof;
	_test_eof15: cs = 15; goto _test_eof;
	_test_eof16: cs = 16; goto _test_eof;
	_test_eof17: cs = 17; goto _test_eof;
	_test_eof18: cs = 18; goto _test_eof;
	_test_eof19: cs = 19; goto _test_eof;
	_test_eof20: cs = 20; goto _test_eof;
	_test_eof21: cs = 21; goto _test_eof;
	_test_eof22: cs = 22; goto _test_eof;
	_test_eof23: cs = 23; goto _test_eof;
	_test_eof24: cs = 24; goto _test_eof;
	_test_eof25: cs = 25; goto _test_eof;
	_test_eof26: cs = 26; goto _test_eof;
	_test_eof27: cs = 27; goto _test_eof;
	_test_eof28: cs = 28; goto _test_eof;
	_test_eof29: cs = 29; goto _test_eof;
	_test_eof30: cs = 30; goto _test_eof;
	_test_eof31: cs = 31; goto _test_eof;
	_test_eof32: cs = 32; goto _test_eof;
	_test_eof33: cs = 33; goto _test_eof;
	_test_eof34: cs = 34; goto _test_eof;
	_test_eof35: cs = 35; goto _test_eof;
	_test_eof36: cs = 36; goto _test_eof;
	_test_eof37: cs = 37; goto _test_eof;
	_test_eof38: cs = 38; goto _test_eof;
	_test_eof39: cs = 39; goto _test_eof;
	_test_eof40: cs = 40; goto _test_eof;
	_test_eof41: cs = 41; goto _test_eof;
	_test_eof42: cs = 42; goto _test_eof;
	_test_eof43: cs = 43; goto _test_eof;
	_test_eof44: cs = 44; goto _test_eof;
	_test_eof45: cs = 45; goto _test_eof;
	_test_eof46: cs = 46; goto _test_eof;
	_test_eof47: cs = 47; goto _test_eof;
	_test_eof48: cs = 48; goto _test_eof;
	_test_eof49: cs = 49; goto _test_eof;
	_test_eof50: cs = 50; goto _test_eof;
	_test_eof51: cs = 51; goto _test_eof;
	_test_eof52: cs = 52; goto _test_eof;
	_test_eof53: cs = 53; goto _test_eof;
	_test_eof54: cs = 54; goto _test_eof;
	_test_eof55: cs = 55; goto _test_eof;
	_test_eof56: cs = 56; goto _test_eof;
	_test_eof57: cs = 57; goto _test_eof;
	_test_eof58: cs = 58; goto _test_eof;
	_test_eof59: cs = 59; goto _test_eof;
	_test_eof60: cs = 60; goto _test_eof;
	_test_eof61: cs = 61; goto _test_eof;
	_test_eof62: cs = 62; goto _test_eof;
	_test_eof63: cs = 63; goto _test_eof;
	_test_eof64: cs = 64; goto _test_eof;
	_test_eof65: cs = 65; goto _test_eof;
	_test_eof66: cs = 66; goto _test_eof;
	_test_eof67: cs = 67; goto _test_eof;
	_test_eof68: cs = 68; goto _test_eof;
	_test_eof69: cs = 69; goto _test_eof;
	_test_eof70: cs = 70; goto _test_eof;
	_test_eof71: cs = 71; goto _test_eof;
	_test_eof72: cs = 72; goto _test_eof;
	_test_eof73: cs = 73; goto _test_eof;
	_test_eof74: cs = 74; goto _test_eof;
	_test_eof75: cs = 75; goto _test_eof;
	_test_eof76: cs = 76; goto _test_eof;
	_test_eof77: cs = 77; goto _test_eof;
	_test_eof78: cs = 78; goto _test_eof;
	_test_eof79: cs = 79; goto _test_eof;
	_test_eof80: cs = 80; goto _test_eof;
	_test_eof81: cs = 81; goto _test_eof;
	_test_eof82: cs = 82; goto _test_eof;
	_test_eof83: cs = 83; goto _test_eof;
	_test_eof84: cs = 84; goto _test_eof;
	_test_eof85: cs = 85; goto _test_eof;
	_test_eof86: cs = 86; goto _test_eof;
	_test_eof87: cs = 87; goto _test_eof;
	_test_eof88: cs = 88; goto _test_eof;
	_test_eof89: cs = 89; goto _test_eof;
	_test_eof90: cs = 90; goto _test_eof;
	_test_eof91: cs = 91; goto _test_eof;
	_test_eof92: cs = 92; goto _test_eof;
	_test_eof93: cs = 93; goto _test_eof;
	_test_eof94: cs = 94; goto _test_eof;
	_test_eof95: cs = 95; goto _test_eof;
	_test_eof96: cs = 96; goto _test_eof;
	_test_eof97: cs = 97; goto _test_eof;
	_test_eof98: cs = 98; goto _test_eof;
	_test_eof99: cs = 99; goto _test_eof;
	_test_eof100: cs = 100; goto _test_eof;
	_test_eof101: cs = 101; goto _test_eof;
	_test_eof102: cs = 102; goto _test_eof;
	_test_eof103: cs = 103; goto _test_eof;
	_test_eof104: cs = 104; goto _test_eof;
	_test_eof105: cs = 105; goto _test_eof;
	_test_eof106: cs = 106; goto _test_eof;
	_test_eof107: cs = 107; goto _test_eof;
	_test_eof108: cs = 108; goto _test_eof;
	_test_eof109: cs = 109; goto _test_eof;
	_test_eof110: cs = 110; goto _test_eof;
	_test_eof111: cs = 111; goto _test_eof;
	_test_eof112: cs = 112; goto _test_eof;
	_test_eof113: cs = 113; goto _test_eof;
	_test_eof114: cs = 114; goto _test_eof;
	_test_eof115: cs = 115; goto _test_eof;
	_test_eof116: cs = 116; goto _test_eof;
	_test_eof117: cs = 117; goto _test_eof;
	_test_eof118: cs = 118; goto _test_eof;
	_test_eof119: cs = 119; goto _test_eof;
	_test_eof120: cs = 120; goto _test_eof;
	_test_eof121: cs = 121; goto _test_eof;
	_test_eof122: cs = 122; goto _test_eof;
	_test_eof123: cs = 123; goto _test_eof;
	_test_eof124: cs = 124; goto _test_eof;
	_test_eof125: cs = 125; goto _test_eof;
	_test_eof126: cs = 126; goto _test_eof;
	_test_eof127: cs = 127; goto _test_eof;
	_test_eof128: cs = 128; goto _test_eof;
	_test_eof129: cs = 129; goto _test_eof;
	_test_eof130: cs = 130; goto _test_eof;
	_test_eof131: cs = 131; goto _test_eof;
	_test_eof132: cs = 132; goto _test_eof;
	_test_eof133: cs = 133; goto _test_eof;
	_test_eof134: cs = 134; goto _test_eof;
	_test_eof135: cs = 135; goto _test_eof;
	_test_eof136: cs = 136; goto _test_eof;
	_test_eof137: cs = 137; goto _test_eof;
	_test_eof138: cs = 138; goto _test_eof;
	_test_eof139: cs = 139; goto _test_eof;
	_test_eof140: cs = 140; goto _test_eof;
	_test_eof141: cs = 141; goto _test_eof;
	_test_eof142: cs = 142; goto _test_eof;
	_test_eof143: cs = 143; goto _test_eof;
	_test_eof144: cs = 144; goto _test_eof;
	_test_eof145: cs = 145; goto _test_eof;
	_test_eof146: cs = 146; goto _test_eof;
	_test_eof147: cs = 147; goto _test_eof;
	_test_eof148: cs = 148; goto _test_eof;
	_test_eof149: cs = 149; goto _test_eof;
	_test_eof150: cs = 150; goto _test_eof;
	_test_eof151: cs = 151; goto _test_eof;
	_test_eof152: cs = 152; goto _test_eof;
	_test_eof153: cs = 153; goto _test_eof;
	_test_eof154: cs = 154; goto _test_eof;
	_test_eof155: cs = 155; goto _test_eof;
	_test_eof156: cs = 156; goto _test_eof;
	_test_eof157: cs = 157; goto _test_eof;
	_test_eof158: cs = 158; goto _test_eof;
	_test_eof159: cs = 159; goto _test_eof;
	_test_eof160: cs = 160; goto _test_eof;
	_test_eof161: cs = 161; goto _test_eof;
	_test_eof162: cs = 162; goto _test_eof;
	_test_eof163: cs = 163; goto _test_eof;
	_test_eof164: cs = 164; goto _test_eof;
	_test_eof165: cs = 165; goto _test_eof;
	_test_eof166: cs = 166; goto _test_eof;
	_test_eof167: cs = 167; goto _test_eof;
	_test_eof168: cs = 168; goto _test_eof;
	_test_eof169: cs = 169; goto _test_eof;
	_test_eof170: cs = 170; goto _test_eof;
	_test_eof171: cs = 171; goto _test_eof;
	_test_eof172: cs = 172; goto _test_eof;
	_test_eof173: cs = 173; goto _test_eof;
	_test_eof174: cs = 174; goto _test_eof;
	_test_eof175: cs = 175; goto _test_eof;
	_test_eof176: cs = 176; goto _test_eof;
	_test_eof177: cs = 177; goto _test_eof;
	_test_eof178: cs = 178; goto _test_eof;
	_test_eof179: cs = 179; goto _test_eof;
	_test_eof1446: cs = 1446; goto _test_eof;
	_test_eof180: cs = 180; goto _test_eof;
	_test_eof181: cs = 181; goto _test_eof;
	_test_eof182: cs = 182; goto _test_eof;
	_test_eof183: cs = 183; goto _test_eof;
	_test_eof184: cs = 184; goto _test_eof;
	_test_eof185: cs = 185; goto _test_eof;
	_test_eof186: cs = 186; goto _test_eof;
	_test_eof187: cs = 187; goto _test_eof;
	_test_eof188: cs = 188; goto _test_eof;
	_test_eof189: cs = 189; goto _test_eof;
	_test_eof1447: cs = 1447; goto _test_eof;
	_test_eof190: cs = 190; goto _test_eof;
	_test_eof191: cs = 191; goto _test_eof;
	_test_eof192: cs = 192; goto _test_eof;
	_test_eof193: cs = 193; goto _test_eof;
	_test_eof194: cs = 194; goto _test_eof;
	_test_eof195: cs = 195; goto _test_eof;
	_test_eof196: cs = 196; goto _test_eof;
	_test_eof197: cs = 197; goto _test_eof;
	_test_eof1448: cs = 1448; goto _test_eof;
	_test_eof198: cs = 198; goto _test_eof;
	_test_eof199: cs = 199; goto _test_eof;
	_test_eof200: cs = 200; goto _test_eof;
	_test_eof1449: cs = 1449; goto _test_eof;
	_test_eof201: cs = 201; goto _test_eof;
	_test_eof202: cs = 202; goto _test_eof;
	_test_eof203: cs = 203; goto _test_eof;
	_test_eof204: cs = 204; goto _test_eof;
	_test_eof205: cs = 205; goto _test_eof;
	_test_eof206: cs = 206; goto _test_eof;
	_test_eof207: cs = 207; goto _test_eof;
	_test_eof208: cs = 208; goto _test_eof;
	_test_eof209: cs = 209; goto _test_eof;
	_test_eof210: cs = 210; goto _test_eof;
	_test_eof211: cs = 211; goto _test_eof;
	_test_eof1450: cs = 1450; goto _test_eof;
	_test_eof212: cs = 212; goto _test_eof;
	_test_eof213: cs = 213; goto _test_eof;
	_test_eof214: cs = 214; goto _test_eof;
	_test_eof215: cs = 215; goto _test_eof;
	_test_eof1451: cs = 1451; goto _test_eof;
	_test_eof216: cs = 216; goto _test_eof;
	_test_eof217: cs = 217; goto _test_eof;
	_test_eof218: cs = 218; goto _test_eof;
	_test_eof219: cs = 219; goto _test_eof;
	_test_eof220: cs = 220; goto _test_eof;
	_test_eof221: cs = 221; goto _test_eof;
	_test_eof222: cs = 222; goto _test_eof;
	_test_eof223: cs = 223; goto _test_eof;
	_test_eof224: cs = 224; goto _test_eof;
	_test_eof225: cs = 225; goto _test_eof;
	_test_eof226: cs = 226; goto _test_eof;
	_test_eof227: cs = 227; goto _test_eof;
	_test_eof228: cs = 228; goto _test_eof;
	_test_eof229: cs = 229; goto _test_eof;
	_test_eof230: cs = 230; goto _test_eof;
	_test_eof231: cs = 231; goto _test_eof;
	_test_eof232: cs = 232; goto _test_eof;
	_test_eof233: cs = 233; goto _test_eof;
	_test_eof234: cs = 234; goto _test_eof;
	_test_eof1452: cs = 1452; goto _test_eof;
	_test_eof235: cs = 235; goto _test_eof;
	_test_eof236: cs = 236; goto _test_eof;
	_test_eof237: cs = 237; goto _test_eof;
	_test_eof238: cs = 238; goto _test_eof;
	_test_eof239: cs = 239; goto _test_eof;
	_test_eof240: cs = 240; goto _test_eof;
	_test_eof241: cs = 241; goto _test_eof;
	_test_eof242: cs = 242; goto _test_eof;
	_test_eof243: cs = 243; goto _test_eof;
	_test_eof244: cs = 244; goto _test_eof;
	_test_eof245: cs = 245; goto _test_eof;
	_test_eof246: cs = 246; goto _test_eof;
	_test_eof247: cs = 247; goto _test_eof;
	_test_eof248: cs = 248; goto _test_eof;
	_test_eof249: cs = 249; goto _test_eof;
	_test_eof250: cs = 250; goto _test_eof;
	_test_eof1453: cs = 1453; goto _test_eof;
	_test_eof251: cs = 251; goto _test_eof;
	_test_eof252: cs = 252; goto _test_eof;
	_test_eof253: cs = 253; goto _test_eof;
	_test_eof254: cs = 254; goto _test_eof;
	_test_eof255: cs = 255; goto _test_eof;
	_test_eof256: cs = 256; goto _test_eof;
	_test_eof257: cs = 257; goto _test_eof;
	_test_eof258: cs = 258; goto _test_eof;
	_test_eof259: cs = 259; goto _test_eof;
	_test_eof260: cs = 260; goto _test_eof;
	_test_eof261: cs = 261; goto _test_eof;
	_test_eof262: cs = 262; goto _test_eof;
	_test_eof263: cs = 263; goto _test_eof;
	_test_eof264: cs = 264; goto _test_eof;
	_test_eof265: cs = 265; goto _test_eof;
	_test_eof266: cs = 266; goto _test_eof;
	_test_eof267: cs = 267; goto _test_eof;
	_test_eof268: cs = 268; goto _test_eof;
	_test_eof269: cs = 269; goto _test_eof;
	_test_eof270: cs = 270; goto _test_eof;
	_test_eof271: cs = 271; goto _test_eof;
	_test_eof272: cs = 272; goto _test_eof;
	_test_eof273: cs = 273; goto _test_eof;
	_test_eof274: cs = 274; goto _test_eof;
	_test_eof275: cs = 275; goto _test_eof;
	_test_eof276: cs = 276; goto _test_eof;
	_test_eof277: cs = 277; goto _test_eof;
	_test_eof278: cs = 278; goto _test_eof;
	_test_eof279: cs = 279; goto _test_eof;
	_test_eof280: cs = 280; goto _test_eof;
	_test_eof281: cs = 281; goto _test_eof;
	_test_eof282: cs = 282; goto _test_eof;
	_test_eof283: cs = 283; goto _test_eof;
	_test_eof284: cs = 284; goto _test_eof;
	_test_eof285: cs = 285; goto _test_eof;
	_test_eof286: cs = 286; goto _test_eof;
	_test_eof287: cs = 287; goto _test_eof;
	_test_eof288: cs = 288; goto _test_eof;
	_test_eof289: cs = 289; goto _test_eof;
	_test_eof290: cs = 290; goto _test_eof;
	_test_eof291: cs = 291; goto _test_eof;
	_test_eof292: cs = 292; goto _test_eof;
	_test_eof293: cs = 293; goto _test_eof;
	_test_eof294: cs = 294; goto _test_eof;
	_test_eof295: cs = 295; goto _test_eof;
	_test_eof296: cs = 296; goto _test_eof;
	_test_eof297: cs = 297; goto _test_eof;
	_test_eof298: cs = 298; goto _test_eof;
	_test_eof299: cs = 299; goto _test_eof;
	_test_eof300: cs = 300; goto _test_eof;
	_test_eof301: cs = 301; goto _test_eof;
	_test_eof302: cs = 302; goto _test_eof;
	_test_eof303: cs = 303; goto _test_eof;
	_test_eof304: cs = 304; goto _test_eof;
	_test_eof305: cs = 305; goto _test_eof;
	_test_eof306: cs = 306; goto _test_eof;
	_test_eof307: cs = 307; goto _test_eof;
	_test_eof308: cs = 308; goto _test_eof;
	_test_eof309: cs = 309; goto _test_eof;
	_test_eof310: cs = 310; goto _test_eof;
	_test_eof311: cs = 311; goto _test_eof;
	_test_eof312: cs = 312; goto _test_eof;
	_test_eof313: cs = 313; goto _test_eof;
	_test_eof314: cs = 314; goto _test_eof;
	_test_eof315: cs = 315; goto _test_eof;
	_test_eof1454: cs = 1454; goto _test_eof;
	_test_eof316: cs = 316; goto _test_eof;
	_test_eof317: cs = 317; goto _test_eof;
	_test_eof1455: cs = 1455; goto _test_eof;
	_test_eof318: cs = 318; goto _test_eof;
	_test_eof319: cs = 319; goto _test_eof;
	_test_eof1456: cs = 1456; goto _test_eof;
	_test_eof320: cs = 320; goto _test_eof;
	_test_eof321: cs = 321; goto _test_eof;
	_test_eof322: cs = 322; goto _test_eof;
	_test_eof323: cs = 323; goto _test_eof;
	_test_eof324: cs = 324; goto _test_eof;
	_test_eof325: cs = 325; goto _test_eof;
	_test_eof326: cs = 326; goto _test_eof;
	_test_eof327: cs = 327; goto _test_eof;
	_test_eof328: cs = 328; goto _test_eof;
	_test_eof1457: cs = 1457; goto _test_eof;
	_test_eof1458: cs = 1458; goto _test_eof;
	_test_eof329: cs = 329; goto _test_eof;
	_test_eof330: cs = 330; goto _test_eof;
	_test_eof331: cs = 331; goto _test_eof;
	_test_eof332: cs = 332; goto _test_eof;
	_test_eof333: cs = 333; goto _test_eof;
	_test_eof334: cs = 334; goto _test_eof;
	_test_eof335: cs = 335; goto _test_eof;
	_test_eof336: cs = 336; goto _test_eof;
	_test_eof337: cs = 337; goto _test_eof;
	_test_eof338: cs = 338; goto _test_eof;
	_test_eof339: cs = 339; goto _test_eof;
	_test_eof340: cs = 340; goto _test_eof;
	_test_eof341: cs = 341; goto _test_eof;
	_test_eof342: cs = 342; goto _test_eof;
	_test_eof343: cs = 343; goto _test_eof;
	_test_eof1459: cs = 1459; goto _test_eof;
	_test_eof344: cs = 344; goto _test_eof;
	_test_eof345: cs = 345; goto _test_eof;
	_test_eof346: cs = 346; goto _test_eof;
	_test_eof347: cs = 347; goto _test_eof;
	_test_eof348: cs = 348; goto _test_eof;
	_test_eof349: cs = 349; goto _test_eof;
	_test_eof350: cs = 350; goto _test_eof;
	_test_eof351: cs = 351; goto _test_eof;
	_test_eof352: cs = 352; goto _test_eof;
	_test_eof353: cs = 353; goto _test_eof;
	_test_eof1460: cs = 1460; goto _test_eof;
	_test_eof354: cs = 354; goto _test_eof;
	_test_eof355: cs = 355; goto _test_eof;
	_test_eof356: cs = 356; goto _test_eof;
	_test_eof357: cs = 357; goto _test_eof;
	_test_eof358: cs = 358; goto _test_eof;
	_test_eof359: cs = 359; goto _test_eof;
	_test_eof360: cs = 360; goto _test_eof;
	_test_eof361: cs = 361; goto _test_eof;
	_test_eof362: cs = 362; goto _test_eof;
	_test_eof363: cs = 363; goto _test_eof;
	_test_eof364: cs = 364; goto _test_eof;
	_test_eof365: cs = 365; goto _test_eof;
	_test_eof366: cs = 366; goto _test_eof;
	_test_eof367: cs = 367; goto _test_eof;
	_test_eof1461: cs = 1461; goto _test_eof;
	_test_eof368: cs = 368; goto _test_eof;
	_test_eof369: cs = 369; goto _test_eof;
	_test_eof370: cs = 370; goto _test_eof;
	_test_eof371: cs = 371; goto _test_eof;
	_test_eof372: cs = 372; goto _test_eof;
	_test_eof373: cs = 373; goto _test_eof;
	_test_eof374: cs = 374; goto _test_eof;
	_test_eof1462: cs = 1462; goto _test_eof;
	_test_eof375: cs = 375; goto _test_eof;
	_test_eof376: cs = 376; goto _test_eof;
	_test_eof377: cs = 377; goto _test_eof;
	_test_eof378: cs = 378; goto _test_eof;
	_test_eof379: cs = 379; goto _test_eof;
	_test_eof380: cs = 380; goto _test_eof;
	_test_eof381: cs = 381; goto _test_eof;
	_test_eof382: cs = 382; goto _test_eof;
	_test_eof383: cs = 383; goto _test_eof;
	_test_eof1463: cs = 1463; goto _test_eof;
	_test_eof1464: cs = 1464; goto _test_eof;
	_test_eof1465: cs = 1465; goto _test_eof;
	_test_eof384: cs = 384; goto _test_eof;
	_test_eof385: cs = 385; goto _test_eof;
	_test_eof386: cs = 386; goto _test_eof;
	_test_eof387: cs = 387; goto _test_eof;
	_test_eof388: cs = 388; goto _test_eof;
	_test_eof389: cs = 389; goto _test_eof;
	_test_eof390: cs = 390; goto _test_eof;
	_test_eof391: cs = 391; goto _test_eof;
	_test_eof1466: cs = 1466; goto _test_eof;
	_test_eof1467: cs = 1467; goto _test_eof;
	_test_eof392: cs = 392; goto _test_eof;
	_test_eof393: cs = 393; goto _test_eof;
	_test_eof394: cs = 394; goto _test_eof;
	_test_eof1468: cs = 1468; goto _test_eof;
	_test_eof395: cs = 395; goto _test_eof;
	_test_eof396: cs = 396; goto _test_eof;
	_test_eof397: cs = 397; goto _test_eof;
	_test_eof398: cs = 398; goto _test_eof;
	_test_eof399: cs = 399; goto _test_eof;
	_test_eof400: cs = 400; goto _test_eof;
	_test_eof401: cs = 401; goto _test_eof;
	_test_eof402: cs = 402; goto _test_eof;
	_test_eof403: cs = 403; goto _test_eof;
	_test_eof404: cs = 404; goto _test_eof;
	_test_eof405: cs = 405; goto _test_eof;
	_test_eof406: cs = 406; goto _test_eof;
	_test_eof407: cs = 407; goto _test_eof;
	_test_eof408: cs = 408; goto _test_eof;
	_test_eof409: cs = 409; goto _test_eof;
	_test_eof410: cs = 410; goto _test_eof;
	_test_eof411: cs = 411; goto _test_eof;
	_test_eof412: cs = 412; goto _test_eof;
	_test_eof413: cs = 413; goto _test_eof;
	_test_eof414: cs = 414; goto _test_eof;
	_test_eof415: cs = 415; goto _test_eof;
	_test_eof416: cs = 416; goto _test_eof;
	_test_eof417: cs = 417; goto _test_eof;
	_test_eof418: cs = 418; goto _test_eof;
	_test_eof419: cs = 419; goto _test_eof;
	_test_eof420: cs = 420; goto _test_eof;
	_test_eof421: cs = 421; goto _test_eof;
	_test_eof422: cs = 422; goto _test_eof;
	_test_eof423: cs = 423; goto _test_eof;
	_test_eof424: cs = 424; goto _test_eof;
	_test_eof425: cs = 425; goto _test_eof;
	_test_eof426: cs = 426; goto _test_eof;
	_test_eof427: cs = 427; goto _test_eof;
	_test_eof428: cs = 428; goto _test_eof;
	_test_eof429: cs = 429; goto _test_eof;
	_test_eof430: cs = 430; goto _test_eof;
	_test_eof431: cs = 431; goto _test_eof;
	_test_eof432: cs = 432; goto _test_eof;
	_test_eof433: cs = 433; goto _test_eof;
	_test_eof434: cs = 434; goto _test_eof;
	_test_eof435: cs = 435; goto _test_eof;
	_test_eof436: cs = 436; goto _test_eof;
	_test_eof437: cs = 437; goto _test_eof;
	_test_eof438: cs = 438; goto _test_eof;
	_test_eof439: cs = 439; goto _test_eof;
	_test_eof440: cs = 440; goto _test_eof;
	_test_eof441: cs = 441; goto _test_eof;
	_test_eof442: cs = 442; goto _test_eof;
	_test_eof443: cs = 443; goto _test_eof;
	_test_eof444: cs = 444; goto _test_eof;
	_test_eof445: cs = 445; goto _test_eof;
	_test_eof446: cs = 446; goto _test_eof;
	_test_eof447: cs = 447; goto _test_eof;
	_test_eof448: cs = 448; goto _test_eof;
	_test_eof449: cs = 449; goto _test_eof;
	_test_eof450: cs = 450; goto _test_eof;
	_test_eof451: cs = 451; goto _test_eof;
	_test_eof452: cs = 452; goto _test_eof;
	_test_eof453: cs = 453; goto _test_eof;
	_test_eof454: cs = 454; goto _test_eof;
	_test_eof455: cs = 455; goto _test_eof;
	_test_eof456: cs = 456; goto _test_eof;
	_test_eof457: cs = 457; goto _test_eof;
	_test_eof458: cs = 458; goto _test_eof;
	_test_eof459: cs = 459; goto _test_eof;
	_test_eof460: cs = 460; goto _test_eof;
	_test_eof461: cs = 461; goto _test_eof;
	_test_eof462: cs = 462; goto _test_eof;
	_test_eof463: cs = 463; goto _test_eof;
	_test_eof464: cs = 464; goto _test_eof;
	_test_eof465: cs = 465; goto _test_eof;
	_test_eof466: cs = 466; goto _test_eof;
	_test_eof467: cs = 467; goto _test_eof;
	_test_eof468: cs = 468; goto _test_eof;
	_test_eof469: cs = 469; goto _test_eof;
	_test_eof470: cs = 470; goto _test_eof;
	_test_eof471: cs = 471; goto _test_eof;
	_test_eof472: cs = 472; goto _test_eof;
	_test_eof473: cs = 473; goto _test_eof;
	_test_eof474: cs = 474; goto _test_eof;
	_test_eof475: cs = 475; goto _test_eof;
	_test_eof476: cs = 476; goto _test_eof;
	_test_eof477: cs = 477; goto _test_eof;
	_test_eof478: cs = 478; goto _test_eof;
	_test_eof479: cs = 479; goto _test_eof;
	_test_eof480: cs = 480; goto _test_eof;
	_test_eof481: cs = 481; goto _test_eof;
	_test_eof482: cs = 482; goto _test_eof;
	_test_eof483: cs = 483; goto _test_eof;
	_test_eof484: cs = 484; goto _test_eof;
	_test_eof485: cs = 485; goto _test_eof;
	_test_eof486: cs = 486; goto _test_eof;
	_test_eof487: cs = 487; goto _test_eof;
	_test_eof488: cs = 488; goto _test_eof;
	_test_eof489: cs = 489; goto _test_eof;
	_test_eof490: cs = 490; goto _test_eof;
	_test_eof491: cs = 491; goto _test_eof;
	_test_eof492: cs = 492; goto _test_eof;
	_test_eof493: cs = 493; goto _test_eof;
	_test_eof494: cs = 494; goto _test_eof;
	_test_eof495: cs = 495; goto _test_eof;
	_test_eof496: cs = 496; goto _test_eof;
	_test_eof497: cs = 497; goto _test_eof;
	_test_eof498: cs = 498; goto _test_eof;
	_test_eof499: cs = 499; goto _test_eof;
	_test_eof500: cs = 500; goto _test_eof;
	_test_eof501: cs = 501; goto _test_eof;
	_test_eof502: cs = 502; goto _test_eof;
	_test_eof503: cs = 503; goto _test_eof;
	_test_eof504: cs = 504; goto _test_eof;
	_test_eof505: cs = 505; goto _test_eof;
	_test_eof506: cs = 506; goto _test_eof;
	_test_eof507: cs = 507; goto _test_eof;
	_test_eof508: cs = 508; goto _test_eof;
	_test_eof509: cs = 509; goto _test_eof;
	_test_eof510: cs = 510; goto _test_eof;
	_test_eof511: cs = 511; goto _test_eof;
	_test_eof512: cs = 512; goto _test_eof;
	_test_eof513: cs = 513; goto _test_eof;
	_test_eof514: cs = 514; goto _test_eof;
	_test_eof515: cs = 515; goto _test_eof;
	_test_eof516: cs = 516; goto _test_eof;
	_test_eof517: cs = 517; goto _test_eof;
	_test_eof518: cs = 518; goto _test_eof;
	_test_eof519: cs = 519; goto _test_eof;
	_test_eof520: cs = 520; goto _test_eof;
	_test_eof521: cs = 521; goto _test_eof;
	_test_eof522: cs = 522; goto _test_eof;
	_test_eof523: cs = 523; goto _test_eof;
	_test_eof524: cs = 524; goto _test_eof;
	_test_eof525: cs = 525; goto _test_eof;
	_test_eof526: cs = 526; goto _test_eof;
	_test_eof527: cs = 527; goto _test_eof;
	_test_eof528: cs = 528; goto _test_eof;
	_test_eof529: cs = 529; goto _test_eof;
	_test_eof530: cs = 530; goto _test_eof;
	_test_eof531: cs = 531; goto _test_eof;
	_test_eof532: cs = 532; goto _test_eof;
	_test_eof533: cs = 533; goto _test_eof;
	_test_eof534: cs = 534; goto _test_eof;
	_test_eof535: cs = 535; goto _test_eof;
	_test_eof536: cs = 536; goto _test_eof;
	_test_eof537: cs = 537; goto _test_eof;
	_test_eof538: cs = 538; goto _test_eof;
	_test_eof539: cs = 539; goto _test_eof;
	_test_eof540: cs = 540; goto _test_eof;
	_test_eof541: cs = 541; goto _test_eof;
	_test_eof542: cs = 542; goto _test_eof;
	_test_eof543: cs = 543; goto _test_eof;
	_test_eof544: cs = 544; goto _test_eof;
	_test_eof545: cs = 545; goto _test_eof;
	_test_eof546: cs = 546; goto _test_eof;
	_test_eof547: cs = 547; goto _test_eof;
	_test_eof548: cs = 548; goto _test_eof;
	_test_eof549: cs = 549; goto _test_eof;
	_test_eof550: cs = 550; goto _test_eof;
	_test_eof551: cs = 551; goto _test_eof;
	_test_eof552: cs = 552; goto _test_eof;
	_test_eof553: cs = 553; goto _test_eof;
	_test_eof554: cs = 554; goto _test_eof;
	_test_eof555: cs = 555; goto _test_eof;
	_test_eof556: cs = 556; goto _test_eof;
	_test_eof557: cs = 557; goto _test_eof;
	_test_eof558: cs = 558; goto _test_eof;
	_test_eof559: cs = 559; goto _test_eof;
	_test_eof560: cs = 560; goto _test_eof;
	_test_eof561: cs = 561; goto _test_eof;
	_test_eof1469: cs = 1469; goto _test_eof;
	_test_eof1470: cs = 1470; goto _test_eof;
	_test_eof1471: cs = 1471; goto _test_eof;
	_test_eof562: cs = 562; goto _test_eof;
	_test_eof563: cs = 563; goto _test_eof;
	_test_eof564: cs = 564; goto _test_eof;
	_test_eof565: cs = 565; goto _test_eof;
	_test_eof566: cs = 566; goto _test_eof;
	_test_eof1472: cs = 1472; goto _test_eof;
	_test_eof567: cs = 567; goto _test_eof;
	_test_eof568: cs = 568; goto _test_eof;
	_test_eof569: cs = 569; goto _test_eof;
	_test_eof570: cs = 570; goto _test_eof;
	_test_eof1473: cs = 1473; goto _test_eof;
	_test_eof1474: cs = 1474; goto _test_eof;
	_test_eof1475: cs = 1475; goto _test_eof;
	_test_eof571: cs = 571; goto _test_eof;
	_test_eof572: cs = 572; goto _test_eof;
	_test_eof1476: cs = 1476; goto _test_eof;
	_test_eof573: cs = 573; goto _test_eof;
	_test_eof574: cs = 574; goto _test_eof;
	_test_eof575: cs = 575; goto _test_eof;
	_test_eof576: cs = 576; goto _test_eof;
	_test_eof577: cs = 577; goto _test_eof;
	_test_eof578: cs = 578; goto _test_eof;
	_test_eof1477: cs = 1477; goto _test_eof;
	_test_eof579: cs = 579; goto _test_eof;
	_test_eof580: cs = 580; goto _test_eof;
	_test_eof581: cs = 581; goto _test_eof;
	_test_eof582: cs = 582; goto _test_eof;
	_test_eof583: cs = 583; goto _test_eof;
	_test_eof584: cs = 584; goto _test_eof;
	_test_eof585: cs = 585; goto _test_eof;
	_test_eof586: cs = 586; goto _test_eof;
	_test_eof587: cs = 587; goto _test_eof;
	_test_eof588: cs = 588; goto _test_eof;
	_test_eof589: cs = 589; goto _test_eof;
	_test_eof590: cs = 590; goto _test_eof;
	_test_eof591: cs = 591; goto _test_eof;
	_test_eof592: cs = 592; goto _test_eof;
	_test_eof593: cs = 593; goto _test_eof;
	_test_eof594: cs = 594; goto _test_eof;
	_test_eof595: cs = 595; goto _test_eof;
	_test_eof596: cs = 596; goto _test_eof;
	_test_eof597: cs = 597; goto _test_eof;
	_test_eof598: cs = 598; goto _test_eof;
	_test_eof599: cs = 599; goto _test_eof;
	_test_eof600: cs = 600; goto _test_eof;
	_test_eof601: cs = 601; goto _test_eof;
	_test_eof602: cs = 602; goto _test_eof;
	_test_eof603: cs = 603; goto _test_eof;
	_test_eof604: cs = 604; goto _test_eof;
	_test_eof605: cs = 605; goto _test_eof;
	_test_eof606: cs = 606; goto _test_eof;
	_test_eof607: cs = 607; goto _test_eof;
	_test_eof608: cs = 608; goto _test_eof;
	_test_eof609: cs = 609; goto _test_eof;
	_test_eof610: cs = 610; goto _test_eof;
	_test_eof611: cs = 611; goto _test_eof;
	_test_eof612: cs = 612; goto _test_eof;
	_test_eof613: cs = 613; goto _test_eof;
	_test_eof614: cs = 614; goto _test_eof;
	_test_eof615: cs = 615; goto _test_eof;
	_test_eof616: cs = 616; goto _test_eof;
	_test_eof617: cs = 617; goto _test_eof;
	_test_eof618: cs = 618; goto _test_eof;
	_test_eof619: cs = 619; goto _test_eof;
	_test_eof620: cs = 620; goto _test_eof;
	_test_eof621: cs = 621; goto _test_eof;
	_test_eof622: cs = 622; goto _test_eof;
	_test_eof623: cs = 623; goto _test_eof;
	_test_eof624: cs = 624; goto _test_eof;
	_test_eof625: cs = 625; goto _test_eof;
	_test_eof626: cs = 626; goto _test_eof;
	_test_eof627: cs = 627; goto _test_eof;
	_test_eof628: cs = 628; goto _test_eof;
	_test_eof629: cs = 629; goto _test_eof;
	_test_eof630: cs = 630; goto _test_eof;
	_test_eof631: cs = 631; goto _test_eof;
	_test_eof632: cs = 632; goto _test_eof;
	_test_eof633: cs = 633; goto _test_eof;
	_test_eof634: cs = 634; goto _test_eof;
	_test_eof635: cs = 635; goto _test_eof;
	_test_eof636: cs = 636; goto _test_eof;
	_test_eof637: cs = 637; goto _test_eof;
	_test_eof638: cs = 638; goto _test_eof;
	_test_eof1478: cs = 1478; goto _test_eof;
	_test_eof1479: cs = 1479; goto _test_eof;
	_test_eof639: cs = 639; goto _test_eof;
	_test_eof640: cs = 640; goto _test_eof;
	_test_eof641: cs = 641; goto _test_eof;
	_test_eof642: cs = 642; goto _test_eof;
	_test_eof643: cs = 643; goto _test_eof;
	_test_eof644: cs = 644; goto _test_eof;
	_test_eof645: cs = 645; goto _test_eof;
	_test_eof646: cs = 646; goto _test_eof;
	_test_eof647: cs = 647; goto _test_eof;
	_test_eof1480: cs = 1480; goto _test_eof;
	_test_eof648: cs = 648; goto _test_eof;
	_test_eof649: cs = 649; goto _test_eof;
	_test_eof650: cs = 650; goto _test_eof;
	_test_eof651: cs = 651; goto _test_eof;
	_test_eof652: cs = 652; goto _test_eof;
	_test_eof653: cs = 653; goto _test_eof;
	_test_eof654: cs = 654; goto _test_eof;
	_test_eof655: cs = 655; goto _test_eof;
	_test_eof656: cs = 656; goto _test_eof;
	_test_eof657: cs = 657; goto _test_eof;
	_test_eof658: cs = 658; goto _test_eof;
	_test_eof659: cs = 659; goto _test_eof;
	_test_eof660: cs = 660; goto _test_eof;
	_test_eof661: cs = 661; goto _test_eof;
	_test_eof662: cs = 662; goto _test_eof;
	_test_eof663: cs = 663; goto _test_eof;
	_test_eof664: cs = 664; goto _test_eof;
	_test_eof665: cs = 665; goto _test_eof;
	_test_eof666: cs = 666; goto _test_eof;
	_test_eof667: cs = 667; goto _test_eof;
	_test_eof668: cs = 668; goto _test_eof;
	_test_eof669: cs = 669; goto _test_eof;
	_test_eof670: cs = 670; goto _test_eof;
	_test_eof671: cs = 671; goto _test_eof;
	_test_eof672: cs = 672; goto _test_eof;
	_test_eof673: cs = 673; goto _test_eof;
	_test_eof674: cs = 674; goto _test_eof;
	_test_eof675: cs = 675; goto _test_eof;
	_test_eof676: cs = 676; goto _test_eof;
	_test_eof677: cs = 677; goto _test_eof;
	_test_eof678: cs = 678; goto _test_eof;
	_test_eof679: cs = 679; goto _test_eof;
	_test_eof680: cs = 680; goto _test_eof;
	_test_eof681: cs = 681; goto _test_eof;
	_test_eof682: cs = 682; goto _test_eof;
	_test_eof683: cs = 683; goto _test_eof;
	_test_eof684: cs = 684; goto _test_eof;
	_test_eof685: cs = 685; goto _test_eof;
	_test_eof686: cs = 686; goto _test_eof;
	_test_eof687: cs = 687; goto _test_eof;
	_test_eof688: cs = 688; goto _test_eof;
	_test_eof689: cs = 689; goto _test_eof;
	_test_eof690: cs = 690; goto _test_eof;
	_test_eof691: cs = 691; goto _test_eof;
	_test_eof692: cs = 692; goto _test_eof;
	_test_eof693: cs = 693; goto _test_eof;
	_test_eof694: cs = 694; goto _test_eof;
	_test_eof695: cs = 695; goto _test_eof;
	_test_eof696: cs = 696; goto _test_eof;
	_test_eof697: cs = 697; goto _test_eof;
	_test_eof698: cs = 698; goto _test_eof;
	_test_eof699: cs = 699; goto _test_eof;
	_test_eof700: cs = 700; goto _test_eof;
	_test_eof701: cs = 701; goto _test_eof;
	_test_eof702: cs = 702; goto _test_eof;
	_test_eof703: cs = 703; goto _test_eof;
	_test_eof704: cs = 704; goto _test_eof;
	_test_eof705: cs = 705; goto _test_eof;
	_test_eof706: cs = 706; goto _test_eof;
	_test_eof707: cs = 707; goto _test_eof;
	_test_eof708: cs = 708; goto _test_eof;
	_test_eof709: cs = 709; goto _test_eof;
	_test_eof710: cs = 710; goto _test_eof;
	_test_eof711: cs = 711; goto _test_eof;
	_test_eof712: cs = 712; goto _test_eof;
	_test_eof713: cs = 713; goto _test_eof;
	_test_eof714: cs = 714; goto _test_eof;
	_test_eof715: cs = 715; goto _test_eof;
	_test_eof716: cs = 716; goto _test_eof;
	_test_eof717: cs = 717; goto _test_eof;
	_test_eof718: cs = 718; goto _test_eof;
	_test_eof719: cs = 719; goto _test_eof;
	_test_eof720: cs = 720; goto _test_eof;
	_test_eof721: cs = 721; goto _test_eof;
	_test_eof722: cs = 722; goto _test_eof;
	_test_eof723: cs = 723; goto _test_eof;
	_test_eof724: cs = 724; goto _test_eof;
	_test_eof725: cs = 725; goto _test_eof;
	_test_eof726: cs = 726; goto _test_eof;
	_test_eof727: cs = 727; goto _test_eof;
	_test_eof728: cs = 728; goto _test_eof;
	_test_eof729: cs = 729; goto _test_eof;
	_test_eof730: cs = 730; goto _test_eof;
	_test_eof731: cs = 731; goto _test_eof;
	_test_eof732: cs = 732; goto _test_eof;
	_test_eof733: cs = 733; goto _test_eof;
	_test_eof734: cs = 734; goto _test_eof;
	_test_eof735: cs = 735; goto _test_eof;
	_test_eof736: cs = 736; goto _test_eof;
	_test_eof737: cs = 737; goto _test_eof;
	_test_eof738: cs = 738; goto _test_eof;
	_test_eof739: cs = 739; goto _test_eof;
	_test_eof740: cs = 740; goto _test_eof;
	_test_eof741: cs = 741; goto _test_eof;
	_test_eof742: cs = 742; goto _test_eof;
	_test_eof1481: cs = 1481; goto _test_eof;
	_test_eof743: cs = 743; goto _test_eof;
	_test_eof744: cs = 744; goto _test_eof;
	_test_eof745: cs = 745; goto _test_eof;
	_test_eof746: cs = 746; goto _test_eof;
	_test_eof747: cs = 747; goto _test_eof;
	_test_eof748: cs = 748; goto _test_eof;
	_test_eof749: cs = 749; goto _test_eof;
	_test_eof750: cs = 750; goto _test_eof;
	_test_eof751: cs = 751; goto _test_eof;
	_test_eof752: cs = 752; goto _test_eof;
	_test_eof753: cs = 753; goto _test_eof;
	_test_eof754: cs = 754; goto _test_eof;
	_test_eof755: cs = 755; goto _test_eof;
	_test_eof756: cs = 756; goto _test_eof;
	_test_eof757: cs = 757; goto _test_eof;
	_test_eof758: cs = 758; goto _test_eof;
	_test_eof759: cs = 759; goto _test_eof;
	_test_eof760: cs = 760; goto _test_eof;
	_test_eof761: cs = 761; goto _test_eof;
	_test_eof762: cs = 762; goto _test_eof;
	_test_eof763: cs = 763; goto _test_eof;
	_test_eof764: cs = 764; goto _test_eof;
	_test_eof765: cs = 765; goto _test_eof;
	_test_eof766: cs = 766; goto _test_eof;
	_test_eof767: cs = 767; goto _test_eof;
	_test_eof768: cs = 768; goto _test_eof;
	_test_eof769: cs = 769; goto _test_eof;
	_test_eof770: cs = 770; goto _test_eof;
	_test_eof771: cs = 771; goto _test_eof;
	_test_eof772: cs = 772; goto _test_eof;
	_test_eof773: cs = 773; goto _test_eof;
	_test_eof774: cs = 774; goto _test_eof;
	_test_eof775: cs = 775; goto _test_eof;
	_test_eof776: cs = 776; goto _test_eof;
	_test_eof777: cs = 777; goto _test_eof;
	_test_eof778: cs = 778; goto _test_eof;
	_test_eof779: cs = 779; goto _test_eof;
	_test_eof780: cs = 780; goto _test_eof;
	_test_eof781: cs = 781; goto _test_eof;
	_test_eof782: cs = 782; goto _test_eof;
	_test_eof783: cs = 783; goto _test_eof;
	_test_eof784: cs = 784; goto _test_eof;
	_test_eof785: cs = 785; goto _test_eof;
	_test_eof786: cs = 786; goto _test_eof;
	_test_eof787: cs = 787; goto _test_eof;
	_test_eof788: cs = 788; goto _test_eof;
	_test_eof789: cs = 789; goto _test_eof;
	_test_eof790: cs = 790; goto _test_eof;
	_test_eof791: cs = 791; goto _test_eof;
	_test_eof792: cs = 792; goto _test_eof;
	_test_eof793: cs = 793; goto _test_eof;
	_test_eof794: cs = 794; goto _test_eof;
	_test_eof795: cs = 795; goto _test_eof;
	_test_eof796: cs = 796; goto _test_eof;
	_test_eof797: cs = 797; goto _test_eof;
	_test_eof798: cs = 798; goto _test_eof;
	_test_eof799: cs = 799; goto _test_eof;
	_test_eof800: cs = 800; goto _test_eof;
	_test_eof801: cs = 801; goto _test_eof;
	_test_eof802: cs = 802; goto _test_eof;
	_test_eof803: cs = 803; goto _test_eof;
	_test_eof804: cs = 804; goto _test_eof;
	_test_eof805: cs = 805; goto _test_eof;
	_test_eof806: cs = 806; goto _test_eof;
	_test_eof807: cs = 807; goto _test_eof;
	_test_eof808: cs = 808; goto _test_eof;
	_test_eof809: cs = 809; goto _test_eof;
	_test_eof810: cs = 810; goto _test_eof;
	_test_eof811: cs = 811; goto _test_eof;
	_test_eof812: cs = 812; goto _test_eof;
	_test_eof813: cs = 813; goto _test_eof;
	_test_eof814: cs = 814; goto _test_eof;
	_test_eof815: cs = 815; goto _test_eof;
	_test_eof816: cs = 816; goto _test_eof;
	_test_eof817: cs = 817; goto _test_eof;
	_test_eof818: cs = 818; goto _test_eof;
	_test_eof819: cs = 819; goto _test_eof;
	_test_eof820: cs = 820; goto _test_eof;
	_test_eof821: cs = 821; goto _test_eof;
	_test_eof822: cs = 822; goto _test_eof;
	_test_eof823: cs = 823; goto _test_eof;
	_test_eof824: cs = 824; goto _test_eof;
	_test_eof825: cs = 825; goto _test_eof;
	_test_eof826: cs = 826; goto _test_eof;
	_test_eof827: cs = 827; goto _test_eof;
	_test_eof828: cs = 828; goto _test_eof;
	_test_eof829: cs = 829; goto _test_eof;
	_test_eof830: cs = 830; goto _test_eof;
	_test_eof831: cs = 831; goto _test_eof;
	_test_eof832: cs = 832; goto _test_eof;
	_test_eof833: cs = 833; goto _test_eof;
	_test_eof834: cs = 834; goto _test_eof;
	_test_eof835: cs = 835; goto _test_eof;
	_test_eof836: cs = 836; goto _test_eof;
	_test_eof837: cs = 837; goto _test_eof;
	_test_eof838: cs = 838; goto _test_eof;
	_test_eof839: cs = 839; goto _test_eof;
	_test_eof840: cs = 840; goto _test_eof;
	_test_eof841: cs = 841; goto _test_eof;
	_test_eof842: cs = 842; goto _test_eof;
	_test_eof843: cs = 843; goto _test_eof;
	_test_eof844: cs = 844; goto _test_eof;
	_test_eof845: cs = 845; goto _test_eof;
	_test_eof846: cs = 846; goto _test_eof;
	_test_eof1482: cs = 1482; goto _test_eof;
	_test_eof847: cs = 847; goto _test_eof;
	_test_eof848: cs = 848; goto _test_eof;
	_test_eof849: cs = 849; goto _test_eof;
	_test_eof850: cs = 850; goto _test_eof;
	_test_eof851: cs = 851; goto _test_eof;
	_test_eof852: cs = 852; goto _test_eof;
	_test_eof853: cs = 853; goto _test_eof;
	_test_eof854: cs = 854; goto _test_eof;
	_test_eof855: cs = 855; goto _test_eof;
	_test_eof856: cs = 856; goto _test_eof;
	_test_eof857: cs = 857; goto _test_eof;
	_test_eof858: cs = 858; goto _test_eof;
	_test_eof859: cs = 859; goto _test_eof;
	_test_eof860: cs = 860; goto _test_eof;
	_test_eof861: cs = 861; goto _test_eof;
	_test_eof862: cs = 862; goto _test_eof;
	_test_eof863: cs = 863; goto _test_eof;
	_test_eof864: cs = 864; goto _test_eof;
	_test_eof865: cs = 865; goto _test_eof;
	_test_eof866: cs = 866; goto _test_eof;
	_test_eof867: cs = 867; goto _test_eof;
	_test_eof868: cs = 868; goto _test_eof;
	_test_eof869: cs = 869; goto _test_eof;
	_test_eof870: cs = 870; goto _test_eof;
	_test_eof871: cs = 871; goto _test_eof;
	_test_eof872: cs = 872; goto _test_eof;
	_test_eof873: cs = 873; goto _test_eof;
	_test_eof874: cs = 874; goto _test_eof;
	_test_eof875: cs = 875; goto _test_eof;
	_test_eof876: cs = 876; goto _test_eof;
	_test_eof877: cs = 877; goto _test_eof;
	_test_eof878: cs = 878; goto _test_eof;
	_test_eof879: cs = 879; goto _test_eof;
	_test_eof880: cs = 880; goto _test_eof;
	_test_eof881: cs = 881; goto _test_eof;
	_test_eof882: cs = 882; goto _test_eof;
	_test_eof883: cs = 883; goto _test_eof;
	_test_eof884: cs = 884; goto _test_eof;
	_test_eof885: cs = 885; goto _test_eof;
	_test_eof886: cs = 886; goto _test_eof;
	_test_eof887: cs = 887; goto _test_eof;
	_test_eof1483: cs = 1483; goto _test_eof;
	_test_eof888: cs = 888; goto _test_eof;
	_test_eof889: cs = 889; goto _test_eof;
	_test_eof1484: cs = 1484; goto _test_eof;
	_test_eof890: cs = 890; goto _test_eof;
	_test_eof891: cs = 891; goto _test_eof;
	_test_eof892: cs = 892; goto _test_eof;
	_test_eof893: cs = 893; goto _test_eof;
	_test_eof894: cs = 894; goto _test_eof;
	_test_eof895: cs = 895; goto _test_eof;
	_test_eof896: cs = 896; goto _test_eof;
	_test_eof897: cs = 897; goto _test_eof;
	_test_eof898: cs = 898; goto _test_eof;
	_test_eof899: cs = 899; goto _test_eof;
	_test_eof900: cs = 900; goto _test_eof;
	_test_eof901: cs = 901; goto _test_eof;
	_test_eof902: cs = 902; goto _test_eof;
	_test_eof903: cs = 903; goto _test_eof;
	_test_eof1485: cs = 1485; goto _test_eof;
	_test_eof904: cs = 904; goto _test_eof;
	_test_eof905: cs = 905; goto _test_eof;
	_test_eof906: cs = 906; goto _test_eof;
	_test_eof907: cs = 907; goto _test_eof;
	_test_eof908: cs = 908; goto _test_eof;
	_test_eof909: cs = 909; goto _test_eof;
	_test_eof910: cs = 910; goto _test_eof;
	_test_eof911: cs = 911; goto _test_eof;
	_test_eof912: cs = 912; goto _test_eof;
	_test_eof913: cs = 913; goto _test_eof;
	_test_eof914: cs = 914; goto _test_eof;
	_test_eof915: cs = 915; goto _test_eof;
	_test_eof916: cs = 916; goto _test_eof;
	_test_eof917: cs = 917; goto _test_eof;
	_test_eof918: cs = 918; goto _test_eof;
	_test_eof919: cs = 919; goto _test_eof;
	_test_eof920: cs = 920; goto _test_eof;
	_test_eof921: cs = 921; goto _test_eof;
	_test_eof922: cs = 922; goto _test_eof;
	_test_eof923: cs = 923; goto _test_eof;
	_test_eof924: cs = 924; goto _test_eof;
	_test_eof925: cs = 925; goto _test_eof;
	_test_eof1486: cs = 1486; goto _test_eof;
	_test_eof926: cs = 926; goto _test_eof;
	_test_eof927: cs = 927; goto _test_eof;
	_test_eof928: cs = 928; goto _test_eof;
	_test_eof929: cs = 929; goto _test_eof;
	_test_eof930: cs = 930; goto _test_eof;
	_test_eof1487: cs = 1487; goto _test_eof;
	_test_eof931: cs = 931; goto _test_eof;
	_test_eof932: cs = 932; goto _test_eof;
	_test_eof933: cs = 933; goto _test_eof;
	_test_eof934: cs = 934; goto _test_eof;
	_test_eof935: cs = 935; goto _test_eof;
	_test_eof1488: cs = 1488; goto _test_eof;
	_test_eof936: cs = 936; goto _test_eof;
	_test_eof937: cs = 937; goto _test_eof;
	_test_eof938: cs = 938; goto _test_eof;
	_test_eof939: cs = 939; goto _test_eof;
	_test_eof940: cs = 940; goto _test_eof;
	_test_eof1489: cs = 1489; goto _test_eof;
	_test_eof1490: cs = 1490; goto _test_eof;
	_test_eof1491: cs = 1491; goto _test_eof;
	_test_eof941: cs = 941; goto _test_eof;
	_test_eof942: cs = 942; goto _test_eof;
	_test_eof1492: cs = 1492; goto _test_eof;
	_test_eof943: cs = 943; goto _test_eof;
	_test_eof944: cs = 944; goto _test_eof;
	_test_eof945: cs = 945; goto _test_eof;
	_test_eof946: cs = 946; goto _test_eof;
	_test_eof947: cs = 947; goto _test_eof;
	_test_eof948: cs = 948; goto _test_eof;
	_test_eof949: cs = 949; goto _test_eof;
	_test_eof950: cs = 950; goto _test_eof;
	_test_eof951: cs = 951; goto _test_eof;
	_test_eof952: cs = 952; goto _test_eof;
	_test_eof953: cs = 953; goto _test_eof;
	_test_eof954: cs = 954; goto _test_eof;
	_test_eof955: cs = 955; goto _test_eof;
	_test_eof956: cs = 956; goto _test_eof;
	_test_eof957: cs = 957; goto _test_eof;
	_test_eof958: cs = 958; goto _test_eof;
	_test_eof959: cs = 959; goto _test_eof;
	_test_eof960: cs = 960; goto _test_eof;
	_test_eof961: cs = 961; goto _test_eof;
	_test_eof962: cs = 962; goto _test_eof;
	_test_eof963: cs = 963; goto _test_eof;
	_test_eof964: cs = 964; goto _test_eof;
	_test_eof965: cs = 965; goto _test_eof;
	_test_eof966: cs = 966; goto _test_eof;
	_test_eof967: cs = 967; goto _test_eof;
	_test_eof968: cs = 968; goto _test_eof;
	_test_eof969: cs = 969; goto _test_eof;
	_test_eof1493: cs = 1493; goto _test_eof;
	_test_eof1494: cs = 1494; goto _test_eof;
	_test_eof1495: cs = 1495; goto _test_eof;
	_test_eof970: cs = 970; goto _test_eof;
	_test_eof971: cs = 971; goto _test_eof;
	_test_eof972: cs = 972; goto _test_eof;
	_test_eof1496: cs = 1496; goto _test_eof;
	_test_eof1497: cs = 1497; goto _test_eof;
	_test_eof973: cs = 973; goto _test_eof;
	_test_eof974: cs = 974; goto _test_eof;
	_test_eof975: cs = 975; goto _test_eof;
	_test_eof976: cs = 976; goto _test_eof;
	_test_eof1498: cs = 1498; goto _test_eof;
	_test_eof1499: cs = 1499; goto _test_eof;
	_test_eof977: cs = 977; goto _test_eof;
	_test_eof978: cs = 978; goto _test_eof;
	_test_eof979: cs = 979; goto _test_eof;
	_test_eof980: cs = 980; goto _test_eof;
	_test_eof1500: cs = 1500; goto _test_eof;
	_test_eof1501: cs = 1501; goto _test_eof;
	_test_eof981: cs = 981; goto _test_eof;
	_test_eof982: cs = 982; goto _test_eof;
	_test_eof983: cs = 983; goto _test_eof;
	_test_eof984: cs = 984; goto _test_eof;
	_test_eof985: cs = 985; goto _test_eof;
	_test_eof986: cs = 986; goto _test_eof;
	_test_eof987: cs = 987; goto _test_eof;
	_test_eof988: cs = 988; goto _test_eof;
	_test_eof989: cs = 989; goto _test_eof;
	_test_eof990: cs = 990; goto _test_eof;
	_test_eof991: cs = 991; goto _test_eof;
	_test_eof992: cs = 992; goto _test_eof;
	_test_eof993: cs = 993; goto _test_eof;
	_test_eof994: cs = 994; goto _test_eof;
	_test_eof995: cs = 995; goto _test_eof;
	_test_eof996: cs = 996; goto _test_eof;
	_test_eof997: cs = 997; goto _test_eof;
	_test_eof998: cs = 998; goto _test_eof;
	_test_eof999: cs = 999; goto _test_eof;
	_test_eof1000: cs = 1000; goto _test_eof;
	_test_eof1001: cs = 1001; goto _test_eof;
	_test_eof1002: cs = 1002; goto _test_eof;
	_test_eof1003: cs = 1003; goto _test_eof;
	_test_eof1004: cs = 1004; goto _test_eof;
	_test_eof1005: cs = 1005; goto _test_eof;
	_test_eof1502: cs = 1502; goto _test_eof;
	_test_eof1006: cs = 1006; goto _test_eof;
	_test_eof1007: cs = 1007; goto _test_eof;
	_test_eof1008: cs = 1008; goto _test_eof;
	_test_eof1009: cs = 1009; goto _test_eof;
	_test_eof1010: cs = 1010; goto _test_eof;
	_test_eof1011: cs = 1011; goto _test_eof;
	_test_eof1012: cs = 1012; goto _test_eof;
	_test_eof1013: cs = 1013; goto _test_eof;
	_test_eof1014: cs = 1014; goto _test_eof;
	_test_eof1015: cs = 1015; goto _test_eof;
	_test_eof1016: cs = 1016; goto _test_eof;
	_test_eof1017: cs = 1017; goto _test_eof;
	_test_eof1018: cs = 1018; goto _test_eof;
	_test_eof1019: cs = 1019; goto _test_eof;
	_test_eof1020: cs = 1020; goto _test_eof;
	_test_eof1503: cs = 1503; goto _test_eof;
	_test_eof1021: cs = 1021; goto _test_eof;
	_test_eof1022: cs = 1022; goto _test_eof;
	_test_eof1023: cs = 1023; goto _test_eof;
	_test_eof1024: cs = 1024; goto _test_eof;
	_test_eof1025: cs = 1025; goto _test_eof;
	_test_eof1026: cs = 1026; goto _test_eof;
	_test_eof1027: cs = 1027; goto _test_eof;
	_test_eof1028: cs = 1028; goto _test_eof;
	_test_eof1029: cs = 1029; goto _test_eof;
	_test_eof1030: cs = 1030; goto _test_eof;
	_test_eof1031: cs = 1031; goto _test_eof;
	_test_eof1032: cs = 1032; goto _test_eof;
	_test_eof1033: cs = 1033; goto _test_eof;
	_test_eof1504: cs = 1504; goto _test_eof;
	_test_eof1034: cs = 1034; goto _test_eof;
	_test_eof1035: cs = 1035; goto _test_eof;
	_test_eof1036: cs = 1036; goto _test_eof;
	_test_eof1037: cs = 1037; goto _test_eof;
	_test_eof1038: cs = 1038; goto _test_eof;
	_test_eof1039: cs = 1039; goto _test_eof;
	_test_eof1040: cs = 1040; goto _test_eof;
	_test_eof1041: cs = 1041; goto _test_eof;
	_test_eof1042: cs = 1042; goto _test_eof;
	_test_eof1043: cs = 1043; goto _test_eof;
	_test_eof1044: cs = 1044; goto _test_eof;
	_test_eof1505: cs = 1505; goto _test_eof;
	_test_eof1506: cs = 1506; goto _test_eof;
	_test_eof1045: cs = 1045; goto _test_eof;
	_test_eof1046: cs = 1046; goto _test_eof;
	_test_eof1047: cs = 1047; goto _test_eof;
	_test_eof1507: cs = 1507; goto _test_eof;
	_test_eof1048: cs = 1048; goto _test_eof;
	_test_eof1049: cs = 1049; goto _test_eof;
	_test_eof1050: cs = 1050; goto _test_eof;
	_test_eof1051: cs = 1051; goto _test_eof;
	_test_eof1052: cs = 1052; goto _test_eof;
	_test_eof1053: cs = 1053; goto _test_eof;
	_test_eof1054: cs = 1054; goto _test_eof;
	_test_eof1055: cs = 1055; goto _test_eof;
	_test_eof1056: cs = 1056; goto _test_eof;
	_test_eof1057: cs = 1057; goto _test_eof;
	_test_eof1508: cs = 1508; goto _test_eof;
	_test_eof1509: cs = 1509; goto _test_eof;
	_test_eof1510: cs = 1510; goto _test_eof;
	_test_eof1058: cs = 1058; goto _test_eof;
	_test_eof1059: cs = 1059; goto _test_eof;
	_test_eof1060: cs = 1060; goto _test_eof;
	_test_eof1061: cs = 1061; goto _test_eof;
	_test_eof1062: cs = 1062; goto _test_eof;
	_test_eof1063: cs = 1063; goto _test_eof;
	_test_eof1064: cs = 1064; goto _test_eof;
	_test_eof1065: cs = 1065; goto _test_eof;
	_test_eof1066: cs = 1066; goto _test_eof;
	_test_eof1067: cs = 1067; goto _test_eof;
	_test_eof1068: cs = 1068; goto _test_eof;
	_test_eof1511: cs = 1511; goto _test_eof;
	_test_eof1512: cs = 1512; goto _test_eof;
	_test_eof1513: cs = 1513; goto _test_eof;
	_test_eof1069: cs = 1069; goto _test_eof;
	_test_eof1070: cs = 1070; goto _test_eof;
	_test_eof1071: cs = 1071; goto _test_eof;
	_test_eof1072: cs = 1072; goto _test_eof;
	_test_eof1073: cs = 1073; goto _test_eof;
	_test_eof1074: cs = 1074; goto _test_eof;
	_test_eof1075: cs = 1075; goto _test_eof;
	_test_eof1076: cs = 1076; goto _test_eof;
	_test_eof1077: cs = 1077; goto _test_eof;
	_test_eof1078: cs = 1078; goto _test_eof;
	_test_eof1079: cs = 1079; goto _test_eof;
	_test_eof1080: cs = 1080; goto _test_eof;
	_test_eof1514: cs = 1514; goto _test_eof;
	_test_eof1081: cs = 1081; goto _test_eof;
	_test_eof1082: cs = 1082; goto _test_eof;
	_test_eof1083: cs = 1083; goto _test_eof;
	_test_eof1515: cs = 1515; goto _test_eof;
	_test_eof1516: cs = 1516; goto _test_eof;
	_test_eof1084: cs = 1084; goto _test_eof;
	_test_eof1517: cs = 1517; goto _test_eof;
	_test_eof1518: cs = 1518; goto _test_eof;
	_test_eof1085: cs = 1085; goto _test_eof;
	_test_eof1519: cs = 1519; goto _test_eof;
	_test_eof1520: cs = 1520; goto _test_eof;
	_test_eof1086: cs = 1086; goto _test_eof;
	_test_eof1087: cs = 1087; goto _test_eof;
	_test_eof1088: cs = 1088; goto _test_eof;
	_test_eof1089: cs = 1089; goto _test_eof;
	_test_eof1090: cs = 1090; goto _test_eof;
	_test_eof1091: cs = 1091; goto _test_eof;
	_test_eof1092: cs = 1092; goto _test_eof;
	_test_eof1093: cs = 1093; goto _test_eof;
	_test_eof1094: cs = 1094; goto _test_eof;
	_test_eof1095: cs = 1095; goto _test_eof;
	_test_eof1096: cs = 1096; goto _test_eof;
	_test_eof1097: cs = 1097; goto _test_eof;
	_test_eof1098: cs = 1098; goto _test_eof;
	_test_eof1099: cs = 1099; goto _test_eof;
	_test_eof1100: cs = 1100; goto _test_eof;
	_test_eof1101: cs = 1101; goto _test_eof;
	_test_eof1102: cs = 1102; goto _test_eof;
	_test_eof1103: cs = 1103; goto _test_eof;
	_test_eof1104: cs = 1104; goto _test_eof;
	_test_eof1105: cs = 1105; goto _test_eof;
	_test_eof1106: cs = 1106; goto _test_eof;
	_test_eof1107: cs = 1107; goto _test_eof;
	_test_eof1108: cs = 1108; goto _test_eof;
	_test_eof1109: cs = 1109; goto _test_eof;
	_test_eof1110: cs = 1110; goto _test_eof;
	_test_eof1111: cs = 1111; goto _test_eof;
	_test_eof1112: cs = 1112; goto _test_eof;
	_test_eof1113: cs = 1113; goto _test_eof;
	_test_eof1114: cs = 1114; goto _test_eof;
	_test_eof1115: cs = 1115; goto _test_eof;
	_test_eof1116: cs = 1116; goto _test_eof;
	_test_eof1117: cs = 1117; goto _test_eof;
	_test_eof1118: cs = 1118; goto _test_eof;
	_test_eof1119: cs = 1119; goto _test_eof;
	_test_eof1120: cs = 1120; goto _test_eof;
	_test_eof1121: cs = 1121; goto _test_eof;
	_test_eof1122: cs = 1122; goto _test_eof;
	_test_eof1123: cs = 1123; goto _test_eof;
	_test_eof1124: cs = 1124; goto _test_eof;
	_test_eof1125: cs = 1125; goto _test_eof;
	_test_eof1126: cs = 1126; goto _test_eof;
	_test_eof1127: cs = 1127; goto _test_eof;
	_test_eof1521: cs = 1521; goto _test_eof;
	_test_eof1128: cs = 1128; goto _test_eof;
	_test_eof1129: cs = 1129; goto _test_eof;
	_test_eof1130: cs = 1130; goto _test_eof;
	_test_eof1131: cs = 1131; goto _test_eof;
	_test_eof1132: cs = 1132; goto _test_eof;
	_test_eof1133: cs = 1133; goto _test_eof;
	_test_eof1134: cs = 1134; goto _test_eof;
	_test_eof1135: cs = 1135; goto _test_eof;
	_test_eof1136: cs = 1136; goto _test_eof;
	_test_eof1137: cs = 1137; goto _test_eof;
	_test_eof1138: cs = 1138; goto _test_eof;
	_test_eof1139: cs = 1139; goto _test_eof;
	_test_eof1140: cs = 1140; goto _test_eof;
	_test_eof1141: cs = 1141; goto _test_eof;
	_test_eof1142: cs = 1142; goto _test_eof;
	_test_eof1143: cs = 1143; goto _test_eof;
	_test_eof1144: cs = 1144; goto _test_eof;
	_test_eof1145: cs = 1145; goto _test_eof;
	_test_eof1146: cs = 1146; goto _test_eof;
	_test_eof1147: cs = 1147; goto _test_eof;
	_test_eof1148: cs = 1148; goto _test_eof;
	_test_eof1149: cs = 1149; goto _test_eof;
	_test_eof1150: cs = 1150; goto _test_eof;
	_test_eof1151: cs = 1151; goto _test_eof;
	_test_eof1152: cs = 1152; goto _test_eof;
	_test_eof1153: cs = 1153; goto _test_eof;
	_test_eof1154: cs = 1154; goto _test_eof;
	_test_eof1155: cs = 1155; goto _test_eof;
	_test_eof1156: cs = 1156; goto _test_eof;
	_test_eof1157: cs = 1157; goto _test_eof;
	_test_eof1158: cs = 1158; goto _test_eof;
	_test_eof1159: cs = 1159; goto _test_eof;
	_test_eof1160: cs = 1160; goto _test_eof;
	_test_eof1161: cs = 1161; goto _test_eof;
	_test_eof1162: cs = 1162; goto _test_eof;
	_test_eof1163: cs = 1163; goto _test_eof;
	_test_eof1164: cs = 1164; goto _test_eof;
	_test_eof1165: cs = 1165; goto _test_eof;
	_test_eof1166: cs = 1166; goto _test_eof;
	_test_eof1167: cs = 1167; goto _test_eof;
	_test_eof1168: cs = 1168; goto _test_eof;
	_test_eof1169: cs = 1169; goto _test_eof;
	_test_eof1170: cs = 1170; goto _test_eof;
	_test_eof1171: cs = 1171; goto _test_eof;
	_test_eof1172: cs = 1172; goto _test_eof;
	_test_eof1173: cs = 1173; goto _test_eof;
	_test_eof1174: cs = 1174; goto _test_eof;
	_test_eof1175: cs = 1175; goto _test_eof;
	_test_eof1176: cs = 1176; goto _test_eof;
	_test_eof1177: cs = 1177; goto _test_eof;
	_test_eof1178: cs = 1178; goto _test_eof;
	_test_eof1179: cs = 1179; goto _test_eof;
	_test_eof1180: cs = 1180; goto _test_eof;
	_test_eof1181: cs = 1181; goto _test_eof;
	_test_eof1182: cs = 1182; goto _test_eof;
	_test_eof1183: cs = 1183; goto _test_eof;
	_test_eof1184: cs = 1184; goto _test_eof;
	_test_eof1185: cs = 1185; goto _test_eof;
	_test_eof1186: cs = 1186; goto _test_eof;
	_test_eof1187: cs = 1187; goto _test_eof;
	_test_eof1188: cs = 1188; goto _test_eof;
	_test_eof1189: cs = 1189; goto _test_eof;
	_test_eof1190: cs = 1190; goto _test_eof;
	_test_eof1191: cs = 1191; goto _test_eof;
	_test_eof1192: cs = 1192; goto _test_eof;
	_test_eof1193: cs = 1193; goto _test_eof;
	_test_eof1194: cs = 1194; goto _test_eof;
	_test_eof1195: cs = 1195; goto _test_eof;
	_test_eof1196: cs = 1196; goto _test_eof;
	_test_eof1197: cs = 1197; goto _test_eof;
	_test_eof1198: cs = 1198; goto _test_eof;
	_test_eof1199: cs = 1199; goto _test_eof;
	_test_eof1200: cs = 1200; goto _test_eof;
	_test_eof1201: cs = 1201; goto _test_eof;
	_test_eof1202: cs = 1202; goto _test_eof;
	_test_eof1203: cs = 1203; goto _test_eof;
	_test_eof1204: cs = 1204; goto _test_eof;
	_test_eof1205: cs = 1205; goto _test_eof;
	_test_eof1206: cs = 1206; goto _test_eof;
	_test_eof1207: cs = 1207; goto _test_eof;
	_test_eof1208: cs = 1208; goto _test_eof;
	_test_eof1209: cs = 1209; goto _test_eof;
	_test_eof1210: cs = 1210; goto _test_eof;
	_test_eof1211: cs = 1211; goto _test_eof;
	_test_eof1212: cs = 1212; goto _test_eof;
	_test_eof1213: cs = 1213; goto _test_eof;
	_test_eof1214: cs = 1214; goto _test_eof;
	_test_eof1215: cs = 1215; goto _test_eof;
	_test_eof1216: cs = 1216; goto _test_eof;
	_test_eof1217: cs = 1217; goto _test_eof;
	_test_eof1218: cs = 1218; goto _test_eof;
	_test_eof1219: cs = 1219; goto _test_eof;
	_test_eof1220: cs = 1220; goto _test_eof;
	_test_eof1221: cs = 1221; goto _test_eof;
	_test_eof1222: cs = 1222; goto _test_eof;
	_test_eof1223: cs = 1223; goto _test_eof;
	_test_eof1224: cs = 1224; goto _test_eof;
	_test_eof1225: cs = 1225; goto _test_eof;
	_test_eof1226: cs = 1226; goto _test_eof;
	_test_eof1227: cs = 1227; goto _test_eof;
	_test_eof1228: cs = 1228; goto _test_eof;
	_test_eof1229: cs = 1229; goto _test_eof;
	_test_eof1230: cs = 1230; goto _test_eof;
	_test_eof1231: cs = 1231; goto _test_eof;
	_test_eof1232: cs = 1232; goto _test_eof;
	_test_eof1233: cs = 1233; goto _test_eof;
	_test_eof1234: cs = 1234; goto _test_eof;
	_test_eof1235: cs = 1235; goto _test_eof;
	_test_eof1236: cs = 1236; goto _test_eof;
	_test_eof1237: cs = 1237; goto _test_eof;
	_test_eof1238: cs = 1238; goto _test_eof;
	_test_eof1239: cs = 1239; goto _test_eof;
	_test_eof1240: cs = 1240; goto _test_eof;
	_test_eof1241: cs = 1241; goto _test_eof;
	_test_eof1242: cs = 1242; goto _test_eof;
	_test_eof1243: cs = 1243; goto _test_eof;
	_test_eof1244: cs = 1244; goto _test_eof;
	_test_eof1245: cs = 1245; goto _test_eof;
	_test_eof1246: cs = 1246; goto _test_eof;
	_test_eof1247: cs = 1247; goto _test_eof;
	_test_eof1248: cs = 1248; goto _test_eof;
	_test_eof1249: cs = 1249; goto _test_eof;
	_test_eof1250: cs = 1250; goto _test_eof;
	_test_eof1251: cs = 1251; goto _test_eof;
	_test_eof1252: cs = 1252; goto _test_eof;
	_test_eof1253: cs = 1253; goto _test_eof;
	_test_eof1254: cs = 1254; goto _test_eof;
	_test_eof1255: cs = 1255; goto _test_eof;
	_test_eof1256: cs = 1256; goto _test_eof;
	_test_eof1257: cs = 1257; goto _test_eof;
	_test_eof1258: cs = 1258; goto _test_eof;
	_test_eof1259: cs = 1259; goto _test_eof;
	_test_eof1260: cs = 1260; goto _test_eof;
	_test_eof1261: cs = 1261; goto _test_eof;
	_test_eof1262: cs = 1262; goto _test_eof;
	_test_eof1263: cs = 1263; goto _test_eof;
	_test_eof1264: cs = 1264; goto _test_eof;
	_test_eof1265: cs = 1265; goto _test_eof;
	_test_eof1266: cs = 1266; goto _test_eof;
	_test_eof1267: cs = 1267; goto _test_eof;
	_test_eof1268: cs = 1268; goto _test_eof;
	_test_eof1269: cs = 1269; goto _test_eof;
	_test_eof1270: cs = 1270; goto _test_eof;
	_test_eof1271: cs = 1271; goto _test_eof;
	_test_eof1272: cs = 1272; goto _test_eof;
	_test_eof1273: cs = 1273; goto _test_eof;
	_test_eof1274: cs = 1274; goto _test_eof;
	_test_eof1275: cs = 1275; goto _test_eof;
	_test_eof1276: cs = 1276; goto _test_eof;
	_test_eof1277: cs = 1277; goto _test_eof;
	_test_eof1278: cs = 1278; goto _test_eof;
	_test_eof1279: cs = 1279; goto _test_eof;
	_test_eof1280: cs = 1280; goto _test_eof;
	_test_eof1281: cs = 1281; goto _test_eof;
	_test_eof1282: cs = 1282; goto _test_eof;
	_test_eof1283: cs = 1283; goto _test_eof;
	_test_eof1284: cs = 1284; goto _test_eof;
	_test_eof1285: cs = 1285; goto _test_eof;
	_test_eof1286: cs = 1286; goto _test_eof;
	_test_eof1287: cs = 1287; goto _test_eof;
	_test_eof1288: cs = 1288; goto _test_eof;
	_test_eof1289: cs = 1289; goto _test_eof;
	_test_eof1290: cs = 1290; goto _test_eof;
	_test_eof1291: cs = 1291; goto _test_eof;
	_test_eof1292: cs = 1292; goto _test_eof;
	_test_eof1293: cs = 1293; goto _test_eof;
	_test_eof1294: cs = 1294; goto _test_eof;
	_test_eof1295: cs = 1295; goto _test_eof;
	_test_eof1296: cs = 1296; goto _test_eof;
	_test_eof1297: cs = 1297; goto _test_eof;
	_test_eof1298: cs = 1298; goto _test_eof;
	_test_eof1299: cs = 1299; goto _test_eof;
	_test_eof1300: cs = 1300; goto _test_eof;
	_test_eof1301: cs = 1301; goto _test_eof;
	_test_eof1302: cs = 1302; goto _test_eof;
	_test_eof1303: cs = 1303; goto _test_eof;
	_test_eof1304: cs = 1304; goto _test_eof;
	_test_eof1522: cs = 1522; goto _test_eof;
	_test_eof1305: cs = 1305; goto _test_eof;
	_test_eof1306: cs = 1306; goto _test_eof;
	_test_eof1307: cs = 1307; goto _test_eof;
	_test_eof1308: cs = 1308; goto _test_eof;
	_test_eof1309: cs = 1309; goto _test_eof;
	_test_eof1310: cs = 1310; goto _test_eof;
	_test_eof1311: cs = 1311; goto _test_eof;
	_test_eof1312: cs = 1312; goto _test_eof;
	_test_eof1523: cs = 1523; goto _test_eof;
	_test_eof1313: cs = 1313; goto _test_eof;
	_test_eof1314: cs = 1314; goto _test_eof;
	_test_eof1315: cs = 1315; goto _test_eof;
	_test_eof1316: cs = 1316; goto _test_eof;
	_test_eof1317: cs = 1317; goto _test_eof;
	_test_eof1524: cs = 1524; goto _test_eof;
	_test_eof1318: cs = 1318; goto _test_eof;
	_test_eof1319: cs = 1319; goto _test_eof;
	_test_eof1320: cs = 1320; goto _test_eof;
	_test_eof1321: cs = 1321; goto _test_eof;
	_test_eof1322: cs = 1322; goto _test_eof;
	_test_eof1323: cs = 1323; goto _test_eof;
	_test_eof1324: cs = 1324; goto _test_eof;
	_test_eof1325: cs = 1325; goto _test_eof;
	_test_eof1326: cs = 1326; goto _test_eof;
	_test_eof1327: cs = 1327; goto _test_eof;
	_test_eof1328: cs = 1328; goto _test_eof;
	_test_eof1329: cs = 1329; goto _test_eof;
	_test_eof1330: cs = 1330; goto _test_eof;
	_test_eof1331: cs = 1331; goto _test_eof;
	_test_eof1332: cs = 1332; goto _test_eof;
	_test_eof1333: cs = 1333; goto _test_eof;
	_test_eof1334: cs = 1334; goto _test_eof;
	_test_eof1335: cs = 1335; goto _test_eof;
	_test_eof1525: cs = 1525; goto _test_eof;
	_test_eof1336: cs = 1336; goto _test_eof;
	_test_eof1337: cs = 1337; goto _test_eof;
	_test_eof1338: cs = 1338; goto _test_eof;
	_test_eof1339: cs = 1339; goto _test_eof;
	_test_eof1340: cs = 1340; goto _test_eof;
	_test_eof1341: cs = 1341; goto _test_eof;
	_test_eof1342: cs = 1342; goto _test_eof;
	_test_eof1343: cs = 1343; goto _test_eof;
	_test_eof1344: cs = 1344; goto _test_eof;
	_test_eof1345: cs = 1345; goto _test_eof;
	_test_eof1346: cs = 1346; goto _test_eof;
	_test_eof1347: cs = 1347; goto _test_eof;
	_test_eof1348: cs = 1348; goto _test_eof;
	_test_eof1349: cs = 1349; goto _test_eof;
	_test_eof1350: cs = 1350; goto _test_eof;
	_test_eof1351: cs = 1351; goto _test_eof;
	_test_eof1352: cs = 1352; goto _test_eof;
	_test_eof1353: cs = 1353; goto _test_eof;
	_test_eof1354: cs = 1354; goto _test_eof;
	_test_eof1526: cs = 1526; goto _test_eof;
	_test_eof1355: cs = 1355; goto _test_eof;
	_test_eof1356: cs = 1356; goto _test_eof;
	_test_eof1357: cs = 1357; goto _test_eof;
	_test_eof1358: cs = 1358; goto _test_eof;
	_test_eof1359: cs = 1359; goto _test_eof;
	_test_eof1360: cs = 1360; goto _test_eof;
	_test_eof1361: cs = 1361; goto _test_eof;
	_test_eof1362: cs = 1362; goto _test_eof;
	_test_eof1363: cs = 1363; goto _test_eof;
	_test_eof1364: cs = 1364; goto _test_eof;
	_test_eof1365: cs = 1365; goto _test_eof;
	_test_eof1366: cs = 1366; goto _test_eof;
	_test_eof1367: cs = 1367; goto _test_eof;
	_test_eof1368: cs = 1368; goto _test_eof;
	_test_eof1369: cs = 1369; goto _test_eof;
	_test_eof1527: cs = 1527; goto _test_eof;
	_test_eof1528: cs = 1528; goto _test_eof;
	_test_eof1529: cs = 1529; goto _test_eof;
	_test_eof1370: cs = 1370; goto _test_eof;
	_test_eof1371: cs = 1371; goto _test_eof;
	_test_eof1372: cs = 1372; goto _test_eof;
	_test_eof1373: cs = 1373; goto _test_eof;
	_test_eof1374: cs = 1374; goto _test_eof;
	_test_eof1375: cs = 1375; goto _test_eof;
	_test_eof1376: cs = 1376; goto _test_eof;
	_test_eof1377: cs = 1377; goto _test_eof;
	_test_eof1530: cs = 1530; goto _test_eof;
	_test_eof1378: cs = 1378; goto _test_eof;
	_test_eof1379: cs = 1379; goto _test_eof;
	_test_eof1380: cs = 1380; goto _test_eof;
	_test_eof1381: cs = 1381; goto _test_eof;
	_test_eof1382: cs = 1382; goto _test_eof;
	_test_eof1383: cs = 1383; goto _test_eof;
	_test_eof1384: cs = 1384; goto _test_eof;
	_test_eof1385: cs = 1385; goto _test_eof;
	_test_eof1386: cs = 1386; goto _test_eof;
	_test_eof1387: cs = 1387; goto _test_eof;
	_test_eof1388: cs = 1388; goto _test_eof;
	_test_eof1531: cs = 1531; goto _test_eof;
	_test_eof1532: cs = 1532; goto _test_eof;
	_test_eof1533: cs = 1533; goto _test_eof;
	_test_eof1389: cs = 1389; goto _test_eof;
	_test_eof1390: cs = 1390; goto _test_eof;
	_test_eof1391: cs = 1391; goto _test_eof;
	_test_eof1392: cs = 1392; goto _test_eof;
	_test_eof1393: cs = 1393; goto _test_eof;
	_test_eof1394: cs = 1394; goto _test_eof;
	_test_eof1395: cs = 1395; goto _test_eof;
	_test_eof1534: cs = 1534; goto _test_eof;
	_test_eof1396: cs = 1396; goto _test_eof;
	_test_eof1397: cs = 1397; goto _test_eof;
	_test_eof1398: cs = 1398; goto _test_eof;
	_test_eof1399: cs = 1399; goto _test_eof;
	_test_eof1400: cs = 1400; goto _test_eof;
	_test_eof1401: cs = 1401; goto _test_eof;
	_test_eof1402: cs = 1402; goto _test_eof;
	_test_eof1403: cs = 1403; goto _test_eof;
	_test_eof1404: cs = 1404; goto _test_eof;
	_test_eof1405: cs = 1405; goto _test_eof;
	_test_eof1406: cs = 1406; goto _test_eof;
	_test_eof1407: cs = 1407; goto _test_eof;
	_test_eof1408: cs = 1408; goto _test_eof;
	_test_eof1535: cs = 1535; goto _test_eof;
	_test_eof1409: cs = 1409; goto _test_eof;
	_test_eof1410: cs = 1410; goto _test_eof;
	_test_eof1411: cs = 1411; goto _test_eof;
	_test_eof1412: cs = 1412; goto _test_eof;
	_test_eof1413: cs = 1413; goto _test_eof;
	_test_eof1414: cs = 1414; goto _test_eof;
	_test_eof1415: cs = 1415; goto _test_eof;
	_test_eof1536: cs = 1536; goto _test_eof;
	_test_eof1416: cs = 1416; goto _test_eof;
	_test_eof1417: cs = 1417; goto _test_eof;
	_test_eof1418: cs = 1418; goto _test_eof;
	_test_eof1419: cs = 1419; goto _test_eof;
	_test_eof1420: cs = 1420; goto _test_eof;
	_test_eof1421: cs = 1421; goto _test_eof;
	_test_eof1537: cs = 1537; goto _test_eof;
	_test_eof1422: cs = 1422; goto _test_eof;
	_test_eof1423: cs = 1423; goto _test_eof;
	_test_eof1424: cs = 1424; goto _test_eof;
	_test_eof1425: cs = 1425; goto _test_eof;
	_test_eof1426: cs = 1426; goto _test_eof;
	_test_eof1427: cs = 1427; goto _test_eof;
	_test_eof1538: cs = 1538; goto _test_eof;
	_test_eof1428: cs = 1428; goto _test_eof;
	_test_eof1429: cs = 1429; goto _test_eof;
	_test_eof1430: cs = 1430; goto _test_eof;
	_test_eof1431: cs = 1431; goto _test_eof;
	_test_eof1432: cs = 1432; goto _test_eof;
	_test_eof1433: cs = 1433; goto _test_eof;
	_test_eof1434: cs = 1434; goto _test_eof;
	_test_eof1435: cs = 1435; goto _test_eof;
	_test_eof1539: cs = 1539; goto _test_eof;
	_test_eof1436: cs = 1436; goto _test_eof;
	_test_eof1437: cs = 1437; goto _test_eof;
	_test_eof1438: cs = 1438; goto _test_eof;
	_test_eof1439: cs = 1439; goto _test_eof;
	_test_eof1440: cs = 1440; goto _test_eof;
	_test_eof1441: cs = 1441; goto _test_eof;
	_test_eof1442: cs = 1442; goto _test_eof;
	_test_eof1540: cs = 1540; goto _test_eof;
	_test_eof1443: cs = 1443; goto _test_eof;

	_test_eof: {}
	if ( p == eof )
	{
	switch ( cs ) {
	case 7:
	case 8:
	case 189:
	case 213:
	case 215:
	case 271:
	case 285:
	case 311:
	case 367:
	case 368:
	case 374:
	{
		WARN(ZS_BAD_REST);
		p--; {       if ( p == pe )
               goto _test_eof316;
goto st316;}
	}
	break;
	case 318:
	case 319:
	case 320:
	case 325:
	case 326:
	{
		WARN(ZS_BAD_DNAME_CHAR);
		p--; {       if ( p == pe )
               goto _test_eof316;
goto st316;}
	}
	break;
	case 198:
	{
		s->r_owner_length = 0;
		WARN(ZS_BAD_OWNER);
		p--; {       if ( p == pe )
               goto _test_eof316;
goto st316;}
	}
	break;
	case 335:
	{
		WARN(ZS_BAD_TEXT);
		p--; {       if ( p == pe )
               goto _test_eof316;
goto st316;}
	}
	break;
	case 340:
	case 348:
	{
		ERR(ZS_BAD_TTL);
		p--; {       if ( p == pe )
               goto _test_eof316;
goto st316;}
	}
	break;
	case 349:
	case 350:
	case 351:
	case 360:
	{
		ERR(ZS_BAD_ORIGIN);
		p--; {       if ( p == pe )
               goto _test_eof316;
goto st316;}
	}
	break;
	case 362:
	{
		ERR(ZS_BAD_INCLUDE_FILENAME);
		p--; {       if ( p == pe )
               goto _test_eof316;
goto st316;}
	}
	break;
	case 365:
	case 375:
	{
		ERR(ZS_BAD_INCLUDE_ORIGIN);
		p--; {       if ( p == pe )
               goto _test_eof316;
goto st316;}
	}
	break;
	case 1448:
	{
		NOERR;
	}
	break;
	case 190:
	case 191:
	case 192:
	case 193:
	case 194:
	case 195:
	case 196:
	case 197:
	case 236:
	case 237:
	case 238:
	case 239:
	case 240:
	case 241:
	case 242:
	case 243:
	case 244:
	{
		ERR(ZS_BAD_DIRECTIVE);
		p--; {       if ( p == pe )
               goto _test_eof316;
goto st316;}
	}
	break;
	case 378:
	case 379:
	case 380:
	case 381:
	case 382:
	case 383:
	case 384:
	{
		WARN(ZS_BAD_BASE64_CHAR);
		p--; {       if ( p == pe )
               goto _test_eof316;
goto st316;}
	}
	break;
	case 385:
	case 386:
	case 387:
	case 388:
	case 389:
	case 390:
	case 391:
	case 392:
	case 393:
	case 394:
	case 395:
	case 396:
	case 397:
	case 398:
	case 399:
	case 400:
	case 401:
	case 402:
	case 403:
	case 404:
	case 405:
	case 406:
	case 407:
	case 408:
	case 409:
	case 410:
	case 411:
	case 412:
	case 413:
	case 414:
	case 415:
	case 416:
	case 417:
	case 418:
	case 419:
	case 420:
	case 421:
	case 422:
	case 423:
	case 424:
	case 425:
	case 426:
	case 427:
	case 428:
	case 429:
	case 430:
	case 431:
	case 432:
	case 433:
	case 434:
	case 435:
	case 436:
	case 437:
	case 438:
	case 439:
	case 440:
	case 441:
	case 442:
	case 443:
	case 444:
	case 445:
	case 446:
	case 447:
	case 448:
	case 449:
	case 450:
	case 451:
	case 452:
	case 453:
	case 454:
	case 455:
	case 456:
	case 457:
	case 458:
	case 459:
	case 460:
	case 461:
	case 462:
	case 463:
	case 464:
	case 465:
	case 466:
	case 467:
	case 468:
	case 469:
	case 470:
	case 471:
	case 472:
	case 473:
	case 474:
	case 475:
	case 476:
	case 477:
	case 478:
	case 479:
	case 480:
	case 481:
	case 482:
	case 483:
	case 484:
	case 485:
	case 486:
	case 487:
	case 488:
	case 489:
	case 490:
	case 491:
	case 492:
	case 493:
	case 494:
	case 495:
	case 496:
	case 497:
	case 498:
	case 499:
	case 500:
	case 501:
	case 502:
	case 503:
	case 504:
	case 505:
	case 506:
	case 507:
	case 508:
	case 509:
	case 510:
	case 511:
	case 512:
	case 513:
	case 514:
	case 515:
	case 516:
	case 517:
	case 518:
	case 519:
	case 520:
	case 521:
	case 522:
	case 523:
	case 524:
	case 525:
	case 526:
	case 527:
	case 528:
	case 529:
	case 530:
	case 531:
	case 532:
	case 533:
	case 534:
	case 535:
	case 536:
	case 537:
	case 538:
	case 539:
	case 540:
	case 541:
	case 542:
	case 543:
	case 544:
	case 545:
	case 546:
	case 547:
	case 548:
	case 549:
	case 550:
	case 551:
	case 552:
	case 553:
	case 554:
	{
		WARN(ZS_BAD_BITMAP);
		p--; {       if ( p == pe )
               goto _test_eof316;
goto st316;}
	}
	break;
	case 555:
	case 562:
	case 563:
	case 564:
	case 571:
	case 573:
	{
		WARN(ZS_BAD_HEX_RDATA);
		p--; {       if ( p == pe )
               goto _test_eof316;
goto st316;}
	}
	break;
	case 630:
	case 631:
	case 632:
	case 633:
	case 634:
	case 635:
	case 636:
	case 637:
	case 638:
	case 639:
	case 640:
	case 641:
	case 642:
	case 643:
	case 644:
	case 645:
	case 646:
	case 647:
	case 648:
	case 649:
	case 650:
	case 651:
	case 652:
	case 653:
	case 654:
	case 655:
	case 656:
	case 657:
	case 658:
	case 659:
	case 660:
	case 661:
	case 662:
	case 663:
	case 664:
	case 665:
	case 666:
	case 667:
	case 668:
	case 669:
	case 670:
	case 671:
	case 672:
	case 673:
	case 680:
	case 681:
	case 682:
	case 683:
	case 684:
	case 691:
	case 692:
	case 695:
	case 696:
	case 697:
	case 698:
	case 699:
	case 700:
	case 701:
	case 702:
	case 703:
	case 704:
	case 705:
	case 706:
	case 707:
	case 708:
	case 709:
	case 710:
	case 711:
	case 712:
	case 713:
	case 714:
	case 715:
	case 716:
	case 717:
	case 718:
	case 719:
	case 720:
	case 721:
	case 722:
	case 723:
	case 724:
	case 725:
	case 726:
	case 727:
	case 728:
	case 729:
	case 730:
	case 731:
	case 732:
	case 733:
	case 734:
	case 739:
	case 740:
	{
		WARN(ZS_BAD_SVCB_PARAM);
		p--; {       if ( p == pe )
               goto _test_eof316;
goto st316;}
	}
	break;
	case 574:
	case 575:
	case 576:
	case 577:
	case 578:
	case 579:
	case 580:
	case 581:
	case 582:
	case 583:
	case 584:
	case 585:
	case 586:
	case 587:
	case 588:
	case 589:
	case 590:
	case 591:
	case 592:
	case 593:
	case 594:
	case 595:
	case 596:
	case 597:
	case 598:
	case 599:
	case 600:
	case 601:
	case 602:
	case 603:
	case 606:
	case 607:
	case 608:
	case 609:
	case 610:
	case 611:
	case 612:
	case 613:
	case 614:
	case 615:
	case 616:
	case 617:
	case 618:
	case 619:
	case 620:
	case 621:
	case 622:
	case 623:
	case 624:
	case 625:
	case 626:
	case 627:
	case 628:
	case 629:
	{
		WARN(ZS_BAD_SVCB_MANDATORY);
		p--; {       if ( p == pe )
               goto _test_eof316;
goto st316;}
	}
	break;
	case 741:
	case 742:
	case 743:
	case 744:
	case 745:
	case 746:
	case 747:
	case 748:
	case 749:
	case 750:
	case 751:
	case 752:
	case 753:
	case 754:
	case 755:
	case 756:
	case 757:
	case 758:
	case 759:
	case 760:
	case 761:
	case 762:
	case 763:
	case 764:
	case 765:
	case 766:
	case 767:
	case 768:
	case 769:
	case 770:
	case 771:
	case 772:
	case 773:
	case 774:
	case 775:
	case 776:
	case 777:
	case 778:
	case 779:
	case 780:
	case 781:
	case 782:
	case 783:
	case 784:
	case 785:
	case 786:
	case 787:
	case 788:
	case 789:
	case 790:
	case 791:
	case 792:
	case 793:
	case 794:
	case 795:
	case 796:
	case 797:
	case 798:
	case 799:
	case 800:
	case 801:
	case 802:
	case 803:
	case 804:
	case 805:
	case 806:
	case 807:
	case 808:
	case 809:
	case 810:
	case 811:
	case 812:
	case 813:
	case 814:
	case 815:
	case 816:
	case 817:
	case 818:
	case 819:
	case 820:
	case 821:
	case 822:
	case 823:
	case 824:
	case 825:
	case 826:
	case 827:
	case 828:
	case 829:
	case 830:
	case 831:
	case 832:
	case 833:
	case 834:
	case 835:
	case 836:
	case 837:
	case 838:
	case 839:
	case 840:
	case 841:
	case 842:
	case 843:
	case 844:
	{
		WARN(ZS_BAD_ALGORITHM);
		p--; {       if ( p == pe )
               goto _test_eof316;
goto st316;}
	}
	break;
	case 845:
	case 846:
	case 847:
	case 848:
	case 849:
	case 850:
	case 851:
	case 852:
	case 853:
	case 854:
	case 855:
	case 856:
	case 857:
	case 858:
	case 859:
	case 860:
	case 861:
	case 862:
	case 863:
	case 864:
	case 865:
	case 866:
	case 867:
	case 868:
	case 869:
	case 870:
	case 871:
	case 872:
	case 873:
	case 874:
	case 875:
	case 876:
	case 877:
	case 878:
	case 879:
	case 880:
	case 881:
	case 882:
	case 883:
	case 884:
	case 885:
	{
		WARN(ZS_BAD_CERT_TYPE);
		p--; {       if ( p == pe )
               goto _test_eof316;
goto st316;}
	}
	break;
	case 5:
	case 9:
	case 10:
	case 290:
	case 888:
	case 889:
	case 890:
	case 891:
	case 892:
	case 893:
	case 907:
	case 911:
	case 915:
	case 919:
	case 920:
	case 921:
	case 922:
	case 923:
	case 924:
	case 925:
	case 926:
	case 927:
	case 928:
	case 929:
	case 930:
	case 931:
	case 934:
	case 935:
	case 936:
	case 1004:
	case 1005:
	case 1006:
	case 1007:
	case 1008:
	case 1013:
	case 1014:
	case 1015:
	case 1016:
	case 1017:
	case 1018:
	case 1019:
	case 1020:
	case 1021:
	case 1022:
	case 1023:
	case 1024:
	case 1025:
	case 1026:
	case 1027:
	case 1030:
	case 1031:
	case 1032:
	case 1033:
	case 1034:
	case 1035:
	case 1036:
	case 1044:
	case 1050:
	case 1051:
	case 1058:
	case 1059:
	case 1060:
	case 1069:
	case 1070:
	case 1109:
	case 1112:
	case 1113:
	case 1124:
	case 1125:
	case 1126:
	case 1127:
	case 1128:
	case 1129:
	case 1130:
	case 1131:
	case 1132:
	case 1133:
	case 1134:
	case 1135:
	case 1302:
	case 1303:
	case 1304:
	case 1309:
	case 1310:
	case 1311:
	case 1312:
	case 1313:
	case 1314:
	case 1315:
	case 1316:
	case 1317:
	case 1335:
	case 1341:
	case 1344:
	case 1345:
	case 1346:
	case 1357:
	case 1358:
	case 1359:
	case 1370:
	case 1371:
	case 1372:
	case 1377:
	case 1378:
	case 1389:
	case 1390:
	case 1391:
	case 1396:
	case 1409:
	case 1426:
	case 1427:
	case 1428:
	case 1429:
	case 1432:
	case 1433:
	case 1434:
	case 1435:
	case 1436:
	case 1437:
	case 1440:
	case 1441:
	case 1442:
	case 1443:
	{
		WARN(ZS_BAD_RDATA);
		p--; {       if ( p == pe )
               goto _test_eof316;
goto st316;}
	}
	break;
	case 3:
	case 17:
	case 18:
	case 22:
	case 23:
	case 24:
	case 25:
	case 26:
	case 29:
	case 30:
	case 32:
	case 33:
	case 34:
	case 36:
	case 37:
	case 38:
	case 40:
	case 41:
	case 42:
	case 43:
	case 45:
	case 46:
	case 47:
	case 49:
	case 50:
	case 51:
	case 54:
	case 55:
	case 56:
	case 57:
	case 59:
	case 61:
	case 62:
	case 63:
	case 64:
	case 66:
	case 67:
	case 68:
	case 70:
	case 71:
	case 72:
	case 73:
	case 74:
	case 75:
	case 76:
	case 77:
	case 78:
	case 79:
	case 81:
	case 82:
	case 85:
	case 86:
	case 88:
	case 90:
	case 93:
	case 94:
	case 95:
	case 96:
	case 99:
	case 100:
	case 101:
	case 102:
	case 104:
	case 107:
	case 110:
	case 111:
	case 112:
	case 113:
	case 115:
	case 116:
	case 117:
	case 118:
	case 119:
	case 120:
	case 121:
	case 122:
	case 123:
	case 125:
	case 126:
	case 128:
	case 130:
	case 131:
	case 132:
	case 135:
	case 136:
	case 137:
	case 138:
	case 139:
	case 141:
	case 143:
	case 145:
	case 147:
	case 148:
	case 149:
	case 151:
	case 152:
	case 154:
	case 155:
	case 156:
	case 158:
	case 160:
	case 161:
	case 164:
	case 165:
	case 167:
	case 168:
	case 169:
	case 170:
	case 171:
	case 173:
	case 174:
	case 175:
	case 176:
	case 177:
	case 179:
	case 181:
	case 182:
	case 188:
	case 203:
	case 207:
	case 274:
	case 275:
	case 277:
	case 278:
	case 279:
	case 281:
	{
		WARN(ZS_UNSUPPORTED_TYPE);
		p--; {       if ( p == pe )
               goto _test_eof316;
goto st316;}
	}
	break;
	case 343:
	case 344:
	{
		WARN(ZS_BAD_REST);
		p--; {       if ( p == pe )
               goto _test_eof316;
goto st316;}
	}
	{
		ERR(ZS_BAD_TTL);
		p--; {       if ( p == pe )
               goto _test_eof316;
goto st316;}
	}
	break;
	case 352:
	case 353:
	case 354:
	case 359:
	{
		WARN(ZS_BAD_REST);
		p--; {       if ( p == pe )
               goto _test_eof316;
goto st316;}
	}
	{
		ERR(ZS_BAD_ORIGIN);
		p--; {       if ( p == pe )
               goto _test_eof316;
goto st316;}
	}
	break;
	case 321:
	case 322:
	case 323:
	case 324:
	{
		WARN(ZS_BAD_NUMBER);
		p--; {       if ( p == pe )
               goto _test_eof316;
goto st316;}
	}
	{
		WARN(ZS_BAD_DNAME_CHAR);
		p--; {       if ( p == pe )
               goto _test_eof316;
goto st316;}
	}
	break;
	case 355:
	case 356:
	case 357:
	case 358:
	{
		WARN(ZS_BAD_NUMBER);
		p--; {       if ( p == pe )
               goto _test_eof316;
goto st316;}
	}
	{
		ERR(ZS_BAD_ORIGIN);
		p--; {       if ( p == pe )
               goto _test_eof316;
goto st316;}
	}
	break;
	case 369:
	case 370:
	case 371:
	case 372:
	{
		WARN(ZS_BAD_NUMBER);
		p--; {       if ( p == pe )
               goto _test_eof316;
goto st316;}
	}
	{
		ERR(ZS_BAD_INCLUDE_ORIGIN);
		p--; {       if ( p == pe )
               goto _test_eof316;
goto st316;}
	}
	break;
	case 268:
	{
		s->r_owner_length = 0;
		WARN(ZS_BAD_OWNER);
		p--; {       if ( p == pe )
               goto _test_eof316;
goto st316;}
	}
	{
		WARN(ZS_BAD_RDATA);
		p--; {       if ( p == pe )
               goto _test_eof316;
goto st316;}
	}
	break;
	case 294:
	case 295:
	case 296:
	case 297:
	case 298:
	case 299:
	case 300:
	case 301:
	case 302:
	case 303:
	case 304:
	case 305:
	case 306:
	case 307:
	case 308:
	case 309:
	case 310:
	case 313:
	{
		s->r_owner_length = 0;
		WARN(ZS_BAD_OWNER);
		p--; {       if ( p == pe )
               goto _test_eof316;
goto st316;}
	}
	{
		WARN(ZS_UNSUPPORTED_TYPE);
		p--; {       if ( p == pe )
               goto _test_eof316;
goto st316;}
	}
	break;
	case 341:
	{
		WARN(ZS_BAD_NUMBER);
		p--; {       if ( p == pe )
               goto _test_eof316;
goto st316;}
	}
	{
		ERR(ZS_BAD_TTL);
		p--; {       if ( p == pe )
               goto _test_eof316;
goto st316;}
	}
	break;
	case 556:
	case 557:
	case 565:
	case 566:
	case 572:
	{
		WARN(ZS_BAD_NUMBER);
		p--; {       if ( p == pe )
               goto _test_eof316;
goto st316;}
	}
	{
		WARN(ZS_BAD_HEX_RDATA);
		p--; {       if ( p == pe )
               goto _test_eof316;
goto st316;}
	}
	break;
	case 693:
	case 694:
	case 735:
	case 736:
	case 737:
	case 738:
	{
		WARN(ZS_BAD_NUMBER);
		p--; {       if ( p == pe )
               goto _test_eof316;
goto st316;}
	}
	{
		WARN(ZS_BAD_SVCB_PARAM);
		p--; {       if ( p == pe )
               goto _test_eof316;
goto st316;}
	}
	break;
	case 604:
	case 605:
	{
		WARN(ZS_BAD_NUMBER);
		p--; {       if ( p == pe )
               goto _test_eof316;
goto st316;}
	}
	{
		WARN(ZS_BAD_SVCB_MANDATORY);
		p--; {       if ( p == pe )
               goto _test_eof316;
goto st316;}
	}
	break;
	case 894:
	case 895:
	case 896:
	case 898:
	case 900:
	case 902:
	case 932:
	case 933:
	case 998:
	case 999:
	case 1000:
	case 1001:
	case 1002:
	case 1003:
	case 1009:
	case 1010:
	case 1011:
	case 1012:
	case 1028:
	case 1029:
	case 1048:
	case 1049:
	case 1052:
	case 1053:
	case 1061:
	case 1062:
	case 1063:
	case 1064:
	case 1071:
	case 1072:
	case 1114:
	case 1115:
	case 1116:
	case 1117:
	case 1122:
	case 1123:
	case 1305:
	case 1306:
	case 1307:
	case 1308:
	case 1318:
	case 1319:
	case 1320:
	case 1321:
	case 1322:
	case 1323:
	case 1347:
	case 1348:
	case 1349:
	case 1350:
	case 1351:
	case 1352:
	case 1360:
	case 1361:
	case 1362:
	case 1363:
	case 1364:
	case 1365:
	case 1373:
	case 1374:
	case 1375:
	case 1376:
	case 1379:
	case 1380:
	case 1381:
	case 1382:
	case 1383:
	case 1384:
	case 1392:
	case 1393:
	case 1397:
	case 1398:
	case 1422:
	case 1423:
	case 1424:
	case 1425:
	case 1430:
	case 1431:
	case 1438:
	case 1439:
	{
		WARN(ZS_BAD_NUMBER);
		p--; {       if ( p == pe )
               goto _test_eof316;
goto st316;}
	}
	{
		WARN(ZS_BAD_RDATA);
		p--; {       if ( p == pe )
               goto _test_eof316;
goto st316;}
	}
	break;
	case 162:
	case 183:
	case 199:
	case 202:
	{
		WARN(ZS_BAD_NUMBER);
		p--; {       if ( p == pe )
               goto _test_eof316;
goto st316;}
	}
	{
		WARN(ZS_UNSUPPORTED_TYPE);
		p--; {       if ( p == pe )
               goto _test_eof316;
goto st316;}
	}
	break;
	case 1118:
	case 1119:
	case 1120:
	case 1121:
	{
		WARN(ZS_BAD_TIMESTAMP_CHAR);
		p--; {       if ( p == pe )
               goto _test_eof316;
goto st316;}
	}
	{
		WARN(ZS_BAD_RDATA);
		p--; {       if ( p == pe )
               goto _test_eof316;
goto st316;}
	}
	break;
	case 327:
	case 328:
	case 333:
	case 334:
	{
		WARN(ZS_BAD_TEXT_CHAR);
		p--; {       if ( p == pe )
               goto _test_eof316;
goto st316;}
	}
	{
		WARN(ZS_BAD_TEXT);
		p--; {       if ( p == pe )
               goto _test_eof316;
goto st316;}
	}
	break;
	case 937:
	case 938:
	case 939:
	case 940:
	{
		s->long_string = false;
	}
	{
		WARN(ZS_BAD_RDATA);
		p--; {       if ( p == pe )
               goto _test_eof316;
goto st316;}
	}
	break;
	case 363:
	{
		ERR(ZS_BAD_INCLUDE_FILENAME);
		p--; {       if ( p == pe )
               goto _test_eof316;
goto st316;}
	}
	{
		WARN(ZS_BAD_REST);
		p--; {       if ( p == pe )
               goto _test_eof316;
goto st316;}
	}
	break;
	case 364:
	case 366:
	case 373:
	{
		ERR(ZS_BAD_INCLUDE_ORIGIN);
		p--; {       if ( p == pe )
               goto _test_eof316;
goto st316;}
	}
	{
		WARN(ZS_BAD_REST);
		p--; {       if ( p == pe )
               goto _test_eof316;
goto st316;}
	}
	break;
	case 674:
	case 675:
	case 676:
	case 677:
	case 678:
	case 679:
	case 685:
	case 686:
	case 687:
	case 688:
	case 689:
	case 690:
	{
		WARN(ZS_BAD_ADDRESS_CHAR);
		p--; {       if ( p == pe )
               goto _test_eof316;
goto st316;}
	}
	{
		WARN(ZS_BAD_SVCB_PARAM);
		p--; {       if ( p == pe )
               goto _test_eof316;
goto st316;}
	}
	break;
	case 886:
	case 887:
	case 941:
	case 942:
	case 1394:
	case 1395:
	{
		WARN(ZS_BAD_ADDRESS_CHAR);
		p--; {       if ( p == pe )
               goto _test_eof316;
goto st316;}
	}
	{
		WARN(ZS_BAD_RDATA);
		p--; {       if ( p == pe )
               goto _test_eof316;
goto st316;}
	}
	break;
	case 1037:
	case 1038:
	case 1039:
	case 1042:
	case 1043:
	case 1045:
	{
		WARN(ZS_BAD_APL);
		p--; {       if ( p == pe )
               goto _test_eof316;
goto st316;}
	}
	{
		WARN(ZS_BAD_RDATA);
		p--; {       if ( p == pe )
               goto _test_eof316;
goto st316;}
	}
	break;
	case 1054:
	case 1055:
	case 1056:
	case 1057:
	case 1065:
	case 1066:
	case 1067:
	case 1068:
	case 1324:
	case 1325:
	case 1342:
	case 1343:
	case 1353:
	case 1354:
	case 1355:
	case 1356:
	case 1366:
	case 1367:
	case 1368:
	case 1369:
	case 1385:
	case 1386:
	case 1387:
	case 1388:
	case 1399:
	case 1400:
	case 1401:
	case 1402:
	case 1404:
	case 1405:
	case 1406:
	case 1407:
	case 1410:
	case 1411:
	case 1413:
	case 1414:
	case 1416:
	case 1417:
	case 1419:
	case 1420:
	{
		WARN(ZS_BAD_HEX_CHAR);
		p--; {       if ( p == pe )
               goto _test_eof316;
goto st316;}
	}
	{
		WARN(ZS_BAD_RDATA);
		p--; {       if ( p == pe )
               goto _test_eof316;
goto st316;}
	}
	break;
	case 1326:
	case 1327:
	case 1328:
	case 1329:
	case 1330:
	case 1331:
	case 1332:
	case 1333:
	case 1334:
	case 1336:
	case 1337:
	case 1338:
	case 1339:
	case 1340:
	{
		WARN(ZS_BAD_BASE32HEX_CHAR);
		p--; {       if ( p == pe )
               goto _test_eof316;
goto st316;}
	}
	{
		WARN(ZS_BAD_RDATA);
		p--; {       if ( p == pe )
               goto _test_eof316;
goto st316;}
	}
	break;
	case 1073:
	case 1074:
	case 1077:
	case 1086:
	case 1087:
	case 1088:
	case 1093:
	case 1094:
	case 1095:
	case 1100:
	case 1101:
	case 1102:
	case 1105:
	case 1107:
	case 1108:
	{
		WARN(ZS_BAD_GATEWAY);
		p--; {       if ( p == pe )
               goto _test_eof316;
goto st316;}
	}
	{
		WARN(ZS_BAD_RDATA);
		p--; {       if ( p == pe )
               goto _test_eof316;
goto st316;}
	}
	break;
	case 1079:
	case 1080:
	case 1081:
	case 1082:
	case 1083:
	case 1084:
	case 1085:
	{
		WARN(ZS_BAD_GATEWAY_KEY);
		p--; {       if ( p == pe )
               goto _test_eof316;
goto st316;}
	}
	{
		WARN(ZS_BAD_RDATA);
		p--; {       if ( p == pe )
               goto _test_eof316;
goto st316;}
	}
	break;
	case 1110:
	case 1111:
	case 1136:
	case 1137:
	case 1138:
	case 1139:
	case 1140:
	case 1141:
	case 1142:
	case 1143:
	case 1144:
	case 1145:
	case 1146:
	case 1147:
	case 1148:
	case 1149:
	case 1150:
	case 1151:
	case 1152:
	case 1153:
	case 1154:
	case 1155:
	case 1156:
	case 1157:
	case 1158:
	case 1159:
	case 1160:
	case 1161:
	case 1162:
	case 1163:
	case 1164:
	case 1165:
	case 1166:
	case 1167:
	case 1168:
	case 1169:
	case 1170:
	case 1171:
	case 1172:
	case 1173:
	case 1174:
	case 1175:
	case 1176:
	case 1177:
	case 1178:
	case 1179:
	case 1180:
	case 1181:
	case 1182:
	case 1183:
	case 1184:
	case 1185:
	case 1186:
	case 1187:
	case 1188:
	case 1189:
	case 1190:
	case 1191:
	case 1192:
	case 1193:
	case 1194:
	case 1195:
	case 1196:
	case 1197:
	case 1198:
	case 1199:
	case 1200:
	case 1201:
	case 1202:
	case 1203:
	case 1204:
	case 1205:
	case 1206:
	case 1207:
	case 1208:
	case 1209:
	case 1210:
	case 1211:
	case 1212:
	case 1213:
	case 1214:
	case 1215:
	case 1216:
	case 1217:
	case 1218:
	case 1219:
	case 1220:
	case 1221:
	case 1222:
	case 1223:
	case 1224:
	case 1225:
	case 1226:
	case 1227:
	case 1228:
	case 1229:
	case 1230:
	case 1231:
	case 1232:
	case 1233:
	case 1234:
	case 1235:
	case 1236:
	case 1237:
	case 1238:
	case 1239:
	case 1240:
	case 1241:
	case 1242:
	case 1243:
	case 1244:
	case 1245:
	case 1246:
	case 1247:
	case 1248:
	case 1249:
	case 1250:
	case 1251:
	case 1252:
	case 1253:
	case 1254:
	case 1255:
	case 1256:
	case 1257:
	case 1258:
	case 1259:
	case 1260:
	case 1261:
	case 1262:
	case 1263:
	case 1264:
	case 1265:
	case 1266:
	case 1267:
	case 1268:
	case 1269:
	case 1270:
	case 1271:
	case 1272:
	case 1273:
	case 1274:
	case 1275:
	case 1276:
	case 1277:
	case 1278:
	case 1279:
	case 1280:
	case 1281:
	case 1282:
	case 1283:
	case 1284:
	case 1287:
	case 1288:
	case 1289:
	case 1290:
	case 1291:
	case 1292:
	case 1293:
	case 1294:
	case 1295:
	case 1296:
	case 1297:
	case 1298:
	case 1299:
	case 1300:
	case 1301:
	{
		WARN(ZS_UNSUPPORTED_TYPE);
		p--; {       if ( p == pe )
               goto _test_eof316;
goto st316;}
	}
	{
		WARN(ZS_BAD_RDATA);
		p--; {       if ( p == pe )
               goto _test_eof316;
goto st316;}
	}
	break;
	case 943:
	case 944:
	case 945:
	case 946:
	case 947:
	case 948:
	case 949:
	case 950:
	case 951:
	case 952:
	case 953:
	case 954:
	case 955:
	case 956:
	case 957:
	case 958:
	case 959:
	case 960:
	case 961:
	case 962:
	case 963:
	case 964:
	case 965:
	case 966:
	case 967:
	case 968:
	case 969:
	case 970:
	case 971:
	case 972:
	case 973:
	case 974:
	case 975:
	case 976:
	case 977:
	case 978:
	case 979:
	case 980:
	case 981:
	case 982:
	case 983:
	case 984:
	case 985:
	case 986:
	case 987:
	case 988:
	case 989:
	case 990:
	case 991:
	case 992:
	case 993:
	case 994:
	case 995:
	case 996:
	case 997:
	{
		WARN(ZS_BAD_LOC_DATA);
		p--; {       if ( p == pe )
               goto _test_eof316;
goto st316;}
	}
	{
		WARN(ZS_BAD_RDATA);
		p--; {       if ( p == pe )
               goto _test_eof316;
goto st316;}
	}
	break;
	case 6:
	case 11:
	case 12:
	case 13:
	case 20:
	case 21:
	case 211:
	case 214:
	case 234:
	case 270:
	case 272:
	case 273:
	case 283:
	case 284:
	case 286:
	case 287:
	case 288:
	case 289:
	case 292:
	case 293:
	{
		WARN(ZS_BAD_RDATA);
		p--; {       if ( p == pe )
               goto _test_eof316;
goto st316;}
	}
	{
		WARN(ZS_BAD_REST);
		p--; {       if ( p == pe )
               goto _test_eof316;
goto st316;}
	}
	break;
	case 16:
	case 248:
	case 312:
	case 314:
	{
		WARN(ZS_UNSUPPORTED_TYPE);
		p--; {       if ( p == pe )
               goto _test_eof316;
goto st316;}
	}
	{
		WARN(ZS_BAD_REST);
		p--; {       if ( p == pe )
               goto _test_eof316;
goto st316;}
	}
	break;
	case 4:
	case 19:
	case 27:
	case 28:
	case 31:
	case 35:
	case 39:
	case 44:
	case 48:
	case 52:
	case 53:
	case 58:
	case 60:
	case 65:
	case 69:
	case 80:
	case 83:
	case 84:
	case 87:
	case 89:
	case 91:
	case 92:
	case 97:
	case 98:
	case 103:
	case 105:
	case 106:
	case 108:
	case 109:
	case 114:
	case 124:
	case 127:
	case 129:
	case 133:
	case 134:
	case 140:
	case 142:
	case 144:
	case 146:
	case 150:
	case 153:
	case 157:
	case 159:
	case 166:
	case 172:
	case 178:
	case 276:
	case 280:
	case 282:
	{
		WARN(ZS_UNSUPPORTED_TYPE);
		p--; {       if ( p == pe )
               goto _test_eof316;
goto st316;}
	}
	{
		WARN(ZS_BAD_RDATA);
		p--; {       if ( p == pe )
               goto _test_eof316;
goto st316;}
	}
	break;
	case 245:
	{
		s->r_owner_length = 0;
		WARN(ZS_BAD_OWNER);
		p--; {       if ( p == pe )
               goto _test_eof316;
goto st316;}
	}
	{
		WARN(ZS_BAD_RDATA);
		p--; {       if ( p == pe )
               goto _test_eof316;
goto st316;}
	}
	{
		WARN(ZS_BAD_REST);
		p--; {       if ( p == pe )
               goto _test_eof316;
goto st316;}
	}
	break;
	case 208:
	{
		s->r_owner_length = 0;
		WARN(ZS_BAD_OWNER);
		p--; {       if ( p == pe )
               goto _test_eof316;
goto st316;}
	}
	{
		WARN(ZS_UNSUPPORTED_TYPE);
		p--; {       if ( p == pe )
               goto _test_eof316;
goto st316;}
	}
	{
		WARN(ZS_BAD_RDATA);
		p--; {       if ( p == pe )
               goto _test_eof316;
goto st316;}
	}
	break;
	case 1075:
	case 1076:
	case 1089:
	case 1090:
	case 1096:
	case 1097:
	case 1103:
	case 1104:
	{
		WARN(ZS_BAD_NUMBER);
		p--; {       if ( p == pe )
               goto _test_eof316;
goto st316;}
	}
	{
		WARN(ZS_BAD_GATEWAY);
		p--; {       if ( p == pe )
               goto _test_eof316;
goto st316;}
	}
	{
		WARN(ZS_BAD_RDATA);
		p--; {       if ( p == pe )
               goto _test_eof316;
goto st316;}
	}
	break;
	case 1285:
	case 1286:
	{
		WARN(ZS_BAD_NUMBER);
		p--; {       if ( p == pe )
               goto _test_eof316;
goto st316;}
	}
	{
		WARN(ZS_UNSUPPORTED_TYPE);
		p--; {       if ( p == pe )
               goto _test_eof316;
goto st316;}
	}
	{
		WARN(ZS_BAD_RDATA);
		p--; {       if ( p == pe )
               goto _test_eof316;
goto st316;}
	}
	break;
	case 1:
	case 180:
	case 212:
	case 247:
	{
		WARN(ZS_BAD_NUMBER);
		p--; {       if ( p == pe )
               goto _test_eof316;
goto st316;}
	}
	{
		WARN(ZS_UNSUPPORTED_TYPE);
		p--; {       if ( p == pe )
               goto _test_eof316;
goto st316;}
	}
	{
		WARN(ZS_BAD_REST);
		p--; {       if ( p == pe )
               goto _test_eof316;
goto st316;}
	}
	break;
	case 163:
	case 209:
	{
		WARN(ZS_BAD_NUMBER);
		p--; {       if ( p == pe )
               goto _test_eof316;
goto st316;}
	}
	{
		WARN(ZS_UNSUPPORTED_TYPE);
		p--; {       if ( p == pe )
               goto _test_eof316;
goto st316;}
	}
	{
		WARN(ZS_BAD_RDATA);
		p--; {       if ( p == pe )
               goto _test_eof316;
goto st316;}
	}
	break;
	case 346:
	{
		WARN(ZS_BAD_TIME_UNIT);
		p--; {       if ( p == pe )
               goto _test_eof316;
goto st316;}
	}
	{
		WARN(ZS_BAD_NUMBER);
		p--; {       if ( p == pe )
               goto _test_eof316;
goto st316;}
	}
	{
		ERR(ZS_BAD_TTL);
		p--; {       if ( p == pe )
               goto _test_eof316;
goto st316;}
	}
	break;
	case 897:
	case 899:
	case 901:
	case 903:
	case 904:
	case 905:
	case 906:
	case 908:
	case 909:
	case 910:
	case 912:
	case 913:
	case 914:
	case 916:
	case 917:
	case 918:
	{
		WARN(ZS_BAD_TIME_UNIT);
		p--; {       if ( p == pe )
               goto _test_eof316;
goto st316;}
	}
	{
		WARN(ZS_BAD_NUMBER);
		p--; {       if ( p == pe )
               goto _test_eof316;
goto st316;}
	}
	{
		WARN(ZS_BAD_RDATA);
		p--; {       if ( p == pe )
               goto _test_eof316;
goto st316;}
	}
	break;
	case 2:
	case 184:
	case 185:
	case 186:
	case 187:
	case 204:
	case 205:
	case 206:
	{
		WARN(ZS_BAD_TIME_UNIT);
		p--; {       if ( p == pe )
               goto _test_eof316;
goto st316;}
	}
	{
		WARN(ZS_BAD_NUMBER);
		p--; {       if ( p == pe )
               goto _test_eof316;
goto st316;}
	}
	{
		WARN(ZS_UNSUPPORTED_TYPE);
		p--; {       if ( p == pe )
               goto _test_eof316;
goto st316;}
	}
	break;
	case 329:
	case 330:
	case 331:
	case 332:
	case 336:
	case 337:
	case 338:
	case 339:
	{
		WARN(ZS_BAD_NUMBER);
		p--; {       if ( p == pe )
               goto _test_eof316;
goto st316;}
	}
	{
		WARN(ZS_BAD_TEXT_CHAR);
		p--; {       if ( p == pe )
               goto _test_eof316;
goto st316;}
	}
	{
		WARN(ZS_BAD_TEXT);
		p--; {       if ( p == pe )
               goto _test_eof316;
goto st316;}
	}
	break;
	case 1040:
	case 1041:
	case 1046:
	case 1047:
	{
		WARN(ZS_BAD_ADDRESS_CHAR);
		p--; {       if ( p == pe )
               goto _test_eof316;
goto st316;}
	}
	{
		WARN(ZS_BAD_APL);
		p--; {       if ( p == pe )
               goto _test_eof316;
goto st316;}
	}
	{
		WARN(ZS_BAD_RDATA);
		p--; {       if ( p == pe )
               goto _test_eof316;
goto st316;}
	}
	break;
	case 1091:
	case 1098:
	{
		WARN(ZS_BAD_ADDRESS_CHAR);
		p--; {       if ( p == pe )
               goto _test_eof316;
goto st316;}
	}
	{
		WARN(ZS_BAD_GATEWAY);
		p--; {       if ( p == pe )
               goto _test_eof316;
goto st316;}
	}
	{
		WARN(ZS_BAD_RDATA);
		p--; {       if ( p == pe )
               goto _test_eof316;
goto st316;}
	}
	break;
	case 558:
	case 559:
	case 560:
	case 561:
	case 567:
	case 568:
	case 569:
	case 570:
	{
		WARN(ZS_BAD_HEX_CHAR);
		p--; {       if ( p == pe )
               goto _test_eof316;
goto st316;}
	}
	{
		WARN(ZS_BAD_HEX_RDATA);
		p--; {       if ( p == pe )
               goto _test_eof316;
goto st316;}
	}
	{
		WARN(ZS_BAD_HEX_RDATA);
		p--; {       if ( p == pe )
               goto _test_eof316;
goto st316;}
	}
	break;
	case 1403:
	{
		WARN(ZS_BAD_HEX_CHAR);
		p--; {       if ( p == pe )
               goto _test_eof316;
goto st316;}
	}
	{
		WARN(ZS_BAD_CHAR_COLON);
		p--; {       if ( p == pe )
               goto _test_eof316;
goto st316;}
	}
	{
		WARN(ZS_BAD_RDATA);
		p--; {       if ( p == pe )
               goto _test_eof316;
goto st316;}
	}
	break;
	case 1078:
	case 1106:
	{
		WARN(ZS_BAD_GATEWAY);
		p--; {       if ( p == pe )
               goto _test_eof316;
goto st316;}
	}
	{
		WARN(ZS_BAD_GATEWAY_KEY);
		p--; {       if ( p == pe )
               goto _test_eof316;
goto st316;}
	}
	{
		WARN(ZS_BAD_RDATA);
		p--; {       if ( p == pe )
               goto _test_eof316;
goto st316;}
	}
	break;
	case 1412:
	case 1415:
	case 1418:
	case 1421:
	{
		WARN(ZS_BAD_CHAR_DASH);
		p--; {       if ( p == pe )
               goto _test_eof316;
goto st316;}
	}
	{
		WARN(ZS_BAD_HEX_CHAR);
		p--; {       if ( p == pe )
               goto _test_eof316;
goto st316;}
	}
	{
		WARN(ZS_BAD_RDATA);
		p--; {       if ( p == pe )
               goto _test_eof316;
goto st316;}
	}
	break;
	case 1408:
	{
		WARN(ZS_BAD_CHAR_COLON);
		p--; {       if ( p == pe )
               goto _test_eof316;
goto st316;}
	}
	{
		WARN(ZS_BAD_HEX_CHAR);
		p--; {       if ( p == pe )
               goto _test_eof316;
goto st316;}
	}
	{
		WARN(ZS_BAD_RDATA);
		p--; {       if ( p == pe )
               goto _test_eof316;
goto st316;}
	}
	break;
	case 235:
	{
		WARN(ZS_BAD_RDATA);
		p--; {       if ( p == pe )
               goto _test_eof316;
goto st316;}
	}
	{
		WARN(ZS_BAD_REST);
		p--; {       if ( p == pe )
               goto _test_eof316;
goto st316;}
	}
	{
		ERR(ZS_BAD_DIRECTIVE);
		p--; {       if ( p == pe )
               goto _test_eof316;
goto st316;}
	}
	break;
	case 210:
	case 217:
	case 218:
	case 219:
	case 220:
	case 221:
	case 222:
	case 223:
	case 224:
	case 225:
	case 226:
	case 227:
	case 228:
	case 229:
	case 230:
	case 231:
	case 232:
	case 233:
	{
		WARN(ZS_UNSUPPORTED_TYPE);
		p--; {       if ( p == pe )
               goto _test_eof316;
goto st316;}
	}
	{
		WARN(ZS_BAD_RDATA);
		p--; {       if ( p == pe )
               goto _test_eof316;
goto st316;}
	}
	{
		WARN(ZS_BAD_REST);
		p--; {       if ( p == pe )
               goto _test_eof316;
goto st316;}
	}
	break;
	case 201:
	{
		s->r_owner_length = 0;
		WARN(ZS_BAD_OWNER);
		p--; {       if ( p == pe )
               goto _test_eof316;
goto st316;}
	}
	{
		WARN(ZS_BAD_TIME_UNIT);
		p--; {       if ( p == pe )
               goto _test_eof316;
goto st316;}
	}
	{
		WARN(ZS_BAD_NUMBER);
		p--; {       if ( p == pe )
               goto _test_eof316;
goto st316;}
	}
	{
		WARN(ZS_UNSUPPORTED_TYPE);
		p--; {       if ( p == pe )
               goto _test_eof316;
goto st316;}
	}
	break;
	case 249:
	case 251:
	case 252:
	case 253:
	case 254:
	case 255:
	case 256:
	case 257:
	case 258:
	case 259:
	case 260:
	case 261:
	case 262:
	case 263:
	case 264:
	case 265:
	case 266:
	case 267:
	{
		s->r_owner_length = 0;
		WARN(ZS_BAD_OWNER);
		p--; {       if ( p == pe )
               goto _test_eof316;
goto st316;}
	}
	{
		WARN(ZS_UNSUPPORTED_TYPE);
		p--; {       if ( p == pe )
               goto _test_eof316;
goto st316;}
	}
	{
		WARN(ZS_BAD_RDATA);
		p--; {       if ( p == pe )
               goto _test_eof316;
goto st316;}
	}
	{
		WARN(ZS_BAD_REST);
		p--; {       if ( p == pe )
               goto _test_eof316;
goto st316;}
	}
	break;
	case 14:
	case 216:
	case 250:
	case 269:
	case 291:
	{
		WARN(ZS_BAD_NUMBER);
		p--; {       if ( p == pe )
               goto _test_eof316;
goto st316;}
	}
	{
		WARN(ZS_UNSUPPORTED_TYPE);
		p--; {       if ( p == pe )
               goto _test_eof316;
goto st316;}
	}
	{
		WARN(ZS_BAD_RDATA);
		p--; {       if ( p == pe )
               goto _test_eof316;
goto st316;}
	}
	{
		WARN(ZS_BAD_REST);
		p--; {       if ( p == pe )
               goto _test_eof316;
goto st316;}
	}
	break;
	case 342:
	case 345:
	case 347:
	{
		WARN(ZS_BAD_TIME_UNIT);
		p--; {       if ( p == pe )
               goto _test_eof316;
goto st316;}
	}
	{
		WARN(ZS_BAD_NUMBER);
		p--; {       if ( p == pe )
               goto _test_eof316;
goto st316;}
	}
	{
		WARN(ZS_BAD_REST);
		p--; {       if ( p == pe )
               goto _test_eof316;
goto st316;}
	}
	{
		ERR(ZS_BAD_TTL);
		p--; {       if ( p == pe )
               goto _test_eof316;
goto st316;}
	}
	break;
	case 1092:
	case 1099:
	{
		WARN(ZS_BAD_ADDRESS_CHAR);
		p--; {       if ( p == pe )
               goto _test_eof316;
goto st316;}
	}
	{
		WARN(ZS_BAD_GATEWAY);
		p--; {       if ( p == pe )
               goto _test_eof316;
goto st316;}
	}
	{
		WARN(ZS_BAD_GATEWAY_KEY);
		p--; {       if ( p == pe )
               goto _test_eof316;
goto st316;}
	}
	{
		WARN(ZS_BAD_RDATA);
		p--; {       if ( p == pe )
               goto _test_eof316;
goto st316;}
	}
	break;
	case 15:
	{
		WARN(ZS_BAD_TIME_UNIT);
		p--; {       if ( p == pe )
               goto _test_eof316;
goto st316;}
	}
	{
		WARN(ZS_BAD_NUMBER);
		p--; {       if ( p == pe )
               goto _test_eof316;
goto st316;}
	}
	{
		WARN(ZS_UNSUPPORTED_TYPE);
		p--; {       if ( p == pe )
               goto _test_eof316;
goto st316;}
	}
	{
		WARN(ZS_BAD_RDATA);
		p--; {       if ( p == pe )
               goto _test_eof316;
goto st316;}
	}
	{
		WARN(ZS_BAD_REST);
		p--; {       if ( p == pe )
               goto _test_eof316;
goto st316;}
	}
	break;
	case 246:
	{
		s->r_owner_length = 0;
		WARN(ZS_BAD_OWNER);
		p--; {       if ( p == pe )
               goto _test_eof316;
goto st316;}
	}
	{
		WARN(ZS_BAD_TIME_UNIT);
		p--; {       if ( p == pe )
               goto _test_eof316;
goto st316;}
	}
	{
		WARN(ZS_BAD_NUMBER);
		p--; {       if ( p == pe )
               goto _test_eof316;
goto st316;}
	}
	{
		WARN(ZS_UNSUPPORTED_TYPE);
		p--; {       if ( p == pe )
               goto _test_eof316;
goto st316;}
	}
	{
		WARN(ZS_BAD_RDATA);
		p--; {       if ( p == pe )
               goto _test_eof316;
goto st316;}
	}
	{
		WARN(ZS_BAD_REST);
		p--; {       if ( p == pe )
               goto _test_eof316;
goto st316;}
	}
	break;
	}
	}

	_out: {}
	}


	// Check if the scanner state machine is in an uncovered state.
	bool extra_error = false;
	if (cs == 0) {
		ERR(ZS_UNCOVERED_STATE);
		extra_error = true;
	// Check for an unclosed multiline record.
	} else if (s->input.eof && s->multiline) {
		ERR(ZS_UNCLOSED_MULTILINE);
		extra_error = true;
		s->line_counter--;
	}

	// Treat the extra error.
	if (extra_error) {
		s->error.counter++;
		s->state = ZS_STATE_ERROR;

		// Copy the error context just for the part of the current line.
		s->buffer_length = 0;
		while (p < pe && *p != '\n' && s->buffer_length < 50) {
			s->buffer[s->buffer_length++] = *p++;
		}
		s->buffer[s->buffer_length++] = 0;

		// Execute the error callback.
		if (s->process.automatic && s->process.error != NULL) {
			s->process.error(s);
		}

		return;
	}

	// Storing scanner states.
	s->cs  = cs;
	s->top = top;
	memcpy(s->stack, stack, sizeof(stack));

	// Store the current parser position.
	s->input.current = p;

	// Storing r_data pointer.
	s->r_data_tail = rdata_tail - s->r_data;

	if (*wrap == WRAP_DETECTED) {
		if (set_input_string(s, "\\", 1, true) != 0) {
			return;
		}

		*wrap = WRAP_PROCESS;
		parse(s, wrap);
	} else {
		*wrap = WRAP_NONE;
	}
}

__attribute__((visibility("default")))
int zs_parse_record(
	zs_scanner_t *s)
{
	if (s == NULL) {
		return -1;
	}

	// Check if parsing is possible.
	switch (s->state) {
	case ZS_STATE_NONE:
	case ZS_STATE_DATA:
	case ZS_STATE_INCLUDE:
		break;
	case ZS_STATE_ERROR:
		if (s->error.fatal) {
			return -1;
		}
		break;
	default:
		// Return if stop or end of file.
		return 0;
	}

	// Check for the end of the input.
	if (s->input.current != s->input.end) {
		// Try to parse another item.
		s->state = ZS_STATE_NONE;
		wrap_t wrap = WRAP_NONE;
		parse(s, &wrap);

		// Finish if nothing was parsed.
		if (s->state == ZS_STATE_NONE) {
			// Parse the final block.
			if (set_input_string(s, "\n", 1, true) != 0) {
				return -1;
			}
			parse(s, &wrap);
			if (s->state == ZS_STATE_NONE) {
				s->state = ZS_STATE_EOF;
			}
		}
	} else {
		s->state = ZS_STATE_EOF;
	}

	return 0;
}

__attribute__((visibility("default")))
int zs_parse_all(
	zs_scanner_t *s)
{
	if (s == NULL) {
		return -1;
	}

	s->process.automatic = true;

	// Parse input block.
	wrap_t wrap = WRAP_NONE;
	parse(s, &wrap);

	// Parse trailing newline-char block if it makes sense.
	if (s->state != ZS_STATE_STOP && !s->error.fatal) {
		if (set_input_string(s, "\n", 1, true) != 0) {
			return -1;
		}
		parse(s, &wrap);
	}

	// Check if any errors have occurred.
	if (s->error.counter > 0) {
		return -1;
	}

	return 0;
}
